package Color::Library::Dictionary::NBS_ISCC::A;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::A;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::A - (NBS/ISCC A) Dye Colors

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (A) Dye Colors

        American Association of Textile Chemists and
        Colorists and Society of Dyers and Colourists 

    This combinatorial dictionary's 88 names map to 350 colors; 263 out of 267 centroids are covered.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#A>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black</td><td>black</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>blue</td><td>blue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>blue</td><td>blue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>blue</td><td>blue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>blue</td><td>blue</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>blue</td><td>blue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue</td><td>blue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>blue</td><td>blue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>blue</td><td>blue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>blue</td><td>blue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>blue</td><td>blue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#202428;width:4em;" /><td>bluish black</td><td>bluishblack</td><td>##202428</td><td>32</td> <td>36</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>bluish gray</td><td>bluishgray</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>bluish gray</td><td>bluishgray</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>bluish gray</td><td>bluishgray</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>bluish green</td><td>bluishgreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>bluish green</td><td>bluishgreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#00443f;width:4em;" /><td>bluish green</td><td>bluishgreen</td><td>##00443f</td><td>0</td> <td>68</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>bluish green</td><td>bluishgreen</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>bluish green</td><td>bluishgreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>bluish green</td><td>bluishgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>bluish green</td><td>bluishgreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#002a29;width:4em;" /><td>bluish green</td><td>bluishgreen</td><td>##002a29</td><td>0</td> <td>42</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#404f00;width:4em;" /><td>bluish olive</td><td>bluisholive</td><td>##404f00</td><td>64</td> <td>79</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#232f00;width:4em;" /><td>bluish olive</td><td>bluisholive</td><td>##232f00</td><td>35</td> <td>47</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>bluish olive</td><td>bluisholive</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#2b3d26;width:4em;" /><td>bluish olive</td><td>bluisholive</td><td>##2b3d26</td><td>43</td> <td>61</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>bluish olive</td><td>bluisholive</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#31362b;width:4em;" /><td>bluish olive</td><td>bluisholive</td><td>##31362b</td><td>49</td> <td>54</td> <td>43</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>bluish pink</td><td>bluishpink</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>bluish red</td><td>bluishred</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>bluish red</td><td>bluishred</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#54133b;width:4em;" /><td>bluish red</td><td>bluishred</td><td>##54133b</td><td>84</td> <td>19</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>bluish red</td><td>bluishred</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#32174d;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##32174d</td><td>50</td> <td>23</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>bluish white</td><td>bluishwhite</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>bordeaux</td><td>bordeaux</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#38152c;width:4em;" /><td>bordeaux</td><td>bordeaux</td><td>##38152c</td><td>56</td> <td>21</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>bordeaux</td><td>bordeaux</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>bright blue</td><td>brightblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#008882;width:4em;" /><td>bright bluish green</td><td>brightbluishgreen</td><td>##008882</td><td>0</td> <td>136</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>bright bluish red </td><td>brightbluishred</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>bright bluish violet</td><td>brightbluishviolet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>bright green</td><td>brightgreen</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#0085a1;width:4em;" /><td>bright greenish blue</td><td>brightgreenishblue</td><td>##0085a1</td><td>0</td> <td>133</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd300;width:4em;" /><td>bright greenish yellow</td><td>brightgreenishyellow</td><td>##dcd300</td><td>220</td> <td>211</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>bright orange</td><td>brightorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>bright red</td><td>brightred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>bright reddish blue</td><td>brightreddishblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>bright reddish orange</td><td>brightreddishorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>bright reddish violet</td><td>brightreddishviolet</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>bright reddish yellow</td><td>brightreddishyellow</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>bright reddish yellow</td><td>brightreddishyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>bright violet</td><td>brightviolet</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8db600;width:4em;" /><td>bright yellowish green</td><td>brightyellowishgreen</td><td>##8db600</td><td>141</td> <td>182</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>bright yellowish green</td><td>brightyellowishgreen</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>bright yellowish orange</td><td>brightyellowishorange</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>bright yellowish red</td><td>brightyellowishred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>bright yellowish red</td><td>brightyellowishred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>brown</td><td>brown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#593319;width:4em;" /><td>brown</td><td>brown</td><td>##593319</td><td>89</td> <td>51</td> <td>25</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>brown</td><td>brown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brown</td><td>brown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>brown</td><td>brown</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#28201c;width:4em;" /><td>brownish black</td><td>brownishblack</td><td>##28201c</td><td>40</td> <td>32</td> <td>28</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>brownish gray</td><td>brownishgray</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>brownish gray</td><td>brownishgray</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>brownish gray</td><td>brownishgray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>brownish olive</td><td>brownisholive</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>brownish olive</td><td>brownisholive</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>brownish white</td><td>brownishwhite</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>dull bluish green</td><td>dullbluishgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>dull bluish green</td><td>dullbluishgreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dull bluish green</td><td>dullbluishgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dull bluish green</td><td>dullbluishgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>dull bluish green</td><td>dullbluishgreen</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>dull bluish red</td><td>dullbluishred</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dull bluish red</td><td>dullbluishred</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#38152c;width:4em;" /><td>dull bluish red</td><td>dullbluishred</td><td>##38152c</td><td>56</td> <td>21</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dull bordeaux</td><td>dullbordeaux</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dull bordeaux</td><td>dullbordeaux</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>dull bordeaux</td><td>dullbordeaux</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dull bordeaux</td><td>dullbordeaux</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#38152c;width:4em;" /><td>dull bordeaux</td><td>dullbordeaux</td><td>##38152c</td><td>56</td> <td>21</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>dull brownish olive</td><td>dullbrownisholive</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>dull greenish blue</td><td>dullgreenishblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>dull greenish blue</td><td>dullgreenishblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dull greenish blue</td><td>dullgreenishblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dull greenish blue</td><td>dullgreenishblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>dull greenish blue</td><td>dullgreenishblue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>dull greenish yellow</td><td>dullgreenishyellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>dull greenish yellow</td><td>dullgreenishyellow</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>dull greenish yellow</td><td>dullgreenishyellow</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>dull orange</td><td>dullorange</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>dull orange</td><td>dullorange</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>dull red</td><td>dullred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>dull red</td><td>dullred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>dull red</td><td>dullred</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dull red</td><td>dullred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>dull red</td><td>dullred</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>dull red</td><td>dullred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>dull reddish blue</td><td>dullreddishblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>dull reddish blue</td><td>dullreddishblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dull reddish blue</td><td>dullreddishblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dull reddish blue</td><td>dullreddishblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>dull reddish blue</td><td>dullreddishblue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>dull reddish blue</td><td>dullreddishblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>dull reddish blue</td><td>dullreddishblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dull reddish blue</td><td>dullreddishblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#2e1d21;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##2e1d21</td><td>46</td> <td>29</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>dull reddish brown</td><td>dullreddishbrown</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>dull reddish orange</td><td>dullreddishorange</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>dull reddish violet</td><td>dullreddishviolet</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dull reddish violet</td><td>dullreddishviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dull reddish violet</td><td>dullreddishviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>dull reddish violet</td><td>dullreddishviolet</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>dull reddish violet</td><td>dullreddishviolet</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>dull reddish violet</td><td>dullreddishviolet</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>dull reddish yellow</td><td>dullreddishyellow</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>dull reddish yellow</td><td>dullreddishyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>dull reddish yellow</td><td>dullreddishyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>dull reddish yellow</td><td>dullreddishyellow</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>dull yellow</td><td>dullyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>dull yellow</td><td>dullyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>dull yellow</td><td>dullyellow</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>dull yellowish brown</td><td>dullyellowishbrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>dull yellowish brown</td><td>dullyellowishbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>dull yellowish brown</td><td>dullyellowishbrown</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>dull yellowish brown</td><td>dullyellowishbrown</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>dull yellowish brown</td><td>dullyellowishbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>dull yellowish brown</td><td>dullyellowishbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>dull yellowish green</td><td>dullyellowishgreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>dull yellowish green</td><td>dullyellowishgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>dull yellowish orange</td><td>dullyellowishorange</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>dull yellowish red</td><td>dullyellowishred</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>gray</td><td>gray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gray</td><td>gray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>gray</td><td>gray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>green</td><td>green</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>green</td><td>green</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#00543d;width:4em;" /><td>green</td><td>green</td><td>##00543d</td><td>0</td> <td>84</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>green</td><td>green</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>green</td><td>green</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>green</td><td>green</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>green</td><td>green</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#1c352d;width:4em;" /><td>green</td><td>green</td><td>##1c352d</td><td>28</td> <td>53</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#25241d;width:4em;" /><td>greenish black</td><td>greenishblack</td><td>##25241d</td><td>37</td> <td>36</td> <td>29</td>
</tr> <tr><td style="border:1px solid #666; background:#1e2321;width:4em;" /><td>greenish black</td><td>greenishblack</td><td>##1e2321</td><td>30</td> <td>35</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#002e3b;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##002e3b</td><td>0</td> <td>46</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>greenish gray</td><td>greenishgray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>greenish gray</td><td>greenishgray</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>greenish gray</td><td>greenishgray</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>greenish gray</td><td>greenishgray</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>greenish gray</td><td>greenishgray</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>greenish navy</td><td>greenishnavy</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>greenish navy</td><td>greenishnavy</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>greenish white</td><td>greenishwhite</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>greenish yellow</td><td>greenishyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>greenish yellow</td><td>greenishyellow</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#9b9400;width:4em;" /><td>greenish yellow</td><td>greenishyellow</td><td>##9b9400</td><td>155</td> <td>148</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>greenish yellow</td><td>greenishyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>greenish yellow</td><td>greenishyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>greenish yellow</td><td>greenishyellow</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>navy</td><td>navy</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>navy</td><td>navy</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>navy</td><td>navy</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>olive</td><td>olive</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olive</td><td>olive</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#403d21;width:4em;" /><td>olive</td><td>olive</td><td>##403d21</td><td>64</td> <td>61</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>olive</td><td>olive</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive</td><td>olive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#363527;width:4em;" /><td>olive</td><td>olive</td><td>##363527</td><td>54</td> <td>53</td> <td>39</td>
</tr> <tr><td style="border:1px solid #666; background:#fd943f;width:4em;" /><td>orange</td><td>orange</td><td>##fd943f</td><td>253</td> <td>148</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange</td><td>orange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>orange</td><td>orange</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>orange</td><td>orange</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>orange</td><td>orange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>orange</td><td>orange</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb5ba;width:4em;" /><td>pink</td><td>pink</td><td>##ffb5ba</td><td>255</td> <td>181</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>pink</td><td>pink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>pink</td><td>pink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>pink</td><td>pink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>pink</td><td>pink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>pink</td><td>pink</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>pink</td><td>pink</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>pink</td><td>pink</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>pink</td><td>pink</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>pink</td><td>pink</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>red</td><td>red</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>red</td><td>red</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#5c0923;width:4em;" /><td>red</td><td>red</td><td>##5c0923</td><td>92</td> <td>9</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>red</td><td>red</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>reddish black</td><td>reddishblack</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#282022;width:4em;" /><td>reddish black</td><td>reddishblack</td><td>##282022</td><td>40</td> <td>32</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>reddish black</td><td>reddishblack</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>reddish blue</td><td>reddishblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>reddish blue</td><td>reddishblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>reddish blue</td><td>reddishblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>reddish blue</td><td>reddishblue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>reddish blue</td><td>reddishblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>reddish blue</td><td>reddishblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>reddish blue</td><td>reddishblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#5c0923;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##5c0923</td><td>92</td> <td>9</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>reddish navy</td><td>reddishnavy</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>reddish orange</td><td>reddishorange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>reddish orange</td><td>reddishorange</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>reddish orange</td><td>reddishorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>reddish orange</td><td>reddishorange</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>reddish violet</td><td>reddishviolet</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>reddish violet</td><td>reddishviolet</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#54194e;width:4em;" /><td>reddish violet</td><td>reddishviolet</td><td>##54194e</td><td>84</td> <td>25</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>reddish violet</td><td>reddishviolet</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>reddish violet</td><td>reddishviolet</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>reddish violet</td><td>reddishviolet</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#341731;width:4em;" /><td>reddish violet</td><td>reddishviolet</td><td>##341731</td><td>52</td> <td>23</td> <td>49</td>
</tr> <tr><td style="border:1px solid #666; background:#eae3e1;width:4em;" /><td>reddish white</td><td>reddishwhite</td><td>##eae3e1</td><td>234</td> <td>227</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>reddish white</td><td>reddishwhite</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#c98500;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##c98500</td><td>201</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#d399e6;width:4em;" /><td>violet</td><td>violet</td><td>##d399e6</td><td>211</td> <td>153</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>violet</td><td>violet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>violet</td><td>violet</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#401a4c;width:4em;" /><td>violet</td><td>violet</td><td>##401a4c</td><td>64</td> <td>26</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#d5badb;width:4em;" /><td>violet</td><td>violet</td><td>##d5badb</td><td>213</td> <td>186</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>violet</td><td>violet</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>violet</td><td>violet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>violet</td><td>violet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#301934;width:4em;" /><td>violet</td><td>violet</td><td>##301934</td><td>48</td> <td>25</td> <td>52</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>white</td><td>white</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>yellow</td><td>yellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>yellow</td><td>yellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>yellow</td><td>yellow</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>yellow</td><td>yellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow</td><td>yellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>yellow</td><td>yellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>yellowish brown</td><td>yellowishbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#654522;width:4em;" /><td>yellowish brown</td><td>yellowishbrown</td><td>##654522</td><td>101</td> <td>69</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#467129;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##467129</td><td>70</td> <td>113</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#00622d;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##00622d</td><td>0</td> <td>98</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#003118;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##003118</td><td>0</td> <td>49</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#b6e5af;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##b6e5af</td><td>182</td> <td>229</td> <td>175</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#173620;width:4em;" /><td>yellowish green</td><td>yellowishgreen</td><td>##173620</td><td>23</td> <td>54</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>yellowish orange</td><td>yellowishorange</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>yellowish orange</td><td>yellowishorange</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#c98500;width:4em;" /><td>yellowish orange</td><td>yellowishorange</td><td>##c98500</td><td>201</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>yellowish orange</td><td>yellowishorange</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellowish orange</td><td>yellowishorange</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>yellowish orange</td><td>yellowishorange</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>yellowish pink</td><td>yellowishpink</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>yellowish pink</td><td>yellowishpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>yellowish pink</td><td>yellowishpink</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>yellowish pink</td><td>yellowishpink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>yellowish pink</td><td>yellowishpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>yellowish pink</td><td>yellowishpink</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>yellowish pink</td><td>yellowishpink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>yellowish pink</td><td>yellowishpink</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>yellowish red</td><td>yellowishred</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>yellowish red</td><td>yellowishred</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>yellowish red</td><td>yellowishred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>yellowish red</td><td>yellowishred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item black                   black                 #222222

=item blue                    blue                  #4997d0

=item blue                    blue                  #0067a5

=item blue                    blue                  #00416a

=item blue                    blue                  #a1caf1

=item blue                    blue                  #70a3cc

=item blue                    blue                  #436b95

=item blue                    blue                  #00304e

=item blue                    blue                  #b3bce2

=item blue                    blue                  #8791bf

=item blue                    blue                  #252440

=item bluish black            bluishblack           #202428

=item bluish gray             bluishgray            #b4bcc0

=item bluish gray             bluishgray            #81878b

=item bluish gray             bluishgray            #51585e

=item bluish green            bluishgreen           #00a693

=item bluish green            bluishgreen           #007a74

=item bluish green            bluishgreen           #00443f

=item bluish green            bluishgreen           #96ded1

=item bluish green            bluishgreen           #66ada4

=item bluish green            bluishgreen           #317873

=item bluish green            bluishgreen           #004b49

=item bluish green            bluishgreen           #002a29

=item bluish olive            bluisholive           #404f00

=item bluish olive            bluisholive           #232f00

=item bluish olive            bluisholive           #4a5d23

=item bluish olive            bluisholive           #2b3d26

=item bluish olive            bluisholive           #515744

=item bluish olive            bluisholive           #31362b

=item bluish pink             bluishpink            #ffc8d6

=item bluish pink             bluishpink            #e68fac

=item bluish pink             bluishpink            #de6fa1

=item bluish pink             bluishpink            #efbbcc

=item bluish pink             bluishpink            #d597ae

=item bluish pink             bluishpink            #c17e91

=item bluish pink             bluishpink            #e8ccd7

=item bluish pink             bluishpink            #c3a6b1

=item bluish pink             bluishpink            #af868e

=item bluish red              bluishred             #b3446c

=item bluish red              bluishred             #78184a

=item bluish red              bluishred             #54133b

=item bluish red              bluishred             #a8516e

=item bluish violet           bluishviolet          #7e73b8

=item bluish violet           bluishviolet          #604e97

=item bluish violet           bluishviolet          #32174d

=item bluish violet           bluishviolet          #dcd0ff

=item bluish violet           bluishviolet          #8c82b6

=item bluish violet           bluishviolet          #604e81

=item bluish violet           bluishviolet          #2f2140

=item bluish white            bluishwhite           #e9e9ed

=item bordeaux                bordeaux              #673147

=item bordeaux                bordeaux              #38152c

=item bordeaux                bordeaux              #915f6d

=item bright blue             brightblue            #00a1c2

=item bright bluish green     brightbluishgreen     #008882

=item bright bluish red       brightbluishred       #ce4676

=item bright bluish violet    brightbluishviolet    #9065ca

=item bright green            brightgreen           #008856

=item bright greenish blue    brightgreenishblue    #0085a1

=item bright greenish yellow  brightgreenishyellow  #dcd300

=item bright orange           brightorange          #f38400

=item bright red              brightred             #be0032

=item bright reddish blue     brightreddishblue     #30267a

=item bright reddish orange   brightreddishorange   #e25822

=item bright reddish violet   brightreddishviolet   #870074

=item bright reddish yellow   brightreddishyellow   #f6a600

=item bright reddish yellow   brightreddishyellow   #f3c300

=item bright violet           brightviolet          #9a4eae

=item bright yellow           brightyellow          #f3c300

=item bright yellowish green  brightyellowishgreen  #8db600

=item bright yellowish green  brightyellowishgreen  #27a64c

=item bright yellowish orange brightyellowishorange #f6a600

=item bright yellowish red    brightyellowishred    #be0032

=item bright yellowish red    brightyellowishred    #e25822

=item brown                   brown                 #80461b

=item brown                   brown                 #593319

=item brown                   brown                 #a67b5b

=item brown                   brown                 #6f4e37

=item brown                   brown                 #422518

=item brownish black          brownishblack         #28201c

=item brownish gray           brownishgray          #8e8279

=item brownish gray           brownishgray          #5b504f

=item brownish gray           brownishgray          #bfb8a5

=item brownish olive          brownisholive         #967117

=item brownish olive          brownisholive         #6c541e

=item brownish white          brownishwhite         #f0ead6

=item dull blue               dullblue              #bcd4e6

=item dull blue               dullblue              #91a3b0

=item dull blue               dullblue              #536878

=item dull blue               dullblue              #36454f

=item dull blue               dullblue              #202830

=item dull blue               dullblue              #c0c8e1

=item dull blue               dullblue              #8c92ac

=item dull blue               dullblue              #4c516d

=item dull bluish green       dullbluishgreen       #c7e6d7

=item dull bluish green       dullbluishgreen       #8da399

=item dull bluish green       dullbluishgreen       #5e716a

=item dull bluish green       dullbluishgreen       #3a4b47

=item dull bluish green       dullbluishgreen       #1a2421

=item dull bluish red         dullbluishred         #a8516e

=item dull bluish red         dullbluishred         #673147

=item dull bluish red         dullbluishred         #38152c

=item dull bluish violet      dullbluishviolet      #c4c3dd

=item dull bluish violet      dullbluishviolet      #9690ab

=item dull bluish violet      dullbluishviolet      #554c69

=item dull bluish violet      dullbluishviolet      #d6cadd

=item dull bluish violet      dullbluishviolet      #aa98a9

=item dull bluish violet      dullbluishviolet      #796878

=item dull bluish violet      dullbluishviolet      #50404d

=item dull bluish violet      dullbluishviolet      #291e29

=item dull bordeaux           dullbordeaux          #796878

=item dull bordeaux           dullbordeaux          #50404d

=item dull bordeaux           dullbordeaux          #291e29

=item dull bordeaux           dullbordeaux          #673147

=item dull bordeaux           dullbordeaux          #38152c

=item dull brownish olive     dullbrownisholive     #3b3121

=item dull green              dullgreen             #c7e6d7

=item dull green              dullgreen             #8da399

=item dull green              dullgreen             #5e716a

=item dull green              dullgreen             #3a4b47

=item dull green              dullgreen             #1a2421

=item dull greenish blue      dullgreenishblue      #bcd4e6

=item dull greenish blue      dullgreenishblue      #91a3b0

=item dull greenish blue      dullgreenishblue      #536878

=item dull greenish blue      dullgreenishblue      #36454f

=item dull greenish blue      dullgreenishblue      #202830

=item dull greenish yellow    dullgreenishyellow    #ebe8a4

=item dull greenish yellow    dullgreenishyellow    #b9b57d

=item dull greenish yellow    dullgreenishyellow    #867e36

=item dull orange             dullorange            #d9a6a9

=item dull orange             dullorange            #a67b5b

=item dull red                dullred               #ab4e52

=item dull red                dullred               #722f37

=item dull red                dullred               #3f1728

=item dull red                dullred               #905d5d

=item dull red                dullred               #56070c

=item dull red                dullred               #79443b

=item dull reddish blue       dullreddishblue       #bcd4e6

=item dull reddish blue       dullreddishblue       #91a3b0

=item dull reddish blue       dullreddishblue       #536878

=item dull reddish blue       dullreddishblue       #36454f

=item dull reddish blue       dullreddishblue       #202830

=item dull reddish blue       dullreddishblue       #c0c8e1

=item dull reddish blue       dullreddishblue       #8c92ac

=item dull reddish blue       dullreddishblue       #4c516d

=item dull reddish brown      dullreddishbrown      #722f37

=item dull reddish brown      dullreddishbrown      #3f1728

=item dull reddish brown      dullreddishbrown      #905d5d

=item dull reddish brown      dullreddishbrown      #543d3f

=item dull reddish brown      dullreddishbrown      #2e1d21

=item dull reddish brown      dullreddishbrown      #a87c6d

=item dull reddish brown      dullreddishbrown      #79443b

=item dull reddish brown      dullreddishbrown      #3e1d1e

=item dull reddish brown      dullreddishbrown      #977f73

=item dull reddish brown      dullreddishbrown      #674c47

=item dull reddish brown      dullreddishbrown      #43302e

=item dull reddish orange     dullreddishorange     #b4745e

=item dull reddish violet     dullreddishviolet     #aa98a9

=item dull reddish violet     dullreddishviolet     #796878

=item dull reddish violet     dullreddishviolet     #50404d

=item dull reddish violet     dullreddishviolet     #291e29

=item dull reddish violet     dullreddishviolet     #aa8a9e

=item dull reddish violet     dullreddishviolet     #836479

=item dull reddish yellow     dullreddishyellow     #fad6a5

=item dull reddish yellow     dullreddishyellow     #f3e5ab

=item dull reddish yellow     dullreddishyellow     #c2b280

=item dull reddish yellow     dullreddishyellow     #a18f60

=item dull violet             dullviolet            #d6cadd

=item dull violet             dullviolet            #aa98a9

=item dull violet             dullviolet            #796878

=item dull violet             dullviolet            #50404d

=item dull violet             dullviolet            #291e29

=item dull yellow             dullyellow            #f3e5ab

=item dull yellow             dullyellow            #c2b280

=item dull yellow             dullyellow            #a18f60

=item dull yellowish brown    dullyellowishbrown    #c19a6b

=item dull yellowish brown    dullyellowishbrown    #826644

=item dull yellowish brown    dullyellowishbrown    #4b3621

=item dull yellowish brown    dullyellowishbrown    #ae9b82

=item dull yellowish brown    dullyellowishbrown    #7e6d5a

=item dull yellowish brown    dullyellowishbrown    #483c32

=item dull yellowish green    dullyellowishgreen    #dadfb7

=item dull yellowish green    dullyellowishgreen    #8f9779

=item dull yellowish orange   dullyellowishorange   #fad6a5

=item dull yellowish red      dullyellowishred      #b4745e

=item gray                    gray                  #b9b8b5

=item gray                    gray                  #848482

=item gray                    gray                  #555555

=item green                   green                 #3eb489

=item green                   green                 #007959

=item green                   green                 #00543d

=item green                   green                 #8ed1b2

=item green                   green                 #6aab8e

=item green                   green                 #3b7861

=item green                   green                 #1b4d3e

=item green                   green                 #1c352d

=item greenish black          greenishblack         #25241d

=item greenish black          greenishblack         #1e2321

=item greenish blue           greenishblue          #239eba

=item greenish blue           greenishblue          #007791

=item greenish blue           greenishblue          #2e8495

=item greenish blue           greenishblue          #9cd1dc

=item greenish blue           greenishblue          #66aabc

=item greenish blue           greenishblue          #367588

=item greenish blue           greenishblue          #004958

=item greenish blue           greenishblue          #002e3b

=item greenish gray           greenishgray          #8a8776

=item greenish gray           greenishgray          #57554c

=item greenish gray           greenishgray          #b2beb5

=item greenish gray           greenishgray          #7d8984

=item greenish gray           greenishgray          #4e5755

=item greenish navy           greenishnavy          #00304e

=item greenish navy           greenishnavy          #202830

=item greenish white          greenishwhite         #dfede8

=item greenish yellow         greenishyellow        #e9e450

=item greenish yellow         greenishyellow        #beb72e

=item greenish yellow         greenishyellow        #9b9400

=item greenish yellow         greenishyellow        #eae679

=item greenish yellow         greenishyellow        #b9b459

=item greenish yellow         greenishyellow        #98943e

=item navy                    navy                  #00304e

=item navy                    navy                  #202830

=item navy                    navy                  #252440

=item olive                   olive                 #867e36

=item olive                   olive                 #665d1e

=item olive                   olive                 #403d21

=item olive                   olive                 #8c8767

=item olive                   olive                 #5b5842

=item olive                   olive                 #363527

=item orange                  orange                #fd943f

=item orange                  orange                #ed872d

=item orange                  orange                #be6516

=item orange                  orange                #fab57f

=item orange                  orange                #d99058

=item orange                  orange                #ae6938

=item pink                    pink                  #ffb5ba

=item pink                    pink                  #ea9399

=item pink                    pink                  #e4717a

=item pink                    pink                  #f9ccca

=item pink                    pink                  #dea5a4

=item pink                    pink                  #c08081

=item pink                    pink                  #ead8d7

=item pink                    pink                  #c4aead

=item pink                    pink                  #ad8884

=item pink                    pink                  #af868e

=item red                     red                   #bc3f4a

=item red                     red                   #841b2d

=item red                     red                   #5c0923

=item red                     red                   #ab4e52

=item reddish black           reddishblack          #543d3f

=item reddish black           reddishblack          #282022

=item reddish black           reddishblack          #242124

=item reddish blue            reddishblue           #6c79b8

=item reddish blue            reddishblue           #545aa7

=item reddish blue            reddishblue           #272458

=item reddish blue            reddishblue           #b3bce2

=item reddish blue            reddishblue           #8791bf

=item reddish blue            reddishblue           #4e5180

=item reddish blue            reddishblue           #252440

=item reddish brown           reddishbrown          #841b2d

=item reddish brown           reddishbrown          #5c0923

=item reddish brown           reddishbrown          #722f37

=item reddish brown           reddishbrown          #905d5d

=item reddish brown           reddishbrown          #882d17

=item reddish brown           reddishbrown          #56070c

=item reddish brown           reddishbrown          #79443b

=item reddish gray            reddishgray           #c1b6b3

=item reddish gray            reddishgray           #8f817f

=item reddish gray            reddishgray           #5c504f

=item reddish gray            reddishgray           #bfb9bd

=item reddish gray            reddishgray           #8b8589

=item reddish gray            reddishgray           #5d555b

=item reddish navy            reddishnavy           #2f2140

=item reddish orange          reddishorange         #d9603b

=item reddish orange          reddishorange         #aa381e

=item reddish orange          reddishorange         #cb6d51

=item reddish orange          reddishorange         #9e4732

=item reddish violet          reddishviolet         #9e4f88

=item reddish violet          reddishviolet         #702963

=item reddish violet          reddishviolet         #54194e

=item reddish violet          reddishviolet         #b784a7

=item reddish violet          reddishviolet         #915c83

=item reddish violet          reddishviolet         #5d3954

=item reddish violet          reddishviolet         #341731

=item reddish white           reddishwhite          #eae3e1

=item reddish white           reddishwhite          #e8e3e5

=item reddish yellow          reddishyellow         #ffc14f

=item reddish yellow          reddishyellow         #eaa221

=item reddish yellow          reddishyellow         #c98500

=item reddish yellow          reddishyellow         #fbc97f

=item reddish yellow          reddishyellow         #e3a857

=item reddish yellow          reddishyellow         #be8a3d

=item reddish yellow          reddishyellow         #fada5e

=item reddish yellow          reddishyellow         #d4af37

=item reddish yellow          reddishyellow         #af8d13

=item reddish yellow          reddishyellow         #f8de7e

=item reddish yellow          reddishyellow         #c9ae5d

=item reddish yellow          reddishyellow         #ab9144

=item violet                  violet                #d399e6

=item violet                  violet                #875692

=item violet                  violet                #602f6b

=item violet                  violet                #401a4c

=item violet                  violet                #d5badb

=item violet                  violet                #b695c0

=item violet                  violet                #86608e

=item violet                  violet                #563c5c

=item violet                  violet                #301934

=item white                   white                 #f2f3f4

=item yellow                  yellow                #fada5e

=item yellow                  yellow                #d4af37

=item yellow                  yellow                #af8d13

=item yellow                  yellow                #f8de7e

=item yellow                  yellow                #c9ae5d

=item yellow                  yellow                #ab9144

=item yellowish brown         yellowishbrown        #996515

=item yellowish brown         yellowishbrown        #654522

=item yellowish green         yellowishgreen        #bdda57

=item yellowish green         yellowishgreen        #7e9f2e

=item yellowish green         yellowishgreen        #467129

=item yellowish green         yellowishgreen        #c9dc89

=item yellowish green         yellowishgreen        #8a9a5b

=item yellowish green         yellowishgreen        #4a5d23

=item yellowish green         yellowishgreen        #83d37d

=item yellowish green         yellowishgreen        #44944a

=item yellowish green         yellowishgreen        #00622d

=item yellowish green         yellowishgreen        #003118

=item yellowish green         yellowishgreen        #b6e5af

=item yellowish green         yellowishgreen        #93c592

=item yellowish green         yellowishgreen        #679267

=item yellowish green         yellowishgreen        #355e3b

=item yellowish green         yellowishgreen        #173620

=item yellowish orange        yellowishorange       #ffc14f

=item yellowish orange        yellowishorange       #eaa221

=item yellowish orange        yellowishorange       #c98500

=item yellowish orange        yellowishorange       #fbc97f

=item yellowish orange        yellowishorange       #e3a857

=item yellowish orange        yellowishorange       #be8a3d

=item yellowish pink          yellowishpink         #ffb7a5

=item yellowish pink          yellowishpink         #f88379

=item yellowish pink          yellowishpink         #e66761

=item yellowish pink          yellowishpink         #f4c2c2

=item yellowish pink          yellowishpink         #d9a6a9

=item yellowish pink          yellowishpink         #c48379

=item yellowish pink          yellowishpink         #ecd5c5

=item yellowish pink          yellowishpink         #c7ada3

=item yellowish red           yellowishred          #d9603b

=item yellowish red           yellowishred          #aa381e

=item yellowish red           yellowishred          #cb6d51

=item yellowish red           yellowishred          #9e4732


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-a:black.267','black','black',[34,34,34],'222222',2236962],
['nbs-iscc-a:blue.177','blue','blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-a:blue.178','blue','blue',[0,103,165],'0067a5',26533],
['nbs-iscc-a:blue.179','blue','blue',[0,65,106],'00416a',16746],
['nbs-iscc-a:blue.180','blue','blue',[161,202,241],'a1caf1',10603249],
['nbs-iscc-a:blue.181','blue','blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-a:blue.182','blue','blue',[67,107,149],'436b95',4418453],
['nbs-iscc-a:blue.183','blue','blue',[0,48,78],'00304e',12366],
['nbs-iscc-a:blue.198','blue','blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-a:blue.199','blue','blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-a:blue.201','blue','blue',[37,36,64],'252440',2434112],
['nbs-iscc-a:bluishblack.193','bluishblack','bluish black',[32,36,40],'202428',2106408],
['nbs-iscc-a:bluishgray.190','bluishgray','bluish gray',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-a:bluishgray.191','bluishgray','bluish gray',[129,135,139],'81878b',8488843],
['nbs-iscc-a:bluishgray.192','bluishgray','bluish gray',[81,88,94],'51585e',5331038],
['nbs-iscc-a:bluishgreen.159','bluishgreen','bluish green',[0,166,147],'00a693',42643],
['nbs-iscc-a:bluishgreen.160','bluishgreen','bluish green',[0,122,116],'007a74',31348],
['nbs-iscc-a:bluishgreen.161','bluishgreen','bluish green',[0,68,63],'00443f',17471],
['nbs-iscc-a:bluishgreen.162','bluishgreen','bluish green',[150,222,209],'96ded1',9887441],
['nbs-iscc-a:bluishgreen.163','bluishgreen','bluish green',[102,173,164],'66ada4',6729124],
['nbs-iscc-a:bluishgreen.164','bluishgreen','bluish green',[49,120,115],'317873',3242099],
['nbs-iscc-a:bluishgreen.165','bluishgreen','bluish green',[0,75,73],'004b49',19273],
['nbs-iscc-a:bluishgreen.166','bluishgreen','bluish green',[0,42,41],'002a29',10793],
['nbs-iscc-a:bluisholive.123','bluisholive','bluish olive',[64,79,0],'404f00',4214528],
['nbs-iscc-a:bluisholive.124','bluisholive','bluish olive',[35,47,0],'232f00',2305792],
['nbs-iscc-a:bluisholive.125','bluisholive','bluish olive',[74,93,35],'4a5d23',4873507],
['nbs-iscc-a:bluisholive.126','bluisholive','bluish olive',[43,61,38],'2b3d26',2833702],
['nbs-iscc-a:bluisholive.127','bluisholive','bluish olive',[81,87,68],'515744',5330756],
['nbs-iscc-a:bluisholive.128','bluisholive','bluish olive',[49,54,43],'31362b',3225131],
['nbs-iscc-a:bluishpink.246','bluishpink','bluish pink',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-a:bluishpink.247','bluishpink','bluish pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-a:bluishpink.248','bluishpink','bluish pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-a:bluishpink.249','bluishpink','bluish pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-a:bluishpink.250','bluishpink','bluish pink',[213,151,174],'d597ae',13997998],
['nbs-iscc-a:bluishpink.251','bluishpink','bluish pink',[193,126,145],'c17e91',12680849],
['nbs-iscc-a:bluishpink.252','bluishpink','bluish pink',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-a:bluishpink.253','bluishpink','bluish pink',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-a:bluishpink.261','bluishpink','bluish pink',[175,134,142],'af868e',11503246],
['nbs-iscc-a:bluishred.255','bluishred','bluish red',[179,68,108],'b3446c',11748460],
['nbs-iscc-a:bluishred.256','bluishred','bluish red',[120,24,74],'78184a',7870538],
['nbs-iscc-a:bluishred.257','bluishred','bluish red',[84,19,59],'54133b',5509947],
['nbs-iscc-a:bluishred.258','bluishred','bluish red',[168,81,110],'a8516e',11030894],
['nbs-iscc-a:bluishviolet.206','bluishviolet','bluish violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-a:bluishviolet.207','bluishviolet','bluish violet',[96,78,151],'604e97',6311575],
['nbs-iscc-a:bluishviolet.208','bluishviolet','bluish violet',[50,23,77],'32174d',3282765],
['nbs-iscc-a:bluishviolet.209','bluishviolet','bluish violet',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-a:bluishviolet.210','bluishviolet','bluish violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-a:bluishviolet.211','bluishviolet','bluish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-a:bluishviolet.212','bluishviolet','bluish violet',[47,33,64],'2f2140',3088704],
['nbs-iscc-a:bluishwhite.189','bluishwhite','bluish white',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-a:bordeaux.259','bordeaux','bordeaux',[103,49,71],'673147',6762823],
['nbs-iscc-a:bordeaux.260','bordeaux','bordeaux',[56,21,44],'38152c',3675436],
['nbs-iscc-a:bordeaux.262','bordeaux','bordeaux',[145,95,109],'915f6d',9527149],
['nbs-iscc-a:brightblue.176','brightblue','bright blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-a:brightbluishgreen.158','brightbluishgreen','bright bluish green',[0,136,130],'008882',34946],
['nbs-iscc-a:brightbluishred.254','brightbluishred','bright bluish red ',[206,70,118],'ce4676',13518454],
['nbs-iscc-a:brightbluishviolet.205','brightbluishviolet','bright bluish violet',[144,101,202],'9065ca',9463242],
['nbs-iscc-a:brightgreen.139','brightgreen','bright green',[0,136,86],'008856',34902],
['nbs-iscc-a:brightgreenishblue.167','brightgreenishblue','bright greenish blue',[0,133,161],'0085a1',34209],
['nbs-iscc-a:brightgreenishyellow.97','brightgreenishyellow','bright greenish yellow',[220,211,0],'dcd300',14471936],
['nbs-iscc-a:brightorange.48','brightorange','bright orange',[243,132,0],'f38400',15959040],
['nbs-iscc-a:brightred.11','brightred','bright red',[190,0,50],'be0032',12451890],
['nbs-iscc-a:brightreddishblue.194','brightreddishblue','bright reddish blue',[48,38,122],'30267a',3155578],
['nbs-iscc-a:brightreddishorange.34','brightreddishorange','bright reddish orange',[226,88,34],'e25822',14833698],
['nbs-iscc-a:brightreddishviolet.236','brightreddishviolet','bright reddish violet',[135,0,116],'870074',8847476],
['nbs-iscc-a:brightreddishyellow.66','brightreddishyellow','bright reddish yellow',[246,166,0],'f6a600',16164352],
['nbs-iscc-a:brightreddishyellow.82','brightreddishyellow','bright reddish yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-a:brightviolet.216','brightviolet','bright violet',[154,78,174],'9a4eae',10112686],
['nbs-iscc-a:brightyellow.82','brightyellow','bright yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-a:brightyellowishgreen.115','brightyellowishgreen','bright yellowish green',[141,182,0],'8db600',9287168],
['nbs-iscc-a:brightyellowishgreen.129','brightyellowishgreen','bright yellowish green',[39,166,76],'27a64c',2598476],
['nbs-iscc-a:brightyellowishorange.66','brightyellowishorange','bright yellowish orange',[246,166,0],'f6a600',16164352],
['nbs-iscc-a:brightyellowishred.11','brightyellowishred','bright yellowish red',[190,0,50],'be0032',12451890],
['nbs-iscc-a:brightyellowishred.34','brightyellowishred','bright yellowish red',[226,88,34],'e25822',14833698],
['nbs-iscc-a:brown.55','brown','brown',[128,70,27],'80461b',8406555],
['nbs-iscc-a:brown.56','brown','brown',[89,51,25],'593319',5845785],
['nbs-iscc-a:brown.57','brown','brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-a:brown.58','brown','brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-a:brown.59','brown','brown',[66,37,24],'422518',4334872],
['nbs-iscc-a:brownishblack.65','brownishblack','brownish black',[40,32,28],'28201c',2629660],
['nbs-iscc-a:brownishgray.63','brownishgray','brownish gray',[142,130,121],'8e8279',9339513],
['nbs-iscc-a:brownishgray.64','brownishgray','brownish gray',[91,80,79],'5b504f',5984335],
['nbs-iscc-a:brownishgray.93','brownishgray','brownish gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-a:brownisholive.94','brownisholive','brownish olive',[150,113,23],'967117',9859351],
['nbs-iscc-a:brownisholive.95','brownisholive','brownish olive',[108,84,30],'6c541e',7099422],
['nbs-iscc-a:brownishwhite.92','brownishwhite','brownish white',[240,234,214],'f0ead6',15788758],
['nbs-iscc-a:dullblue.184','dullblue','dull blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-a:dullblue.185','dullblue','dull blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-a:dullblue.186','dullblue','dull blue',[83,104,120],'536878',5466232],
['nbs-iscc-a:dullblue.187','dullblue','dull blue',[54,69,79],'36454f',3556687],
['nbs-iscc-a:dullblue.188','dullblue','dull blue',[32,40,48],'202830',2107440],
['nbs-iscc-a:dullblue.202','dullblue','dull blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-a:dullblue.203','dullblue','dull blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-a:dullblue.204','dullblue','dull blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-a:dullbluishgreen.148','dullbluishgreen','dull bluish green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-a:dullbluishgreen.149','dullbluishgreen','dull bluish green',[141,163,153],'8da399',9282457],
['nbs-iscc-a:dullbluishgreen.150','dullbluishgreen','dull bluish green',[94,113,106],'5e716a',6189418],
['nbs-iscc-a:dullbluishgreen.151','dullbluishgreen','dull bluish green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-a:dullbluishgreen.152','dullbluishgreen','dull bluish green',[26,36,33],'1a2421',1713185],
['nbs-iscc-a:dullbluishred.258','dullbluishred','dull bluish red',[168,81,110],'a8516e',11030894],
['nbs-iscc-a:dullbluishred.259','dullbluishred','dull bluish red',[103,49,71],'673147',6762823],
['nbs-iscc-a:dullbluishred.260','dullbluishred','dull bluish red',[56,21,44],'38152c',3675436],
['nbs-iscc-a:dullbluishviolet.213','dullbluishviolet','dull bluish violet',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-a:dullbluishviolet.214','dullbluishviolet','dull bluish violet',[150,144,171],'9690ab',9867435],
['nbs-iscc-a:dullbluishviolet.215','dullbluishviolet','dull bluish violet',[85,76,105],'554c69',5590121],
['nbs-iscc-a:dullbluishviolet.226','dullbluishviolet','dull bluish violet',[214,202,221],'d6cadd',14076637],
['nbs-iscc-a:dullbluishviolet.227','dullbluishviolet','dull bluish violet',[170,152,169],'aa98a9',11180201],
['nbs-iscc-a:dullbluishviolet.228','dullbluishviolet','dull bluish violet',[121,104,120],'796878',7956600],
['nbs-iscc-a:dullbluishviolet.229','dullbluishviolet','dull bluish violet',[80,64,77],'50404d',5259341],
['nbs-iscc-a:dullbluishviolet.230','dullbluishviolet','dull bluish violet',[41,30,41],'291e29',2694697],
['nbs-iscc-a:dullbordeaux.228','dullbordeaux','dull bordeaux',[121,104,120],'796878',7956600],
['nbs-iscc-a:dullbordeaux.229','dullbordeaux','dull bordeaux',[80,64,77],'50404d',5259341],
['nbs-iscc-a:dullbordeaux.230','dullbordeaux','dull bordeaux',[41,30,41],'291e29',2694697],
['nbs-iscc-a:dullbordeaux.259','dullbordeaux','dull bordeaux',[103,49,71],'673147',6762823],
['nbs-iscc-a:dullbordeaux.260','dullbordeaux','dull bordeaux',[56,21,44],'38152c',3675436],
['nbs-iscc-a:dullbrownisholive.96','dullbrownisholive','dull brownish olive',[59,49,33],'3b3121',3879201],
['nbs-iscc-a:dullgreen.148','dullgreen','dull green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-a:dullgreen.149','dullgreen','dull green',[141,163,153],'8da399',9282457],
['nbs-iscc-a:dullgreen.150','dullgreen','dull green',[94,113,106],'5e716a',6189418],
['nbs-iscc-a:dullgreen.151','dullgreen','dull green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-a:dullgreen.152','dullgreen','dull green',[26,36,33],'1a2421',1713185],
['nbs-iscc-a:dullgreenishblue.184','dullgreenishblue','dull greenish blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-a:dullgreenishblue.185','dullgreenishblue','dull greenish blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-a:dullgreenishblue.186','dullgreenishblue','dull greenish blue',[83,104,120],'536878',5466232],
['nbs-iscc-a:dullgreenishblue.187','dullgreenishblue','dull greenish blue',[54,69,79],'36454f',3556687],
['nbs-iscc-a:dullgreenishblue.188','dullgreenishblue','dull greenish blue',[32,40,48],'202830',2107440],
['nbs-iscc-a:dullgreenishyellow.104','dullgreenishyellow','dull greenish yellow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-a:dullgreenishyellow.105','dullgreenishyellow','dull greenish yellow',[185,181,125],'b9b57d',12170621],
['nbs-iscc-a:dullgreenishyellow.106','dullgreenishyellow','dull greenish yellow',[134,126,54],'867e36',8814134],
['nbs-iscc-a:dullorange.29','dullorange','dull orange',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-a:dullorange.57','dullorange','dull orange',[166,123,91],'a67b5b',10910555],
['nbs-iscc-a:dullred.15','dullred','dull red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-a:dullred.16','dullred','dull red',[114,47,55],'722f37',7483191],
['nbs-iscc-a:dullred.17','dullred','dull red',[63,23,40],'3f1728',4134696],
['nbs-iscc-a:dullred.19','dullred','dull red',[144,93,93],'905d5d',9461085],
['nbs-iscc-a:dullred.41','dullred','dull red',[86,7,12],'56070c',5637900],
['nbs-iscc-a:dullred.43','dullred','dull red',[121,68,59],'79443b',7947323],
['nbs-iscc-a:dullreddishblue.184','dullreddishblue','dull reddish blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-a:dullreddishblue.185','dullreddishblue','dull reddish blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-a:dullreddishblue.186','dullreddishblue','dull reddish blue',[83,104,120],'536878',5466232],
['nbs-iscc-a:dullreddishblue.187','dullreddishblue','dull reddish blue',[54,69,79],'36454f',3556687],
['nbs-iscc-a:dullreddishblue.188','dullreddishblue','dull reddish blue',[32,40,48],'202830',2107440],
['nbs-iscc-a:dullreddishblue.202','dullreddishblue','dull reddish blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-a:dullreddishblue.203','dullreddishblue','dull reddish blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-a:dullreddishblue.204','dullreddishblue','dull reddish blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-a:dullreddishbrown.16','dullreddishbrown','dull reddish brown',[114,47,55],'722f37',7483191],
['nbs-iscc-a:dullreddishbrown.17','dullreddishbrown','dull reddish brown',[63,23,40],'3f1728',4134696],
['nbs-iscc-a:dullreddishbrown.19','dullreddishbrown','dull reddish brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-a:dullreddishbrown.20','dullreddishbrown','dull reddish brown',[84,61,63],'543d3f',5520703],
['nbs-iscc-a:dullreddishbrown.21','dullreddishbrown','dull reddish brown',[46,29,33],'2e1d21',3022113],
['nbs-iscc-a:dullreddishbrown.42','dullreddishbrown','dull reddish brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-a:dullreddishbrown.43','dullreddishbrown','dull reddish brown',[121,68,59],'79443b',7947323],
['nbs-iscc-a:dullreddishbrown.44','dullreddishbrown','dull reddish brown',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-a:dullreddishbrown.45','dullreddishbrown','dull reddish brown',[151,127,115],'977f73',9928563],
['nbs-iscc-a:dullreddishbrown.46','dullreddishbrown','dull reddish brown',[103,76,71],'674c47',6769735],
['nbs-iscc-a:dullreddishbrown.47','dullreddishbrown','dull reddish brown',[67,48,46],'43302e',4403246],
['nbs-iscc-a:dullreddishorange.39','dullreddishorange','dull reddish orange',[180,116,94],'b4745e',11826270],
['nbs-iscc-a:dullreddishviolet.227','dullreddishviolet','dull reddish violet',[170,152,169],'aa98a9',11180201],
['nbs-iscc-a:dullreddishviolet.228','dullreddishviolet','dull reddish violet',[121,104,120],'796878',7956600],
['nbs-iscc-a:dullreddishviolet.229','dullreddishviolet','dull reddish violet',[80,64,77],'50404d',5259341],
['nbs-iscc-a:dullreddishviolet.230','dullreddishviolet','dull reddish violet',[41,30,41],'291e29',2694697],
['nbs-iscc-a:dullreddishviolet.244','dullreddishviolet','dull reddish violet',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-a:dullreddishviolet.245','dullreddishviolet','dull reddish violet',[131,100,121],'836479',8610937],
['nbs-iscc-a:dullreddishyellow.73','dullreddishyellow','dull reddish yellow',[250,214,165],'fad6a5',16438949],
['nbs-iscc-a:dullreddishyellow.89','dullreddishyellow','dull reddish yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-a:dullreddishyellow.90','dullreddishyellow','dull reddish yellow',[194,178,128],'c2b280',12759680],
['nbs-iscc-a:dullreddishyellow.91','dullreddishyellow','dull reddish yellow',[161,143,96],'a18f60',10588000],
['nbs-iscc-a:dullviolet.226','dullviolet','dull violet',[214,202,221],'d6cadd',14076637],
['nbs-iscc-a:dullviolet.227','dullviolet','dull violet',[170,152,169],'aa98a9',11180201],
['nbs-iscc-a:dullviolet.228','dullviolet','dull violet',[121,104,120],'796878',7956600],
['nbs-iscc-a:dullviolet.229','dullviolet','dull violet',[80,64,77],'50404d',5259341],
['nbs-iscc-a:dullviolet.230','dullviolet','dull violet',[41,30,41],'291e29',2694697],
['nbs-iscc-a:dullyellow.89','dullyellow','dull yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-a:dullyellow.90','dullyellow','dull yellow',[194,178,128],'c2b280',12759680],
['nbs-iscc-a:dullyellow.91','dullyellow','dull yellow',[161,143,96],'a18f60',10588000],
['nbs-iscc-a:dullyellowishbrown.76','dullyellowishbrown','dull yellowish brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-a:dullyellowishbrown.77','dullyellowishbrown','dull yellowish brown',[130,102,68],'826644',8545860],
['nbs-iscc-a:dullyellowishbrown.78','dullyellowishbrown','dull yellowish brown',[75,54,33],'4b3621',4929057],
['nbs-iscc-a:dullyellowishbrown.79','dullyellowishbrown','dull yellowish brown',[174,155,130],'ae9b82',11443074],
['nbs-iscc-a:dullyellowishbrown.80','dullyellowishbrown','dull yellowish brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-a:dullyellowishbrown.81','dullyellowishbrown','dull yellowish brown',[72,60,50],'483c32',4734002],
['nbs-iscc-a:dullyellowishgreen.121','dullyellowishgreen','dull yellowish green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-a:dullyellowishgreen.122','dullyellowishgreen','dull yellowish green',[143,151,121],'8f9779',9410425],
['nbs-iscc-a:dullyellowishorange.73','dullyellowishorange','dull yellowish orange',[250,214,165],'fad6a5',16438949],
['nbs-iscc-a:dullyellowishred.39','dullyellowishred','dull yellowish red',[180,116,94],'b4745e',11826270],
['nbs-iscc-a:gray.264','gray','gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-a:gray.265','gray','gray',[132,132,130],'848482',8684674],
['nbs-iscc-a:gray.266','gray','gray',[85,85,85],'555555',5592405],
['nbs-iscc-a:green.140','green','green',[62,180,137],'3eb489',4109449],
['nbs-iscc-a:green.141','green','green',[0,121,89],'007959',31065],
['nbs-iscc-a:green.142','green','green',[0,84,61],'00543d',21565],
['nbs-iscc-a:green.143','green','green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-a:green.144','green','green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-a:green.145','green','green',[59,120,97],'3b7861',3897441],
['nbs-iscc-a:green.146','green','green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-a:green.147','green','green',[28,53,45],'1c352d',1848621],
['nbs-iscc-a:greenishblack.114','greenishblack','greenish black',[37,36,29],'25241d',2434077],
['nbs-iscc-a:greenishblack.157','greenishblack','greenish black',[30,35,33],'1e2321',1975073],
['nbs-iscc-a:greenishblue.168','greenishblue','greenish blue',[35,158,186],'239eba',2334394],
['nbs-iscc-a:greenishblue.169','greenishblue','greenish blue',[0,119,145],'007791',30609],
['nbs-iscc-a:greenishblue.170','greenishblue','greenish blue',[46,132,149],'2e8495',3048597],
['nbs-iscc-a:greenishblue.171','greenishblue','greenish blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-a:greenishblue.172','greenishblue','greenish blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-a:greenishblue.173','greenishblue','greenish blue',[54,117,136],'367588',3569032],
['nbs-iscc-a:greenishblue.174','greenishblue','greenish blue',[0,73,88],'004958',18776],
['nbs-iscc-a:greenishblue.175','greenishblue','greenish blue',[0,46,59],'002e3b',11835],
['nbs-iscc-a:greenishgray.112','greenishgray','greenish gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-a:greenishgray.113','greenishgray','greenish gray',[87,85,76],'57554c',5723468],
['nbs-iscc-a:greenishgray.154','greenishgray','greenish gray',[178,190,181],'b2beb5',11714229],
['nbs-iscc-a:greenishgray.155','greenishgray','greenish gray',[125,137,132],'7d8984',8227204],
['nbs-iscc-a:greenishgray.156','greenishgray','greenish gray',[78,87,85],'4e5755',5134165],
['nbs-iscc-a:greenishnavy.183','greenishnavy','greenish navy',[0,48,78],'00304e',12366],
['nbs-iscc-a:greenishnavy.188','greenishnavy','greenish navy',[32,40,48],'202830',2107440],
['nbs-iscc-a:greenishwhite.153','greenishwhite','greenish white',[223,237,232],'dfede8',14675432],
['nbs-iscc-a:greenishyellow.98','greenishyellow','greenish yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-a:greenishyellow.99','greenishyellow','greenish yellow',[190,183,46],'beb72e',12498734],
['nbs-iscc-a:greenishyellow.100','greenishyellow','greenish yellow',[155,148,0],'9b9400',10195968],
['nbs-iscc-a:greenishyellow.101','greenishyellow','greenish yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-a:greenishyellow.102','greenishyellow','greenish yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-a:greenishyellow.103','greenishyellow','greenish yellow',[152,148,62],'98943e',9999422],
['nbs-iscc-a:navy.183','navy','navy',[0,48,78],'00304e',12366],
['nbs-iscc-a:navy.188','navy','navy',[32,40,48],'202830',2107440],
['nbs-iscc-a:navy.201','navy','navy',[37,36,64],'252440',2434112],
['nbs-iscc-a:olive.106','olive','olive',[134,126,54],'867e36',8814134],
['nbs-iscc-a:olive.107','olive','olive',[102,93,30],'665d1e',6708510],
['nbs-iscc-a:olive.108','olive','olive',[64,61,33],'403d21',4209953],
['nbs-iscc-a:olive.109','olive','olive',[140,135,103],'8c8767',9209703],
['nbs-iscc-a:olive.110','olive','olive',[91,88,66],'5b5842',5986370],
['nbs-iscc-a:olive.111','olive','olive',[54,53,39],'363527',3552551],
['nbs-iscc-a:orange.49','orange','orange',[253,148,63],'fd943f',16618559],
['nbs-iscc-a:orange.50','orange','orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-a:orange.51','orange','orange',[190,101,22],'be6516',12477718],
['nbs-iscc-a:orange.52','orange','orange',[250,181,127],'fab57f',16430463],
['nbs-iscc-a:orange.53','orange','orange',[217,144,88],'d99058',14258264],
['nbs-iscc-a:orange.54','orange','orange',[174,105,56],'ae6938',11430200],
['nbs-iscc-a:pink.1','pink','pink',[255,181,186],'ffb5ba',16758202],
['nbs-iscc-a:pink.2','pink','pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-a:pink.3','pink','pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-a:pink.4','pink','pink',[249,204,202],'f9ccca',16370890],
['nbs-iscc-a:pink.5','pink','pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-a:pink.6','pink','pink',[192,128,129],'c08081',12615809],
['nbs-iscc-a:pink.7','pink','pink',[234,216,215],'ead8d7',15390935],
['nbs-iscc-a:pink.8','pink','pink',[196,174,173],'c4aead',12889773],
['nbs-iscc-a:pink.18','pink','pink',[173,136,132],'ad8884',11372676],
['nbs-iscc-a:pink.261','pink','pink',[175,134,142],'af868e',11503246],
['nbs-iscc-a:red.12','red','red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-a:red.13','red','red',[132,27,45],'841b2d',8657709],
['nbs-iscc-a:red.14','red','red',[92,9,35],'5c0923',6031651],
['nbs-iscc-a:red.15','red','red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-a:reddishblack.20','reddishblack','reddish black',[84,61,63],'543d3f',5520703],
['nbs-iscc-a:reddishblack.24','reddishblack','reddish black',[40,32,34],'282022',2629666],
['nbs-iscc-a:reddishblack.235','reddishblack','reddish black',[36,33,36],'242124',2367780],
['nbs-iscc-a:reddishblue.195','reddishblue','reddish blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-a:reddishblue.196','reddishblue','reddish blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-a:reddishblue.197','reddishblue','reddish blue',[39,36,88],'272458',2565208],
['nbs-iscc-a:reddishblue.198','reddishblue','reddish blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-a:reddishblue.199','reddishblue','reddish blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-a:reddishblue.200','reddishblue','reddish blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-a:reddishblue.201','reddishblue','reddish blue',[37,36,64],'252440',2434112],
['nbs-iscc-a:reddishbrown.13','reddishbrown','reddish brown',[132,27,45],'841b2d',8657709],
['nbs-iscc-a:reddishbrown.14','reddishbrown','reddish brown',[92,9,35],'5c0923',6031651],
['nbs-iscc-a:reddishbrown.16','reddishbrown','reddish brown',[114,47,55],'722f37',7483191],
['nbs-iscc-a:reddishbrown.19','reddishbrown','reddish brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-a:reddishbrown.40','reddishbrown','reddish brown',[136,45,23],'882d17',8924439],
['nbs-iscc-a:reddishbrown.41','reddishbrown','reddish brown',[86,7,12],'56070c',5637900],
['nbs-iscc-a:reddishbrown.43','reddishbrown','reddish brown',[121,68,59],'79443b',7947323],
['nbs-iscc-a:reddishgray.10','reddishgray','reddish gray',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-a:reddishgray.22','reddishgray','reddish gray',[143,129,127],'8f817f',9404799],
['nbs-iscc-a:reddishgray.23','reddishgray','reddish gray',[92,80,79],'5c504f',6049871],
['nbs-iscc-a:reddishgray.232','reddishgray','reddish gray',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-a:reddishgray.233','reddishgray','reddish gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-a:reddishgray.234','reddishgray','reddish gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-a:reddishnavy.212','reddishnavy','reddish navy',[47,33,64],'2f2140',3088704],
['nbs-iscc-a:reddishorange.35','reddishorange','reddish orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-a:reddishorange.36','reddishorange','reddish orange',[170,56,30],'aa381e',11155486],
['nbs-iscc-a:reddishorange.37','reddishorange','reddish orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-a:reddishorange.38','reddishorange','reddish orange',[158,71,50],'9e4732',10372914],
['nbs-iscc-a:reddishviolet.237','reddishviolet','reddish violet',[158,79,136],'9e4f88',10375048],
['nbs-iscc-a:reddishviolet.238','reddishviolet','reddish violet',[112,41,99],'702963',7350627],
['nbs-iscc-a:reddishviolet.239','reddishviolet','reddish violet',[84,25,78],'54194e',5511502],
['nbs-iscc-a:reddishviolet.240','reddishviolet','reddish violet',[183,132,167],'b784a7',12027047],
['nbs-iscc-a:reddishviolet.241','reddishviolet','reddish violet',[145,92,131],'915c83',9526403],
['nbs-iscc-a:reddishviolet.242','reddishviolet','reddish violet',[93,57,84],'5d3954',6109524],
['nbs-iscc-a:reddishviolet.243','reddishviolet','reddish violet',[52,23,49],'341731',3413809],
['nbs-iscc-a:reddishwhite.9','reddishwhite','reddish white',[234,227,225],'eae3e1',15393761],
['nbs-iscc-a:reddishwhite.231','reddishwhite','reddish white',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-a:reddishyellow.67','reddishyellow','reddish yellow',[255,193,79],'ffc14f',16761167],
['nbs-iscc-a:reddishyellow.68','reddishyellow','reddish yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-a:reddishyellow.69','reddishyellow','reddish yellow',[201,133,0],'c98500',13206784],
['nbs-iscc-a:reddishyellow.70','reddishyellow','reddish yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-a:reddishyellow.71','reddishyellow','reddish yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-a:reddishyellow.72','reddishyellow','reddish yellow',[190,138,61],'be8a3d',12487229],
['nbs-iscc-a:reddishyellow.83','reddishyellow','reddish yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-a:reddishyellow.84','reddishyellow','reddish yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-a:reddishyellow.85','reddishyellow','reddish yellow',[175,141,19],'af8d13',11504915],
['nbs-iscc-a:reddishyellow.86','reddishyellow','reddish yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-a:reddishyellow.87','reddishyellow','reddish yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-a:reddishyellow.88','reddishyellow','reddish yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-a:violet.217','violet','violet',[211,153,230],'d399e6',13867494],
['nbs-iscc-a:violet.218','violet','violet',[135,86,146],'875692',8869522],
['nbs-iscc-a:violet.219','violet','violet',[96,47,107],'602f6b',6303595],
['nbs-iscc-a:violet.220','violet','violet',[64,26,76],'401a4c',4201036],
['nbs-iscc-a:violet.221','violet','violet',[213,186,219],'d5badb',14007003],
['nbs-iscc-a:violet.222','violet','violet',[182,149,192],'b695c0',11965888],
['nbs-iscc-a:violet.223','violet','violet',[134,96,142],'86608e',8806542],
['nbs-iscc-a:violet.224','violet','violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-a:violet.225','violet','violet',[48,25,52],'301934',3152180],
['nbs-iscc-a:white.263','white','white',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-a:yellow.83','yellow','yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-a:yellow.84','yellow','yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-a:yellow.85','yellow','yellow',[175,141,19],'af8d13',11504915],
['nbs-iscc-a:yellow.86','yellow','yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-a:yellow.87','yellow','yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-a:yellow.88','yellow','yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-a:yellowishbrown.74','yellowishbrown','yellowish brown',[153,101,21],'996515',10052885],
['nbs-iscc-a:yellowishbrown.75','yellowishbrown','yellowish brown',[101,69,34],'654522',6636834],
['nbs-iscc-a:yellowishgreen.116','yellowishgreen','yellowish green',[189,218,87],'bdda57',12442199],
['nbs-iscc-a:yellowishgreen.117','yellowishgreen','yellowish green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-a:yellowishgreen.118','yellowishgreen','yellowish green',[70,113,41],'467129',4616489],
['nbs-iscc-a:yellowishgreen.119','yellowishgreen','yellowish green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-a:yellowishgreen.120','yellowishgreen','yellowish green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-a:yellowishgreen.125','yellowishgreen','yellowish green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-a:yellowishgreen.130','yellowishgreen','yellowish green',[131,211,125],'83d37d',8639357],
['nbs-iscc-a:yellowishgreen.131','yellowishgreen','yellowish green',[68,148,74],'44944a',4494410],
['nbs-iscc-a:yellowishgreen.132','yellowishgreen','yellowish green',[0,98,45],'00622d',25133],
['nbs-iscc-a:yellowishgreen.133','yellowishgreen','yellowish green',[0,49,24],'003118',12568],
['nbs-iscc-a:yellowishgreen.134','yellowishgreen','yellowish green',[182,229,175],'b6e5af',11986351],
['nbs-iscc-a:yellowishgreen.135','yellowishgreen','yellowish green',[147,197,146],'93c592',9684370],
['nbs-iscc-a:yellowishgreen.136','yellowishgreen','yellowish green',[103,146,103],'679267',6787687],
['nbs-iscc-a:yellowishgreen.137','yellowishgreen','yellowish green',[53,94,59],'355e3b',3497531],
['nbs-iscc-a:yellowishgreen.138','yellowishgreen','yellowish green',[23,54,32],'173620',1521184],
['nbs-iscc-a:yellowishorange.67','yellowishorange','yellowish orange',[255,193,79],'ffc14f',16761167],
['nbs-iscc-a:yellowishorange.68','yellowishorange','yellowish orange',[234,162,33],'eaa221',15376929],
['nbs-iscc-a:yellowishorange.69','yellowishorange','yellowish orange',[201,133,0],'c98500',13206784],
['nbs-iscc-a:yellowishorange.70','yellowishorange','yellowish orange',[251,201,127],'fbc97f',16501119],
['nbs-iscc-a:yellowishorange.71','yellowishorange','yellowish orange',[227,168,87],'e3a857',14919767],
['nbs-iscc-a:yellowishorange.72','yellowishorange','yellowish orange',[190,138,61],'be8a3d',12487229],
['nbs-iscc-a:yellowishpink.25','yellowishpink','yellowish pink',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-a:yellowishpink.26','yellowishpink','yellowish pink',[248,131,121],'f88379',16286585],
['nbs-iscc-a:yellowishpink.27','yellowishpink','yellowish pink',[230,103,97],'e66761',15099745],
['nbs-iscc-a:yellowishpink.28','yellowishpink','yellowish pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-a:yellowishpink.29','yellowishpink','yellowish pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-a:yellowishpink.30','yellowishpink','yellowish pink',[196,131,121],'c48379',12878713],
['nbs-iscc-a:yellowishpink.31','yellowishpink','yellowish pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-a:yellowishpink.32','yellowishpink','yellowish pink',[199,173,163],'c7ada3',13086115],
['nbs-iscc-a:yellowishred.35','yellowishred','yellowish red',[217,96,59],'d9603b',14245947],
['nbs-iscc-a:yellowishred.36','yellowishred','yellowish red',[170,56,30],'aa381e',11155486],
['nbs-iscc-a:yellowishred.37','yellowishred','yellowish red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-a:yellowishred.38','yellowishred','yellowish red',[158,71,50],'9e4732',10372914]
    ];
}

sub _description {
    return {
          'subtitle' => 'Dye Colors',
          'title' => 'NBS/ISCC A',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (A) Dye Colors

        American Association of Textile Chemists and
        Colorists and Society of Dyers and Colourists 

    This combinatorial dictionary\'s 88 names map to 350 colors; 263 out of 267 centroids are covered.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#A]
'
        }

}

1;
