package Color::Library::Dictionary::NBS_ISCC::F;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::F;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::F - (NBS/ISCC F) Colors; (for) Ready-Mixed Paints

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (F) Colors; (for) Ready-Mixed Paints

        Federal Specification TT-C-595,
        Colors; (for) Ready-Mixed Paints 

    This dictionary is a hybrid of combinatorial and idiosyncratic terms. 134 names map to 174 colors, using only 73 out of 267 centroids.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#F>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>aircraft cream</td><td>aircraftcream</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>aircraft gray</td><td>aircraftgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>anti-corrosive brown</td><td>anticorrosivebrown</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#403d21;width:4em;" /><td>anti-corrosive green</td><td>anticorrosivegreen</td><td>##403d21</td><td>64</td> <td>61</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>azure blue</td><td>azureblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>battleship gray</td><td>battleshipgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black</td><td>black</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black boottopping</td><td>blackboottopping</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black deck</td><td>blackdeck</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue</td><td>blue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>blue drab</td><td>bluedrab</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>blue gray</td><td>bluegray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>blue striping</td><td>bluestriping</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>blue tint</td><td>bluetint</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>bright blue</td><td>brightblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>bright green</td><td>brightgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>brilliant yellow</td><td>brilliantyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>brown striping</td><td>brownstriping</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#593319;width:4em;" /><td>brown striping</td><td>brownstriping</td><td>##593319</td><td>89</td> <td>51</td> <td>25</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>buff</td><td>buff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>buff</td><td>buff</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>buff</td><td>buff</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>buff</td><td>buff</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>buff</td><td>buff</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>cameo rose</td><td>cameorose</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>cameo rose</td><td>cameorose</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>canary yellow</td><td>canaryyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>canyon brown</td><td>canyonbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#173620;width:4em;" /><td>chrome green</td><td>chromegreen</td><td>##173620</td><td>23</td> <td>54</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>chrome yellow</td><td>chromeyellow</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>chrome yellow</td><td>chromeyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>clear blue</td><td>clearblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>cream</td><td>cream</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>cream striping</td><td>creamstriping</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>dark earth</td><td>darkearth</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>dark earth</td><td>darkearth</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dark gray</td><td>darkgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark green deck</td><td>darkgreendeck</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>dark gull gray</td><td>darkgullgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>dark putty</td><td>darkputty</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>dark red boottopping </td><td>darkredboottopping</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>dark zinc yellow primer</td><td>darkzincyellowprimer</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>deep navy gray</td><td>deepnavygray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>deep reddish brown</td><td>deepreddishbrown</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>desert sand</td><td>desertsand</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>desert sand</td><td>desertsand</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>dull red</td><td>dullred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>earth brown</td><td>earthbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>earth red </td><td>earthred</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>earth yellow</td><td>earthyellow</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>eggshell </td><td>eggshell</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>eggshell </td><td>eggshell</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>engine gray</td><td>enginegray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>engine gray</td><td>enginegray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#2b3d26;width:4em;" /><td>exterior green #14 or exterior green no. fourteen</td><td>exteriorgreen14orexteriorgreennofourteen</td><td>##2b3d26</td><td>43</td> <td>61</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>exterior green #15 or exterior green no. fifteen</td><td>exteriorgreen15orexteriorgreennofifteen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>field drab</td><td>fielddrab</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>field drab</td><td>fielddrab</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>fire red</td><td>firered</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>flat cream</td><td>flatcream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#2b3d26;width:4em;" /><td>forest green</td><td>forestgreen</td><td>##2b3d26</td><td>43</td> <td>61</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>forest green</td><td>forestgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>gloss black</td><td>glossblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>government wall green</td><td>governmentwallgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gray</td><td>gray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>gray</td><td>gray</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>gray</td><td>gray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>gray #12 </td><td>gray12</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>gray #7 </td><td>gray7</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>gray #7 </td><td>gray7</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>gray deck</td><td>graydeck</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gray deck</td><td>graydeck</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>gray tint</td><td>graytint</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gray wood</td><td>graywood</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>green</td><td>green</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>green</td><td>green</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#1c352d;width:4em;" /><td>green</td><td>green</td><td>##1c352d</td><td>28</td> <td>53</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#2b3d26;width:4em;" /><td>green</td><td>green</td><td>##2b3d26</td><td>43</td> <td>61</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>green</td><td>green</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#403d21;width:4em;" /><td>green</td><td>green</td><td>##403d21</td><td>64</td> <td>61</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>green</td><td>green</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>green boottopping</td><td>greenboottopping</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>green striping</td><td>greenstriping</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>green tint</td><td>greentint</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>green zinc yellow primer</td><td>greenzincyellowprimer</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>haze-gray</td><td>hazegray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>highlight buff</td><td>highlightbuff</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>hospital ship green</td><td>hospitalshipgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>hull black</td><td>hullblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>hull gray</td><td>hullgray</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>insignia blue</td><td>insigniablue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>insignia blue</td><td>insigniablue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>insignia red</td><td>insigniared</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>insignia red</td><td>insigniared</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>insignia white</td><td>insigniawhite</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>instrument black</td><td>instrumentblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>interior green</td><td>interiorgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>intermediate blue</td><td>intermediateblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>international orange</td><td>internationalorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>ivory</td><td>ivory</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ivory cream</td><td>ivorycream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>jet</td><td>jet</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>jet black</td><td>jetblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>light blue</td><td>lightblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>light blue</td><td>lightblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>light blue</td><td>lightblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>light blue</td><td>lightblue</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>light blue</td><td>lightblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>light blue</td><td>lightblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>light blue enamel</td><td>lightblueenamel</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>light blue,, light blue 5</td><td>lightbluelightblue5</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>light gray</td><td>lightgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>light gray</td><td>lightgray</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>light gray</td><td>lightgray</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>light gray</td><td>lightgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>light gray</td><td>lightgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>light gray boottopping</td><td>lightgrayboottopping</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>light green</td><td>lightgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>light green</td><td>lightgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>light green</td><td>lightgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>light green</td><td>lightgreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>light green</td><td>lightgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>light green</td><td>lightgreen</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>light gull gray</td><td>lightgullgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>light ivory</td><td>lightivory</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>light navy gray</td><td>lightnavygray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>light olive</td><td>lightolive</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>light red boottopping </td><td>lightredboottopping</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>light yellow</td><td>lightyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>light yellow</td><td>lightyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>loam</td><td>loam</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>machinery green</td><td>machinerygreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>marine green</td><td>marinegreen</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>maroon</td><td>maroon</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>maroon</td><td>maroon</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>medium blue</td><td>mediumblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>medium blue</td><td>mediumblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>medium gray</td><td>mediumgray</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>medium gray</td><td>mediumgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>medium gray</td><td>mediumgray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>medium green</td><td>mediumgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#00622d;width:4em;" /><td>medium green</td><td>mediumgreen</td><td>##00622d</td><td>0</td> <td>98</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>medium green</td><td>mediumgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>medium navy gray</td><td>mediumnavygray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>medium tan</td><td>mediumtan</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>metallic brown </td><td>metallicbrown</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>metallic brown </td><td>metallicbrown</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#593319;width:4em;" /><td>metallic brown </td><td>metallicbrown</td><td>##593319</td><td>89</td> <td>51</td> <td>25</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>metallic red </td><td>metallicred</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>middle stone </td><td>middlestone</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>middlestone </td><td>middlestone</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>mosstone </td><td>mosstone</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>national school bus chrome </td><td>nationalschoolbuschrome</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>navy gray</td><td>navygray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>ocean gray</td><td>oceangray</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>ocean gray</td><td>oceangray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>olive drab</td><td>olivedrab</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive drab</td><td>olivedrab</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#403d21;width:4em;" /><td>olive drab</td><td>olivedrab</td><td>##403d21</td><td>64</td> <td>61</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#403d21;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##403d21</td><td>64</td> <td>61</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>orange</td><td>orange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>orange</td><td>orange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange</td><td>orange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>oyster gray</td><td>oystergray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>peach</td><td>peach</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>pea green</td><td>peagreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>pearl gray</td><td>pearlgray</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pearl gray</td><td>pearlgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#2b3d26;width:4em;" /><td>pullman green</td><td>pullmangreen</td><td>##2b3d26</td><td>43</td> <td>61</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#403d21;width:4em;" /><td>pullman green</td><td>pullmangreen</td><td>##403d21</td><td>64</td> <td>61</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>pullman green</td><td>pullmangreen</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>purple</td><td>purple</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>red</td><td>red</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>red</td><td>red</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>red</td><td>red</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>red boottopping</td><td>redboottopping</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>red deck</td><td>reddeck</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>red lead</td><td>redlead</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>red lead and oil</td><td>redleadandoil</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>red lead modified</td><td>redleadmodified</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>red oxide</td><td>redoxide</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>red striping</td><td>redstriping</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>road and tire gray</td><td>roadandtiregray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>royal blue</td><td>royalblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>sand</td><td>sand</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>sand</td><td>sand</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>sand</td><td>sand</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>sea blue</td><td>seablue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>sea blue</td><td>seablue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>sea blue</td><td>seablue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>sea blue</td><td>seablue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>sea gray</td><td>seagray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>seal brown</td><td>sealbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>slate</td><td>slate</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>soft yellow </td><td>softyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>spring green</td><td>springgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>spruce green</td><td>sprucegreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>suntan</td><td>suntan</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>terra cotta</td><td>terracotta</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>vineyard green </td><td>vineyardgreen</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>vivid orange</td><td>vividorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>warm gray </td><td>warmgray</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>willow green</td><td>willowgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>yellow</td><td>yellow</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>yellow</td><td>yellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>yellow</td><td>yellow</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>yellow striping</td><td>yellowstriping</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>yellow striping</td><td>yellowstriping</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>yellow tint</td><td>yellowtint</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>zinc chromate</td><td>zincchromate</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>zinc yellow primer </td><td>zincyellowprimer</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item aircraft cream                                    aircraftcream                            #c2b280

=item aircraft gray                                     aircraftgray                             #b9b8b5

=item anti-corrosive brown                              anticorrosivebrown                       #422518

=item anti-corrosive green                              anticorrosivegreen                       #403d21

=item azure blue                                        azureblue                                #8791bf

=item battleship gray                                   battleshipgray                           #848482

=item black                                             black                                    #222222

=item black boottopping                                 blackboottopping                         #222222

=item black deck                                        blackdeck                                #222222

=item blue                                              blue                                     #436b95

=item blue drab                                         bluedrab                                 #4e5755

=item blue gray                                         bluegray                                 #848482

=item blue green                                        bluegreen                                #93c592

=item blue striping                                     bluestriping                             #0067a5

=item blue tint                                         bluetint                                 #c7e6d7

=item bright blue                                       brightblue                               #0067a5

=item bright green                                      brightgreen                              #3b7861

=item brilliant yellow                                  brilliantyellow                          #f3c300

=item brown striping                                    brownstriping                            #56070c

=item brown striping                                    brownstriping                            #593319

=item buff                                              buff                                     #e3a857

=item buff                                              buff                                     #c19a6b

=item buff                                              buff                                     #c2b280

=item buff                                              buff                                     #d99058

=item buff                                              buff                                     #be8a3d

=item cameo rose                                        cameorose                                #fad6a5

=item cameo rose                                        cameorose                                #f4c2c2

=item canary yellow                                     canaryyellow                             #f8de7e

=item canyon brown                                      canyonbrown                              #635147

=item chrome green                                      chromegreen                              #173620

=item chrome yellow                                     chromeyellow                             #f6a600

=item chrome yellow                                     chromeyellow                             #eaa221

=item clear blue                                        clearblue                                #367588

=item cream                                             cream                                    #c2b280

=item cream striping                                    creamstriping                            #f8de7e

=item dark earth                                        darkearth                                #7e6d5a

=item dark earth                                        darkearth                                #6c541e

=item dark gray                                         darkgray                                 #555555

=item dark green                                        darkgreen                                #355e3b

=item dark green                                        darkgreen                                #3a4b47

=item dark green deck                                   darkgreendeck                            #3a4b47

=item dark gull gray                                    darkgullgray                             #848482

=item dark putty                                        darkputty                                #57554c

=item dark red boottopping                              darkredboottopping                       #3e322c

=item dark zinc yellow primer                           darkzincyellowprimer                     #515744

=item deep navy gray                                    deepnavygray                             #555555

=item deep reddish brown                                deepreddishbrown                         #3e1d1e

=item desert sand                                       desertsand                               #958070

=item desert sand                                       desertsand                               #a67b5b

=item dull red                                          dullred                                  #79443b

=item earth brown                                       earthbrown                               #635147

=item earth red                                         earthred                                 #6f4e37

=item earth yellow                                      earthyellow                              #c19a6b

=item eggshell                                          eggshell                                 #f3e5ab

=item eggshell                                          eggshell                                 #f0ead6

=item engine gray                                       enginegray                               #555555

=item engine gray                                       enginegray                               #848482

=item exterior green #14 or exterior green no. fourteen exteriorgreen14orexteriorgreennofourteen #2b3d26

=item exterior green #15 or exterior green no. fifteen  exteriorgreen15orexteriorgreennofifteen  #8a9a5b

=item field drab                                        fielddrab                                #7e6d5a

=item field drab                                        fielddrab                                #6c541e

=item fire red                                          firered                                  #be0032

=item flat cream                                        flatcream                                #f3e5ab

=item forest green                                      forestgreen                              #2b3d26

=item forest green                                      forestgreen                              #355e3b

=item gloss black                                       glossblack                               #222222

=item government wall green                             governmentwallgreen                      #8f9779

=item gray                                              gray                                     #848482

=item gray                                              gray                                     #c2b280

=item gray                                              gray                                     #bfb8a5

=item gray #12                                          gray12                                   #bfb8a5

=item gray #7                                           gray7                                    #8c8767

=item gray #7                                           gray7                                    #8a8776

=item gray deck                                         graydeck                                 #555555

=item gray deck                                         graydeck                                 #848482

=item gray tint                                         graytint                                 #c2b280

=item gray wood                                         graywood                                 #848482

=item green                                             green                                    #355e3b

=item green                                             green                                    #355e3b

=item green                                             green                                    #1c352d

=item green                                             green                                    #2b3d26

=item green                                             green                                    #b9b57d

=item green                                             green                                    #403d21

=item green                                             green                                    #3b7861

=item green boottopping                                 greenboottopping                         #355e3b

=item green striping                                    greenstriping                            #355e3b

=item green tint                                        greentint                                #dadfb7

=item green zinc yellow primer                          greenzincyellowprimer                    #8a9a5b

=item haze-gray                                         hazegray                                 #848482

=item highlight buff                                    highlightbuff                            #c2b280

=item hospital ship green                               hospitalshipgreen                        #679267

=item hull black                                        hullblack                                #222222

=item hull gray                                         hullgray                                 #91a3b0

=item insignia blue                                     insigniablue                             #252440

=item insignia blue                                     insigniablue                             #36454f

=item insignia red                                      insigniared                              #be0032

=item insignia red                                      insigniared                              #ab4e52

=item insignia white                                    insigniawhite                            #f2f3f4

=item instrument black                                  instrumentblack                          #222222

=item interior green                                    interiorgreen                            #4a5d23

=item intermediate blue                                 intermediateblue                         #536878

=item international orange                              internationalorange                      #e25822

=item ivory                                             ivory                                    #f8de7e

=item ivory cream                                       ivorycream                               #f3e5ab

=item jet                                               jet                                      #222222

=item jet black                                         jetblack                                 #222222

=item lemon yellow                                      lemonyellow                              #f3c300

=item light blue                                        lightblue                                #436b95

=item light blue                                        lightblue                                #317873

=item light blue                                        lightblue                                #367588

=item light blue                                        lightblue                                #8ed1b2

=item light blue                                        lightblue                                #317873

=item light blue                                        lightblue                                #367588

=item light blue enamel                                 lightblueenamel                          #00304e

=item light blue,, light blue 5                         lightbluelightblue5                      #c7e6d7

=item light gray                                        lightgray                                #b9b8b5

=item light gray                                        lightgray                                #f3e5ab

=item light gray                                        lightgray                                #c2b280

=item light gray                                        lightgray                                #848482

=item light gray                                        lightgray                                #b9b8b5

=item light gray boottopping                            lightgrayboottopping                     #848482

=item light green                                       lightgreen                               #44944a

=item light green                                       lightgreen                               #c9dc89

=item light green                                       lightgreen                               #679267

=item light green                                       lightgreen                               #b9b57d

=item light green                                       lightgreen                               #8a9a5b

=item light green                                       lightgreen                               #b2beb5

=item light gull gray                                   lightgullgray                            #b9b8b5

=item light ivory                                       lightivory                               #f3e5ab

=item light navy gray                                   lightnavygray                            #848482

=item light olive                                       lightolive                               #8c8767

=item light red boottopping                             lightredboottopping                      #56070c

=item light yellow                                      lightyellow                              #f3c300

=item light yellow                                      lightyellow                              #f8de7e

=item loam                                              loam                                     #57554c

=item machinery green                                   machinerygreen                           #5e716a

=item marine green                                      marinegreen                              #3b3121

=item maroon                                            maroon                                   #56070c

=item maroon                                            maroon                                   #674c47

=item medium blue                                       mediumblue                               #536878

=item medium blue                                       mediumblue                               #436b95

=item medium gray                                       mediumgray                               #8c8767

=item medium gray                                       mediumgray                               #848482

=item medium gray                                       mediumgray                               #8a8776

=item medium green                                      mediumgreen                              #3a4b47

=item medium green                                      mediumgreen                              #00622d

=item medium green                                      mediumgreen                              #5e716a

=item medium navy gray                                  mediumnavygray                           #848482

=item medium tan                                        mediumtan                                #826644

=item metallic brown                                    metallicbrown                            #56070c

=item metallic brown                                    metallicbrown                            #56070c

=item metallic brown                                    metallicbrown                            #593319

=item metallic red                                      metallicred                              #56070c

=item middle stone                                      middlestone                              #967117

=item middlestone                                       middlestone                              #967117

=item mosstone                                          mosstone                                 #8a9a5b

=item national school bus chrome                        nationalschoolbuschrome                  #f6a600

=item navy gray                                         navygray                                 #555555

=item ocean gray                                        oceangray                                #536878

=item ocean gray                                        oceangray                                #848482

=item olive drab                                        olivedrab                                #3b3121

=item olive drab                                        olivedrab                                #5b5842

=item olive drab                                        olivedrab                                #403d21

=item olive green                                       olivegreen                               #403d21

=item orange                                            orange                                   #d9603b

=item orange                                            orange                                   #e25822

=item orange                                            orange                                   #ed872d

=item orange yellow                                     orangeyellow                             #f6a600

=item orange yellow                                     orangeyellow                             #eaa221

=item oyster gray                                       oystergray                               #b9b8b5

=item peach                                             peach                                    #fad6a5

=item pea green                                         peagreen                                 #679267

=item pearl gray                                        pearlgray                                #c2b280

=item pearl gray                                        pearlgray                                #b9b8b5

=item pullman green                                     pullmangreen                             #2b3d26

=item pullman green                                     pullmangreen                             #403d21

=item pullman green                                     pullmangreen                             #5b5842

=item purple                                            purple                                   #86608e

=item red                                               red                                      #be0032

=item red                                               red                                      #be0032

=item red                                               red                                      #ab4e52

=item red boottopping                                   redboottopping                           #56070c

=item red deck                                          reddeck                                  #56070c

=item red lead                                          redlead                                  #d9603b

=item red lead and oil                                  redleadandoil                            #e25822

=item red lead modified                                 redleadmodified                          #aa381e

=item red oxide                                         redoxide                                 #56070c

=item red striping                                      redstriping                              #be0032

=item road and tire gray                                roadandtiregray                          #848482

=item royal blue                                        royalblue                                #00304e

=item sand                                              sand                                     #958070

=item sand                                              sand                                     #c2b280

=item sand                                              sand                                     #a18f60

=item sea blue                                          seablue                                  #202830

=item sea blue                                          seablue                                  #202830

=item sea blue                                          seablue                                  #51585e

=item sea blue                                          seablue                                  #51585e

=item sea gray                                          seagray                                  #555555

=item seal brown                                        sealbrown                                #6f4e37

=item slate                                             slate                                    #555555

=item soft yellow                                       softyellow                               #f8de7e

=item spring green                                      springgreen                              #8f9779

=item spruce green                                      sprucegreen                              #515744

=item suntan                                            suntan                                   #f3e5ab

=item terra cotta                                       terracotta                               #a87c6d

=item vermilion                                         vermilion                                #be0032

=item vineyard green                                    vineyardgreen                            #1a2421

=item vivid orange                                      vividorange                              #e25822

=item warm gray                                         warmgray                                 #c2b280

=item willow green                                      willowgreen                              #44944a

=item yellow                                            yellow                                   #f6a600

=item yellow                                            yellow                                   #eaa221

=item yellow                                            yellow                                   #f6a600

=item yellow striping                                   yellowstriping                           #f6a600

=item yellow striping                                   yellowstriping                           #eaa221

=item yellow tint                                       yellowtint                               #fad6a5

=item zinc chromate                                     zincchromate                             #8a9a5b

=item zinc yellow primer                                zincyellowprimer                         #c9ae5d


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-f:aircraftcream.90','aircraftcream','aircraft cream',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:aircraftgray.264','aircraftgray','aircraft gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-f:anticorrosivebrown.59','anticorrosivebrown','anti-corrosive brown',[66,37,24],'422518',4334872],
['nbs-iscc-f:anticorrosivegreen.108','anticorrosivegreen','anti-corrosive green',[64,61,33],'403d21',4209953],
['nbs-iscc-f:azureblue.199','azureblue','azure blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-f:battleshipgray.265','battleshipgray','battleship gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:black.267','black','black',[34,34,34],'222222',2236962],
['nbs-iscc-f:blackboottopping.267','blackboottopping','black boottopping',[34,34,34],'222222',2236962],
['nbs-iscc-f:blackdeck.267','blackdeck','black deck',[34,34,34],'222222',2236962],
['nbs-iscc-f:blue.182','blue','blue',[67,107,149],'436b95',4418453],
['nbs-iscc-f:bluedrab.156','bluedrab','blue drab',[78,87,85],'4e5755',5134165],
['nbs-iscc-f:bluegray.265','bluegray','blue gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:bluegreen.135','bluegreen','blue green',[147,197,146],'93c592',9684370],
['nbs-iscc-f:bluestriping.178','bluestriping','blue striping',[0,103,165],'0067a5',26533],
['nbs-iscc-f:bluetint.148','bluetint','blue tint',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-f:brightblue.178','brightblue','bright blue',[0,103,165],'0067a5',26533],
['nbs-iscc-f:brightgreen.145','brightgreen','bright green',[59,120,97],'3b7861',3897441],
['nbs-iscc-f:brilliantyellow.82','brilliantyellow','brilliant yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-f:brownstriping.41','brownstriping','brown striping',[86,7,12],'56070c',5637900],
['nbs-iscc-f:brownstriping.56','brownstriping','brown striping',[89,51,25],'593319',5845785],
['nbs-iscc-f:buff.71','buff','buff',[227,168,87],'e3a857',14919767],
['nbs-iscc-f:buff.76','buff','buff',[193,154,107],'c19a6b',12687979],
['nbs-iscc-f:buff.90','buff','buff',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:buff.53','buff','buff',[217,144,88],'d99058',14258264],
['nbs-iscc-f:buff.72','buff','buff',[190,138,61],'be8a3d',12487229],
['nbs-iscc-f:cameorose.73','cameorose','cameo rose',[250,214,165],'fad6a5',16438949],
['nbs-iscc-f:cameorose.28','cameorose','cameo rose',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-f:canaryyellow.86','canaryyellow','canary yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-f:canyonbrown.61','canyonbrown','canyon brown',[99,81,71],'635147',6508871],
['nbs-iscc-f:chromegreen.138','chromegreen','chrome green',[23,54,32],'173620',1521184],
['nbs-iscc-f:chromeyellow.66','chromeyellow','chrome yellow',[246,166,0],'f6a600',16164352],
['nbs-iscc-f:chromeyellow.68','chromeyellow','chrome yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-f:clearblue.173','clearblue','clear blue',[54,117,136],'367588',3569032],
['nbs-iscc-f:cream.90','cream','cream',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:creamstriping.86','creamstriping','cream striping',[248,222,126],'f8de7e',16309886],
['nbs-iscc-f:darkearth.80','darkearth','dark earth',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-f:darkearth.95','darkearth','dark earth',[108,84,30],'6c541e',7099422],
['nbs-iscc-f:darkgray.266','darkgray','dark gray',[85,85,85],'555555',5592405],
['nbs-iscc-f:darkgreen.137','darkgreen','dark green',[53,94,59],'355e3b',3497531],
['nbs-iscc-f:darkgreen.151','darkgreen','dark green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-f:darkgreendeck.151','darkgreendeck','dark green deck',[58,75,71],'3a4b47',3820359],
['nbs-iscc-f:darkgullgray.265','darkgullgray','dark gull gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:darkputty.113','darkputty','dark putty',[87,85,76],'57554c',5723468],
['nbs-iscc-f:darkredboottopping.62','darkredboottopping','dark red boottopping ',[62,50,44],'3e322c',4076076],
['nbs-iscc-f:darkzincyellowprimer.127','darkzincyellowprimer','dark zinc yellow primer',[81,87,68],'515744',5330756],
['nbs-iscc-f:deepnavygray.266','deepnavygray','deep navy gray',[85,85,85],'555555',5592405],
['nbs-iscc-f:deepreddishbrown.44','deepreddishbrown','deep reddish brown',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-f:desertsand.60','desertsand','desert sand',[149,128,112],'958070',9797744],
['nbs-iscc-f:desertsand.57','desertsand','desert sand',[166,123,91],'a67b5b',10910555],
['nbs-iscc-f:dullred.43','dullred','dull red',[121,68,59],'79443b',7947323],
['nbs-iscc-f:earthbrown.61','earthbrown','earth brown',[99,81,71],'635147',6508871],
['nbs-iscc-f:earthred.58','earthred','earth red ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-f:earthyellow.76','earthyellow','earth yellow',[193,154,107],'c19a6b',12687979],
['nbs-iscc-f:eggshell.89','eggshell','eggshell ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-f:eggshell.92','eggshell','eggshell ',[240,234,214],'f0ead6',15788758],
['nbs-iscc-f:enginegray.266','enginegray','engine gray',[85,85,85],'555555',5592405],
['nbs-iscc-f:enginegray.265','enginegray','engine gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:exteriorgreen14orexteriorgreennofourteen.126','exteriorgreen14orexteriorgreennofourteen','exterior green #14 or exterior green no. fourteen',[43,61,38],'2b3d26',2833702],
['nbs-iscc-f:exteriorgreen15orexteriorgreennofifteen.120','exteriorgreen15orexteriorgreennofifteen','exterior green #15 or exterior green no. fifteen',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-f:fielddrab.80','fielddrab','field drab',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-f:fielddrab.95','fielddrab','field drab',[108,84,30],'6c541e',7099422],
['nbs-iscc-f:firered.11','firered','fire red',[190,0,50],'be0032',12451890],
['nbs-iscc-f:flatcream.89','flatcream','flat cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-f:forestgreen.126','forestgreen','forest green',[43,61,38],'2b3d26',2833702],
['nbs-iscc-f:forestgreen.137','forestgreen','forest green',[53,94,59],'355e3b',3497531],
['nbs-iscc-f:glossblack.267','glossblack','gloss black',[34,34,34],'222222',2236962],
['nbs-iscc-f:governmentwallgreen.122','governmentwallgreen','government wall green',[143,151,121],'8f9779',9410425],
['nbs-iscc-f:gray.265','gray','gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:gray.90','gray','gray',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:gray.93','gray','gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-f:gray12.93','gray12','gray #12 ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-f:gray7.109','gray7','gray #7 ',[140,135,103],'8c8767',9209703],
['nbs-iscc-f:gray7.112','gray7','gray #7 ',[138,135,118],'8a8776',9078646],
['nbs-iscc-f:graydeck.266','graydeck','gray deck',[85,85,85],'555555',5592405],
['nbs-iscc-f:graydeck.265','graydeck','gray deck',[132,132,130],'848482',8684674],
['nbs-iscc-f:graytint.90','graytint','gray tint',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:graywood.265','graywood','gray wood',[132,132,130],'848482',8684674],
['nbs-iscc-f:green.137','green','green',[53,94,59],'355e3b',3497531],
['nbs-iscc-f:green.137','green','green',[53,94,59],'355e3b',3497531],
['nbs-iscc-f:green.147','green','green',[28,53,45],'1c352d',1848621],
['nbs-iscc-f:green.126','green','green',[43,61,38],'2b3d26',2833702],
['nbs-iscc-f:green.105','green','green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-f:green.108','green','green',[64,61,33],'403d21',4209953],
['nbs-iscc-f:green.145','green','green',[59,120,97],'3b7861',3897441],
['nbs-iscc-f:greenboottopping.137','greenboottopping','green boottopping',[53,94,59],'355e3b',3497531],
['nbs-iscc-f:greenstriping.137','greenstriping','green striping',[53,94,59],'355e3b',3497531],
['nbs-iscc-f:greentint.121','greentint','green tint',[218,223,183],'dadfb7',14344119],
['nbs-iscc-f:greenzincyellowprimer.120','greenzincyellowprimer','green zinc yellow primer',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-f:hazegray.265','hazegray','haze-gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:highlightbuff.90','highlightbuff','highlight buff',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:hospitalshipgreen.136','hospitalshipgreen','hospital ship green',[103,146,103],'679267',6787687],
['nbs-iscc-f:hullblack.267','hullblack','hull black',[34,34,34],'222222',2236962],
['nbs-iscc-f:hullgray.185','hullgray','hull gray',[145,163,176],'91a3b0',9544624],
['nbs-iscc-f:insigniablue.201','insigniablue','insignia blue',[37,36,64],'252440',2434112],
['nbs-iscc-f:insigniablue.187','insigniablue','insignia blue',[54,69,79],'36454f',3556687],
['nbs-iscc-f:insigniared.11','insigniared','insignia red',[190,0,50],'be0032',12451890],
['nbs-iscc-f:insigniared.15','insigniared','insignia red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-f:insigniawhite.263','insigniawhite','insignia white',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-f:instrumentblack.267','instrumentblack','instrument black',[34,34,34],'222222',2236962],
['nbs-iscc-f:interiorgreen.125','interiorgreen','interior green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-f:intermediateblue.186','intermediateblue','intermediate blue',[83,104,120],'536878',5466232],
['nbs-iscc-f:internationalorange.34','internationalorange','international orange',[226,88,34],'e25822',14833698],
['nbs-iscc-f:ivory.86','ivory','ivory',[248,222,126],'f8de7e',16309886],
['nbs-iscc-f:ivorycream.89','ivorycream','ivory cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-f:jet.267','jet','jet',[34,34,34],'222222',2236962],
['nbs-iscc-f:jetblack.267','jetblack','jet black',[34,34,34],'222222',2236962],
['nbs-iscc-f:lemonyellow.82','lemonyellow','lemon yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-f:lightblue.182','lightblue','light blue',[67,107,149],'436b95',4418453],
['nbs-iscc-f:lightblue.164','lightblue','light blue',[49,120,115],'317873',3242099],
['nbs-iscc-f:lightblue.173','lightblue','light blue',[54,117,136],'367588',3569032],
['nbs-iscc-f:lightblue.143','lightblue','light blue',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-f:lightblue.164','lightblue','light blue',[49,120,115],'317873',3242099],
['nbs-iscc-f:lightblue.173','lightblue','light blue',[54,117,136],'367588',3569032],
['nbs-iscc-f:lightblueenamel.183','lightblueenamel','light blue enamel',[0,48,78],'00304e',12366],
['nbs-iscc-f:lightbluelightblue5.148','lightbluelightblue5','light blue,, light blue 5',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-f:lightgray.264','lightgray','light gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-f:lightgray.89','lightgray','light gray',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-f:lightgray.90','lightgray','light gray',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:lightgray.265','lightgray','light gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:lightgray.264','lightgray','light gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-f:lightgrayboottopping.265','lightgrayboottopping','light gray boottopping',[132,132,130],'848482',8684674],
['nbs-iscc-f:lightgreen.131','lightgreen','light green',[68,148,74],'44944a',4494410],
['nbs-iscc-f:lightgreen.119','lightgreen','light green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-f:lightgreen.136','lightgreen','light green',[103,146,103],'679267',6787687],
['nbs-iscc-f:lightgreen.105','lightgreen','light green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-f:lightgreen.120','lightgreen','light green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-f:lightgreen.154','lightgreen','light green',[178,190,181],'b2beb5',11714229],
['nbs-iscc-f:lightgullgray.264','lightgullgray','light gull gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-f:lightivory.89','lightivory','light ivory',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-f:lightnavygray.265','lightnavygray','light navy gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:lightolive.109','lightolive','light olive',[140,135,103],'8c8767',9209703],
['nbs-iscc-f:lightredboottopping.41','lightredboottopping','light red boottopping ',[86,7,12],'56070c',5637900],
['nbs-iscc-f:lightyellow.82','lightyellow','light yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-f:lightyellow.86','lightyellow','light yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-f:loam.113','loam','loam',[87,85,76],'57554c',5723468],
['nbs-iscc-f:machinerygreen.150','machinerygreen','machinery green',[94,113,106],'5e716a',6189418],
['nbs-iscc-f:marinegreen.96','marinegreen','marine green',[59,49,33],'3b3121',3879201],
['nbs-iscc-f:maroon.41','maroon','maroon',[86,7,12],'56070c',5637900],
['nbs-iscc-f:maroon.46','maroon','maroon',[103,76,71],'674c47',6769735],
['nbs-iscc-f:mediumblue.186','mediumblue','medium blue',[83,104,120],'536878',5466232],
['nbs-iscc-f:mediumblue.182','mediumblue','medium blue',[67,107,149],'436b95',4418453],
['nbs-iscc-f:mediumgray.109','mediumgray','medium gray',[140,135,103],'8c8767',9209703],
['nbs-iscc-f:mediumgray.265','mediumgray','medium gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:mediumgray.112','mediumgray','medium gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-f:mediumgreen.151','mediumgreen','medium green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-f:mediumgreen.132','mediumgreen','medium green',[0,98,45],'00622d',25133],
['nbs-iscc-f:mediumgreen.150','mediumgreen','medium green',[94,113,106],'5e716a',6189418],
['nbs-iscc-f:mediumnavygray.265','mediumnavygray','medium navy gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:mediumtan.77','mediumtan','medium tan',[130,102,68],'826644',8545860],
['nbs-iscc-f:metallicbrown.41','metallicbrown','metallic brown ',[86,7,12],'56070c',5637900],
['nbs-iscc-f:metallicbrown.41','metallicbrown','metallic brown ',[86,7,12],'56070c',5637900],
['nbs-iscc-f:metallicbrown.56','metallicbrown','metallic brown ',[89,51,25],'593319',5845785],
['nbs-iscc-f:metallicred.41','metallicred','metallic red ',[86,7,12],'56070c',5637900],
['nbs-iscc-f:middlestone.94','middlestone','middle stone ',[150,113,23],'967117',9859351],
['nbs-iscc-f:middlestone.94','middlestone','middlestone ',[150,113,23],'967117',9859351],
['nbs-iscc-f:mosstone.120','mosstone','mosstone ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-f:nationalschoolbuschrome.66','nationalschoolbuschrome','national school bus chrome ',[246,166,0],'f6a600',16164352],
['nbs-iscc-f:navygray.266','navygray','navy gray',[85,85,85],'555555',5592405],
['nbs-iscc-f:oceangray.186','oceangray','ocean gray',[83,104,120],'536878',5466232],
['nbs-iscc-f:oceangray.265','oceangray','ocean gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:olivedrab.96','olivedrab','olive drab',[59,49,33],'3b3121',3879201],
['nbs-iscc-f:olivedrab.110','olivedrab','olive drab',[91,88,66],'5b5842',5986370],
['nbs-iscc-f:olivedrab.108','olivedrab','olive drab',[64,61,33],'403d21',4209953],
['nbs-iscc-f:olivegreen.108','olivegreen','olive green',[64,61,33],'403d21',4209953],
['nbs-iscc-f:orange.35','orange','orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-f:orange.34','orange','orange',[226,88,34],'e25822',14833698],
['nbs-iscc-f:orange.50','orange','orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-f:orangeyellow.66','orangeyellow','orange yellow',[246,166,0],'f6a600',16164352],
['nbs-iscc-f:orangeyellow.68','orangeyellow','orange yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-f:oystergray.264','oystergray','oyster gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-f:peach.73','peach','peach',[250,214,165],'fad6a5',16438949],
['nbs-iscc-f:peagreen.136','peagreen','pea green',[103,146,103],'679267',6787687],
['nbs-iscc-f:pearlgray.90','pearlgray','pearl gray',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:pearlgray.264','pearlgray','pearl gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-f:pullmangreen.126','pullmangreen','pullman green',[43,61,38],'2b3d26',2833702],
['nbs-iscc-f:pullmangreen.108','pullmangreen','pullman green',[64,61,33],'403d21',4209953],
['nbs-iscc-f:pullmangreen.110','pullmangreen','pullman green',[91,88,66],'5b5842',5986370],
['nbs-iscc-f:purple.223','purple','purple',[134,96,142],'86608e',8806542],
['nbs-iscc-f:red.11','red','red',[190,0,50],'be0032',12451890],
['nbs-iscc-f:red.11','red','red',[190,0,50],'be0032',12451890],
['nbs-iscc-f:red.15','red','red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-f:redboottopping.41','redboottopping','red boottopping',[86,7,12],'56070c',5637900],
['nbs-iscc-f:reddeck.41','reddeck','red deck',[86,7,12],'56070c',5637900],
['nbs-iscc-f:redlead.35','redlead','red lead',[217,96,59],'d9603b',14245947],
['nbs-iscc-f:redleadandoil.34','redleadandoil','red lead and oil',[226,88,34],'e25822',14833698],
['nbs-iscc-f:redleadmodified.36','redleadmodified','red lead modified',[170,56,30],'aa381e',11155486],
['nbs-iscc-f:redoxide.41','redoxide','red oxide',[86,7,12],'56070c',5637900],
['nbs-iscc-f:redstriping.11','redstriping','red striping',[190,0,50],'be0032',12451890],
['nbs-iscc-f:roadandtiregray.265','roadandtiregray','road and tire gray',[132,132,130],'848482',8684674],
['nbs-iscc-f:royalblue.183','royalblue','royal blue',[0,48,78],'00304e',12366],
['nbs-iscc-f:sand.60','sand','sand',[149,128,112],'958070',9797744],
['nbs-iscc-f:sand.90','sand','sand',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:sand.91','sand','sand',[161,143,96],'a18f60',10588000],
['nbs-iscc-f:seablue.188','seablue','sea blue',[32,40,48],'202830',2107440],
['nbs-iscc-f:seablue.188','seablue','sea blue',[32,40,48],'202830',2107440],
['nbs-iscc-f:seablue.192','seablue','sea blue',[81,88,94],'51585e',5331038],
['nbs-iscc-f:seablue.192','seablue','sea blue',[81,88,94],'51585e',5331038],
['nbs-iscc-f:seagray.266','seagray','sea gray',[85,85,85],'555555',5592405],
['nbs-iscc-f:sealbrown.58','sealbrown','seal brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-f:slate.266','slate','slate',[85,85,85],'555555',5592405],
['nbs-iscc-f:softyellow.86','softyellow','soft yellow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-f:springgreen.122','springgreen','spring green',[143,151,121],'8f9779',9410425],
['nbs-iscc-f:sprucegreen.127','sprucegreen','spruce green',[81,87,68],'515744',5330756],
['nbs-iscc-f:suntan.89','suntan','suntan',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-f:terracotta.42','terracotta','terra cotta',[168,124,109],'a87c6d',11041901],
['nbs-iscc-f:vermilion.11','vermilion','vermilion',[190,0,50],'be0032',12451890],
['nbs-iscc-f:vineyardgreen.152','vineyardgreen','vineyard green ',[26,36,33],'1a2421',1713185],
['nbs-iscc-f:vividorange.34','vividorange','vivid orange',[226,88,34],'e25822',14833698],
['nbs-iscc-f:warmgray.90','warmgray','warm gray ',[194,178,128],'c2b280',12759680],
['nbs-iscc-f:willowgreen.131','willowgreen','willow green',[68,148,74],'44944a',4494410],
['nbs-iscc-f:yellow.66','yellow','yellow',[246,166,0],'f6a600',16164352],
['nbs-iscc-f:yellow.68','yellow','yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-f:yellow.66','yellow','yellow',[246,166,0],'f6a600',16164352],
['nbs-iscc-f:yellowstriping.66','yellowstriping','yellow striping',[246,166,0],'f6a600',16164352],
['nbs-iscc-f:yellowstriping.68','yellowstriping','yellow striping',[234,162,33],'eaa221',15376929],
['nbs-iscc-f:yellowtint.73','yellowtint','yellow tint',[250,214,165],'fad6a5',16438949],
['nbs-iscc-f:zincchromate.120','zincchromate','zinc chromate',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-f:zincyellowprimer.87','zincyellowprimer','zinc yellow primer ',[201,174,93],'c9ae5d',13217373]
    ];
}

sub _description {
    return {
          'subtitle' => 'Colors; (for) Ready-Mixed Paints',
          'title' => 'NBS/ISCC F',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (F) Colors; (for) Ready-Mixed Paints

        Federal Specification TT-C-595,
        Colors; (for) Ready-Mixed Paints 

    This dictionary is a hybrid of combinatorial and idiosyncratic terms. 134 names map to 174 colors, using only 73 out of 267 centroids.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#F]
'
        }

}

1;
