package Color::Library::Dictionary::NBS_ISCC::H;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::H;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::H - (NBS/ISCC H) Horticultural Colour Charts

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (H) Horticultural Colour Charts

        Horticultural Colour Charts,
        R. F. Wilson 

    Most names are of plants or flowers. 199 names map to 261 colors, using only 95 of 267 centroids.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#H>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>aconite violet</td><td>aconiteviolet</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>agathia green</td><td>agathiagreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>agathia green</td><td>agathiagreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>amaranth rose</td><td>amaranthrose</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>amber yellow</td><td>amberyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>amber yellow</td><td>amberyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>amethyst violet</td><td>amethystviolet</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>apricot</td><td>apricot</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>aster violet</td><td>asterviolet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>aureolin</td><td>aureolin</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>azalea pink</td><td>azaleapink</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>azalea pink</td><td>azaleapink</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>barium yellow</td><td>bariumyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>beetroot purple</td><td>beetrootpurple</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#54133b;width:4em;" /><td>beetroot purple</td><td>beetrootpurple</td><td>##54133b</td><td>84</td> <td>19</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>begonia</td><td>begonia</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>bishop's violet</td><td>bishopsviolet</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>blood red</td><td>bloodred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>bluebird blue</td><td>bluebirdblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>bluebird blue</td><td>bluebirdblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>bluebird blue</td><td>bluebirdblue</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>bluebird blue</td><td>bluebirdblue</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>brick red</td><td>brickred</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>burnt orange</td><td>burntorange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>buttercup yellow</td><td>buttercupyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>butterfly blue</td><td>butterflyblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>butterfly blue</td><td>butterflyblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>cadmium orange</td><td>cadmiumorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fd943f;width:4em;" /><td>cadmium orange</td><td>cadmiumorange</td><td>##fd943f</td><td>253</td> <td>148</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>cadmium orange</td><td>cadmiumorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>camelia rose</td><td>cameliarose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>campanula violet</td><td>campanulaviolet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>canary yellow</td><td>canaryyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>capri blue </td><td>capriblue</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>capri blue </td><td>capriblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>capsicum red</td><td>capsicumred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>cardinal red</td><td>cardinalred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carmine</td><td>carmine</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb5ba;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##ffb5ba</td><td>255</td> <td>181</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>carnation green</td><td>carnationgreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>carrot red</td><td>carrotred</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>carrot red</td><td>carrotred</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>cerulein Blue </td><td>ceruleinblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>chartreuse green</td><td>chartreusegreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>cherry</td><td>cherry</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>china rose</td><td>chinarose</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>chinese coral</td><td>chinesecoral</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>chinese coral</td><td>chinesecoral</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>chinese yellow</td><td>chineseyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>chrysanthemum crimson</td><td>chrysanthemumcrimson</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>chrysocolla green</td><td>chrysocollagreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>chrysocolla green</td><td>chrysocollagreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>citron green</td><td>citrongreen</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>citron green</td><td>citrongreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>claret rose</td><td>claretrose</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>cobalt blue</td><td>cobaltblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>cobalt violet</td><td>cobaltviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>coral pink</td><td>coralpink</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>cornflower blue</td><td>cornflowerblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>crimson</td><td>crimson</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>crimson</td><td>crimson</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>currant red</td><td>currantred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>cyclamen purple</td><td>cyclamenpurple</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>cypress green</td><td>cypressgreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dahlia purple</td><td>dahliapurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#38152c;width:4em;" /><td>dahlia purple</td><td>dahliapurple</td><td>##38152c</td><td>56</td> <td>21</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dauphin's violet</td><td>dauphinsviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb5ba;width:4em;" /><td>dawn pink</td><td>dawnpink</td><td>##ffb5ba</td><td>255</td> <td>181</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>delft rose</td><td>delftrose</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>dianthus purple</td><td>dianthuspurple</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>doge purple</td><td>dogepurple</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>dresden yellow</td><td>dresdenyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>dutch vermilion</td><td>dutchvermilion</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>egyptian buff</td><td>egyptianbuff</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>egyptian buff</td><td>egyptianbuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>emerald green</td><td>emeraldgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>empire rose</td><td>empirerose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>empire yellow</td><td>empireyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>enamel blue</td><td>enamelblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>erythrite red</td><td>erythritered</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>ethyl blue</td><td>ethylblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>faence blue </td><td>faenceblue</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>fern green</td><td>ferngreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>fire red</td><td>firered</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>flax blue</td><td>flaxblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>flax blue</td><td>flaxblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>flax blue</td><td>flaxblue</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>french blue</td><td>frenchblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>french rose </td><td>frenchrose</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>fuchsia purple</td><td>fuchsiapurple</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>fuchsine pink</td><td>fuchsinepink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>garnet brown</td><td>garnetbrown</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>garnet lake</td><td>garnetlake</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>gentian blue</td><td>gentianblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>geranium lake</td><td>geraniumlake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>heliotrope</td><td>heliotrope</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>hyacinth blue</td><td>hyacinthblue</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>imperial purple</td><td>imperialpurple</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>indian blue</td><td>indianblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>indian lake</td><td>indianlake</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>indian orange</td><td>indianorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>indian yellow</td><td>indianyellow</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>indian yellow</td><td>indianyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#31362b;width:4em;" /><td>ivy green</td><td>ivygreen</td><td>##31362b</td><td>49</td> <td>54</td> <td>43</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>jade green</td><td>jadegreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>jasper red</td><td>jasperred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>kingfisher blue</td><td>kingfisherblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>langite green</td><td>langitegreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>lavender green</td><td>lavendergreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>leek green</td><td>leekgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>leek green</td><td>leekgreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>lettuce green</td><td>lettucegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>light chrome yellow</td><td>lightchromeyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>lilac purple</td><td>lilacpurple</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>lobelia blue</td><td>lobeliablue</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>magenta</td><td>magenta</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>magenta rose </td><td>magentarose</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>magnolia purple</td><td>magnoliapurple</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>maize yellow</td><td>maizeyellow</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>maize yellow</td><td>maizeyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>maize yellow</td><td>maizeyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>maize yellow</td><td>maizeyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>maize yellow</td><td>maizeyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>maize yellow</td><td>maizeyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>majolica yellow</td><td>majolicayellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>majolica yellow</td><td>majolicayellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>majolica yellow</td><td>majolicayellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>majolica yellow</td><td>majolicayellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>mallow purple</td><td>mallowpurple</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>mandarin red</td><td>mandarinred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>marigold orange</td><td>marigoldorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>marigold orange</td><td>marigoldorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>marigold orange</td><td>marigoldorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>maroon</td><td>maroon</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>mars orange</td><td>marsorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#d399e6;width:4em;" /><td>mauve</td><td>mauve</td><td>##d399e6</td><td>211</td> <td>153</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>mauve</td><td>mauve</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>mauvette</td><td>mauvette</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>mauvette</td><td>mauvette</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>methyl violet </td><td>methylviolet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>mimeosa yellow </td><td>mimeosayellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>mineral violet </td><td>mineralviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>moorish blue </td><td>moorishblue</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>naples yellow </td><td>naplesyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>naples yellow </td><td>naplesyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>nasturtium orange</td><td>nasturtiumorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>nasturtium red</td><td>nasturtiumred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>neyron rose </td><td>neyronrose</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>nickel green</td><td>nickelgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>orange</td><td>orange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>orange buff</td><td>orangebuff</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>orange buff</td><td>orangebuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>orange buff</td><td>orangebuff</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>orange buff</td><td>orangebuff</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>orange buff</td><td>orangebuff</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>orange buff</td><td>orangebuff</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>orchid purple</td><td>orchidpurple</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>oriental blue</td><td>orientalblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>orient pink</td><td>orientpink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>orient pink</td><td>orientpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>orient red</td><td>orientred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>orpiment orange</td><td>orpimentorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orpiment orange</td><td>orpimentorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>oxblood red</td><td>oxbloodred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>pansy purple</td><td>pansypurple</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>pansy purple</td><td>pansypurple</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>pansy violet</td><td>pansyviolet</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>paris green</td><td>parisgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>parsley green</td><td>parsleygreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>pastel lavender</td><td>pastellavender</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>pastel lilac</td><td>pastellilac</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pastel mauve</td><td>pastelmauve</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>peach</td><td>peach</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>peach</td><td>peach</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>peach</td><td>peach</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>pea green</td><td>peagreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>peony purple</td><td>peonypurple</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>persian blue</td><td>persianblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>persian rose</td><td>persianrose</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>persian rose</td><td>persianrose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>persimmon orange</td><td>persimmonorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>persimmon orange</td><td>persimmonorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>petunia purple</td><td>petuniapurple</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>petunia purple</td><td>petuniapurple</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>phlox pink</td><td>phloxpink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>phlox purple</td><td>phloxpurple</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#301934;width:4em;" /><td>plum purple</td><td>plumpurple</td><td>##301934</td><td>48</td> <td>25</td> <td>52</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>pod green</td><td>podgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>poppy red</td><td>poppyred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>porcelain blue</td><td>porcelainblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>porcelain rose</td><td>porcelainrose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>porcelain rose</td><td>porcelainrose</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd300;width:4em;" /><td>primrose yellow</td><td>primroseyellow</td><td>##dcd300</td><td>220</td> <td>211</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>princess blue</td><td>princessblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>purple madder</td><td>purplemadder</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>rhodamine pink</td><td>rhodaminepink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rhodamine purple</td><td>rhodaminepurple</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rhodonite red</td><td>rhodonitered</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rose bengal</td><td>rosebengal</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>roseine purple</td><td>roseinepurple</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rose madder</td><td>rosemadder</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>rose opal</td><td>roseopal</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>rose pink</td><td>rosepink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>rose pink</td><td>rosepink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>rose purple</td><td>rosepurple</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>rose red</td><td>rosered</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>royal purple</td><td>royalpurple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>ruby red</td><td>rubyred</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>saffron yellow</td><td>saffronyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>sage green</td><td>sagegreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>sage green</td><td>sagegreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>salmon</td><td>salmon</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>salmon</td><td>salmon</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#8db600;width:4em;" /><td>sap green</td><td>sapgreen</td><td>##8db600</td><td>141</td> <td>182</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>sap green</td><td>sapgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>saturn red</td><td>saturnred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>scheeles green </td><td>scheelesgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>sea blue</td><td>seablue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>sea lavender violet</td><td>sealavenderviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>shell pink</td><td>shellpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>shrimp red</td><td>shrimpred</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>signal red</td><td>signalred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>solferino purple</td><td>solferinopurple</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>spanish orange</td><td>spanishorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>spectrum blue</td><td>spectrumblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#401a4c;width:4em;" /><td>spectrum violet</td><td>spectrumviolet</td><td>##401a4c</td><td>64</td> <td>26</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>spinach green</td><td>spinachgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>spinach green</td><td>spinachgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>spinel pink</td><td>spinelpink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>spinel red</td><td>spinelred</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>spiraea red</td><td>spiraeared</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>straw yellow</td><td>strawyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>sulphur yellow</td><td>sulphuryellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd300;width:4em;" /><td>sulphur yellow</td><td>sulphuryellow</td><td>##dcd300</td><td>220</td> <td>211</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>sung green</td><td>sunggreen</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>tangerine orange</td><td>tangerineorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>tangerine orange</td><td>tangerineorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>turkey red</td><td>turkeyred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>tyrian purple</td><td>tyrianpurple</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>tyrian rose</td><td>tyrianrose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>uranium green </td><td>uraniumgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>venetian pink</td><td>venetianpink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>verdigris</td><td>verdigris</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>veronese green</td><td>veronesegreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>veronese green</td><td>veronesegreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>veronica violet</td><td>veronicaviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#32174d;width:4em;" /><td>victoria violet</td><td>victoriaviolet</td><td>##32174d</td><td>50</td> <td>23</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>violet</td><td>violet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>violet purple</td><td>violetpurple</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>viridian green</td><td>viridiangreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>viridian green</td><td>viridiangreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>willow green</td><td>willowgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>willow green</td><td>willowgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>wisteria blue</td><td>wisteriablue</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>yellow ochre</td><td>yellowochre</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow ochre</td><td>yellowochre</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item aconite violet        aconiteviolet        #2f2140

=item agathia green         agathiagreen         #7e9f2e

=item agathia green         agathiagreen         #44944a

=item amaranth rose         amaranthrose         #e68fac

=item amber yellow          amberyellow          #fada5e

=item amber yellow          amberyellow          #f8de7e

=item amethyst violet       amethystviolet       #9a4eae

=item apricot               apricot              #eaa221

=item aster violet          asterviolet          #9065ca

=item aureolin              aureolin             #f3c300

=item azalea pink           azaleapink           #ffb7a5

=item azalea pink           azaleapink           #e66761

=item barium yellow         bariumyellow         #fada5e

=item beetroot purple       beetrootpurple       #78184a

=item beetroot purple       beetrootpurple       #54133b

=item begonia               begonia              #e66761

=item bishop's violet       bishopsviolet        #9a4eae

=item blood red             bloodred             #be0032

=item bluebird blue         bluebirdblue         #545aa7

=item bluebird blue         bluebirdblue         #4e5180

=item bluebird blue         bluebirdblue         #604e97

=item bluebird blue         bluebirdblue         #604e81

=item brick red             brickred             #d9603b

=item burnt orange          burntorange          #d9603b

=item buttercup yellow      buttercupyellow      #f3c300

=item butterfly blue        butterflyblue        #4997d0

=item butterfly blue        butterflyblue        #0067a5

=item cadmium orange        cadmiumorange        #f38400

=item cadmium orange        cadmiumorange        #fd943f

=item cadmium orange        cadmiumorange        #ed872d

=item camelia rose          cameliarose          #e4717a

=item campanula violet      campanulaviolet      #9065ca

=item canary yellow         canaryyellow         #f3c300

=item capri blue            capriblue            #007a74

=item capri blue            capriblue            #007791

=item capsicum red          capsicumred          #e25822

=item cardinal red          cardinalred          #be0032

=item carmine               carmine              #be0032

=item carmine rose          carminerose          #ffb5ba

=item carmine rose          carminerose          #e4717a

=item carnation green       carnationgreen       #7d8984

=item carrot red            carrotred            #ed872d

=item carrot red            carrotred            #d99058

=item cerulein Blue         ceruleinblue         #0067a5

=item chartreuse green      chartreusegreen      #bdda57

=item cherry                cherry               #be0032

=item china rose            chinarose            #b3446c

=item chinese coral         chinesecoral         #f88379

=item chinese coral         chinesecoral         #cb6d51

=item chinese yellow        chineseyellow        #fada5e

=item chrysanthemum crimson chrysanthemumcrimson #841b2d

=item chrysocolla green     chrysocollagreen     #3eb489

=item chrysocolla green     chrysocollagreen     #007959

=item citron green          citrongreen          #beb72e

=item citron green          citrongreen          #b9b459

=item claret rose           claretrose           #bc3f4a

=item cobalt blue           cobaltblue           #00a1c2

=item cobalt violet         cobaltviolet         #875692

=item coral pink            coralpink            #e66761

=item cornflower blue       cornflowerblue       #30267a

=item crimson               crimson              #be0032

=item crimson               crimson              #ce4676

=item currant red           currantred           #be0032

=item cyclamen purple       cyclamenpurple       #870074

=item cypress green         cypressgreen         #83d37d

=item dahlia purple         dahliapurple         #673147

=item dahlia purple         dahliapurple         #38152c

=item dauphin's violet      dauphinsviolet       #604e81

=item dawn pink             dawnpink             #ffb5ba

=item delft rose            delftrose            #bc3f4a

=item dianthus purple       dianthuspurple       #ce4676

=item doge purple           dogepurple           #702963

=item dresden yellow        dresdenyellow        #e9e450

=item dutch vermilion       dutchvermilion       #e25822

=item egyptian buff         egyptianbuff         #fbc97f

=item egyptian buff         egyptianbuff         #fad6a5

=item emerald green         emeraldgreen         #44944a

=item empire rose           empirerose           #e4717a

=item empire yellow         empireyellow         #f3c300

=item enamel blue           enamelblue           #00a1c2

=item erythrite red         erythritered         #a8516e

=item ethyl blue            ethylblue            #66aabc

=item faence blue          faenceblue           #239eba

=item fern green            ferngreen            #7e9f2e

=item fire red              firered              #e25822

=item flax blue             flaxblue             #6c79b8

=item flax blue             flaxblue             #545aa7

=item flax blue             flaxblue             #7e73b8

=item french blue           frenchblue           #30267a

=item french rose           frenchrose           #f88379

=item fuchsia purple        fuchsiapurple        #ce4676

=item fuchsine pink         fuchsinepink         #de6fa1

=item garnet brown          garnetbrown          #722f37

=item garnet lake           garnetlake           #78184a

=item gentian blue          gentianblue          #30267a

=item geranium lake         geraniumlake         #be0032

=item heliotrope            heliotrope           #7e73b8

=item hyacinth blue         hyacinthblue         #9065ca

=item imperial purple       imperialpurple       #875692

=item indian blue           indianblue           #007791

=item indian lake           indianlake           #841b2d

=item indian orange         indianorange         #e25822

=item indian yellow         indianyellow         #ffc14f

=item indian yellow         indianyellow         #fbc97f

=item ivy green             ivygreen             #31362b

=item jade green            jadegreen            #007a74

=item jasper red            jasperred            #bc3f4a

=item kingfisher blue       kingfisherblue       #007791

=item langite green         langitegreen         #007a74

=item lavender green        lavendergreen        #8f9779

=item leek green            leekgreen            #4a5d23

=item leek green            leekgreen            #515744

=item lemon yellow          lemonyellow          #f3c300

=item lettuce green         lettucegreen         #7e9f2e

=item light chrome yellow   lightchromeyellow    #f3c300

=item lilac purple          lilacpurple          #a8516e

=item lobelia blue          lobeliablue          #9065ca

=item magenta               magenta              #ce4676

=item magenta rose          magentarose          #b3446c

=item magnolia purple       magnoliapurple       #a8516e

=item maize yellow          maizeyellow          #ffc14f

=item maize yellow          maizeyellow          #eaa221

=item maize yellow          maizeyellow          #fbc97f

=item maize yellow          maizeyellow          #e3a857

=item maize yellow          maizeyellow          #fada5e

=item maize yellow          maizeyellow          #d4af37

=item majolica yellow       majolicayellow       #ed872d

=item majolica yellow       majolicayellow       #d99058

=item majolica yellow       majolicayellow       #eaa221

=item majolica yellow       majolicayellow       #e3a857

=item mallow purple         mallowpurple         #870074

=item mandarin red          mandarinred          #e25822

=item marigold orange       marigoldorange       #e25822

=item marigold orange       marigoldorange       #f38400

=item marigold orange       marigoldorange       #ed872d

=item maroon                maroon               #3f1728

=item mars orange           marsorange           #cb6d51

=item mauve                 mauve                #d399e6

=item mauve                 mauve                #875692

=item mauvette              mauvette             #8c82b6

=item mauvette              mauvette             #9690ab

=item methyl violet         methylviolet         #9065ca

=item mimeosa yellow        mimeosayellow        #e9e450

=item mineral violet        mineralviolet        #875692

=item moorish blue          moorishblue          #9065ca

=item naples yellow         naplesyellow         #fada5e

=item naples yellow         naplesyellow         #f8de7e

=item nasturtium orange     nasturtiumorange     #ed872d

=item nasturtium red        nasturtiumred        #e25822

=item neyron rose           neyronrose           #de6fa1

=item nickel green          nickelgreen          #3eb489

=item orange                orange               #e25822

=item orange buff           orangebuff           #fbc97f

=item orange buff           orangebuff           #e3a857

=item orange buff           orangebuff           #fada5e

=item orange buff           orangebuff           #d4af37

=item orange buff           orangebuff           #f8de7e

=item orange buff           orangebuff           #c9ae5d

=item orchid purple         orchidpurple         #870074

=item oriental blue         orientalblue         #00a1c2

=item orient pink           orientpink           #f4c2c2

=item orient pink           orientpink           #d9a6a9

=item orient red            orientred            #be0032

=item orpiment orange       orpimentorange       #f38400

=item orpiment orange       orpimentorange       #ed872d

=item oxblood red           oxbloodred           #722f37

=item pansy purple          pansypurple          #841b2d

=item pansy purple          pansypurple          #78184a

=item pansy violet          pansyviolet          #915c83

=item paris green           parisgreen           #44944a

=item parsley green         parsleygreen         #4a5d23

=item pastel lavender       pastellavender       #d6cadd

=item pastel lilac          pastellilac          #d6cadd

=item pastel mauve          pastelmauve          #e8ccd7

=item peach                 peach                #f4c2c2

=item peach                 peach                #d9a6a9

=item peach                 peach                #fab57f

=item pea green             peagreen             #bdda57

=item peony purple          peonypurple          #ce4676

=item persian blue          persianblue          #0067a5

=item persian rose          persianrose          #870074

=item persian rose          persianrose          #ce4676

=item persimmon orange      persimmonorange      #f38400

=item persimmon orange      persimmonorange      #ed872d

=item petunia purple        petuniapurple        #9a4eae

=item petunia purple        petuniapurple        #870074

=item phlox pink            phloxpink            #de6fa1

=item phlox purple          phloxpurple          #870074

=item plum purple           plumpurple           #301934

=item pod green             podgreen             #8a9a5b

=item poppy red             poppyred             #e25822

=item porcelain blue        porcelainblue        #007791

=item porcelain rose        porcelainrose        #e4717a

=item porcelain rose        porcelainrose        #e66761

=item primrose yellow       primroseyellow       #dcd300

=item princess blue         princessblue         #00416a

=item purple madder         purplemadder         #722f37

=item rhodamine pink        rhodaminepink        #e68fac

=item rhodamine purple      rhodaminepurple      #ce4676

=item rhodonite red         rhodonitered         #ab4e52

=item rose bengal           rosebengal           #ce4676

=item roseine purple        roseinepurple        #870074

=item rose madder           rosemadder           #ce4676

=item rose opal             roseopal             #bc3f4a

=item rose pink             rosepink             #ea9399

=item rose pink             rosepink             #efbbcc

=item rose purple           rosepurple           #b695c0

=item rose red              rosered              #be0032

=item royal purple          royalpurple          #602f6b

=item ruby red              rubyred              #841b2d

=item saffron yellow        saffronyellow        #eaa221

=item sage green            sagegreen            #4a5d23

=item sage green            sagegreen            #515744

=item salmon                salmon               #f4c2c2

=item salmon                salmon               #fab57f

=item sap green             sapgreen             #8db600

=item sap green             sapgreen             #bdda57

=item saturn red            saturnred            #e25822

=item scarlet               scarlet              #be0032

=item scheeles green        scheelesgreen        #7e9f2e

=item sea blue              seablue              #545aa7

=item sea lavender violet   sealavenderviolet    #7e73b8

=item shell pink            shellpink            #f88379

=item shrimp red            shrimpred            #f88379

=item signal red            signalred            #be0032

=item solferino purple      solferinopurple      #ce4676

=item spanish orange        spanishorange        #ed872d

=item spectrum blue         spectrumblue         #00a1c2

=item spectrum violet       spectrumviolet       #401a4c

=item spinach green         spinachgreen         #4a5d23

=item spinach green         spinachgreen         #355e3b

=item spinel pink           spinelpink           #e4717a

=item spinel red            spinelred            #b3446c

=item spiraea red           spiraeared           #ce4676

=item straw yellow          strawyellow          #fada5e

=item sulphur yellow        sulphuryellow        #f3c300

=item sulphur yellow        sulphuryellow        #dcd300

=item sung green            sunggreen            #b2beb5

=item tangerine orange      tangerineorange      #f38400

=item tangerine orange      tangerineorange      #ed872d

=item turkey red            turkeyred            #be0032

=item tyrian purple         tyrianpurple         #ce4676

=item tyrian rose           tyrianrose           #ce4676

=item uranium green         uraniumgreen         #bdda57

=item venetian pink         venetianpink         #f9ccca

=item verdigris             verdigris            #6aab8e

=item vermilion             vermilion            #be0032

=item vermilion             vermilion            #e25822

=item veronese green        veronesegreen        #bdda57

=item veronese green        veronesegreen        #83d37d

=item veronica violet       veronicaviolet       #7e73b8

=item victoria violet       victoriaviolet       #32174d

=item violet                violet               #9065ca

=item violet purple         violetpurple         #702963

=item viridian green        viridiangreen        #3eb489

=item viridian green        viridiangreen        #007959

=item willow green          willowgreen          #8a9a5b

=item willow green          willowgreen          #8f9779

=item wisteria blue         wisteriablue         #7e73b8

=item yellow ochre          yellowochre          #eaa221

=item yellow ochre          yellowochre          #e3a857


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-h:aconiteviolet.212','aconiteviolet','aconite violet',[47,33,64],'2f2140',3088704],
['nbs-iscc-h:agathiagreen.117','agathiagreen','agathia green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-h:agathiagreen.131','agathiagreen','agathia green',[68,148,74],'44944a',4494410],
['nbs-iscc-h:amaranthrose.247','amaranthrose','amaranth rose',[230,143,172],'e68fac',15110060],
['nbs-iscc-h:amberyellow.83','amberyellow','amber yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-h:amberyellow.86','amberyellow','amber yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-h:amethystviolet.216','amethystviolet','amethyst violet',[154,78,174],'9a4eae',10112686],
['nbs-iscc-h:apricot.68','apricot','apricot',[234,162,33],'eaa221',15376929],
['nbs-iscc-h:asterviolet.205','asterviolet','aster violet',[144,101,202],'9065ca',9463242],
['nbs-iscc-h:aureolin.82','aureolin','aureolin',[243,195,0],'f3c300',15975168],
['nbs-iscc-h:azaleapink.25','azaleapink','azalea pink',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-h:azaleapink.27','azaleapink','azalea pink',[230,103,97],'e66761',15099745],
['nbs-iscc-h:bariumyellow.83','bariumyellow','barium yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-h:beetrootpurple.256','beetrootpurple','beetroot purple',[120,24,74],'78184a',7870538],
['nbs-iscc-h:beetrootpurple.257','beetrootpurple','beetroot purple',[84,19,59],'54133b',5509947],
['nbs-iscc-h:begonia.27','begonia','begonia',[230,103,97],'e66761',15099745],
['nbs-iscc-h:bishopsviolet.216','bishopsviolet','bishop\'s violet',[154,78,174],'9a4eae',10112686],
['nbs-iscc-h:bloodred.11','bloodred','blood red',[190,0,50],'be0032',12451890],
['nbs-iscc-h:bluebirdblue.196','bluebirdblue','bluebird blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-h:bluebirdblue.200','bluebirdblue','bluebird blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-h:bluebirdblue.207','bluebirdblue','bluebird blue',[96,78,151],'604e97',6311575],
['nbs-iscc-h:bluebirdblue.211','bluebirdblue','bluebird blue',[96,78,129],'604e81',6311553],
['nbs-iscc-h:brickred.35','brickred','brick red',[217,96,59],'d9603b',14245947],
['nbs-iscc-h:burntorange.35','burntorange','burnt orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-h:buttercupyellow.82','buttercupyellow','buttercup yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-h:butterflyblue.177','butterflyblue','butterfly blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-h:butterflyblue.178','butterflyblue','butterfly blue',[0,103,165],'0067a5',26533],
['nbs-iscc-h:cadmiumorange.48','cadmiumorange','cadmium orange',[243,132,0],'f38400',15959040],
['nbs-iscc-h:cadmiumorange.49','cadmiumorange','cadmium orange',[253,148,63],'fd943f',16618559],
['nbs-iscc-h:cadmiumorange.50','cadmiumorange','cadmium orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:cameliarose.3','cameliarose','camelia rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-h:campanulaviolet.205','campanulaviolet','campanula violet',[144,101,202],'9065ca',9463242],
['nbs-iscc-h:canaryyellow.82','canaryyellow','canary yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-h:capriblue.160','capriblue','capri blue ',[0,122,116],'007a74',31348],
['nbs-iscc-h:capriblue.169','capriblue','capri blue ',[0,119,145],'007791',30609],
['nbs-iscc-h:capsicumred.34','capsicumred','capsicum red',[226,88,34],'e25822',14833698],
['nbs-iscc-h:cardinalred.11','cardinalred','cardinal red',[190,0,50],'be0032',12451890],
['nbs-iscc-h:carmine.11','carmine','carmine',[190,0,50],'be0032',12451890],
['nbs-iscc-h:carminerose.1','carminerose','carmine rose',[255,181,186],'ffb5ba',16758202],
['nbs-iscc-h:carminerose.3','carminerose','carmine rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-h:carnationgreen.155','carnationgreen','carnation green',[125,137,132],'7d8984',8227204],
['nbs-iscc-h:carrotred.50','carrotred','carrot red',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:carrotred.53','carrotred','carrot red',[217,144,88],'d99058',14258264],
['nbs-iscc-h:ceruleinblue.178','ceruleinblue','cerulein Blue ',[0,103,165],'0067a5',26533],
['nbs-iscc-h:chartreusegreen.116','chartreusegreen','chartreuse green',[189,218,87],'bdda57',12442199],
['nbs-iscc-h:cherry.11','cherry','cherry',[190,0,50],'be0032',12451890],
['nbs-iscc-h:chinarose.255','chinarose','china rose',[179,68,108],'b3446c',11748460],
['nbs-iscc-h:chinesecoral.26','chinesecoral','chinese coral',[248,131,121],'f88379',16286585],
['nbs-iscc-h:chinesecoral.37','chinesecoral','chinese coral',[203,109,81],'cb6d51',13331793],
['nbs-iscc-h:chineseyellow.83','chineseyellow','chinese yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-h:chrysanthemumcrimson.13','chrysanthemumcrimson','chrysanthemum crimson',[132,27,45],'841b2d',8657709],
['nbs-iscc-h:chrysocollagreen.140','chrysocollagreen','chrysocolla green',[62,180,137],'3eb489',4109449],
['nbs-iscc-h:chrysocollagreen.141','chrysocollagreen','chrysocolla green',[0,121,89],'007959',31065],
['nbs-iscc-h:citrongreen.99','citrongreen','citron green',[190,183,46],'beb72e',12498734],
['nbs-iscc-h:citrongreen.102','citrongreen','citron green',[185,180,89],'b9b459',12170329],
['nbs-iscc-h:claretrose.12','claretrose','claret rose',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-h:cobaltblue.176','cobaltblue','cobalt blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-h:cobaltviolet.218','cobaltviolet','cobalt violet',[135,86,146],'875692',8869522],
['nbs-iscc-h:coralpink.27','coralpink','coral pink',[230,103,97],'e66761',15099745],
['nbs-iscc-h:cornflowerblue.194','cornflowerblue','cornflower blue',[48,38,122],'30267a',3155578],
['nbs-iscc-h:crimson.11','crimson','crimson',[190,0,50],'be0032',12451890],
['nbs-iscc-h:crimson.254','crimson','crimson',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:currantred.11','currantred','currant red',[190,0,50],'be0032',12451890],
['nbs-iscc-h:cyclamenpurple.236','cyclamenpurple','cyclamen purple',[135,0,116],'870074',8847476],
['nbs-iscc-h:cypressgreen.130','cypressgreen','cypress green',[131,211,125],'83d37d',8639357],
['nbs-iscc-h:dahliapurple.259','dahliapurple','dahlia purple',[103,49,71],'673147',6762823],
['nbs-iscc-h:dahliapurple.260','dahliapurple','dahlia purple',[56,21,44],'38152c',3675436],
['nbs-iscc-h:dauphinsviolet.211','dauphinsviolet','dauphin\'s violet',[96,78,129],'604e81',6311553],
['nbs-iscc-h:dawnpink.1','dawnpink','dawn pink',[255,181,186],'ffb5ba',16758202],
['nbs-iscc-h:delftrose.12','delftrose','delft rose',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-h:dianthuspurple.254','dianthuspurple','dianthus purple',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:dogepurple.238','dogepurple','doge purple',[112,41,99],'702963',7350627],
['nbs-iscc-h:dresdenyellow.98','dresdenyellow','dresden yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-h:dutchvermilion.34','dutchvermilion','dutch vermilion',[226,88,34],'e25822',14833698],
['nbs-iscc-h:egyptianbuff.70','egyptianbuff','egyptian buff',[251,201,127],'fbc97f',16501119],
['nbs-iscc-h:egyptianbuff.73','egyptianbuff','egyptian buff',[250,214,165],'fad6a5',16438949],
['nbs-iscc-h:emeraldgreen.131','emeraldgreen','emerald green',[68,148,74],'44944a',4494410],
['nbs-iscc-h:empirerose.3','empirerose','empire rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-h:empireyellow.82','empireyellow','empire yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-h:enamelblue.176','enamelblue','enamel blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-h:erythritered.258','erythritered','erythrite red',[168,81,110],'a8516e',11030894],
['nbs-iscc-h:ethylblue.172','ethylblue','ethyl blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-h:faenceblue.168','faenceblue','faence blue ',[35,158,186],'239eba',2334394],
['nbs-iscc-h:ferngreen.117','ferngreen','fern green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-h:firered.34','firered','fire red',[226,88,34],'e25822',14833698],
['nbs-iscc-h:flaxblue.195','flaxblue','flax blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-h:flaxblue.196','flaxblue','flax blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-h:flaxblue.206','flaxblue','flax blue',[126,115,184],'7e73b8',8287160],
['nbs-iscc-h:frenchblue.194','frenchblue','french blue',[48,38,122],'30267a',3155578],
['nbs-iscc-h:frenchrose.26','frenchrose','french rose ',[248,131,121],'f88379',16286585],
['nbs-iscc-h:fuchsiapurple.254','fuchsiapurple','fuchsia purple',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:fuchsinepink.248','fuchsinepink','fuchsine pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-h:garnetbrown.16','garnetbrown','garnet brown',[114,47,55],'722f37',7483191],
['nbs-iscc-h:garnetlake.256','garnetlake','garnet lake',[120,24,74],'78184a',7870538],
['nbs-iscc-h:gentianblue.194','gentianblue','gentian blue',[48,38,122],'30267a',3155578],
['nbs-iscc-h:geraniumlake.11','geraniumlake','geranium lake',[190,0,50],'be0032',12451890],
['nbs-iscc-h:heliotrope.206','heliotrope','heliotrope',[126,115,184],'7e73b8',8287160],
['nbs-iscc-h:hyacinthblue.205','hyacinthblue','hyacinth blue',[144,101,202],'9065ca',9463242],
['nbs-iscc-h:imperialpurple.218','imperialpurple','imperial purple',[135,86,146],'875692',8869522],
['nbs-iscc-h:indianblue.169','indianblue','indian blue',[0,119,145],'007791',30609],
['nbs-iscc-h:indianlake.13','indianlake','indian lake',[132,27,45],'841b2d',8657709],
['nbs-iscc-h:indianorange.34','indianorange','indian orange',[226,88,34],'e25822',14833698],
['nbs-iscc-h:indianyellow.67','indianyellow','indian yellow',[255,193,79],'ffc14f',16761167],
['nbs-iscc-h:indianyellow.70','indianyellow','indian yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-h:ivygreen.128','ivygreen','ivy green',[49,54,43],'31362b',3225131],
['nbs-iscc-h:jadegreen.160','jadegreen','jade green',[0,122,116],'007a74',31348],
['nbs-iscc-h:jasperred.12','jasperred','jasper red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-h:kingfisherblue.169','kingfisherblue','kingfisher blue',[0,119,145],'007791',30609],
['nbs-iscc-h:langitegreen.160','langitegreen','langite green',[0,122,116],'007a74',31348],
['nbs-iscc-h:lavendergreen.122','lavendergreen','lavender green',[143,151,121],'8f9779',9410425],
['nbs-iscc-h:leekgreen.125','leekgreen','leek green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-h:leekgreen.127','leekgreen','leek green',[81,87,68],'515744',5330756],
['nbs-iscc-h:lemonyellow.82','lemonyellow','lemon yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-h:lettucegreen.117','lettucegreen','lettuce green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-h:lightchromeyellow.82','lightchromeyellow','light chrome yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-h:lilacpurple.258','lilacpurple','lilac purple',[168,81,110],'a8516e',11030894],
['nbs-iscc-h:lobeliablue.205','lobeliablue','lobelia blue',[144,101,202],'9065ca',9463242],
['nbs-iscc-h:magenta.254','magenta','magenta',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:magentarose.255','magentarose','magenta rose ',[179,68,108],'b3446c',11748460],
['nbs-iscc-h:magnoliapurple.258','magnoliapurple','magnolia purple',[168,81,110],'a8516e',11030894],
['nbs-iscc-h:maizeyellow.67','maizeyellow','maize yellow',[255,193,79],'ffc14f',16761167],
['nbs-iscc-h:maizeyellow.68','maizeyellow','maize yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-h:maizeyellow.70','maizeyellow','maize yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-h:maizeyellow.71','maizeyellow','maize yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-h:maizeyellow.83','maizeyellow','maize yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-h:maizeyellow.84','maizeyellow','maize yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-h:majolicayellow.50','majolicayellow','majolica yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:majolicayellow.53','majolicayellow','majolica yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-h:majolicayellow.68','majolicayellow','majolica yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-h:majolicayellow.71','majolicayellow','majolica yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-h:mallowpurple.236','mallowpurple','mallow purple',[135,0,116],'870074',8847476],
['nbs-iscc-h:mandarinred.34','mandarinred','mandarin red',[226,88,34],'e25822',14833698],
['nbs-iscc-h:marigoldorange.34','marigoldorange','marigold orange',[226,88,34],'e25822',14833698],
['nbs-iscc-h:marigoldorange.48','marigoldorange','marigold orange',[243,132,0],'f38400',15959040],
['nbs-iscc-h:marigoldorange.50','marigoldorange','marigold orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:maroon.17','maroon','maroon',[63,23,40],'3f1728',4134696],
['nbs-iscc-h:marsorange.37','marsorange','mars orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-h:mauve.217','mauve','mauve',[211,153,230],'d399e6',13867494],
['nbs-iscc-h:mauve.218','mauve','mauve',[135,86,146],'875692',8869522],
['nbs-iscc-h:mauvette.210','mauvette','mauvette',[140,130,182],'8c82b6',9208502],
['nbs-iscc-h:mauvette.214','mauvette','mauvette',[150,144,171],'9690ab',9867435],
['nbs-iscc-h:methylviolet.205','methylviolet','methyl violet ',[144,101,202],'9065ca',9463242],
['nbs-iscc-h:mimeosayellow.98','mimeosayellow','mimeosa yellow ',[233,228,80],'e9e450',15328336],
['nbs-iscc-h:mineralviolet.218','mineralviolet','mineral violet ',[135,86,146],'875692',8869522],
['nbs-iscc-h:moorishblue.205','moorishblue','moorish blue ',[144,101,202],'9065ca',9463242],
['nbs-iscc-h:naplesyellow.83','naplesyellow','naples yellow ',[250,218,94],'fada5e',16439902],
['nbs-iscc-h:naplesyellow.86','naplesyellow','naples yellow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-h:nasturtiumorange.50','nasturtiumorange','nasturtium orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:nasturtiumred.34','nasturtiumred','nasturtium red',[226,88,34],'e25822',14833698],
['nbs-iscc-h:neyronrose.248','neyronrose','neyron rose ',[222,111,161],'de6fa1',14577569],
['nbs-iscc-h:nickelgreen.140','nickelgreen','nickel green',[62,180,137],'3eb489',4109449],
['nbs-iscc-h:orange.34','orange','orange',[226,88,34],'e25822',14833698],
['nbs-iscc-h:orangebuff.70','orangebuff','orange buff',[251,201,127],'fbc97f',16501119],
['nbs-iscc-h:orangebuff.71','orangebuff','orange buff',[227,168,87],'e3a857',14919767],
['nbs-iscc-h:orangebuff.83','orangebuff','orange buff',[250,218,94],'fada5e',16439902],
['nbs-iscc-h:orangebuff.84','orangebuff','orange buff',[212,175,55],'d4af37',13938487],
['nbs-iscc-h:orangebuff.86','orangebuff','orange buff',[248,222,126],'f8de7e',16309886],
['nbs-iscc-h:orangebuff.87','orangebuff','orange buff',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-h:orchidpurple.236','orchidpurple','orchid purple',[135,0,116],'870074',8847476],
['nbs-iscc-h:orientalblue.176','orientalblue','oriental blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-h:orientpink.28','orientpink','orient pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-h:orientpink.29','orientpink','orient pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-h:orientred.11','orientred','orient red',[190,0,50],'be0032',12451890],
['nbs-iscc-h:orpimentorange.48','orpimentorange','orpiment orange',[243,132,0],'f38400',15959040],
['nbs-iscc-h:orpimentorange.50','orpimentorange','orpiment orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:oxbloodred.16','oxbloodred','oxblood red',[114,47,55],'722f37',7483191],
['nbs-iscc-h:pansypurple.13','pansypurple','pansy purple',[132,27,45],'841b2d',8657709],
['nbs-iscc-h:pansypurple.256','pansypurple','pansy purple',[120,24,74],'78184a',7870538],
['nbs-iscc-h:pansyviolet.241','pansyviolet','pansy violet',[145,92,131],'915c83',9526403],
['nbs-iscc-h:parisgreen.131','parisgreen','paris green',[68,148,74],'44944a',4494410],
['nbs-iscc-h:parsleygreen.125','parsleygreen','parsley green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-h:pastellavender.226','pastellavender','pastel lavender',[214,202,221],'d6cadd',14076637],
['nbs-iscc-h:pastellilac.226','pastellilac','pastel lilac',[214,202,221],'d6cadd',14076637],
['nbs-iscc-h:pastelmauve.252','pastelmauve','pastel mauve',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-h:peach.28','peach','peach',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-h:peach.29','peach','peach',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-h:peach.52','peach','peach',[250,181,127],'fab57f',16430463],
['nbs-iscc-h:peagreen.116','peagreen','pea green',[189,218,87],'bdda57',12442199],
['nbs-iscc-h:peonypurple.254','peonypurple','peony purple',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:persianblue.178','persianblue','persian blue',[0,103,165],'0067a5',26533],
['nbs-iscc-h:persianrose.236','persianrose','persian rose',[135,0,116],'870074',8847476],
['nbs-iscc-h:persianrose.254','persianrose','persian rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:persimmonorange.48','persimmonorange','persimmon orange',[243,132,0],'f38400',15959040],
['nbs-iscc-h:persimmonorange.50','persimmonorange','persimmon orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:petuniapurple.216','petuniapurple','petunia purple',[154,78,174],'9a4eae',10112686],
['nbs-iscc-h:petuniapurple.236','petuniapurple','petunia purple',[135,0,116],'870074',8847476],
['nbs-iscc-h:phloxpink.248','phloxpink','phlox pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-h:phloxpurple.236','phloxpurple','phlox purple',[135,0,116],'870074',8847476],
['nbs-iscc-h:plumpurple.225','plumpurple','plum purple',[48,25,52],'301934',3152180],
['nbs-iscc-h:podgreen.120','podgreen','pod green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-h:poppyred.34','poppyred','poppy red',[226,88,34],'e25822',14833698],
['nbs-iscc-h:porcelainblue.169','porcelainblue','porcelain blue',[0,119,145],'007791',30609],
['nbs-iscc-h:porcelainrose.3','porcelainrose','porcelain rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-h:porcelainrose.27','porcelainrose','porcelain rose',[230,103,97],'e66761',15099745],
['nbs-iscc-h:primroseyellow.97','primroseyellow','primrose yellow',[220,211,0],'dcd300',14471936],
['nbs-iscc-h:princessblue.179','princessblue','princess blue',[0,65,106],'00416a',16746],
['nbs-iscc-h:purplemadder.16','purplemadder','purple madder',[114,47,55],'722f37',7483191],
['nbs-iscc-h:rhodaminepink.247','rhodaminepink','rhodamine pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-h:rhodaminepurple.254','rhodaminepurple','rhodamine purple',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:rhodonitered.15','rhodonitered','rhodonite red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-h:rosebengal.254','rosebengal','rose bengal',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:roseinepurple.236','roseinepurple','roseine purple',[135,0,116],'870074',8847476],
['nbs-iscc-h:rosemadder.254','rosemadder','rose madder',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:roseopal.12','roseopal','rose opal',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-h:rosepink.2','rosepink','rose pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-h:rosepink.249','rosepink','rose pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-h:rosepurple.222','rosepurple','rose purple',[182,149,192],'b695c0',11965888],
['nbs-iscc-h:rosered.11','rosered','rose red',[190,0,50],'be0032',12451890],
['nbs-iscc-h:royalpurple.219','royalpurple','royal purple',[96,47,107],'602f6b',6303595],
['nbs-iscc-h:rubyred.13','rubyred','ruby red',[132,27,45],'841b2d',8657709],
['nbs-iscc-h:saffronyellow.68','saffronyellow','saffron yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-h:sagegreen.125','sagegreen','sage green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-h:sagegreen.127','sagegreen','sage green',[81,87,68],'515744',5330756],
['nbs-iscc-h:salmon.28','salmon','salmon',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-h:salmon.52','salmon','salmon',[250,181,127],'fab57f',16430463],
['nbs-iscc-h:sapgreen.115','sapgreen','sap green',[141,182,0],'8db600',9287168],
['nbs-iscc-h:sapgreen.116','sapgreen','sap green',[189,218,87],'bdda57',12442199],
['nbs-iscc-h:saturnred.34','saturnred','saturn red',[226,88,34],'e25822',14833698],
['nbs-iscc-h:scarlet.11','scarlet','scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-h:scheelesgreen.117','scheelesgreen','scheeles green ',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-h:seablue.196','seablue','sea blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-h:sealavenderviolet.206','sealavenderviolet','sea lavender violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-h:shellpink.26','shellpink','shell pink',[248,131,121],'f88379',16286585],
['nbs-iscc-h:shrimpred.26','shrimpred','shrimp red',[248,131,121],'f88379',16286585],
['nbs-iscc-h:signalred.11','signalred','signal red',[190,0,50],'be0032',12451890],
['nbs-iscc-h:solferinopurple.254','solferinopurple','solferino purple',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:spanishorange.50','spanishorange','spanish orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:spectrumblue.176','spectrumblue','spectrum blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-h:spectrumviolet.220','spectrumviolet','spectrum violet',[64,26,76],'401a4c',4201036],
['nbs-iscc-h:spinachgreen.125','spinachgreen','spinach green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-h:spinachgreen.137','spinachgreen','spinach green',[53,94,59],'355e3b',3497531],
['nbs-iscc-h:spinelpink.3','spinelpink','spinel pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-h:spinelred.255','spinelred','spinel red',[179,68,108],'b3446c',11748460],
['nbs-iscc-h:spiraeared.254','spiraeared','spiraea red',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:strawyellow.83','strawyellow','straw yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-h:sulphuryellow.82','sulphuryellow','sulphur yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-h:sulphuryellow.97','sulphuryellow','sulphur yellow',[220,211,0],'dcd300',14471936],
['nbs-iscc-h:sunggreen.154','sunggreen','sung green',[178,190,181],'b2beb5',11714229],
['nbs-iscc-h:tangerineorange.48','tangerineorange','tangerine orange',[243,132,0],'f38400',15959040],
['nbs-iscc-h:tangerineorange.50','tangerineorange','tangerine orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-h:turkeyred.11','turkeyred','turkey red',[190,0,50],'be0032',12451890],
['nbs-iscc-h:tyrianpurple.254','tyrianpurple','tyrian purple',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:tyrianrose.254','tyrianrose','tyrian rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-h:uraniumgreen.116','uraniumgreen','uranium green ',[189,218,87],'bdda57',12442199],
['nbs-iscc-h:venetianpink.4','venetianpink','venetian pink',[249,204,202],'f9ccca',16370890],
['nbs-iscc-h:verdigris.144','verdigris','verdigris',[106,171,142],'6aab8e',6990734],
['nbs-iscc-h:vermilion.11','vermilion','vermilion',[190,0,50],'be0032',12451890],
['nbs-iscc-h:vermilion.34','vermilion','vermilion',[226,88,34],'e25822',14833698],
['nbs-iscc-h:veronesegreen.116','veronesegreen','veronese green',[189,218,87],'bdda57',12442199],
['nbs-iscc-h:veronesegreen.130','veronesegreen','veronese green',[131,211,125],'83d37d',8639357],
['nbs-iscc-h:veronicaviolet.206','veronicaviolet','veronica violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-h:victoriaviolet.208','victoriaviolet','victoria violet',[50,23,77],'32174d',3282765],
['nbs-iscc-h:violet.205','violet','violet',[144,101,202],'9065ca',9463242],
['nbs-iscc-h:violetpurple.238','violetpurple','violet purple',[112,41,99],'702963',7350627],
['nbs-iscc-h:viridiangreen.140','viridiangreen','viridian green',[62,180,137],'3eb489',4109449],
['nbs-iscc-h:viridiangreen.141','viridiangreen','viridian green',[0,121,89],'007959',31065],
['nbs-iscc-h:willowgreen.120','willowgreen','willow green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-h:willowgreen.122','willowgreen','willow green',[143,151,121],'8f9779',9410425],
['nbs-iscc-h:wisteriablue.206','wisteriablue','wisteria blue',[126,115,184],'7e73b8',8287160],
['nbs-iscc-h:yellowochre.68','yellowochre','yellow ochre',[234,162,33],'eaa221',15376929],
['nbs-iscc-h:yellowochre.71','yellowochre','yellow ochre',[227,168,87],'e3a857',14919767]
    ];
}

sub _description {
    return {
          'subtitle' => 'Horticultural Colour Charts',
          'title' => 'NBS/ISCC H',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (H) Horticultural Colour Charts

        Horticultural Colour Charts,
        R. F. Wilson 

    Most names are of plants or flowers. 199 names map to 261 colors, using only 95 of 267 centroids.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#H]
'
        }

}

1;
