package Color::Library::Dictionary::NBS_ISCC::SC;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::SC;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::SC - (NBS/ISCC SC) Soil Color Charts

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (SC) Soil Color Charts

        U.S. Department of Agriculture
        Soil Color Charts 

    This combinatorial field-work dictionary's 50 names mape to 176 colors, using 76 of 267 centroids. Again, its focus on soil colors limits its general usefulness.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#SC>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>black</td><td>black</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#28201c;width:4em;" /><td>black</td><td>black</td><td>##28201c</td><td>40</td> <td>32</td> <td>28</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>black</td><td>black</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#363527;width:4em;" /><td>black</td><td>black</td><td>##363527</td><td>54</td> <td>53</td> <td>39</td>
</tr> <tr><td style="border:1px solid #666; background:#25241d;width:4em;" /><td>black</td><td>black</td><td>##25241d</td><td>37</td> <td>36</td> <td>29</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black</td><td>black</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>brown</td><td>brown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brown</td><td>brown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>brown</td><td>brown</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>brown</td><td>brown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>brown</td><td>brown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>brown</td><td>brown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>brownish yellow</td><td>brownishyellow</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>brownish yellow</td><td>brownishyellow</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>dark gray</td><td>darkgray</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>dark gray</td><td>darkgray</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dark gray</td><td>darkgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>dark grayish brown</td><td>darkgrayishbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>dark grayish brown</td><td>darkgrayishbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>dark olive</td><td>darkolive</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#403d21;width:4em;" /><td>dark olive</td><td>darkolive</td><td>##403d21</td><td>64</td> <td>61</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#363527;width:4em;" /><td>dark olive</td><td>darkolive</td><td>##363527</td><td>54</td> <td>53</td> <td>39</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>dark olive-gray</td><td>darkolivegray</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>dark red</td><td>darkred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>dark red</td><td>darkred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>dark red</td><td>darkred</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>dark red</td><td>darkred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>dark red</td><td>darkred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>dark reddish brown</td><td>darkreddishbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>dark reddish brown</td><td>darkreddishbrown</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>dark reddish brown</td><td>darkreddishbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>dark reddish brown</td><td>darkreddishbrown</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>dark reddish brown</td><td>darkreddishbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>dark reddish brown</td><td>darkreddishbrown</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>dark reddish brown</td><td>darkreddishbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>dark reddish brown</td><td>darkreddishbrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>dark reddish gray</td><td>darkreddishgray</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>dark reddish gray</td><td>darkreddishgray</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>dark reddish gray</td><td>darkreddishgray</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>dark yellowish brown</td><td>darkyellowishbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>dark yellowish brown</td><td>darkyellowishbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>dark yellowish brown</td><td>darkyellowishbrown</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>dusky red</td><td>duskyred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>dusky red</td><td>duskyred</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>gray</td><td>gray</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>gray</td><td>gray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gray</td><td>gray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>grayish brown</td><td>grayishbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>grayish brown</td><td>grayishbrown</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>light brown</td><td>lightbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>light brownish gray</td><td>lightbrownishgray</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>light brownish gray</td><td>lightbrownishgray</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>light gray</td><td>lightgray</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>light gray</td><td>lightgray</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>light gray</td><td>lightgray</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>light gray</td><td>lightgray</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>light gray</td><td>lightgray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>light gray</td><td>lightgray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>light gray</td><td>lightgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>light gray</td><td>lightgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>light olive brown</td><td>lightolivebrown</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>light olive-gray</td><td>lightolivegray</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>light olive-gray</td><td>lightolivegray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>light red</td><td>lightred</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>light red</td><td>lightred</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>light red</td><td>lightred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>light red</td><td>lightred</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>light red</td><td>lightred</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>light reddish brown</td><td>lightreddishbrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>light reddish brown</td><td>lightreddishbrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>light reddish brown</td><td>lightreddishbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>light yellowish brown</td><td>lightyellowishbrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>light yellowish brown</td><td>lightyellowishbrown</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>olive</td><td>olive</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olive</td><td>olive</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>olive</td><td>olive</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive</td><td>olive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pale brown</td><td>palebrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>pale brown</td><td>palebrown</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>pale olive</td><td>paleolive</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>pale olive</td><td>paleolive</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>pale red</td><td>palered</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>pale red</td><td>palered</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>pale red</td><td>palered</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>pale yellow </td><td>paleyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>pale yellow </td><td>paleyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pink</td><td>pink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>pink</td><td>pink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>pink</td><td>pink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>pink</td><td>pink</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>pink</td><td>pink</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>pink</td><td>pink</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pink</td><td>pink</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>pinkish gray</td><td>pinkishgray</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>pinkish gray</td><td>pinkishgray</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>pinkish gray</td><td>pinkishgray</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>pinkish gray</td><td>pinkishgray</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>pinkish white</td><td>pinkishwhite</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>pinkish white</td><td>pinkishwhite</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>pinkish white</td><td>pinkishwhite</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>red</td><td>red</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>red</td><td>red</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>red</td><td>red</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>red</td><td>red</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>red</td><td>red</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>red</td><td>red</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>red</td><td>red</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>red</td><td>red</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#282022;width:4em;" /><td>reddish black</td><td>reddishblack</td><td>##282022</td><td>40</td> <td>32</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>reddish black</td><td>reddishblack</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>reddish black</td><td>reddishblack</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>reddish black</td><td>reddishblack</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#28201c;width:4em;" /><td>reddish black</td><td>reddishblack</td><td>##28201c</td><td>40</td> <td>32</td> <td>28</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>reddish gray</td><td>reddishgray</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>reddish yellow</td><td>reddishyellow</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>strong brown</td><td>strongbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>strong brown</td><td>strongbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>very dark brown</td><td>verydarkbrown</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>very dark brown</td><td>verydarkbrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>very dark brown</td><td>verydarkbrown</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>very dark brown</td><td>verydarkbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>very dark gray </td><td>verydarkgray</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>very dark gray </td><td>verydarkgray</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>very dark gray </td><td>verydarkgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>very dark grayish brown</td><td>verydarkgrayishbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>very dark grayish brown</td><td>verydarkgrayishbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>very dusky red</td><td>veryduskyred</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>very dusky red</td><td>veryduskyred</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>very pale brown</td><td>verypalebrown</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>very pale brown</td><td>verypalebrown</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>very pale brown</td><td>verypalebrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>very pale brown</td><td>verypalebrown</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>weak red</td><td>weakred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>weak red</td><td>weakred</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>weak red</td><td>weakred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>weak red</td><td>weakred</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>weak red</td><td>weakred</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#eae3e1;width:4em;" /><td>white</td><td>white</td><td>##eae3e1</td><td>234</td> <td>227</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>white</td><td>white</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>white</td><td>white</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>white</td><td>white</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>white</td><td>white</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>white</td><td>white</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>white</td><td>white</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>yellow</td><td>yellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow</td><td>yellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>yellow</td><td>yellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow</td><td>yellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>yellowish brown</td><td>yellowishbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>yellowish brown</td><td>yellowishbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>yellow red</td><td>yellowred</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>yellow red</td><td>yellowred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item black                   black                #3e322c

=item black                   black                #28201c

=item black                   black                #3b3121

=item black                   black                #363527

=item black                   black                #25241d

=item black                   black                #222222

=item brown                   brown                #a67b5b

=item brown                   brown                #6f4e37

=item brown                   brown                #958070

=item brown                   brown                #635147

=item brown                   brown                #826644

=item brown                   brown                #7e6d5a

=item brownish yellow         brownishyellow       #be8a3d

=item brownish yellow         brownishyellow       #c19a6b

=item dark brown              darkbrown            #6f4e37

=item dark brown              darkbrown            #635147

=item dark brown              darkbrown            #826644

=item dark brown              darkbrown            #4b3621

=item dark brown              darkbrown            #7e6d5a

=item dark gray               darkgray             #5b504f

=item dark gray               darkgray             #57554c

=item dark gray               darkgray             #555555

=item dark grayish brown      darkgrayishbrown     #7e6d5a

=item dark grayish brown      darkgrayishbrown     #6c541e

=item dark olive              darkolive            #665d1e

=item dark olive              darkolive            #403d21

=item dark olive              darkolive            #363527

=item dark olive-gray         darkolivegray        #5b5842

=item dark red                darkred              #722f37

=item dark red                darkred              #882d17

=item dark red                darkred              #56070c

=item dark red                darkred              #79443b

=item dark red                darkred              #80461b

=item dark reddish brown      darkreddishbrown     #79443b

=item dark reddish brown      darkreddishbrown     #3e1d1e

=item dark reddish brown      darkreddishbrown     #674c47

=item dark reddish brown      darkreddishbrown     #43302e

=item dark reddish brown      darkreddishbrown     #6f4e37

=item dark reddish brown      darkreddishbrown     #422518

=item dark reddish brown      darkreddishbrown     #635147

=item dark reddish brown      darkreddishbrown     #3e322c

=item dark reddish gray       darkreddishgray      #5c504f

=item dark reddish gray       darkreddishgray      #635147

=item dark reddish gray       darkreddishgray      #5b504f

=item dark yellowish brown    darkyellowishbrown   #996515

=item dark yellowish brown    darkyellowishbrown   #826644

=item dark yellowish brown    darkyellowishbrown   #4b3621

=item dusky red               duskyred             #79443b

=item dusky red               duskyred             #674c47

=item gray                    gray                 #8e8279

=item gray                    gray                 #8a8776

=item gray                    gray                 #848482

=item grayish brown           grayishbrown         #7e6d5a

=item grayish brown           grayishbrown         #967117

=item light brown             lightbrown           #a67b5b

=item light brownish gray     lightbrownishgray    #ae9b82

=item light brownish gray     lightbrownishgray    #967117

=item light gray              lightgray            #c1b6b3

=item light gray              lightgray            #8e8279

=item light gray              lightgray            #ae9b82

=item light gray              lightgray            #c2b280

=item light gray              lightgray            #bfb8a5

=item light gray              lightgray            #8a8776

=item light gray              lightgray            #b9b8b5

=item light gray              lightgray            #848482

=item light olive brown       lightolivebrown      #967117

=item light olive-gray        lightolivegray       #8c8767

=item light olive-gray        lightolivegray       #8a8776

=item light red               lightred             #e66761

=item light red               lightred             #c48379

=item light red               lightred             #cb6d51

=item light red               lightred             #b4745e

=item light red               lightred             #d99058

=item light reddish brown     lightreddishbrown    #a87c6d

=item light reddish brown     lightreddishbrown    #977f73

=item light reddish brown     lightreddishbrown    #a67b5b

=item light yellowish brown   lightyellowishbrown  #c19a6b

=item light yellowish brown   lightyellowishbrown  #a18f60

=item olive                   olive                #867e36

=item olive                   olive                #665d1e

=item olive                   olive                #8c8767

=item olive                   olive                #5b5842

=item olive brown             olivebrown           #6c541e

=item olive brown             olivebrown           #3b3121

=item olive gray              olivegray            #8c8767

=item olive gray              olivegray            #5b5842

=item olive gray              olivegray            #8a8776

=item olive yellow            oliveyellow          #ab9144

=item pale brown              palebrown            #c19a6b

=item pale brown              palebrown            #ae9b82

=item pale olive              paleolive            #a18f60

=item pale olive              paleolive            #8c8767

=item pale red                palered              #ad8884

=item pale red                palered              #a87c6d

=item pale red                palered              #977f73

=item pale yellow             paleyellow           #f3e5ab

=item pale yellow             paleyellow           #c2b280

=item pink                    pink                 #f4c2c2

=item pink                    pink                 #d9a6a9

=item pink                    pink                 #ecd5c5

=item pink                    pink                 #c7ada3

=item pink                    pink                 #c2ac99

=item pink                    pink                 #fad6a5

=item pink                    pink                 #c19a6b

=item pinkish gray            pinkishgray          #c7ada3

=item pinkish gray            pinkishgray          #c2ac99

=item pinkish gray            pinkishgray          #977f73

=item pinkish gray            pinkishgray          #958070

=item pinkish white           pinkishwhite         #ecd5c5

=item pinkish white           pinkishwhite         #c7ada3

=item pinkish white           pinkishwhite         #c2ac99

=item red                     red                  #ab4e52

=item red                     red                  #905d5d

=item red                     red                  #cb6d51

=item red                     red                  #9e4732

=item red                     red                  #b4745e

=item red                     red                  #79443b

=item red                     red                  #ae6938

=item red                     red                  #80461b

=item reddish black           reddishblack         #282022

=item reddish black           reddishblack         #3e1d1e

=item reddish black           reddishblack         #43302e

=item reddish black           reddishblack         #3e322c

=item reddish black           reddishblack         #28201c

=item reddish brown           reddishbrown         #a87c6d

=item reddish brown           reddishbrown         #79443b

=item reddish brown           reddishbrown         #977f73

=item reddish brown           reddishbrown         #674c47

=item reddish brown           reddishbrown         #a67b5b

=item reddish brown           reddishbrown         #6f4e37

=item reddish gray            reddishgray          #8f817f

=item reddish gray            reddishgray          #977f73

=item reddish gray            reddishgray          #958070

=item reddish gray            reddishgray          #8e8279

=item reddish yellow          reddishyellow        #fab57f

=item reddish yellow          reddishyellow        #d99058

=item reddish yellow          reddishyellow        #fbc97f

=item reddish yellow          reddishyellow        #e3a857

=item reddish yellow          reddishyellow        #be8a3d

=item strong brown            strongbrown          #80461b

=item strong brown            strongbrown          #996515

=item very dark brown         verydarkbrown        #422518

=item very dark brown         verydarkbrown        #3e322c

=item very dark brown         verydarkbrown        #4b3621

=item very dark brown         verydarkbrown        #483c32

=item very dark gray          verydarkgray         #5b504f

=item very dark gray          verydarkgray         #57554c

=item very dark gray          verydarkgray         #555555

=item very dark grayish brown verydarkgrayishbrown #483c32

=item very dark grayish brown verydarkgrayishbrown #6c541e

=item very dusky red          veryduskyred         #3e1d1e

=item very dusky red          veryduskyred         #43302e

=item very pale brown         verypalebrown        #c2ac99

=item very pale brown         verypalebrown        #fad6a5

=item very pale brown         verypalebrown        #c19a6b

=item very pale brown         verypalebrown        #ae9b82

=item weak red                weakred              #905d5d

=item weak red                weakred              #a87c6d

=item weak red                weakred              #79443b

=item weak red                weakred              #977f73

=item weak red                weakred              #674c47

=item white                   white                #eae3e1

=item white                   white                #c1b6b3

=item white                   white                #fad6a5

=item white                   white                #f0ead6

=item white                   white                #bfb8a5

=item white                   white                #f2f3f4

=item white                   white                #b9b8b5

=item yellow                  yellow               #fbc97f

=item yellow                  yellow               #e3a857

=item yellow                  yellow               #f8de7e

=item yellow                  yellow               #c9ae5d

=item yellowish brown         yellowishbrown       #996515

=item yellowish brown         yellowishbrown       #826644

=item yellow red              yellowred            #ae6938

=item yellow red              yellowred            #80461b


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-sc:black.62','black','black',[62,50,44],'3e322c',4076076],
['nbs-iscc-sc:black.65','black','black',[40,32,28],'28201c',2629660],
['nbs-iscc-sc:black.96','black','black',[59,49,33],'3b3121',3879201],
['nbs-iscc-sc:black.111','black','black',[54,53,39],'363527',3552551],
['nbs-iscc-sc:black.114','black','black',[37,36,29],'25241d',2434077],
['nbs-iscc-sc:black.267','black','black',[34,34,34],'222222',2236962],
['nbs-iscc-sc:brown.57','brown','brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-sc:brown.58','brown','brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-sc:brown.60','brown','brown',[149,128,112],'958070',9797744],
['nbs-iscc-sc:brown.61','brown','brown',[99,81,71],'635147',6508871],
['nbs-iscc-sc:brown.77','brown','brown',[130,102,68],'826644',8545860],
['nbs-iscc-sc:brown.80','brown','brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-sc:brownishyellow.72','brownishyellow','brownish yellow',[190,138,61],'be8a3d',12487229],
['nbs-iscc-sc:brownishyellow.76','brownishyellow','brownish yellow',[193,154,107],'c19a6b',12687979],
['nbs-iscc-sc:darkbrown.58','darkbrown','dark brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-sc:darkbrown.61','darkbrown','dark brown',[99,81,71],'635147',6508871],
['nbs-iscc-sc:darkbrown.77','darkbrown','dark brown',[130,102,68],'826644',8545860],
['nbs-iscc-sc:darkbrown.78','darkbrown','dark brown',[75,54,33],'4b3621',4929057],
['nbs-iscc-sc:darkbrown.80','darkbrown','dark brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-sc:darkgray.64','darkgray','dark gray',[91,80,79],'5b504f',5984335],
['nbs-iscc-sc:darkgray.113','darkgray','dark gray',[87,85,76],'57554c',5723468],
['nbs-iscc-sc:darkgray.266','darkgray','dark gray',[85,85,85],'555555',5592405],
['nbs-iscc-sc:darkgrayishbrown.80','darkgrayishbrown','dark grayish brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-sc:darkgrayishbrown.95','darkgrayishbrown','dark grayish brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-sc:darkolive.107','darkolive','dark olive',[102,93,30],'665d1e',6708510],
['nbs-iscc-sc:darkolive.108','darkolive','dark olive',[64,61,33],'403d21',4209953],
['nbs-iscc-sc:darkolive.111','darkolive','dark olive',[54,53,39],'363527',3552551],
['nbs-iscc-sc:darkolivegray.110','darkolivegray','dark olive-gray',[91,88,66],'5b5842',5986370],
['nbs-iscc-sc:darkred.16','darkred','dark red',[114,47,55],'722f37',7483191],
['nbs-iscc-sc:darkred.40','darkred','dark red',[136,45,23],'882d17',8924439],
['nbs-iscc-sc:darkred.41','darkred','dark red',[86,7,12],'56070c',5637900],
['nbs-iscc-sc:darkred.43','darkred','dark red',[121,68,59],'79443b',7947323],
['nbs-iscc-sc:darkred.55','darkred','dark red',[128,70,27],'80461b',8406555],
['nbs-iscc-sc:darkreddishbrown.43','darkreddishbrown','dark reddish brown',[121,68,59],'79443b',7947323],
['nbs-iscc-sc:darkreddishbrown.44','darkreddishbrown','dark reddish brown',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-sc:darkreddishbrown.46','darkreddishbrown','dark reddish brown',[103,76,71],'674c47',6769735],
['nbs-iscc-sc:darkreddishbrown.47','darkreddishbrown','dark reddish brown',[67,48,46],'43302e',4403246],
['nbs-iscc-sc:darkreddishbrown.58','darkreddishbrown','dark reddish brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-sc:darkreddishbrown.59','darkreddishbrown','dark reddish brown',[66,37,24],'422518',4334872],
['nbs-iscc-sc:darkreddishbrown.61','darkreddishbrown','dark reddish brown',[99,81,71],'635147',6508871],
['nbs-iscc-sc:darkreddishbrown.62','darkreddishbrown','dark reddish brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-sc:darkreddishgray.23','darkreddishgray','dark reddish gray',[92,80,79],'5c504f',6049871],
['nbs-iscc-sc:darkreddishgray.61','darkreddishgray','dark reddish gray',[99,81,71],'635147',6508871],
['nbs-iscc-sc:darkreddishgray.64','darkreddishgray','dark reddish gray',[91,80,79],'5b504f',5984335],
['nbs-iscc-sc:darkyellowishbrown.74','darkyellowishbrown','dark yellowish brown',[153,101,21],'996515',10052885],
['nbs-iscc-sc:darkyellowishbrown.77','darkyellowishbrown','dark yellowish brown',[130,102,68],'826644',8545860],
['nbs-iscc-sc:darkyellowishbrown.78','darkyellowishbrown','dark yellowish brown',[75,54,33],'4b3621',4929057],
['nbs-iscc-sc:duskyred.43','duskyred','dusky red',[121,68,59],'79443b',7947323],
['nbs-iscc-sc:duskyred.46','duskyred','dusky red',[103,76,71],'674c47',6769735],
['nbs-iscc-sc:gray.63','gray','gray',[142,130,121],'8e8279',9339513],
['nbs-iscc-sc:gray.112','gray','gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-sc:gray.265','gray','gray',[132,132,130],'848482',8684674],
['nbs-iscc-sc:grayishbrown.80','grayishbrown','grayish brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-sc:grayishbrown.94','grayishbrown','grayish brown',[150,113,23],'967117',9859351],
['nbs-iscc-sc:lightbrown.57','lightbrown','light brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-sc:lightbrownishgray.79','lightbrownishgray','light brownish gray',[174,155,130],'ae9b82',11443074],
['nbs-iscc-sc:lightbrownishgray.94','lightbrownishgray','light brownish gray',[150,113,23],'967117',9859351],
['nbs-iscc-sc:lightgray.10','lightgray','light gray',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-sc:lightgray.63','lightgray','light gray',[142,130,121],'8e8279',9339513],
['nbs-iscc-sc:lightgray.79','lightgray','light gray',[174,155,130],'ae9b82',11443074],
['nbs-iscc-sc:lightgray.90','lightgray','light gray',[194,178,128],'c2b280',12759680],
['nbs-iscc-sc:lightgray.93','lightgray','light gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-sc:lightgray.112','lightgray','light gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-sc:lightgray.264','lightgray','light gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-sc:lightgray.265','lightgray','light gray',[132,132,130],'848482',8684674],
['nbs-iscc-sc:lightolivebrown.94','lightolivebrown','light olive brown',[150,113,23],'967117',9859351],
['nbs-iscc-sc:lightolivegray.109','lightolivegray','light olive-gray',[140,135,103],'8c8767',9209703],
['nbs-iscc-sc:lightolivegray.112','lightolivegray','light olive-gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-sc:lightred.27','lightred','light red',[230,103,97],'e66761',15099745],
['nbs-iscc-sc:lightred.30','lightred','light red',[196,131,121],'c48379',12878713],
['nbs-iscc-sc:lightred.37','lightred','light red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-sc:lightred.39','lightred','light red',[180,116,94],'b4745e',11826270],
['nbs-iscc-sc:lightred.53','lightred','light red',[217,144,88],'d99058',14258264],
['nbs-iscc-sc:lightreddishbrown.42','lightreddishbrown','light reddish brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-sc:lightreddishbrown.45','lightreddishbrown','light reddish brown',[151,127,115],'977f73',9928563],
['nbs-iscc-sc:lightreddishbrown.57','lightreddishbrown','light reddish brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-sc:lightyellowishbrown.76','lightyellowishbrown','light yellowish brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-sc:lightyellowishbrown.91','lightyellowishbrown','light yellowish brown',[161,143,96],'a18f60',10588000],
['nbs-iscc-sc:olive.106','olive','olive',[134,126,54],'867e36',8814134],
['nbs-iscc-sc:olive.107','olive','olive',[102,93,30],'665d1e',6708510],
['nbs-iscc-sc:olive.109','olive','olive',[140,135,103],'8c8767',9209703],
['nbs-iscc-sc:olive.110','olive','olive',[91,88,66],'5b5842',5986370],
['nbs-iscc-sc:olivebrown.95','olivebrown','olive brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-sc:olivebrown.96','olivebrown','olive brown',[59,49,33],'3b3121',3879201],
['nbs-iscc-sc:olivegray.109','olivegray','olive gray',[140,135,103],'8c8767',9209703],
['nbs-iscc-sc:olivegray.110','olivegray','olive gray',[91,88,66],'5b5842',5986370],
['nbs-iscc-sc:olivegray.112','olivegray','olive gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-sc:oliveyellow.88','oliveyellow','olive yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-sc:palebrown.76','palebrown','pale brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-sc:palebrown.79','palebrown','pale brown',[174,155,130],'ae9b82',11443074],
['nbs-iscc-sc:paleolive.91','paleolive','pale olive',[161,143,96],'a18f60',10588000],
['nbs-iscc-sc:paleolive.109','paleolive','pale olive',[140,135,103],'8c8767',9209703],
['nbs-iscc-sc:palered.18','palered','pale red',[173,136,132],'ad8884',11372676],
['nbs-iscc-sc:palered.42','palered','pale red',[168,124,109],'a87c6d',11041901],
['nbs-iscc-sc:palered.45','palered','pale red',[151,127,115],'977f73',9928563],
['nbs-iscc-sc:paleyellow.89','paleyellow','pale yellow ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-sc:paleyellow.90','paleyellow','pale yellow ',[194,178,128],'c2b280',12759680],
['nbs-iscc-sc:pink.28','pink','pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-sc:pink.29','pink','pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-sc:pink.31','pink','pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-sc:pink.32','pink','pink',[199,173,163],'c7ada3',13086115],
['nbs-iscc-sc:pink.33','pink','pink',[194,172,153],'c2ac99',12758169],
['nbs-iscc-sc:pink.73','pink','pink',[250,214,165],'fad6a5',16438949],
['nbs-iscc-sc:pink.76','pink','pink',[193,154,107],'c19a6b',12687979],
['nbs-iscc-sc:pinkishgray.32','pinkishgray','pinkish gray',[199,173,163],'c7ada3',13086115],
['nbs-iscc-sc:pinkishgray.33','pinkishgray','pinkish gray',[194,172,153],'c2ac99',12758169],
['nbs-iscc-sc:pinkishgray.45','pinkishgray','pinkish gray',[151,127,115],'977f73',9928563],
['nbs-iscc-sc:pinkishgray.60','pinkishgray','pinkish gray',[149,128,112],'958070',9797744],
['nbs-iscc-sc:pinkishwhite.31','pinkishwhite','pinkish white',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-sc:pinkishwhite.32','pinkishwhite','pinkish white',[199,173,163],'c7ada3',13086115],
['nbs-iscc-sc:pinkishwhite.33','pinkishwhite','pinkish white',[194,172,153],'c2ac99',12758169],
['nbs-iscc-sc:red.15','red','red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-sc:red.19','red','red',[144,93,93],'905d5d',9461085],
['nbs-iscc-sc:red.37','red','red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-sc:red.38','red','red',[158,71,50],'9e4732',10372914],
['nbs-iscc-sc:red.39','red','red',[180,116,94],'b4745e',11826270],
['nbs-iscc-sc:red.43','red','red',[121,68,59],'79443b',7947323],
['nbs-iscc-sc:red.54','red','red',[174,105,56],'ae6938',11430200],
['nbs-iscc-sc:red.55','red','red',[128,70,27],'80461b',8406555],
['nbs-iscc-sc:reddishblack.24','reddishblack','reddish black',[40,32,34],'282022',2629666],
['nbs-iscc-sc:reddishblack.44','reddishblack','reddish black',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-sc:reddishblack.47','reddishblack','reddish black',[67,48,46],'43302e',4403246],
['nbs-iscc-sc:reddishblack.62','reddishblack','reddish black',[62,50,44],'3e322c',4076076],
['nbs-iscc-sc:reddishblack.65','reddishblack','reddish black',[40,32,28],'28201c',2629660],
['nbs-iscc-sc:reddishbrown.42','reddishbrown','reddish brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-sc:reddishbrown.43','reddishbrown','reddish brown',[121,68,59],'79443b',7947323],
['nbs-iscc-sc:reddishbrown.45','reddishbrown','reddish brown',[151,127,115],'977f73',9928563],
['nbs-iscc-sc:reddishbrown.46','reddishbrown','reddish brown',[103,76,71],'674c47',6769735],
['nbs-iscc-sc:reddishbrown.57','reddishbrown','reddish brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-sc:reddishbrown.58','reddishbrown','reddish brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-sc:reddishgray.22','reddishgray','reddish gray',[143,129,127],'8f817f',9404799],
['nbs-iscc-sc:reddishgray.45','reddishgray','reddish gray',[151,127,115],'977f73',9928563],
['nbs-iscc-sc:reddishgray.60','reddishgray','reddish gray',[149,128,112],'958070',9797744],
['nbs-iscc-sc:reddishgray.63','reddishgray','reddish gray',[142,130,121],'8e8279',9339513],
['nbs-iscc-sc:reddishyellow.52','reddishyellow','reddish yellow',[250,181,127],'fab57f',16430463],
['nbs-iscc-sc:reddishyellow.53','reddishyellow','reddish yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-sc:reddishyellow.70','reddishyellow','reddish yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-sc:reddishyellow.71','reddishyellow','reddish yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-sc:reddishyellow.72','reddishyellow','reddish yellow',[190,138,61],'be8a3d',12487229],
['nbs-iscc-sc:strongbrown.55','strongbrown','strong brown',[128,70,27],'80461b',8406555],
['nbs-iscc-sc:strongbrown.74','strongbrown','strong brown',[153,101,21],'996515',10052885],
['nbs-iscc-sc:verydarkbrown.59','verydarkbrown','very dark brown',[66,37,24],'422518',4334872],
['nbs-iscc-sc:verydarkbrown.62','verydarkbrown','very dark brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-sc:verydarkbrown.78','verydarkbrown','very dark brown',[75,54,33],'4b3621',4929057],
['nbs-iscc-sc:verydarkbrown.81','verydarkbrown','very dark brown',[72,60,50],'483c32',4734002],
['nbs-iscc-sc:verydarkgray.64','verydarkgray','very dark gray ',[91,80,79],'5b504f',5984335],
['nbs-iscc-sc:verydarkgray.113','verydarkgray','very dark gray ',[87,85,76],'57554c',5723468],
['nbs-iscc-sc:verydarkgray.266','verydarkgray','very dark gray ',[85,85,85],'555555',5592405],
['nbs-iscc-sc:verydarkgrayishbrown.81','verydarkgrayishbrown','very dark grayish brown',[72,60,50],'483c32',4734002],
['nbs-iscc-sc:verydarkgrayishbrown.95','verydarkgrayishbrown','very dark grayish brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-sc:veryduskyred.44','veryduskyred','very dusky red',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-sc:veryduskyred.47','veryduskyred','very dusky red',[67,48,46],'43302e',4403246],
['nbs-iscc-sc:verypalebrown.33','verypalebrown','very pale brown',[194,172,153],'c2ac99',12758169],
['nbs-iscc-sc:verypalebrown.73','verypalebrown','very pale brown',[250,214,165],'fad6a5',16438949],
['nbs-iscc-sc:verypalebrown.76','verypalebrown','very pale brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-sc:verypalebrown.79','verypalebrown','very pale brown',[174,155,130],'ae9b82',11443074],
['nbs-iscc-sc:weakred.19','weakred','weak red',[144,93,93],'905d5d',9461085],
['nbs-iscc-sc:weakred.42','weakred','weak red',[168,124,109],'a87c6d',11041901],
['nbs-iscc-sc:weakred.43','weakred','weak red',[121,68,59],'79443b',7947323],
['nbs-iscc-sc:weakred.45','weakred','weak red',[151,127,115],'977f73',9928563],
['nbs-iscc-sc:weakred.46','weakred','weak red',[103,76,71],'674c47',6769735],
['nbs-iscc-sc:white.9','white','white',[234,227,225],'eae3e1',15393761],
['nbs-iscc-sc:white.10','white','white',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-sc:white.73','white','white',[250,214,165],'fad6a5',16438949],
['nbs-iscc-sc:white.92','white','white',[240,234,214],'f0ead6',15788758],
['nbs-iscc-sc:white.93','white','white',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-sc:white.263','white','white',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-sc:white.264','white','white',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-sc:yellow.70','yellow','yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-sc:yellow.71','yellow','yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-sc:yellow.86','yellow','yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-sc:yellow.87','yellow','yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-sc:yellowishbrown.74','yellowishbrown','yellowish brown',[153,101,21],'996515',10052885],
['nbs-iscc-sc:yellowishbrown.77','yellowishbrown','yellowish brown',[130,102,68],'826644',8545860],
['nbs-iscc-sc:yellowred.54','yellowred','yellow red',[174,105,56],'ae6938',11430200],
['nbs-iscc-sc:yellowred.55','yellowred','yellow red',[128,70,27],'80461b',8406555]
    ];
}

sub _description {
    return {
          'subtitle' => 'Soil Color Charts',
          'title' => 'NBS/ISCC SC',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (SC) Soil Color Charts

        U.S. Department of Agriculture
        Soil Color Charts 

    This combinatorial field-work dictionary\'s 50 names mape to 176 colors, using 76 of 267 centroids. Again, its focus on soil colors limits its general usefulness.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#SC]
'
        }

}

1;
