package Color::Library::Dictionary::NBS_ISCC::TC;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::TC;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::TC - (NBS/ISCC TC) Standard Color Card of America

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (TC) Standard Color Card of America

        Textile Color Card Association [TCCA],
        Standard Color Card of America and U.S. Army Color Card 

    The 237 names of this idiosyncratic dictionary map to 267 colors, but only 129 out of 267 possible centroids are called out.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#TC>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>african brown</td><td>africanbrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>african brown</td><td>africanbrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>almond green</td><td>almondgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>amberlite</td><td>amberlite</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>american beauty</td><td>americanbeauty</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>amethyst</td><td>amethyst</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>apple red</td><td>applered</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>apricot</td><td>apricot</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>aqua</td><td>aqua</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>arbutus pink</td><td>arbutuspink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>ashes of rose</td><td>ashesofrose</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>autumn brown</td><td>autumnbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>autumn brown</td><td>autumnbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>baby blue</td><td>babyblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>baby pink</td><td>babypink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>beaver</td><td>beaver</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>beige</td><td>beige</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>bisque</td><td>bisque</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black</td><td>black</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue bird, bluebird</td><td>bluebirdbluebird</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>blue flower</td><td>blueflower</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>blue spruce</td><td>bluespruce</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>bluesteel</td><td>bluesteel</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>blue turquoise</td><td>blueturquoise</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>bois de rose </td><td>boisderose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>bottle green</td><td>bottlegreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>brick red</td><td>brickred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>brittany blue</td><td>brittanyblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>bronze</td><td>bronze</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brown,</td><td>brown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>buff</td><td>buff</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>buff</td><td>buff</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>burgundy</td><td>burgundy</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#38152c;width:4em;" /><td>burgundy</td><td>burgundy</td><td>##38152c</td><td>56</td> <td>21</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>burnished straw</td><td>burnishedstraw</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>burnt orange</td><td>burntorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>caramel brown</td><td>caramelbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>caramel brown</td><td>caramelbrown</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>cardinal</td><td>cardinal</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carmine</td><td>carmine</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>castor</td><td>castor</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>catawba</td><td>catawba</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>chalk pink</td><td>chalkpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>chamois</td><td>chamois</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>champagne</td><td>champagne</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>chartreuse</td><td>chartreuse</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>cherry</td><td>cherry</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>claret</td><td>claret</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>cobalt blue</td><td>cobaltblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>cocoa</td><td>cocoa</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>copenhagen</td><td>copenhagen</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>coral</td><td>coral</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>cork</td><td>cork</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>cornflower blue</td><td>cornflowerblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>crab apple</td><td>crabapple</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>crayon green</td><td>crayongreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cream</td><td>cream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>crimson</td><td>crimson</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>crocus</td><td>crocus</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>dahlia purple</td><td>dahliapurple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>dark cardinal</td><td>darkcardinal</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>duckling</td><td>duckling</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>dustblu</td><td>dustblu</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>dusty pink</td><td>dustypink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>ecru</td><td>ecru</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>eggplant</td><td>eggplant</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>eggshell </td><td>eggshell</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>electric </td><td>electric</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>emerald</td><td>emerald</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>evergreen</td><td>evergreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#173620;width:4em;" /><td>evergreen</td><td>evergreen</td><td>##173620</td><td>23</td> <td>54</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>fawn</td><td>fawn</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>flame red</td><td>flamered</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>flax</td><td>flax</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>flemish blue</td><td>flemishblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>flesh pink</td><td>fleshpink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>forget-me-not</td><td>forgetmenot</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>fuchsia</td><td>fuchsia</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>garnet</td><td>garnet</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>geranium</td><td>geranium</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>gold</td><td>gold</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>gold brown</td><td>goldbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>gold brown</td><td>goldbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>golden orange</td><td>goldenorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>golden poppy</td><td>goldenpoppy</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>golden yellow</td><td>goldenyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>goldmist</td><td>goldmist</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>graphite blue</td><td>graphiteblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>graphite blue</td><td>graphiteblue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>graphite blue</td><td>graphiteblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>graphite blue</td><td>graphiteblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>grebe</td><td>grebe</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>grecian rose</td><td>grecianrose</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>green</td><td>green</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>grotto blue</td><td>grottoblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>gull</td><td>gull</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>harvard crimson</td><td>harvardcrimson</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>henna</td><td>henna</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>homage blue</td><td>homageblue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>homage blue</td><td>homageblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>honeydew</td><td>honeydew</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>hunter</td><td>hunter</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>hydrangea blue</td><td>hydrangeablue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>imperial purple</td><td>imperialpurple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>independence</td><td>independence</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>independence</td><td>independence</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>indian orange</td><td>indianorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#00543d;width:4em;" /><td>irish green</td><td>irishgreen</td><td>##00543d</td><td>0</td> <td>84</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>ivory</td><td>ivory</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>jade green</td><td>jadegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>jasmine</td><td>jasmine</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>jungle green</td><td>junglegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>khaki</td><td>khaki</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>lacquer</td><td>lacquer</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>lavender</td><td>lavender</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>leghorn</td><td>leghorn</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>light blue</td><td>lightblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>light blue</td><td>lightblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>light olive drab</td><td>lightolivedrab</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>lilac</td><td>lilac</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>limepeel </td><td>limepeel</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>lupine</td><td>lupine</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>lupine</td><td>lupine</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>lustre blue</td><td>lustreblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>magenta</td><td>magenta</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>magenta</td><td>magenta</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mahogany</td><td>mahogany</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>maize</td><td>maize</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>majolica blue</td><td>majolicablue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>maple sugar</td><td>maplesugar</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>marine corps</td><td>marinecorps</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>maroon</td><td>maroon</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>maroon</td><td>maroon</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>maroon</td><td>maroon</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>mauve</td><td>mauve</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>melon pink</td><td>melonpink</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>midnight </td><td>midnight</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>mintleaf </td><td>mintleaf</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>mistiblu </td><td>mistiblu</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>myrtle </td><td>myrtle</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>national flag blue</td><td>nationalflagblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>natural</td><td>natural</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>navy 1 </td><td>navy1</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>navy 2 </td><td>navy2</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>nickel</td><td>nickel</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>nickel</td><td>nickel</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>nile</td><td>nile</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>nile</td><td>nile</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>nude</td><td>nude</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>nugget gold</td><td>nuggetgold</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>oakwood</td><td>oakwood</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>old blue</td><td>oldblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>old china</td><td>oldchina</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>old glory blue</td><td>oldgloryblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>old glory red</td><td>oldgloryred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>old gold</td><td>oldgold</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>old gold</td><td>oldgold</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>old rose</td><td>oldrose</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>olive</td><td>olive</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange</td><td>orange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>orange</td><td>orange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>orchid</td><td>orchid</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>oriental blue</td><td>orientalblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>pale blue</td><td>paleblue</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pale blue</td><td>paleblue</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>palmetto</td><td>palmetto</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>pansy</td><td>pansy</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#32174d;width:4em;" /><td>pansy</td><td>pansy</td><td>##32174d</td><td>50</td> <td>23</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>paprica</td><td>paprica</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>parma violet</td><td>parmaviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>parrot blue</td><td>parrotblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>parrot blue</td><td>parrotblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pastel blue</td><td>pastelblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>pastel pink</td><td>pastelpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>peach</td><td>peach</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>peach blossom</td><td>peachblossom</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>peach blossom</td><td>peachblossom</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>peacock</td><td>peacock</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>pearl grey </td><td>pearlgrey</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pearl grey </td><td>pearlgrey</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>peasant blue</td><td>peasantblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>peking blue</td><td>pekingblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>peking blue</td><td>pekingblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>periwinkle blue</td><td>periwinkleblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>pigeon</td><td>pigeon</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>pimento</td><td>pimento</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>plum</td><td>plum</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>popcorn</td><td>popcorn</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>primitive green</td><td>primitivegreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>princeton orange</td><td>princetonorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>prune</td><td>prune</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#301934;width:4em;" /><td>prune</td><td>prune</td><td>##301934</td><td>48</td> <td>25</td> <td>52</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>purple</td><td>purple</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>purple orchid</td><td>purpleorchid</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>putty</td><td>putty</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>putty</td><td>putty</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>raspberry</td><td>raspberry</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>raspberry</td><td>raspberry</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>redgrape</td><td>redgrape</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>reseda</td><td>reseda</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>reseda</td><td>reseda</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>river blue</td><td>riverblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>river blue</td><td>riverblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>robin's egg</td><td>robinsegg</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>rose beige</td><td>rosebeige</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>rose pink</td><td>rosepink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>royal blue</td><td>royalblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>royal blue</td><td>royalblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>ruby</td><td>ruby</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>salmon</td><td>salmon</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>salmon pink </td><td>salmonpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>sand</td><td>sand</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sandalwood</td><td>sandalwood</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>sapphire blue</td><td>sapphireblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>saxe blue</td><td>saxeblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>scarab green</td><td>scarabgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>seal</td><td>seal</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>sea pink</td><td>seapink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>shell pink</td><td>shellpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>shrimp pink</td><td>shrimppink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>shrimp pink</td><td>shrimppink</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>silver</td><td>silver</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>silver gray</td><td>silvergray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>sistine</td><td>sistine</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>sky blue</td><td>skyblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>sky blue</td><td>skyblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>smoke</td><td>smoke</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>spanish yellow</td><td>spanishyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>spicebrown </td><td>spicebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>spraygreen </td><td>spraygreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>spring green</td><td>springgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>starlight blue</td><td>starlightblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>steel</td><td>steel</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>stone blue</td><td>stoneblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>strawberry</td><td>strawberry</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>sunset</td><td>sunset</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>tan</td><td>tan</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>tangerine</td><td>tangerine</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>tarragon</td><td>tarragon</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>taupe</td><td>taupe</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>teal</td><td>teal</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>tea rose</td><td>tearose</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>terra cotta</td><td>terracotta</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>terra cotta</td><td>terracotta</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>terra cotta</td><td>terracotta</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>tigerlily</td><td>tigerlily</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>tile blue</td><td>tileblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>toast brown</td><td>toastbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>tobacco</td><td>tobacco</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>topaz</td><td>topaz</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>tourmaline</td><td>tourmaline</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>turquoise</td><td>turquoise</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>ultramarine blue</td><td>ultramarineblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>ultramarine blue</td><td>ultramarineblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>vassar rose</td><td>vassarrose</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>violet</td><td>violet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>violine pink</td><td>violinepink</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>west point</td><td>westpoint</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>white</td><td>white</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>white</td><td>white</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>white</td><td>white</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>white</td><td>white</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>yale blue</td><td>yaleblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>yellow</td><td>yellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item african brown       africanbrown     #3e322c

=item african brown       africanbrown     #5b504f

=item almond green        almondgreen      #5e716a

=item amberlite           amberlite        #c19a6b

=item american beauty     americanbeauty   #673147

=item amethyst            amethyst         #86608e

=item apple red           applered         #be0032

=item apricot             apricot          #d99058

=item aqua                aqua             #66ada4

=item arbutus pink        arbutuspink      #dea5a4

=item ashes of rose       ashesofrose      #915f6d

=item autumn brown        autumnbrown      #6f4e37

=item autumn brown        autumnbrown      #635147

=item baby blue           babyblue         #bcd4e6

=item baby pink           babypink         #f9ccca

=item beaver              beaver           #635147

=item beige               beige            #958070

=item bisque              bisque           #958070

=item black               black            #222222

=item blue bird, bluebird bluebirdbluebird #436b95

=item blue flower         blueflower       #91a3b0

=item blue spruce         bluespruce       #3b7861

=item bluesteel           bluesteel        #536878

=item blue turquoise      blueturquoise    #66aabc

=item bois de rose        boisderose       #905d5d

=item bottle green        bottlegreen      #1b4d3e

=item brick red           brickred         #722f37

=item brittany blue       brittanyblue     #367588

=item bronze              bronze           #6c541e

=item brown,              brown            #6f4e37

=item buff                buff             #d99058

=item buff                buff             #c19a6b

=item burgundy            burgundy         #673147

=item burgundy            burgundy         #38152c

=item burnished straw     burnishedstraw   #a67b5b

=item burnt orange        burntorange      #cb6d51

=item caramel brown       caramelbrown     #6f4e37

=item caramel brown       caramelbrown     #422518

=item cardinal            cardinal         #841b2d

=item carmine             carmine          #be0032

=item castor              castor           #5b504f

=item catawba             catawba          #673147

=item chalk pink          chalkpink        #dea5a4

=item chamois             chamois          #c9ae5d

=item champagne           champagne        #fad6a5

=item chartreuse          chartreuse       #beb72e

=item cherry              cherry           #b3446c

=item claret              claret           #673147

=item cobalt blue         cobaltblue       #00304e

=item cocoa               cocoa            #79443b

=item copenhagen          copenhagen       #536878

=item coral               coral            #ea9399

=item cork                cork             #a67b5b

=item cornflower blue     cornflowerblue   #545aa7

=item crab apple          crabapple        #d9603b

=item crayon green        crayongreen      #93c592

=item cream               cream            #f0ead6

=item crimson             crimson          #78184a

=item crocus              crocus           #b784a7

=item dahlia purple       dahliapurple     #602f6b

=item dark blue           darkblue         #222222

=item dark cardinal       darkcardinal     #722f37

=item duckling            duckling         #004958

=item dustblu             dustblu          #91a3b0

=item dusty pink          dustypink        #d9a6a9

=item ecru                ecru             #ae9b82

=item eggplant            eggplant         #291e29

=item eggshell            eggshell         #f3e5ab

=item electric            electric         #367588

=item emerald             emerald          #44944a

=item evergreen           evergreen        #355e3b

=item evergreen           evergreen        #173620

=item fawn                fawn             #7e6d5a

=item flame red           flamered         #d9603b

=item flax                flax             #c2b280

=item flemish blue        flemishblue      #536878

=item flesh pink          fleshpink        #ecd5c5

=item forget-me-not       forgetmenot      #70a3cc

=item fuchsia             fuchsia          #ce4676

=item garnet              garnet           #722f37

=item geranium            geranium         #be0032

=item gold                gold             #ab9144

=item gold brown          goldbrown        #ae6938

=item gold brown          goldbrown        #80461b

=item golden orange       goldenorange     #ed872d

=item golden poppy        goldenpoppy      #e25822

=item golden yellow       goldenyellow     #f3c300

=item goldmist            goldmist         #c2b280

=item graphite blue       graphiteblue     #36454f

=item graphite blue       graphiteblue     #202830

=item graphite blue       graphiteblue     #252440

=item graphite blue       graphiteblue     #4c516d

=item grebe               grebe            #555555

=item grecian rose        grecianrose      #c48379

=item green               green            #355e3b

=item grotto blue         grottoblue       #007791

=item gull                gull             #c1b6b3

=item harvard crimson     harvardcrimson   #78184a

=item henna               henna            #79443b

=item homage blue         homageblue       #202830

=item homage blue         homageblue       #252440

=item honeydew            honeydew         #d99058

=item hunter              hunter           #355e3b

=item hydrangea blue      hydrangeablue    #436b95

=item imperial purple     imperialpurple   #602f6b

=item independence        independence     #252440

=item independence        independence     #4c516d

=item indian orange       indianorange     #e25822

=item irish green         irishgreen       #00543d

=item ivory               ivory            #f0ead6

=item jade green          jadegreen        #679267

=item jasmine             jasmine          #f8de7e

=item jungle green        junglegreen      #004b49

=item khaki               khaki            #967117

=item lacquer             lacquer          #9e4732

=item lavender            lavender         #aa98a9

=item leghorn             leghorn          #f3e5ab

=item lemon yellow        lemonyellow      #fada5e

=item light blue          lightblue        #367588

=item light blue          lightblue        #536878

=item light olive drab    lightolivedrab   #6c541e

=item lilac               lilac            #86608e

=item limepeel            limepeel         #8a9a5b

=item lupine              lupine           #8791bf

=item lupine              lupine           #8c92ac

=item lustre blue         lustreblue       #436b95

=item magenta             magenta          #78184a

=item magenta             magenta          #673147

=item mahogany            mahogany         #79443b

=item maize               maize            #f8de7e

=item majolica blue       majolicablue     #436b95

=item maple sugar         maplesugar       #826644

=item marine corps        marinecorps      #00304e

=item maroon              maroon           #722f37

=item maroon              maroon           #673147

=item maroon              maroon           #543d3f

=item mauve               mauve            #875692

=item melon pink          melonpink        #ffb7a5

=item midnight            midnight         #202830

=item mintleaf            mintleaf         #44944a

=item mistiblu            mistiblu         #536878

=item myrtle              myrtle           #1b4d3e

=item national flag blue  nationalflagblue #252440

=item natural             natural          #bfb8a5

=item navy 1              navy1            #00304e

=item navy 2              navy2            #00304e

=item nickel              nickel           #8f817f

=item nickel              nickel           #848482

=item nile                nile             #c9dc89

=item nile                nile             #8a9a5b

=item nude                nude             #ae9b82

=item nugget gold         nuggetgold       #af8d13

=item oakwood             oakwood          #6f4e37

=item old blue            oldblue          #91a3b0

=item old china           oldchina         #436b95

=item old glory blue      oldgloryblue     #4e5180

=item old glory red       oldgloryred      #be0032

=item old gold            oldgold          #ab9144

=item old gold            oldgold          #c9ae5d

=item old rose            oldrose          #c08081

=item olive               olive            #4a5d23

=item orange              orange           #ed872d

=item orange              orange           #e25822

=item orchid              orchid           #b695c0

=item oriental blue       orientalblue     #0067a5

=item pale blue           paleblue         #b2beb5

=item pale blue           paleblue         #b9b8b5

=item palmetto            palmetto         #5e716a

=item pansy               pansy            #604e97

=item pansy               pansy            #32174d

=item paprica             paprica          #e25822

=item parma violet        parmaviolet      #604e97

=item parrot blue         parrotblue       #317873

=item parrot blue         parrotblue       #367588

=item pastel blue         pastelblue       #bcd4e6

=item pastel pink         pastelpink       #dea5a4

=item peach               peach            #d9a6a9

=item peach blossom       peachblossom     #e4717a

=item peach blossom       peachblossom     #a8516e

=item peacock             peacock          #367588

=item pearl grey          pearlgrey        #bfb8a5

=item pearl grey          pearlgrey        #b9b8b5

=item peasant blue        peasantblue      #536878

=item peking blue         pekingblue       #436b95

=item peking blue         pekingblue       #00304e

=item periwinkle blue     periwinkleblue   #8791bf

=item pigeon              pigeon           #8f817f

=item pimento             pimento          #be0032

=item plum                plum             #563c5c

=item popcorn             popcorn          #c9ae5d

=item primitive green     primitivegreen   #007959

=item princeton orange    princetonorange  #ed872d

=item prune               prune            #563c5c

=item prune               prune            #301934

=item purple              purple           #2f2140

=item purple orchid       purpleorchid     #9e4f88

=item putty               putty            #958070

=item putty               putty            #8e8279

=item raspberry           raspberry        #a8516e

=item raspberry           raspberry        #673147

=item redgrape            redgrape         #673147

=item reseda              reseda           #5e716a

=item reseda              reseda           #3a4b47

=item river blue          riverblue        #367588

=item river blue          riverblue        #536878

=item robin's egg         robinsegg        #536878

=item rose beige          rosebeige        #a67b5b

=item rose pink           rosepink         #ea9399

=item royal blue          royalblue        #00304e

=item royal blue          royalblue        #00416a

=item ruby                ruby             #78184a

=item salmon              salmon           #cb6d51

=item salmon pink         salmonpink       #f88379

=item sand                sand             #bfb8a5

=item sandalwood          sandalwood       #a67b5b

=item sapphire blue       sapphireblue     #272458

=item saxe blue           saxeblue         #536878

=item scarab green        scarabgreen      #3eb489

=item scarlet             scarlet          #be0032

=item scarlet             scarlet          #bc3f4a

=item seal                seal             #3e322c

=item sea pink            seapink          #e4717a

=item shell pink          shellpink        #f88379

=item shrimp pink         shrimppink       #e4717a

=item shrimp pink         shrimppink       #e66761

=item silver              silver           #848482

=item silver gray         silvergray       #848482

=item sistine             sistine          #91a3b0

=item sky blue            skyblue          #91a3b0

=item sky blue            skyblue          #00304e

=item smoke               smoke            #555555

=item spanish yellow      spanishyellow    #eaa221

=item spicebrown          spicebrown       #6f4e37

=item spraygreen          spraygreen       #8da399

=item spring green        springgreen      #7e9f2e

=item starlight blue      starlightblue    #8c92ac

=item steel               steel            #8b8589

=item stone blue          stoneblue        #536878

=item strawberry          strawberry       #a8516e

=item sunset              sunset           #fad6a5

=item tan                 tan              #c19a6b

=item tangerine           tangerine        #d9603b

=item tarragon            tarragon         #679267

=item taupe               taupe            #5b504f

=item teal                teal             #004958

=item tea rose            tearose          #f88379

=item terra cotta         terracotta       #9e4732

=item terra cotta         terracotta       #882d17

=item terra cotta         terracotta       #79443b

=item tigerlily           tigerlily        #e66761

=item tile blue           tileblue         #536878

=item toast brown         toastbrown       #6f4e37

=item tobacco             tobacco          #6f4e37

=item topaz               topaz            #be8a3d

=item tourmaline          tourmaline       #c7e6d7

=item turquoise           turquoise        #66ada4

=item ultramarine blue    ultramarineblue  #00a1c2

=item ultramarine blue    ultramarineblue  #30267a

=item vassar rose         vassarrose       #d597ae

=item violet              violet           #604e97

=item violine pink        violinepink      #a8516e

=item west point          westpoint        #536878

=item white               white            #f0ead6

=item white               white            #f2f3f4

=item white               white            #f0ead6

=item white               white            #bfb8a5

=item yale blue           yaleblue         #272458

=item yellow              yellow           #eaa221


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-tc:africanbrown.62','africanbrown','african brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-tc:africanbrown.64','africanbrown','african brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-tc:almondgreen.150','almondgreen','almond green',[94,113,106],'5e716a',6189418],
['nbs-iscc-tc:amberlite.76','amberlite','amberlite',[193,154,107],'c19a6b',12687979],
['nbs-iscc-tc:americanbeauty.259','americanbeauty','american beauty',[103,49,71],'673147',6762823],
['nbs-iscc-tc:amethyst.223','amethyst','amethyst',[134,96,142],'86608e',8806542],
['nbs-iscc-tc:applered.11','applered','apple red',[190,0,50],'be0032',12451890],
['nbs-iscc-tc:apricot.53','apricot','apricot',[217,144,88],'d99058',14258264],
['nbs-iscc-tc:aqua.163','aqua','aqua',[102,173,164],'66ada4',6729124],
['nbs-iscc-tc:arbutuspink.5','arbutuspink','arbutus pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-tc:ashesofrose.262','ashesofrose','ashes of rose',[145,95,109],'915f6d',9527149],
['nbs-iscc-tc:autumnbrown.58','autumnbrown','autumn brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-tc:autumnbrown.61','autumnbrown','autumn brown',[99,81,71],'635147',6508871],
['nbs-iscc-tc:babyblue.184','babyblue','baby blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-tc:babypink.4','babypink','baby pink',[249,204,202],'f9ccca',16370890],
['nbs-iscc-tc:beaver.61','beaver','beaver',[99,81,71],'635147',6508871],
['nbs-iscc-tc:beige.60','beige','beige',[149,128,112],'958070',9797744],
['nbs-iscc-tc:bisque.60','bisque','bisque',[149,128,112],'958070',9797744],
['nbs-iscc-tc:black.267','black','black',[34,34,34],'222222',2236962],
['nbs-iscc-tc:bluebirdbluebird.182','bluebirdbluebird','blue bird, bluebird',[67,107,149],'436b95',4418453],
['nbs-iscc-tc:blueflower.185','blueflower','blue flower',[145,163,176],'91a3b0',9544624],
['nbs-iscc-tc:bluespruce.145','bluespruce','blue spruce',[59,120,97],'3b7861',3897441],
['nbs-iscc-tc:bluesteel.186','bluesteel','bluesteel',[83,104,120],'536878',5466232],
['nbs-iscc-tc:blueturquoise.172','blueturquoise','blue turquoise',[102,170,188],'66aabc',6728380],
['nbs-iscc-tc:boisderose.19','boisderose','bois de rose ',[144,93,93],'905d5d',9461085],
['nbs-iscc-tc:bottlegreen.146','bottlegreen','bottle green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-tc:brickred.16','brickred','brick red',[114,47,55],'722f37',7483191],
['nbs-iscc-tc:brittanyblue.173','brittanyblue','brittany blue',[54,117,136],'367588',3569032],
['nbs-iscc-tc:bronze.95','bronze','bronze',[108,84,30],'6c541e',7099422],
['nbs-iscc-tc:brown.58','brown','brown,',[111,78,55],'6f4e37',7294519],
['nbs-iscc-tc:buff.53','buff','buff',[217,144,88],'d99058',14258264],
['nbs-iscc-tc:buff.76','buff','buff',[193,154,107],'c19a6b',12687979],
['nbs-iscc-tc:burgundy.259','burgundy','burgundy',[103,49,71],'673147',6762823],
['nbs-iscc-tc:burgundy.260','burgundy','burgundy',[56,21,44],'38152c',3675436],
['nbs-iscc-tc:burnishedstraw.57','burnishedstraw','burnished straw',[166,123,91],'a67b5b',10910555],
['nbs-iscc-tc:burntorange.37','burntorange','burnt orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-tc:caramelbrown.58','caramelbrown','caramel brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-tc:caramelbrown.59','caramelbrown','caramel brown',[66,37,24],'422518',4334872],
['nbs-iscc-tc:cardinal.13','cardinal','cardinal',[132,27,45],'841b2d',8657709],
['nbs-iscc-tc:carmine.11','carmine','carmine',[190,0,50],'be0032',12451890],
['nbs-iscc-tc:castor.64','castor','castor',[91,80,79],'5b504f',5984335],
['nbs-iscc-tc:catawba.259','catawba','catawba',[103,49,71],'673147',6762823],
['nbs-iscc-tc:chalkpink.5','chalkpink','chalk pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-tc:chamois.87','chamois','chamois',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-tc:champagne.73','champagne','champagne',[250,214,165],'fad6a5',16438949],
['nbs-iscc-tc:chartreuse.99','chartreuse','chartreuse',[190,183,46],'beb72e',12498734],
['nbs-iscc-tc:cherry.255','cherry','cherry',[179,68,108],'b3446c',11748460],
['nbs-iscc-tc:claret.259','claret','claret',[103,49,71],'673147',6762823],
['nbs-iscc-tc:cobaltblue.183','cobaltblue','cobalt blue',[0,48,78],'00304e',12366],
['nbs-iscc-tc:cocoa.43','cocoa','cocoa',[121,68,59],'79443b',7947323],
['nbs-iscc-tc:copenhagen.186','copenhagen','copenhagen',[83,104,120],'536878',5466232],
['nbs-iscc-tc:coral.2','coral','coral',[234,147,153],'ea9399',15373209],
['nbs-iscc-tc:cork.57','cork','cork',[166,123,91],'a67b5b',10910555],
['nbs-iscc-tc:cornflowerblue.196','cornflowerblue','cornflower blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-tc:crabapple.35','crabapple','crab apple',[217,96,59],'d9603b',14245947],
['nbs-iscc-tc:crayongreen.135','crayongreen','crayon green',[147,197,146],'93c592',9684370],
['nbs-iscc-tc:cream.92','cream','cream',[240,234,214],'f0ead6',15788758],
['nbs-iscc-tc:crimson.256','crimson','crimson',[120,24,74],'78184a',7870538],
['nbs-iscc-tc:crocus.240','crocus','crocus',[183,132,167],'b784a7',12027047],
['nbs-iscc-tc:dahliapurple.219','dahliapurple','dahlia purple',[96,47,107],'602f6b',6303595],
['nbs-iscc-tc:darkblue.267','darkblue','dark blue',[34,34,34],'222222',2236962],
['nbs-iscc-tc:darkcardinal.16','darkcardinal','dark cardinal',[114,47,55],'722f37',7483191],
['nbs-iscc-tc:duckling.174','duckling','duckling',[0,73,88],'004958',18776],
['nbs-iscc-tc:dustblu.185','dustblu','dustblu',[145,163,176],'91a3b0',9544624],
['nbs-iscc-tc:dustypink.29','dustypink','dusty pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-tc:ecru.79','ecru','ecru',[174,155,130],'ae9b82',11443074],
['nbs-iscc-tc:eggplant.230','eggplant','eggplant',[41,30,41],'291e29',2694697],
['nbs-iscc-tc:eggshell.89','eggshell','eggshell ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-tc:electric.173','electric','electric ',[54,117,136],'367588',3569032],
['nbs-iscc-tc:emerald.131','emerald','emerald',[68,148,74],'44944a',4494410],
['nbs-iscc-tc:evergreen.137','evergreen','evergreen',[53,94,59],'355e3b',3497531],
['nbs-iscc-tc:evergreen.138','evergreen','evergreen',[23,54,32],'173620',1521184],
['nbs-iscc-tc:fawn.80','fawn','fawn',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-tc:flamered.35','flamered','flame red',[217,96,59],'d9603b',14245947],
['nbs-iscc-tc:flax.90','flax','flax',[194,178,128],'c2b280',12759680],
['nbs-iscc-tc:flemishblue.186','flemishblue','flemish blue',[83,104,120],'536878',5466232],
['nbs-iscc-tc:fleshpink.31','fleshpink','flesh pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-tc:forgetmenot.181','forgetmenot','forget-me-not',[112,163,204],'70a3cc',7381964],
['nbs-iscc-tc:fuchsia.254','fuchsia','fuchsia',[206,70,118],'ce4676',13518454],
['nbs-iscc-tc:garnet.16','garnet','garnet',[114,47,55],'722f37',7483191],
['nbs-iscc-tc:geranium.11','geranium','geranium',[190,0,50],'be0032',12451890],
['nbs-iscc-tc:gold.88','gold','gold',[171,145,68],'ab9144',11243844],
['nbs-iscc-tc:goldbrown.54','goldbrown','gold brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-tc:goldbrown.55','goldbrown','gold brown',[128,70,27],'80461b',8406555],
['nbs-iscc-tc:goldenorange.50','goldenorange','golden orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-tc:goldenpoppy.34','goldenpoppy','golden poppy',[226,88,34],'e25822',14833698],
['nbs-iscc-tc:goldenyellow.82','goldenyellow','golden yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-tc:goldmist.90','goldmist','goldmist',[194,178,128],'c2b280',12759680],
['nbs-iscc-tc:graphiteblue.187','graphiteblue','graphite blue',[54,69,79],'36454f',3556687],
['nbs-iscc-tc:graphiteblue.188','graphiteblue','graphite blue',[32,40,48],'202830',2107440],
['nbs-iscc-tc:graphiteblue.201','graphiteblue','graphite blue',[37,36,64],'252440',2434112],
['nbs-iscc-tc:graphiteblue.204','graphiteblue','graphite blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-tc:grebe.266','grebe','grebe',[85,85,85],'555555',5592405],
['nbs-iscc-tc:grecianrose.30','grecianrose','grecian rose',[196,131,121],'c48379',12878713],
['nbs-iscc-tc:green.137','green','green',[53,94,59],'355e3b',3497531],
['nbs-iscc-tc:grottoblue.169','grottoblue','grotto blue',[0,119,145],'007791',30609],
['nbs-iscc-tc:gull.10','gull','gull',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-tc:harvardcrimson.256','harvardcrimson','harvard crimson',[120,24,74],'78184a',7870538],
['nbs-iscc-tc:henna.43','henna','henna',[121,68,59],'79443b',7947323],
['nbs-iscc-tc:homageblue.188','homageblue','homage blue',[32,40,48],'202830',2107440],
['nbs-iscc-tc:homageblue.201','homageblue','homage blue',[37,36,64],'252440',2434112],
['nbs-iscc-tc:honeydew.53','honeydew','honeydew',[217,144,88],'d99058',14258264],
['nbs-iscc-tc:hunter.137','hunter','hunter',[53,94,59],'355e3b',3497531],
['nbs-iscc-tc:hydrangeablue.182','hydrangeablue','hydrangea blue',[67,107,149],'436b95',4418453],
['nbs-iscc-tc:imperialpurple.219','imperialpurple','imperial purple',[96,47,107],'602f6b',6303595],
['nbs-iscc-tc:independence.201','independence','independence',[37,36,64],'252440',2434112],
['nbs-iscc-tc:independence.204','independence','independence',[76,81,109],'4c516d',5001581],
['nbs-iscc-tc:indianorange.34','indianorange','indian orange',[226,88,34],'e25822',14833698],
['nbs-iscc-tc:irishgreen.142','irishgreen','irish green',[0,84,61],'00543d',21565],
['nbs-iscc-tc:ivory.92','ivory','ivory',[240,234,214],'f0ead6',15788758],
['nbs-iscc-tc:jadegreen.136','jadegreen','jade green',[103,146,103],'679267',6787687],
['nbs-iscc-tc:jasmine.86','jasmine','jasmine',[248,222,126],'f8de7e',16309886],
['nbs-iscc-tc:junglegreen.165','junglegreen','jungle green',[0,75,73],'004b49',19273],
['nbs-iscc-tc:khaki.94','khaki','khaki',[150,113,23],'967117',9859351],
['nbs-iscc-tc:lacquer.38','lacquer','lacquer',[158,71,50],'9e4732',10372914],
['nbs-iscc-tc:lavender.227','lavender','lavender',[170,152,169],'aa98a9',11180201],
['nbs-iscc-tc:leghorn.89','leghorn','leghorn',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-tc:lemonyellow.83','lemonyellow','lemon yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-tc:lightblue.173','lightblue','light blue',[54,117,136],'367588',3569032],
['nbs-iscc-tc:lightblue.186','lightblue','light blue',[83,104,120],'536878',5466232],
['nbs-iscc-tc:lightolivedrab.95','lightolivedrab','light olive drab',[108,84,30],'6c541e',7099422],
['nbs-iscc-tc:lilac.223','lilac','lilac',[134,96,142],'86608e',8806542],
['nbs-iscc-tc:limepeel.120','limepeel','limepeel ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-tc:lupine.199','lupine','lupine',[135,145,191],'8791bf',8884671],
['nbs-iscc-tc:lupine.203','lupine','lupine',[140,146,172],'8c92ac',9212588],
['nbs-iscc-tc:lustreblue.182','lustreblue','lustre blue',[67,107,149],'436b95',4418453],
['nbs-iscc-tc:magenta.256','magenta','magenta',[120,24,74],'78184a',7870538],
['nbs-iscc-tc:magenta.259','magenta','magenta',[103,49,71],'673147',6762823],
['nbs-iscc-tc:mahogany.43','mahogany','mahogany',[121,68,59],'79443b',7947323],
['nbs-iscc-tc:maize.86','maize','maize',[248,222,126],'f8de7e',16309886],
['nbs-iscc-tc:majolicablue.182','majolicablue','majolica blue',[67,107,149],'436b95',4418453],
['nbs-iscc-tc:maplesugar.77','maplesugar','maple sugar',[130,102,68],'826644',8545860],
['nbs-iscc-tc:marinecorps.183','marinecorps','marine corps',[0,48,78],'00304e',12366],
['nbs-iscc-tc:maroon.16','maroon','maroon',[114,47,55],'722f37',7483191],
['nbs-iscc-tc:maroon.259','maroon','maroon',[103,49,71],'673147',6762823],
['nbs-iscc-tc:maroon.20','maroon','maroon',[84,61,63],'543d3f',5520703],
['nbs-iscc-tc:mauve.218','mauve','mauve',[135,86,146],'875692',8869522],
['nbs-iscc-tc:melonpink.25','melonpink','melon pink',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-tc:midnight.188','midnight','midnight ',[32,40,48],'202830',2107440],
['nbs-iscc-tc:mintleaf.131','mintleaf','mintleaf ',[68,148,74],'44944a',4494410],
['nbs-iscc-tc:mistiblu.186','mistiblu','mistiblu ',[83,104,120],'536878',5466232],
['nbs-iscc-tc:myrtle.146','myrtle','myrtle ',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-tc:nationalflagblue.201','nationalflagblue','national flag blue',[37,36,64],'252440',2434112],
['nbs-iscc-tc:natural.93','natural','natural',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-tc:navy1.183','navy1','navy 1 ',[0,48,78],'00304e',12366],
['nbs-iscc-tc:navy2.183','navy2','navy 2 ',[0,48,78],'00304e',12366],
['nbs-iscc-tc:nickel.22','nickel','nickel',[143,129,127],'8f817f',9404799],
['nbs-iscc-tc:nickel.265','nickel','nickel',[132,132,130],'848482',8684674],
['nbs-iscc-tc:nile.119','nile','nile',[201,220,137],'c9dc89',13229193],
['nbs-iscc-tc:nile.120','nile','nile',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-tc:nude.79','nude','nude',[174,155,130],'ae9b82',11443074],
['nbs-iscc-tc:nuggetgold.85','nuggetgold','nugget gold',[175,141,19],'af8d13',11504915],
['nbs-iscc-tc:oakwood.58','oakwood','oakwood',[111,78,55],'6f4e37',7294519],
['nbs-iscc-tc:oldblue.185','oldblue','old blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-tc:oldchina.182','oldchina','old china',[67,107,149],'436b95',4418453],
['nbs-iscc-tc:oldgloryblue.200','oldgloryblue','old glory blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-tc:oldgloryred.11','oldgloryred','old glory red',[190,0,50],'be0032',12451890],
['nbs-iscc-tc:oldgold.88','oldgold','old gold',[171,145,68],'ab9144',11243844],
['nbs-iscc-tc:oldgold.87','oldgold','old gold',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-tc:oldrose.6','oldrose','old rose',[192,128,129],'c08081',12615809],
['nbs-iscc-tc:olive.125','olive','olive',[74,93,35],'4a5d23',4873507],
['nbs-iscc-tc:orange.50','orange','orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-tc:orange.34','orange','orange',[226,88,34],'e25822',14833698],
['nbs-iscc-tc:orchid.222','orchid','orchid',[182,149,192],'b695c0',11965888],
['nbs-iscc-tc:orientalblue.178','orientalblue','oriental blue',[0,103,165],'0067a5',26533],
['nbs-iscc-tc:paleblue.154','paleblue','pale blue',[178,190,181],'b2beb5',11714229],
['nbs-iscc-tc:paleblue.264','paleblue','pale blue',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-tc:palmetto.150','palmetto','palmetto',[94,113,106],'5e716a',6189418],
['nbs-iscc-tc:pansy.207','pansy','pansy',[96,78,151],'604e97',6311575],
['nbs-iscc-tc:pansy.208','pansy','pansy',[50,23,77],'32174d',3282765],
['nbs-iscc-tc:paprica.34','paprica','paprica',[226,88,34],'e25822',14833698],
['nbs-iscc-tc:parmaviolet.207','parmaviolet','parma violet',[96,78,151],'604e97',6311575],
['nbs-iscc-tc:parrotblue.164','parrotblue','parrot blue',[49,120,115],'317873',3242099],
['nbs-iscc-tc:parrotblue.173','parrotblue','parrot blue',[54,117,136],'367588',3569032],
['nbs-iscc-tc:pastelblue.184','pastelblue','pastel blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-tc:pastelpink.5','pastelpink','pastel pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-tc:peach.29','peach','peach',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-tc:peachblossom.3','peachblossom','peach blossom',[228,113,122],'e4717a',14971258],
['nbs-iscc-tc:peachblossom.258','peachblossom','peach blossom',[168,81,110],'a8516e',11030894],
['nbs-iscc-tc:peacock.173','peacock','peacock',[54,117,136],'367588',3569032],
['nbs-iscc-tc:pearlgrey.93','pearlgrey','pearl grey ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-tc:pearlgrey.264','pearlgrey','pearl grey ',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-tc:peasantblue.186','peasantblue','peasant blue',[83,104,120],'536878',5466232],
['nbs-iscc-tc:pekingblue.182','pekingblue','peking blue',[67,107,149],'436b95',4418453],
['nbs-iscc-tc:pekingblue.183','pekingblue','peking blue',[0,48,78],'00304e',12366],
['nbs-iscc-tc:periwinkleblue.199','periwinkleblue','periwinkle blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-tc:pigeon.22','pigeon','pigeon',[143,129,127],'8f817f',9404799],
['nbs-iscc-tc:pimento.11','pimento','pimento',[190,0,50],'be0032',12451890],
['nbs-iscc-tc:plum.224','plum','plum',[86,60,92],'563c5c',5651548],
['nbs-iscc-tc:popcorn.87','popcorn','popcorn',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-tc:primitivegreen.141','primitivegreen','primitive green',[0,121,89],'007959',31065],
['nbs-iscc-tc:princetonorange.50','princetonorange','princeton orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-tc:prune.224','prune','prune',[86,60,92],'563c5c',5651548],
['nbs-iscc-tc:prune.225','prune','prune',[48,25,52],'301934',3152180],
['nbs-iscc-tc:purple.212','purple','purple',[47,33,64],'2f2140',3088704],
['nbs-iscc-tc:purpleorchid.237','purpleorchid','purple orchid',[158,79,136],'9e4f88',10375048],
['nbs-iscc-tc:putty.60','putty','putty',[149,128,112],'958070',9797744],
['nbs-iscc-tc:putty.63','putty','putty',[142,130,121],'8e8279',9339513],
['nbs-iscc-tc:raspberry.258','raspberry','raspberry',[168,81,110],'a8516e',11030894],
['nbs-iscc-tc:raspberry.259','raspberry','raspberry',[103,49,71],'673147',6762823],
['nbs-iscc-tc:redgrape.259','redgrape','redgrape',[103,49,71],'673147',6762823],
['nbs-iscc-tc:reseda.150','reseda','reseda',[94,113,106],'5e716a',6189418],
['nbs-iscc-tc:reseda.151','reseda','reseda',[58,75,71],'3a4b47',3820359],
['nbs-iscc-tc:riverblue.173','riverblue','river blue',[54,117,136],'367588',3569032],
['nbs-iscc-tc:riverblue.186','riverblue','river blue',[83,104,120],'536878',5466232],
['nbs-iscc-tc:robinsegg.186','robinsegg','robin\'s egg',[83,104,120],'536878',5466232],
['nbs-iscc-tc:rosebeige.57','rosebeige','rose beige',[166,123,91],'a67b5b',10910555],
['nbs-iscc-tc:rosepink.2','rosepink','rose pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-tc:royalblue.183','royalblue','royal blue',[0,48,78],'00304e',12366],
['nbs-iscc-tc:royalblue.179','royalblue','royal blue',[0,65,106],'00416a',16746],
['nbs-iscc-tc:ruby.256','ruby','ruby',[120,24,74],'78184a',7870538],
['nbs-iscc-tc:salmon.37','salmon','salmon',[203,109,81],'cb6d51',13331793],
['nbs-iscc-tc:salmonpink.26','salmonpink','salmon pink ',[248,131,121],'f88379',16286585],
['nbs-iscc-tc:sand.93','sand','sand',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-tc:sandalwood.57','sandalwood','sandalwood',[166,123,91],'a67b5b',10910555],
['nbs-iscc-tc:sapphireblue.197','sapphireblue','sapphire blue',[39,36,88],'272458',2565208],
['nbs-iscc-tc:saxeblue.186','saxeblue','saxe blue',[83,104,120],'536878',5466232],
['nbs-iscc-tc:scarabgreen.140','scarabgreen','scarab green',[62,180,137],'3eb489',4109449],
['nbs-iscc-tc:scarlet.11','scarlet','scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-tc:scarlet.12','scarlet','scarlet',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-tc:seal.62','seal','seal',[62,50,44],'3e322c',4076076],
['nbs-iscc-tc:seapink.3','seapink','sea pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-tc:shellpink.26','shellpink','shell pink',[248,131,121],'f88379',16286585],
['nbs-iscc-tc:shrimppink.3','shrimppink','shrimp pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-tc:shrimppink.27','shrimppink','shrimp pink',[230,103,97],'e66761',15099745],
['nbs-iscc-tc:silver.265','silver','silver',[132,132,130],'848482',8684674],
['nbs-iscc-tc:silvergray.265','silvergray','silver gray',[132,132,130],'848482',8684674],
['nbs-iscc-tc:sistine.185','sistine','sistine',[145,163,176],'91a3b0',9544624],
['nbs-iscc-tc:skyblue.185','skyblue','sky blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-tc:skyblue.183','skyblue','sky blue',[0,48,78],'00304e',12366],
['nbs-iscc-tc:smoke.266','smoke','smoke',[85,85,85],'555555',5592405],
['nbs-iscc-tc:spanishyellow.68','spanishyellow','spanish yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-tc:spicebrown.58','spicebrown','spicebrown ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-tc:spraygreen.149','spraygreen','spraygreen ',[141,163,153],'8da399',9282457],
['nbs-iscc-tc:springgreen.117','springgreen','spring green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-tc:starlightblue.203','starlightblue','starlight blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-tc:steel.233','steel','steel',[139,133,137],'8b8589',9143689],
['nbs-iscc-tc:stoneblue.186','stoneblue','stone blue',[83,104,120],'536878',5466232],
['nbs-iscc-tc:strawberry.258','strawberry','strawberry',[168,81,110],'a8516e',11030894],
['nbs-iscc-tc:sunset.73','sunset','sunset',[250,214,165],'fad6a5',16438949],
['nbs-iscc-tc:tan.76','tan','tan',[193,154,107],'c19a6b',12687979],
['nbs-iscc-tc:tangerine.35','tangerine','tangerine',[217,96,59],'d9603b',14245947],
['nbs-iscc-tc:tarragon.136','tarragon','tarragon',[103,146,103],'679267',6787687],
['nbs-iscc-tc:taupe.64','taupe','taupe',[91,80,79],'5b504f',5984335],
['nbs-iscc-tc:teal.174','teal','teal',[0,73,88],'004958',18776],
['nbs-iscc-tc:tearose.26','tearose','tea rose',[248,131,121],'f88379',16286585],
['nbs-iscc-tc:terracotta.38','terracotta','terra cotta',[158,71,50],'9e4732',10372914],
['nbs-iscc-tc:terracotta.40','terracotta','terra cotta',[136,45,23],'882d17',8924439],
['nbs-iscc-tc:terracotta.43','terracotta','terra cotta',[121,68,59],'79443b',7947323],
['nbs-iscc-tc:tigerlily.27','tigerlily','tigerlily',[230,103,97],'e66761',15099745],
['nbs-iscc-tc:tileblue.186','tileblue','tile blue',[83,104,120],'536878',5466232],
['nbs-iscc-tc:toastbrown.58','toastbrown','toast brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-tc:tobacco.58','tobacco','tobacco',[111,78,55],'6f4e37',7294519],
['nbs-iscc-tc:topaz.72','topaz','topaz',[190,138,61],'be8a3d',12487229],
['nbs-iscc-tc:tourmaline.148','tourmaline','tourmaline',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-tc:turquoise.163','turquoise','turquoise',[102,173,164],'66ada4',6729124],
['nbs-iscc-tc:ultramarineblue.176','ultramarineblue','ultramarine blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-tc:ultramarineblue.194','ultramarineblue','ultramarine blue',[48,38,122],'30267a',3155578],
['nbs-iscc-tc:vassarrose.250','vassarrose','vassar rose',[213,151,174],'d597ae',13997998],
['nbs-iscc-tc:violet.207','violet','violet',[96,78,151],'604e97',6311575],
['nbs-iscc-tc:violinepink.258','violinepink','violine pink',[168,81,110],'a8516e',11030894],
['nbs-iscc-tc:westpoint.186','westpoint','west point',[83,104,120],'536878',5466232],
['nbs-iscc-tc:white.92','white','white',[240,234,214],'f0ead6',15788758],
['nbs-iscc-tc:white.263','white','white',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-tc:white.92','white','white',[240,234,214],'f0ead6',15788758],
['nbs-iscc-tc:white.93','white','white',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-tc:yaleblue.197','yaleblue','yale blue',[39,36,88],'272458',2565208],
['nbs-iscc-tc:yellow.68','yellow','yellow',[234,162,33],'eaa221',15376929]
    ];
}

sub _description {
    return {
          'subtitle' => 'Standard Color Card of America',
          'title' => 'NBS/ISCC TC',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (TC) Standard Color Card of America

        Textile Color Card Association [TCCA],
        Standard Color Card of America and U.S. Army Color Card 

    The 237 names of this idiosyncratic dictionary map to 267 colors, but only 129 out of 267 possible centroids are called out.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#TC]
'
        }

}

1;
