package Color::Library::Dictionary::NBS_ISCC::M;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::M;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::M - (NBS/ISCC M) Dictionary of Color

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (M) Dictionary of Color

Maerz and Paul,
Dictionary of Color, 1st ed. 

This idiosyncratic dictionary's 3064 names map to 4401 colors, using 223 of the 267 centroids.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#M>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>abbey</td><td>abbey</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>absinthe [green] </td><td>absinthegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>absinthe yellow</td><td>absintheyellow</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>acacia</td><td>acacia</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>acacia</td><td>acacia</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>academy blue</td><td>academyblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>acajou</td><td>acajou</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>acanthe</td><td>acanthe</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>acier</td><td>acier</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>ackermann's green</td><td>ackermannsgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>aconite violet</td><td>aconiteviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>acorn</td><td>acorn</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>adamia</td><td>adamia</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#32174d;width:4em;" /><td>adelaide</td><td>adelaide</td><td>##32174d</td><td>50</td> <td>23</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>aden</td><td>aden</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>admiral</td><td>admiral</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>admiral</td><td>admiral</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>adobe</td><td>adobe</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>adrianople red</td><td>adrianoplered</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>adriatic</td><td>adriatic</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>adust</td><td>adust</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>aero</td><td>aero</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>afghan</td><td>afghan</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>afghan red</td><td>afghanred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>african</td><td>african</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>african brown</td><td>africanbrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>afterglow</td><td>afterglow</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>agate</td><td>agate</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>agate</td><td>agate</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>agate grey</td><td>agategrey</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>ageratum blue</td><td>ageratumblue</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>ageratum violet</td><td>ageratumviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>air blue</td><td>airblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>airedale</td><td>airedale</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>airedale</td><td>airedale</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>airway</td><td>airway</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>akbar</td><td>akbar</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>akbar</td><td>akbar</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>alabaster</td><td>alabaster</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>alabaster</td><td>alabaster</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>alamo</td><td>alamo</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>alcanna</td><td>alcanna</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>alcazar</td><td>alcazar</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>alcazar</td><td>alcazar</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>alderney</td><td>alderney</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>alesan</td><td>alesan</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>alesan</td><td>alesan</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>alesan</td><td>alesan</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>alexandria blue</td><td>alexandriablue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>alexandria blue</td><td>alexandriablue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>alfalfa</td><td>alfalfa</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>algerian</td><td>algerian</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>algerian red</td><td>algerianred</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>algonquin</td><td>algonquin</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>algonquin</td><td>algonquin</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>alhambra</td><td>alhambra</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>alhambra</td><td>alhambra</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>alice blue</td><td>aliceblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>alkermes</td><td>alkermes</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>almond</td><td>almond</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>almond</td><td>almond</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>almond</td><td>almond</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>almond</td><td>almond</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>almond blossom</td><td>almondblossom</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>almond blossom</td><td>almondblossom</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>almond blossom</td><td>almondblossom</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>almond blossom</td><td>almondblossom</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>almond brown </td><td>almondbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>almond brown </td><td>almondbrown</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>almond brown </td><td>almondbrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>almond brown </td><td>almondbrown</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>almond green</td><td>almondgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>almond [pink] </td><td>almondpink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>almond [pink] </td><td>almondpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>almond [pink] </td><td>almondpink</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>almond [pink] </td><td>almondpink</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>aloes [green] </td><td>aloesgreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>aloma</td><td>aloma</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>aloma</td><td>aloma</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>aloma</td><td>aloma</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>alpine</td><td>alpine</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>alpine green</td><td>alpinegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>aluminum</td><td>aluminum</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>aluminum</td><td>aluminum</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>amaranth</td><td>amaranth</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>amaranthine</td><td>amaranthine</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>amaranth pink</td><td>amaranthpink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>amaranth purple</td><td>amaranthpurple</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#00543d;width:4em;" /><td>amarna</td><td>amarna</td><td>##00543d</td><td>0</td> <td>84</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>amarna</td><td>amarna</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>amarylis</td><td>amarylis</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>amarylis</td><td>amarylis</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>amazon</td><td>amazon</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>amber brown</td><td>amberbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>amberglow</td><td>amberglow</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>amberglow</td><td>amberglow</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>amber white</td><td>amberwhite</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>amber white</td><td>amberwhite</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>amber white</td><td>amberwhite</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>amber white</td><td>amberwhite</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>amber white</td><td>amberwhite</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>amber [yellow] </td><td>amberyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>amber [yellow] </td><td>amberyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>ambrosia</td><td>ambrosia</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>ambulance</td><td>ambulance</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>amelie</td><td>amelie</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>american beauty</td><td>americanbeauty</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>american green</td><td>americangreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>american green</td><td>americangreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>american green</td><td>americangreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>amethyst [violet] </td><td>amethystviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>amethyst [violet] </td><td>amethystviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>amethyst [violet] </td><td>amethystviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>amparo blue</td><td>amparoblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>amparo blue</td><td>amparoblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>amparo purple</td><td>amparopurple</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>amulet</td><td>amulet</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>anamite</td><td>anamite</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>anatolia</td><td>anatolia</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>anatta</td><td>anatta</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>andorra</td><td>andorra</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>andorra</td><td>andorra</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>andorre</td><td>andorre</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>andorre</td><td>andorre</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>andover green</td><td>andovergreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>andrinople berries</td><td>andrinopleberries</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>andrinople berries</td><td>andrinopleberries</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>anemone</td><td>anemone</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>angel red</td><td>angelred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>animal rouge</td><td>animalrouge</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>animal rouge</td><td>animalrouge</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>annapolis</td><td>annapolis</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>annatto</td><td>annatto</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>annotto</td><td>annotto</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>antelope</td><td>antelope</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>antimony yellow</td><td>antimonyyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>antique</td><td>antique</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>antique</td><td>antique</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>antique brass</td><td>antiquebrass</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>antique brass</td><td>antiquebrass</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>antique bronze</td><td>antiquebronze</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>antique brown</td><td>antiquebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>antique drab</td><td>antiquedrab</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>antique drab</td><td>antiquedrab</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>antique drab</td><td>antiquedrab</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>antique fuchsia</td><td>antiquefuchsia</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>antique fuchsia</td><td>antiquefuchsia</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>antique gold</td><td>antiquegold</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>antique gold</td><td>antiquegold</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>antique green</td><td>antiquegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>antique red</td><td>antiquered</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>antique red</td><td>antiquered</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>antique red</td><td>antiquered</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>antique red</td><td>antiquered</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>antique ruby</td><td>antiqueruby</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>antwerp blue</td><td>antwerpblue</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>antwerp blue</td><td>antwerpblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>antwerp brown</td><td>antwerpbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>antwerp red</td><td>antwerpred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>apache</td><td>apache</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>aphrodite</td><td>aphrodite</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>appleblossom [pink] </td><td>appleblossompink</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>apple-fallow</td><td>applefallow</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>apple-fallow</td><td>applefallow</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>apple green</td><td>applegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>apricot</td><td>apricot</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>apricot yellow</td><td>apricotyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>apricot yellow</td><td>apricotyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>aquagreen</td><td>aquagreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>aquamarine</td><td>aquamarine</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>aquamarine</td><td>aquamarine</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>arab [brown] </td><td>arabbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>arabesque</td><td>arabesque</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>arabian brown</td><td>arabianbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>arabian brown</td><td>arabianbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>arabian red</td><td>arabianred</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>araby</td><td>araby</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>araby</td><td>araby</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>aragon</td><td>aragon</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>arbutus</td><td>arbutus</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>arbutus</td><td>arbutus</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>arbutus</td><td>arbutus</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>arbutus</td><td>arbutus</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>arcadian green</td><td>arcadiangreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>archel</td><td>archel</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>archil </td><td>archil</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>arctic</td><td>arctic</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>arctic blue</td><td>arcticblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>ardoise</td><td>ardoise</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>ardoise</td><td>ardoise</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>argali</td><td>argali</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>argali</td><td>argali</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>argent</td><td>argent</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>argentina</td><td>argentina</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>argus brown</td><td>argusbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>argyle purple</td><td>argylepurple</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>argyle purple</td><td>argylepurple</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>arizona</td><td>arizona</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>armada</td><td>armada</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>armada</td><td>armada</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>armenian blue</td><td>armenianblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>armenian blue</td><td>armenianblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>armenian bole</td><td>armenianbole</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>armenian red</td><td>armenianred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>armenian stone</td><td>armenianstone</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>army brown</td><td>armybrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>arno blue</td><td>arnoblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>arno blue</td><td>arnoblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>arnotto</td><td>arnotto</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>arona</td><td>arona</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>arrowwood</td><td>arrowwood</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>arsenate</td><td>arsenate</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>art brown</td><td>artbrown</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>artemesia green</td><td>artemesiagreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>art gray, art grey</td><td>artgrayartgrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>art gray, art grey</td><td>artgrayartgrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>art green</td><td>artgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>art green</td><td>artgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>artichoke green</td><td>artichokegreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>artificial vermilion</td><td>artificialvermilion</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>artillery</td><td>artillery</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>ascot tan</td><td>ascottan</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>ashes of rose</td><td>ashesofrose</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>ash [grey] </td><td>ashgrey</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>asmalte</td><td>asmalte</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>asmalte</td><td>asmalte</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>asparagus green</td><td>asparagusgreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>aspen green</td><td>aspengreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>asphalt</td><td>asphalt</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>asphaltum</td><td>asphaltum</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>asphodel green</td><td>asphodelgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>aster</td><td>aster</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>aster purple</td><td>asterpurple</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>athenia</td><td>athenia</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>atlantic</td><td>atlantic</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>atlantis</td><td>atlantis</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>atlantis</td><td>atlantis</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>atmosphere</td><td>atmosphere</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>atmosphere</td><td>atmosphere</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>atmosphere</td><td>atmosphere</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>atramentous</td><td>atramentous</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>attar of roses</td><td>attarofroses</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>attar of roses</td><td>attarofroses</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>aubergine</td><td>aubergine</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>aubergine</td><td>aubergine</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>auburn</td><td>auburn</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>aubusson</td><td>aubusson</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>aucuba</td><td>aucuba</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>aureolin</td><td>aureolin</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>aureolin</td><td>aureolin</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>auricula purple</td><td>auriculapurple</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>auripigmentum</td><td>auripigmentum</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>auripigmentum</td><td>auripigmentum</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>auripigmentum</td><td>auripigmentum</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>auripigmentum</td><td>auripigmentum</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>aurora [orange] </td><td>auroraorange</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>aurora [orange] </td><td>auroraorange</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>aurora [orange] </td><td>auroraorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>aurora red</td><td>aurorared</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>aurora red</td><td>aurorared</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>aurora red</td><td>aurorared</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>aurora yellow</td><td>aurorayellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>aurora yellow</td><td>aurorayellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>aurora yellow</td><td>aurorayellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>aurora yellow</td><td>aurorayellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>aurore</td><td>aurore</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>aurum</td><td>aurum</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>australian pine</td><td>australianpine</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>auteuil</td><td>auteuil</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>autumn</td><td>autumn</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#363527;width:4em;" /><td>autumn</td><td>autumn</td><td>##363527</td><td>54</td> <td>53</td> <td>39</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>autumn blonde</td><td>autumnblonde</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>autumn blonde</td><td>autumnblonde</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>autumn blonde</td><td>autumnblonde</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>autumn blonde</td><td>autumnblonde</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>autumn brown</td><td>autumnbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>autumn glory</td><td>autumnglory</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>autumn glory</td><td>autumnglory</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>autumn green</td><td>autumngreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>autumn green</td><td>autumngreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>autumn leaf</td><td>autumnleaf</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>autumn leaf</td><td>autumnleaf</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>autumn leaf</td><td>autumnleaf</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>autumn oak</td><td>autumnoak</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>avellaneous</td><td>avellaneous</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>avellaneous</td><td>avellaneous</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>avignon berries</td><td>avignonberries</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>avignon berries</td><td>avignonberries</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>azalea</td><td>azalea</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>aztec</td><td>aztec</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>aztec</td><td>aztec</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>aztec</td><td>aztec</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>aztec maroon</td><td>aztecmaroon</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>azulin</td><td>azulin</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>baby blue</td><td>babyblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>baby blue</td><td>babyblue</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>baby blue</td><td>babyblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>baby pink</td><td>babypink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>baby pink</td><td>babypink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>baby rose</td><td>babyrose</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>bacchus</td><td>bacchus</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>bachelor button</td><td>bachelorbutton</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>bagdad</td><td>bagdad</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>bagdad</td><td>bagdad</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>bagdad</td><td>bagdad</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>bakst green</td><td>bakstgreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>balge yellow</td><td>balgeyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>ball lake</td><td>balllake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>ball lake</td><td>balllake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>balsam</td><td>balsam</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>balsam green</td><td>balsamgreen</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>baltic</td><td>baltic</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>baltic</td><td>baltic</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>bambino</td><td>bambino</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>bamboo</td><td>bamboo</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>bamboo</td><td>bamboo</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>banana</td><td>banana</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>banner</td><td>banner</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>banshee</td><td>banshee</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>barberry</td><td>barberry</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>barberry</td><td>barberry</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>bark</td><td>bark</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>barwood</td><td>barwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>basketball</td><td>basketball</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>bastard saffron</td><td>bastardsaffron</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>bat</td><td>bat</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>bath stone</td><td>bathstone</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>battleship grey</td><td>battleshipgrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>bay</td><td>bay</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>bayou</td><td>bayou</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>beach</td><td>beach</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>beach</td><td>beach</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>beach tan </td><td>beachtan</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>bear</td><td>bear</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>bear's hair</td><td>bearshair</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>bearskin [grey] </td><td>bearskingrey</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>beaucaire</td><td>beaucaire</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>beaucaire</td><td>beaucaire</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>beaver</td><td>beaver</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>beaverpelt</td><td>beaverpelt</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>beech</td><td>beech</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>beech</td><td>beech</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>beechnut</td><td>beechnut</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>beef's blood</td><td>beefsblood</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>beeswax</td><td>beeswax</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>beetle</td><td>beetle</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>begonia</td><td>begonia</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>begonia rose</td><td>begoniarose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>beige</td><td>beige</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>beige</td><td>beige</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>beige soire</td><td>beigesoire</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>belladonna</td><td>belladonna</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>belleek</td><td>belleek</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>belleek</td><td>belleek</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>belleek</td><td>belleek</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>belleek</td><td>belleek</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>bellemonte</td><td>bellemonte</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>bellflower</td><td>bellflower</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>berlin brown</td><td>berlinbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>berlin brown</td><td>berlinbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>berlin red</td><td>berlinred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>bermuda</td><td>bermuda</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>beryl</td><td>beryl</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>beryl blue</td><td>berylblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>beryl green</td><td>berylgreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>biarritz</td><td>biarritz</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>biarritz</td><td>biarritz</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>big four yellow, big 4 yellow</td><td>bigfouryellowbig4yellow</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>big four yellow, big 4 yellow</td><td>bigfouryellowbig4yellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>billiard</td><td>billiard</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>biscay green</td><td>biscaygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>biscuit</td><td>biscuit</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>biscuit</td><td>biscuit</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>biscuit</td><td>biscuit</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>biscuit</td><td>biscuit</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>bishop</td><td>bishop</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>bishop's purple</td><td>bishopspurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>bishop's violet</td><td>bishopsviolet</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>biskra</td><td>biskra</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>bismarck</td><td>bismarck</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>bismarck brown</td><td>bismarckbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>bison</td><td>bison</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>bisque</td><td>bisque</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>bisque</td><td>bisque</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>bister</td><td>bister</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>bister</td><td>bister</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>bistre</td><td>bistre</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>bistre</td><td>bistre</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>bistre green</td><td>bistregreen</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>bistre green</td><td>bistregreen</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>bittersweet</td><td>bittersweet</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>bittersweet</td><td>bittersweet</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>bittersweet orange</td><td>bittersweetorange</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>bittersweet pink</td><td>bittersweetpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>bitumen</td><td>bitumen</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>bladder green</td><td>bladdergreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>blaze </td><td>blaze</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>blaze </td><td>blaze</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>bleu de lyons</td><td>bleudelyons</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>bleu de lyons</td><td>bleudelyons</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>bleu d'orient</td><td>bleudorient</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>bleu louise</td><td>bleulouise</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>bleu louise</td><td>bleulouise</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>bleu pass </td><td>bleupass</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>bleu pass </td><td>bleupass</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>bleu pass </td><td>bleupass</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>blond</td><td>blond</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>blond</td><td>blond</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>blondine</td><td>blondine</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>blonket</td><td>blonket</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>blood red</td><td>bloodred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>blood red</td><td>bloodred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>blossom</td><td>blossom</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue ashes</td><td>blueashes</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue aster</td><td>blueaster</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>bluebell</td><td>bluebell</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>bluebell</td><td>bluebell</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue bice</td><td>bluebice</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue bird, bluebird</td><td>bluebirdbluebird</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>blue devil</td><td>bluedevil</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>blue fox</td><td>bluefox</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>blue grass</td><td>bluegrass</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>blue haze</td><td>bluehaze</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>bluejay</td><td>bluejay</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>bluejay</td><td>bluejay</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>blue jewel</td><td>bluejewel</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>blue lavender</td><td>bluelavender</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>blue lotus</td><td>bluelotus</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>blue ochre</td><td>blueochre</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>blue ochre</td><td>blueochre</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>blue orchid</td><td>blueorchid</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>blue sapphire</td><td>bluesapphire</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>blue spruce</td><td>bluespruce</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>blue spruce</td><td>bluespruce</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>bluet</td><td>bluet</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>blue turquoise</td><td>blueturquoise</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>blue turquoise</td><td>blueturquoise</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue untramarine ash </td><td>blueuntramarineash</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue verditer</td><td>blueverditer</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>blunket</td><td>blunket</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>blush</td><td>blush</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>blush</td><td>blush</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>blush rose</td><td>blushrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>boa</td><td>boa</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>boa</td><td>boa</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>boa</td><td>boa</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>bobolink</td><td>bobolink</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>bois de rose </td><td>boisderose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>bokhara</td><td>bokhara</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>bole</td><td>bole</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>bole armoniack</td><td>bolearmoniack</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>bolus</td><td>bolus</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>bombay</td><td>bombay</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>bombay</td><td>bombay</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>bone brown</td><td>bonebrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>bone brown</td><td>bonebrown</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>bonfire</td><td>bonfire</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>bonito</td><td>bonito</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>bonnie blue</td><td>bonnieblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>boreal</td><td>boreal</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>bosphorus</td><td>bosphorus</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>botticelli</td><td>botticelli</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>bottle green</td><td>bottlegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>bottle green</td><td>bottlegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>bougainville</td><td>bougainville</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>bougainville</td><td>bougainville</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>boulevard</td><td>boulevard</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>bouquet green</td><td>bouquetgreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>bourgeon</td><td>bourgeon</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>box green</td><td>boxgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>bracken</td><td>bracken</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>bracken</td><td>bracken</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>bramble</td><td>bramble</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>bran</td><td>bran</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>bran</td><td>bran</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>brass</td><td>brass</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>brazen yellow</td><td>brazenyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>brazil brown</td><td>brazilbrown</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>brazil [red] </td><td>brazilred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>brazilwood</td><td>brazilwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>brazilwood</td><td>brazilwood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>bremen blue</td><td>bremenblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>bremen green</td><td>bremengreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>brewster green</td><td>brewstergreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>briar</td><td>briar</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>briar</td><td>briar</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>briarwood</td><td>briarwood</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>brickdust</td><td>brickdust</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>brick red</td><td>brickred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brick red</td><td>brickred</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>bridal rose</td><td>bridalrose</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>brigand</td><td>brigand</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>brigand</td><td>brigand</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>brigand</td><td>brigand</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>brigand</td><td>brigand</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>brimstone [yellow] </td><td>brimstoneyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>brittany</td><td>brittany</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>brittany</td><td>brittany</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>brittany</td><td>brittany</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>broccoli brown</td><td>broccolibrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>broncho</td><td>broncho</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>broncho</td><td>broncho</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>broncho</td><td>broncho</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>bronze</td><td>bronze</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>bronze brown</td><td>bronzebrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>bronze clair</td><td>bronzeclair</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>bronze green</td><td>bronzegreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>bronze lustre</td><td>bronzelustre</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>bronze nude</td><td>bronzenude</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>bronze red</td><td>bronzered</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>bronzesheen</td><td>bronzesheen</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>bronze yellow</td><td>bronzeyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>bronze yellow</td><td>bronzeyellow</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>brown bay</td><td>brownbay</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>brown bread</td><td>brownbread</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brown bread</td><td>brownbread</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>brown madder</td><td>brownmadder</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>brown ochre</td><td>brownochre</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>brown pink</td><td>brownpink</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>brown pink</td><td>brownpink</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>brown red</td><td>brownred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>brown stone</td><td>brownstone</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>brownstone</td><td>brownstone</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brown sugar</td><td>brownsugar</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>brown sugar</td><td>brownsugar</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>brown sugar</td><td>brownsugar</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>brown sugar</td><td>brownsugar</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>bruges</td><td>bruges</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>bruges</td><td>bruges</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>brushwood</td><td>brushwood</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brussels brown</td><td>brusselsbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>brussels brown</td><td>brusselsbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>brussels brown</td><td>brusselsbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>brussels brown</td><td>brusselsbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>buccaneer</td><td>buccaneer</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>buccaneer</td><td>buccaneer</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>buccaneer</td><td>buccaneer</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>buccaneer</td><td>buccaneer</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>buckskin</td><td>buckskin</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>buckskin</td><td>buckskin</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>buckthorn berries</td><td>buckthornberries</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>buckthorn berries</td><td>buckthornberries</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>buckthorn brown</td><td>buckthornbrown</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>buckthorn brown</td><td>buckthornbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>buckthorn brown</td><td>buckthornbrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>buckthorn brown</td><td>buckthornbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>buckthorn brown</td><td>buckthornbrown</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>buckthorn brown</td><td>buckthornbrown</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>buckthorn brown</td><td>buckthornbrown</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>buddha</td><td>buddha</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>buddha</td><td>buddha</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>bud green</td><td>budgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>buff</td><td>buff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>buffalo</td><td>buffalo</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>bulgare</td><td>bulgare</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>bunny</td><td>bunny</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>bure</td><td>bure</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>bure</td><td>bure</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>bure</td><td>bure</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>burel</td><td>burel</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>burgundy</td><td>burgundy</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>burgundy</td><td>burgundy</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>burgundy violet</td><td>burgundyviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>burlwood</td><td>burlwood</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>burlwood</td><td>burlwood</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>burma</td><td>burma</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>burmese gold</td><td>burmesegold</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>burmese ruby</td><td>burmeseruby</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>burn blue</td><td>burnblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>burn blue</td><td>burnblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>burn blue</td><td>burnblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>burn blue</td><td>burnblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>burnished gold</td><td>burnishedgold</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>burnished gold</td><td>burnishedgold</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>burnished gold</td><td>burnishedgold</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>burnished gold</td><td>burnishedgold</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>burnished gold</td><td>burnishedgold</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>burnous</td><td>burnous</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>burnt</td><td>burnt</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>burnt almond</td><td>burntalmond</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>burnt carmine</td><td>burntcarmine</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>burnt carmine</td><td>burntcarmine</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>burnt coral</td><td>burntcoral</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>burnt crimson lake</td><td>burntcrimsonlake</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>burnt crimson lake</td><td>burntcrimsonlake</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>burnt italian earth</td><td>burntitalianearth</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>burnt italian ochre</td><td>burntitalianochre</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>burnt lake</td><td>burntlake</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>burnt lake</td><td>burntlake</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>burnt ochre</td><td>burntochre</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>burnt orange</td><td>burntorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>burnt roman ochre</td><td>burntromanochre</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>burnt rose</td><td>burntrose</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>burnt rose</td><td>burntrose</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>burnt russet</td><td>burntrusset</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>burnt russet</td><td>burntrusset</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>burnt sienna</td><td>burntsienna</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>burnt terre verte</td><td>burntterreverte</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>burnt umber</td><td>burntumber</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>buttercup [yellow] </td><td>buttercupyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>butterfly</td><td>butterfly</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>butternut</td><td>butternut</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>butterscotch</td><td>butterscotch</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>butterscotch</td><td>butterscotch</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>byron</td><td>byron</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>byzantine</td><td>byzantine</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>byzantium</td><td>byzantium</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>byzantium</td><td>byzantium</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>cabaret</td><td>cabaret</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>cabbage green</td><td>cabbagegreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>cacao</td><td>cacao</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>cacao brown</td><td>cacaobrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cacha</td><td>cacha</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cachou</td><td>cachou</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>cactus</td><td>cactus</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>cadet</td><td>cadet</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>cadet blue</td><td>cadetblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>cadet grey </td><td>cadetgrey</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>cadmium carmine</td><td>cadmiumcarmine</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>cadmium green</td><td>cadmiumgreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd300;width:4em;" /><td>cadmium lemon</td><td>cadmiumlemon</td><td>##dcd300</td><td>220</td> <td>211</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>cadmium lemon</td><td>cadmiumlemon</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>cadmium orange</td><td>cadmiumorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>cadmium purple</td><td>cadmiumpurple</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>cadmium purple</td><td>cadmiumpurple</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>cadmium vermilion</td><td>cadmiumvermilion</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>cadmium vermilion</td><td>cadmiumvermilion</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>cadmium yellow</td><td>cadmiumyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>cadmium yellow</td><td>cadmiumyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>cadmium yellow</td><td>cadmiumyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>cadmium yellow</td><td>cadmiumyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>caen stone</td><td>caenstone</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#0085a1;width:4em;" /><td>caeruleum</td><td>caeruleum</td><td>##0085a1</td><td>0</td> <td>133</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>caeruleum</td><td>caeruleum</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>caf-au-lait</td><td>cafaulait</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>caf-au-lait</td><td>cafaulait</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>caf-au-lait</td><td>cafaulait</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>caf crme</td><td>cafcrme</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>caf crme</td><td>cafcrme</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>caf crme</td><td>cafcrme</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>caf noir</td><td>cafnoir</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>cairo</td><td>cairo</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>calabash</td><td>calabash</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>calabash</td><td>calabash</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>calamine blue</td><td>calamineblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>caldera</td><td>caldera</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>caledonian brown</td><td>caledonianbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>caliaturwood</td><td>caliaturwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>california color</td><td>californiacolor</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>california green</td><td>californiagreen</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>calla green</td><td>callagreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>calliste green</td><td>callistegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>calliste green</td><td>callistegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>cambridge blue</td><td>cambridgeblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>cambridge red</td><td>cambridgered</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>cambridge red</td><td>cambridgered</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>camel</td><td>camel</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>camellia </td><td>camellia</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>camellia </td><td>camellia</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>camels hair or camel's hair</td><td>camelshairorcamelshair</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>cameo blue</td><td>cameoblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>cameo brown</td><td>cameobrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>cameo brown</td><td>cameobrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>cameo brown</td><td>cameobrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>cameo brown</td><td>cameobrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>cameo green</td><td>cameogreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>cameo green</td><td>cameogreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>cameo green</td><td>cameogreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>cameo pink</td><td>cameopink</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cameo yellow</td><td>cameoyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>campanula</td><td>campanula</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>campanula</td><td>campanula</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>campanula blue</td><td>campanulablue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>campanula blue</td><td>campanulablue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>campanula blue</td><td>campanulablue</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>campanula purple</td><td>campanulapurple</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>campanula violet</td><td>campanulaviolet</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>camrier</td><td>camrier</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>camwood</td><td>camwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>canard</td><td>canard</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>canard</td><td>canard</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>canary-bird green</td><td>canarybirdgreen</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>canary green</td><td>canarygreen</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>canary [yellow] </td><td>canaryyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>candida</td><td>candida</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>candy pink</td><td>candypink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>candy pink</td><td>candypink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>candy pink</td><td>candypink</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>canna</td><td>canna</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>canna</td><td>canna</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>canna</td><td>canna</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>canna</td><td>canna</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>cannon</td><td>cannon</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>canterbury</td><td>canterbury</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>canton [blue] </td><td>cantonblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>canton jade</td><td>cantonjade</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>canyon</td><td>canyon</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>canyon</td><td>canyon</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cappagh</td><td>cappagh</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cappah brown</td><td>cappahbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>capri </td><td>capri</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>caprice</td><td>caprice</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>caprice</td><td>caprice</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>capucine </td><td>capucine</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>capucine buff </td><td>capucinebuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>capucine lake </td><td>capucinelake</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>capucine lake </td><td>capucinelake</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>capucine lake </td><td>capucinelake</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>capucine lake </td><td>capucinelake</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>capucine madder </td><td>capucinemadder</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>capucine orange </td><td>capucineorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>capucine red </td><td>capucinered</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>capucine red </td><td>capucinered</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>capucine yellow </td><td>capucineyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>caput mortuum</td><td>caputmortuum</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>caraibe</td><td>caraibe</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>caraibe</td><td>caraibe</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>caraibe</td><td>caraibe</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>caraibe</td><td>caraibe</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>caramel</td><td>caramel</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>caramel</td><td>caramel</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>carbuncle</td><td>carbuncle</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>cardinal [red] </td><td>cardinalred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carmine</td><td>carmine</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>carmine</td><td>carmine</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carmine lake</td><td>carminelake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>carmine lake</td><td>carminelake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>carnation</td><td>carnation</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>carnation</td><td>carnation</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>carnation [red] </td><td>carnationred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>carnation rose</td><td>carnationrose</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>carnelian</td><td>carnelian</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>carnelian red</td><td>carnelianred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>carnival red</td><td>carnivalred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>carob brown</td><td>carobbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>caroubier</td><td>caroubier</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>carrara green</td><td>carraragreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>carrot red</td><td>carrotred</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>carrot red</td><td>carrotred</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carthamus red</td><td>carthamusred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carthamus rose</td><td>carthamusrose</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cartouche</td><td>cartouche</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cartridge buff</td><td>cartridgebuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>cartridge buff</td><td>cartridgebuff</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>cascade</td><td>cascade</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cashew</td><td>cashew</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cashew lake</td><td>cashewlake</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>cashew nut</td><td>cashewnut</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cashoo</td><td>cashoo</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>casino pink</td><td>casinopink</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cassel brown</td><td>casselbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cassel earth</td><td>casselearth</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>cassel yellow</td><td>casselyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>cassel yellow</td><td>casselyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>cassel yellow</td><td>casselyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>cassel yellow</td><td>casselyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>casserole</td><td>casserole</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>castaneous</td><td>castaneous</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>castellon</td><td>castellon</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>castile earth</td><td>castileearth</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>castilian brown</td><td>castilianbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>castilian red</td><td>castilianred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>castor</td><td>castor</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>castor grey </td><td>castorgrey</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>catalpa</td><td>catalpa</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>catawba</td><td>catawba</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#2e1d21;width:4em;" /><td>catawba</td><td>catawba</td><td>##2e1d21</td><td>46</td> <td>29</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cate</td><td>cate</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>catechu</td><td>catechu</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>cathay</td><td>cathay</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>cathay</td><td>cathay</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>cathedral</td><td>cathedral</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>cathedral blue</td><td>cathedralblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>cathedral blue</td><td>cathedralblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>cattail</td><td>cattail</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>cattleya</td><td>cattleya</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>caucasia</td><td>caucasia</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>cauldron</td><td>cauldron</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>cauldron</td><td>cauldron</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>cauldron</td><td>cauldron</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>cavalry</td><td>cavalry</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>cedar</td><td>cedar</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>cedarbark</td><td>cedarbark</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>cedarbark</td><td>cedarbark</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>cedar green</td><td>cedargreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>cedar wood</td><td>cedarwood</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>cedre</td><td>cedre</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>celadon green</td><td>celadongreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>celandine green</td><td>celandinegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>celest</td><td>celest</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>celest</td><td>celest</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>celestial</td><td>celestial</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>celestial blue</td><td>celestialblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>cellini</td><td>cellini</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>cellini</td><td>cellini</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>cement</td><td>cement</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>cendrillon</td><td>cendrillon</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>cendrillon</td><td>cendrillon</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>centennial brown</td><td>centennialbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>centennial brown</td><td>centennialbrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>centennial brown</td><td>centennialbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>centre blue</td><td>centreblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>ceramic</td><td>ceramic</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>ceres</td><td>ceres</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>cerise</td><td>cerise</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>cerro green</td><td>cerrogreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>cerro green</td><td>cerrogreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>certosa</td><td>certosa</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>certosa</td><td>certosa</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>certosa</td><td>certosa</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>cerulean</td><td>cerulean</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>cerulean</td><td>cerulean</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#0085a1;width:4em;" /><td>cerulean blue</td><td>ceruleanblue</td><td>##0085a1</td><td>0</td> <td>133</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>cerulean blue</td><td>ceruleanblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>ceylon blue</td><td>ceylonblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>chaetura black</td><td>chaeturablack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>chaetura drab</td><td>chaeturadrab</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>chalcedony yellow</td><td>chalcedonyyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>chalet red</td><td>chaletred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>chamois</td><td>chamois</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>chamois skin</td><td>chamoisskin</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>chamoline</td><td>chamoline</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>chamoline</td><td>chamoline</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>chamoline</td><td>chamoline</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>chamoline</td><td>chamoline</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>chamoline</td><td>chamoline</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>chamoline</td><td>chamoline</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>chamoline</td><td>chamoline</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>champagne</td><td>champagne</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>champagne</td><td>champagne</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>champagne</td><td>champagne</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>champagne</td><td>champagne</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>chantilly</td><td>chantilly</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>charcoal grey</td><td>charcoalgrey</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>chardon</td><td>chardon</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>charles x</td><td>charlesx</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>chartreuse</td><td>chartreuse</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>chartreuse</td><td>chartreuse</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>chartreuse</td><td>chartreuse</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>chartreuse</td><td>chartreuse</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>chartreuse green</td><td>chartreusegreen</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>chartreuse yellow</td><td>chartreuseyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>chartreuse yellow</td><td>chartreuseyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#173620;width:4em;" /><td>chasseur</td><td>chasseur</td><td>##173620</td><td>23</td> <td>54</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>chatemuc</td><td>chatemuc</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>chatenay pink</td><td>chatenaypink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>chatenay pink</td><td>chatenaypink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>chaudron</td><td>chaudron</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>chaudron</td><td>chaudron</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>chaudron</td><td>chaudron</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>chaudron</td><td>chaudron</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>checkerberry</td><td>checkerberry</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>chemic blue </td><td>chemicblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>chemic green </td><td>chemicgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>cherokee</td><td>cherokee</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>cherry</td><td>cherry</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>cherry bloom</td><td>cherrybloom</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>cherry blossom</td><td>cherryblossom</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>cherry red</td><td>cherryred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>cherub</td><td>cherub</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>chessylite blue</td><td>chessyliteblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>chestnut</td><td>chestnut</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>chevreuse</td><td>chevreuse</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>chevreuse</td><td>chevreuse</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>chianti</td><td>chianti</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>chickadee gray</td><td>chickadeegray</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>chicle</td><td>chicle</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>chicory</td><td>chicory</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>chicory blue</td><td>chicoryblue</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>chicory blue</td><td>chicoryblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>chimney red</td><td>chimneyred</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>chimney red</td><td>chimneyred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>china blue</td><td>chinablue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>china blue</td><td>chinablue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>china rose</td><td>chinarose</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>chinchilla</td><td>chinchilla</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>chin-chin blue</td><td>chinchinblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>chinese gold</td><td>chinesegold</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>chinese green</td><td>chinesegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>chinese green</td><td>chinesegreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>chinese green</td><td>chinesegreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>chinese green</td><td>chinesegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>chinese lake</td><td>chineselake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>chinese lake</td><td>chineselake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>chinese orange</td><td>chineseorange</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>chinese orange</td><td>chineseorange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>chinese red</td><td>chinesered</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>chinese red</td><td>chinesered</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>chinese red</td><td>chinesered</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>chinese rouge</td><td>chineserouge</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>chinese vermilion </td><td>chinesevermilion</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>chinese violet</td><td>chineseviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>chinese yellow</td><td>chineseyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>chinese yellow</td><td>chineseyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>chinese yellow</td><td>chineseyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>chinese yellow</td><td>chineseyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>chinese yellow</td><td>chineseyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>ch'ing</td><td>ching</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>chinook</td><td>chinook</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>chip</td><td>chip</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>chip</td><td>chip</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>chipmunk</td><td>chipmunk</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>chippendale</td><td>chippendale</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>chiswick</td><td>chiswick</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>chocolate</td><td>chocolate</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>chocolate brown</td><td>chocolatebrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>chocolate maroon</td><td>chocolatemaroon</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>chrome citron</td><td>chromecitron</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>chrome green</td><td>chromegreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>chrome green</td><td>chromegreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>chrome lemon</td><td>chromelemon</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>chrome orange</td><td>chromeorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>chrome orange</td><td>chromeorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>chrome primrose</td><td>chromeprimrose</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>chrome primrose</td><td>chromeprimrose</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>chrome scarlet</td><td>chromescarlet</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>chromium green</td><td>chromiumgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>chromium oxide </td><td>chromiumoxide</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>chrysanthemum</td><td>chrysanthemum</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>chrysanthemum</td><td>chrysanthemum</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>chrysocollo</td><td>chrysocollo</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>chrysolite green</td><td>chrysolitegreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>chrysolite green</td><td>chrysolitegreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>chrysolite green</td><td>chrysolitegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>chrysopraise [green] </td><td>chrysopraisegreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>chrysopraise [green] </td><td>chrysopraisegreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>chukker brown</td><td>chukkerbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>chukker brown</td><td>chukkerbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>chutney</td><td>chutney</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cigarette</td><td>cigarette</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>cinder [grey] </td><td>cindergrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>cineraria</td><td>cineraria</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>cinereous</td><td>cinereous</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>cinnamon</td><td>cinnamon</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>cinnamon</td><td>cinnamon</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cinnamon brown</td><td>cinnamonbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>cinnamon brown</td><td>cinnamonbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>cinnamon pink</td><td>cinnamonpink</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>circassian</td><td>circassian</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>citrine</td><td>citrine</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>citronelle</td><td>citronelle</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>citronelle</td><td>citronelle</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>citronelle</td><td>citronelle</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>citronelle</td><td>citronelle</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>citron green</td><td>citrongreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>citron green</td><td>citrongreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>citron [yellow] </td><td>citronyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>citrus</td><td>citrus</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>civette green</td><td>civettegreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>clair de lune</td><td>clairdelune</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>claret cup</td><td>claretcup</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>claret lees</td><td>claretlees</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>claret [red] </td><td>claretred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>claver</td><td>claver</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>clay</td><td>clay</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>clay</td><td>clay</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>clay</td><td>clay</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>clay bank</td><td>claybank</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>clay drab</td><td>claydrab</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>clay drab</td><td>claydrab</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>clematis</td><td>clematis</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>cleopatra</td><td>cleopatra</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>clochette</td><td>clochette</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>clochette</td><td>clochette</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>cloisonn</td><td>cloisonn</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>cloisonn</td><td>cloisonn</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>cloud</td><td>cloud</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>cloud grey </td><td>cloudgrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>cloud grey </td><td>cloudgrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>cloudy amber</td><td>cloudyamber</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>cloudy amber</td><td>cloudyamber</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>clove</td><td>clove</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>clove brown</td><td>clovebrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>clove pink</td><td>clovepink</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>clover</td><td>clover</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>cobalt blue</td><td>cobaltblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>cobalt glass</td><td>cobaltglass</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>cobalt glass</td><td>cobaltglass</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>cobalt green</td><td>cobaltgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>cobalt red</td><td>cobaltred</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>cobalt red</td><td>cobaltred</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>cobalt ultramarine </td><td>cobaltultramarine</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>cobalt violet</td><td>cobaltviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>cobalt yellow</td><td>cobaltyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>cobalt yellow</td><td>cobaltyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>cobblestone</td><td>cobblestone</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>cobweb</td><td>cobweb</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>coccineous</td><td>coccineous</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>cocher</td><td>cocher</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cochin</td><td>cochin</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>cochineal</td><td>cochineal</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>cockatoo</td><td>cockatoo</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cocoa</td><td>cocoa</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cocoa brown</td><td>cocoabrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>cocobala</td><td>cocobala</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>cocobala</td><td>cocobala</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>coconut</td><td>coconut</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>coconut brown</td><td>coconutbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>cod grey</td><td>codgrey</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>cod grey</td><td>codgrey</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#0085a1;width:4em;" /><td>coeruleum</td><td>coeruleum</td><td>##0085a1</td><td>0</td> <td>133</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>coeruleum</td><td>coeruleum</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>coffee</td><td>coffee</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cognac</td><td>cognac</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>colcothar</td><td>colcothar</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>colewort green</td><td>colewortgreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>colibri</td><td>colibri</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>collie</td><td>collie</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cologne brown</td><td>colognebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cologne earth</td><td>cologneearth</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>cologne yellow</td><td>cologneyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>colonial</td><td>colonial</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>colonial</td><td>colonial</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>colonial</td><td>colonial</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>colonial</td><td>colonial</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>colonial buff</td><td>colonialbuff</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>colonial buff</td><td>colonialbuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>colonial yellow</td><td>colonialyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>columbia</td><td>columbia</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>columbia blue</td><td>columbiablue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>columbian red</td><td>columbianred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>columbine blue </td><td>columbineblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>columbine blue </td><td>columbineblue</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>columbine red </td><td>columbinered</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>comet</td><td>comet</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>commelina blue</td><td>commelinablue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>commodore</td><td>commodore</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>como</td><td>como</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>conch shell</td><td>conchshell</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>concord</td><td>concord</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>condor</td><td>condor</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>confetti</td><td>confetti</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>confetti</td><td>confetti</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>congo [brown] </td><td>congobrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>congo pink</td><td>congopink</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>continental blue</td><td>continentalblue</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>continental blue</td><td>continentalblue</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cookie</td><td>cookie</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>coolie</td><td>coolie</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>coolie</td><td>coolie</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>copenhagen [blue] </td><td>copenhagenblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>copenhagen [blue] </td><td>copenhagenblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>copper</td><td>copper</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>copper blue</td><td>copperblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>copper brown</td><td>copperbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>copper green</td><td>coppergreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>copperleaf</td><td>copperleaf</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>copper lustre</td><td>copperlustre</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>copper red</td><td>copperred</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>copper rose</td><td>copperrose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>copper yellow</td><td>copperyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>copra</td><td>copra</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>coptic</td><td>coptic</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>coquelicot</td><td>coquelicot</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>coquelicot</td><td>coquelicot</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>coquette</td><td>coquette</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>coquette</td><td>coquette</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>coralbell</td><td>coralbell</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>coralbell</td><td>coralbell</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>coral blush</td><td>coralblush</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>coral blush</td><td>coralblush</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>coral blush</td><td>coralblush</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>coral pink</td><td>coralpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>coral [red] </td><td>coralred</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>coral sands</td><td>coralsands</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>coral sands</td><td>coralsands</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>corcir</td><td>corcir</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>cordova</td><td>cordova</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>cordovan</td><td>cordovan</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>cordovan</td><td>cordovan</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>corial</td><td>corial</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>corial</td><td>corial</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>corinth</td><td>corinth</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>corinthian pink</td><td>corinthianpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>corinthian pink</td><td>corinthianpink</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>corinthian purple</td><td>corinthianpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>corinthian purple</td><td>corinthianpurple</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>corinthian red</td><td>corinthianred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>cork</td><td>cork</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>cork</td><td>cork</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>corker</td><td>corker</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>corkur</td><td>corkur</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>corn</td><td>corn</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>cornelian red</td><td>cornelianred</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>cornflower [blue] </td><td>cornflowerblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>cornhusk</td><td>cornhusk</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>cornhusk</td><td>cornhusk</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>cornsilk</td><td>cornsilk</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>coromandel</td><td>coromandel</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>coronation</td><td>coronation</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>coronation</td><td>coronation</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>corsage green</td><td>corsagegreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>corsage green</td><td>corsagegreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>corsair</td><td>corsair</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>corsican blue</td><td>corsicanblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>corsican blue</td><td>corsicanblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>corsican blue</td><td>corsicanblue</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>corydalis green</td><td>corydalisgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>cosmos</td><td>cosmos</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>cossack</td><td>cossack</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>cossack green</td><td>cossackgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>cosse green</td><td>cossegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cotch</td><td>cotch</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>cotinga purple</td><td>cotingapurple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>cotinga purple</td><td>cotingapurple</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>cotinga purple</td><td>cotingapurple</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>cotinga purple</td><td>cotingapurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>cotrine</td><td>cotrine</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>cotrine</td><td>cotrine</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>courge green</td><td>courgegreen</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>courge green</td><td>courgegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>courge green</td><td>courgegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cowboy</td><td>cowboy</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>cowboy</td><td>cowboy</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>cowboy</td><td>cowboy</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>cowboy</td><td>cowboy</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>cowslip</td><td>cowslip</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>cowslip</td><td>cowslip</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>crabapple</td><td>crabapple</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>cracker</td><td>cracker</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>crag</td><td>crag</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>crane</td><td>crane</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>crash</td><td>crash</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>crash</td><td>crash</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>crash</td><td>crash</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>crash</td><td>crash</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>crawshay red</td><td>crawshayred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>crawshay red</td><td>crawshayred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>crayon blue</td><td>crayonblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cream</td><td>cream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>cream beige</td><td>creambeige</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>cream beige</td><td>creambeige</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>cream beige</td><td>creambeige</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cream buff</td><td>creambuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>cream buff</td><td>creambuff</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>creole</td><td>creole</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>creole</td><td>creole</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>cress green</td><td>cressgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>cresson</td><td>cresson</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>crevette</td><td>crevette</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>crimson lake</td><td>crimsonlake</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>crimson madder</td><td>crimsonmadder</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>crimson maple</td><td>crimsonmaple</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>croceus</td><td>croceus</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>croceus</td><td>croceus</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>crocreal</td><td>crocreal</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>crocreal</td><td>crocreal</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>crocus</td><td>crocus</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>crocus</td><td>crocus</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>crocus</td><td>crocus</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>crocus</td><td>crocus</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>crocus martis</td><td>crocusmartis</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>crostil</td><td>crostil</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>crotal</td><td>crotal</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>crottle</td><td>crottle</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>crowshay red</td><td>crowshayred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>crowshay red</td><td>crowshayred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>cruiser</td><td>cruiser</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>crushed berry</td><td>crushedberry</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>crushed strawberry</td><td>crushedstrawberry</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>crushed violets</td><td>crushedviolets</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>crystal grey</td><td>crystalgrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>crystal palace blue</td><td>crystalpalaceblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>crystal palace green</td><td>crystalpalacegreen</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>crystals of venus</td><td>crystalsofvenus</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>cub</td><td>cub</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>cuba</td><td>cuba</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>cuba</td><td>cuba</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>cuban sand</td><td>cubansand</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>cudbear</td><td>cudbear</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>cuir</td><td>cuir</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cuisse de nymphe</td><td>cuissedenymphe</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cullen earth</td><td>cullenearth</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>cupid pink</td><td>cupidpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>cupreous</td><td>cupreous</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>curcuma</td><td>curcuma</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>currant [red] </td><td>currantred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cutch</td><td>cutch</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>cuyahoga red</td><td>cuyahogared</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>cyan blue</td><td>cyanblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>cyan blue</td><td>cyanblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>cyanine blue</td><td>cyanineblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>cyanine blue</td><td>cyanineblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>cyanine blue</td><td>cyanineblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#341731;width:4em;" /><td>cyclamen</td><td>cyclamen</td><td>##341731</td><td>52</td> <td>23</td> <td>49</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>cygnet</td><td>cygnet</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>cypress [green] </td><td>cypressgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>cypress green</td><td>cypressgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>cyprus earth</td><td>cyprusearth</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>cyprus earth</td><td>cyprusearth</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>cyprus umber</td><td>cyprusumber</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>cyprus umber</td><td>cyprusumber</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>daffodile [yellow] </td><td>daffodileyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>daffodil yellow</td><td>daffodilyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>daffodil yellow</td><td>daffodilyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>daffodil yellow</td><td>daffodilyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>daffodil yellow</td><td>daffodilyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>dagestan</td><td>dagestan</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>dahlia</td><td>dahlia</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dahlia carmine</td><td>dahliacarmine</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>dahlia mauve</td><td>dahliamauve</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dahlia purple</td><td>dahliapurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#38152c;width:4em;" /><td>dahlia purple</td><td>dahliapurple</td><td>##38152c</td><td>56</td> <td>21</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>damascen</td><td>damascen</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>damascen</td><td>damascen</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>damask</td><td>damask</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>damonico</td><td>damonico</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>damonico</td><td>damonico</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>damonico</td><td>damonico</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>damonico</td><td>damonico</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>damson</td><td>damson</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>damson</td><td>damson</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>dana</td><td>dana</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>dana</td><td>dana</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dana</td><td>dana</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>dandelion</td><td>dandelion</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dante</td><td>dante</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>dante</td><td>dante</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dante</td><td>dante</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>danube green</td><td>danubegreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>danube green</td><td>danubegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>daphne</td><td>daphne</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>daphne pink</td><td>daphnepink</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>daphne red</td><td>daphnered</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>daphne red</td><td>daphnered</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>dark beaver</td><td>darkbeaver</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>dark beaver</td><td>darkbeaver</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>dark cardinal</td><td>darkcardinal</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>dark gobelin blue </td><td>darkgobelinblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dark gobelin blue </td><td>darkgobelinblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>dark wedgwood [blue] </td><td>darkwedgwoodblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dark wedgwood [blue] </td><td>darkwedgwoodblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>date</td><td>date</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>datura</td><td>datura</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>dauphine</td><td>dauphine</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>davy's grey</td><td>davysgrey</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>dawn</td><td>dawn</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>dawn grey </td><td>dawngrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>daybreak</td><td>daybreak</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>daybreak</td><td>daybreak</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>daytona</td><td>daytona</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>dbutante pink </td><td>dbutantepink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>dead carnations</td><td>deadcarnations</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>dead leaf</td><td>deadleaf</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>dead leaf</td><td>deadleaf</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>dead leaf</td><td>deadleaf</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>deauville sand</td><td>deauvillesand</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>deauville sand</td><td>deauvillesand</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>deep brunswick green</td><td>deepbrunswickgreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>deep chrome green</td><td>deepchromegreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>deep chrome yellow</td><td>deepchromeyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>deep stone</td><td>deepstone</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>deep stone</td><td>deepstone</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>deep stone</td><td>deepstone</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>deer</td><td>deer</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>delft blue</td><td>delftblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>della robbia</td><td>dellarobbia</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>del monte</td><td>delmonte</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>delphinium</td><td>delphinium</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>delphinium</td><td>delphinium</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>delphinium</td><td>delphinium</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>de'medici </td><td>demedici</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>denmark</td><td>denmark</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>denver</td><td>denver</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>derby blue</td><td>derbyblue</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>desert</td><td>desert</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>devil's red</td><td>devilsred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>devil's red</td><td>devilsred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>devon [brown] </td><td>devonbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>dewey red</td><td>deweyred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>dewey red</td><td>deweyred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dewkiss</td><td>dewkiss</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>diadem</td><td>diadem</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>diana</td><td>diana</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>dianthus</td><td>dianthus</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dianthus</td><td>dianthus</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>diavolo</td><td>diavolo</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>digitalis</td><td>digitalis</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>di palito</td><td>dipalito</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>directoire blue</td><td>directoireblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>directoire blue</td><td>directoireblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>distilled green</td><td>distilledgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>diva blue</td><td>divablue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>diva blue</td><td>divablue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>doe</td><td>doe</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>doe</td><td>doe</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>doe</td><td>doe</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>doe</td><td>doe</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>doe-skin brown</td><td>doeskinbrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>doge</td><td>doge</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>dogwood</td><td>dogwood</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>dogwood</td><td>dogwood</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>dogwood</td><td>dogwood</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>dolly pink</td><td>dollypink</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>domingo</td><td>domingo</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>domingo brown</td><td>domingobrown</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>dorado</td><td>dorado</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>doubloon</td><td>doubloon</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dove</td><td>dove</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dove</td><td>dove</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>dove grey</td><td>dovegrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dover grey</td><td>dovergrey</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>dozer</td><td>dozer</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>drab</td><td>drab</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>drabolive </td><td>drabolive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>dragonfly</td><td>dragonfly</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dragon's blood</td><td>dragonsblood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>dragon's blood</td><td>dragonsblood</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>dragon's blood</td><td>dragonsblood</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>drake</td><td>drake</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>drake's-neck green</td><td>drakesneckgreen</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>dregs of wine</td><td>dregsofwine</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>dregs of wine</td><td>dregsofwine</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>dregs of wine</td><td>dregsofwine</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>dresden blue</td><td>dresdenblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>dresden brown</td><td>dresdenbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>dresden brown</td><td>dresdenbrown</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>dresden brown</td><td>dresdenbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dryad</td><td>dryad</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dry rose</td><td>dryrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>dry rose</td><td>dryrose</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>du barry</td><td>dubarry</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>duck blue</td><td>duckblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>duck green</td><td>duckgreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>duckling</td><td>duckling</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>duckling</td><td>duckling</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>duck-wing</td><td>duckwing</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>du gueslin</td><td>dugueslin</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>du gueslin</td><td>dugueslin</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>du gueslin</td><td>dugueslin</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>dumont's blue</td><td>dumontsblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>dumont's blue</td><td>dumontsblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>dune</td><td>dune</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>durango</td><td>durango</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dusk</td><td>dusk</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>dust</td><td>dust</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>dusty green</td><td>dustygreen</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>dutch azure</td><td>dutchazure</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>dutch azure</td><td>dutchazure</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dutch blue</td><td>dutchblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>dutch orange</td><td>dutchorange</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>dutch orange</td><td>dutchorange</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>dutch pink</td><td>dutchpink</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>dutch pink</td><td>dutchpink</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>dutch pink</td><td>dutchpink</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>dutch pink</td><td>dutchpink</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>dutch scarlet</td><td>dutchscarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>dutch vermilion</td><td>dutchvermilion</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dutch ware blue</td><td>dutchwareblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>dyer's broom</td><td>dyersbroom</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>dyer's broom</td><td>dyersbroom</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>dyer's greenwood</td><td>dyersgreenwood</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>dyer's greenwood</td><td>dyersgreenwood</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>dyer's saffron</td><td>dyerssaffron</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>eagle</td><td>eagle</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>eau-de-javel green</td><td>eaudejavelgreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>eau-de-nile</td><td>eaudenile</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>eau-de-nile</td><td>eaudenile</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>eau-de-nile</td><td>eaudenile</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>eburnean</td><td>eburnean</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>ecclesiastic</td><td>ecclesiastic</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>ecclesiastic</td><td>ecclesiastic</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ecru</td><td>ecru</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>ecru</td><td>ecru</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>eden green</td><td>edengreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>eden green</td><td>edengreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>eggplant</td><td>eggplant</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>eggplant</td><td>eggplant</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>eggshell blue</td><td>eggshellblue</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>eggshell blue</td><td>eggshellblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>eggshell green</td><td>eggshellgreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>eggshell green</td><td>eggshellgreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>eglantine</td><td>eglantine</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>egypt</td><td>egypt</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>egyptian</td><td>egyptian</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>egyptian blue</td><td>egyptianblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>egyptian blue</td><td>egyptianblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>egyptian brown</td><td>egyptianbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>egyptian green</td><td>egyptiangreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>egyptian red</td><td>egyptianred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>egyptian red</td><td>egyptianred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>eifel</td><td>eifel</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>eifel</td><td>eifel</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>elderberry</td><td>elderberry</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>eldorado</td><td>eldorado</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>electric [blue] </td><td>electricblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>electric green</td><td>electricgreen</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#173620;width:4em;" /><td>elephant green</td><td>elephantgreen</td><td>##173620</td><td>23</td> <td>54</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>elephant skin</td><td>elephantskin</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>elf</td><td>elf</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>elf</td><td>elf</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>elfin green</td><td>elfingreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>elk</td><td>elk</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>elm green</td><td>elmgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>elmwood</td><td>elmwood</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>elmwood</td><td>elmwood</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>email</td><td>email</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>email</td><td>email</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>ember</td><td>ember</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>emberglow</td><td>emberglow</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>emberglow</td><td>emberglow</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>emberglow</td><td>emberglow</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>emerald green</td><td>emeraldgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>emerald green</td><td>emeraldgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>emeraude</td><td>emeraude</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>emeraude</td><td>emeraude</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>emeraude</td><td>emeraude</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>eminence</td><td>eminence</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>emperor green</td><td>emperorgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>empire</td><td>empire</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>empire blue</td><td>empireblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>empire green</td><td>empiregreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>empire green</td><td>empiregreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>empire yellow</td><td>empireyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>empire yellow</td><td>empireyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>enamel blue</td><td>enamelblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>enamel blue</td><td>enamelblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>endive</td><td>endive</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>endive</td><td>endive</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>endive blue</td><td>endiveblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>endive blue</td><td>endiveblue</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>english blue</td><td>englishblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>english green</td><td>englishgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>english green</td><td>englishgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>english green</td><td>englishgreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>english grey </td><td>englishgrey</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>english inde</td><td>englishinde</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>english ivy</td><td>englishivy</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>english oak</td><td>englishoak</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>english ochre</td><td>englishochre</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>english pink</td><td>englishpink</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>english pink</td><td>englishpink</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>english pink</td><td>englishpink</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>english pink</td><td>englishpink</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>english red</td><td>englishred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>english red</td><td>englishred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>english red</td><td>englishred</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>english red</td><td>englishred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>english red</td><td>englishred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>english red</td><td>englishred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>english red</td><td>englishred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>english vermilion</td><td>englishvermilion</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>english violet</td><td>englishviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>ensign</td><td>ensign</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>epinauche</td><td>epinauche</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>epsom</td><td>epsom</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>erin</td><td>erin</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>erlau green</td><td>erlaugreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>escadre</td><td>escadre</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>eschel</td><td>eschel</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>eschel</td><td>eschel</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>eskimo</td><td>eskimo</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>esthetic grey</td><td>estheticgrey</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>etain blue</td><td>etainblue</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>etain blue</td><td>etainblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>etain blue</td><td>etainblue</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>etain blue</td><td>etainblue</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>etain blue</td><td>etainblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>etain blue</td><td>etainblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>etang</td><td>etang</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>etang</td><td>etang</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>ether</td><td>ether</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>ethereal blue</td><td>etherealblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>ethereal blue</td><td>etherealblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>eton blue</td><td>etonblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>etruscan</td><td>etruscan</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>etruscan</td><td>etruscan</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>etruscan red</td><td>etruscanred</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>eucalyptus [green] </td><td>eucalyptusgreen</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>eucalyptus [green] </td><td>eucalyptusgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>eugenia red</td><td>eugeniared</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>eugenie</td><td>eugenie</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>eupatorium purple</td><td>eupatoriumpurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>eureka red</td><td>eurekared</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>eve green</td><td>evegreen</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>eve green</td><td>evegreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>eve green</td><td>evegreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>evenglow</td><td>evenglow</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>eventide</td><td>eventide</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>everglade</td><td>everglade</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>evergreen</td><td>evergreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>evque</td><td>evque</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>faded rose</td><td>fadedrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>faience</td><td>faience</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>faience</td><td>faience</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>fairway</td><td>fairway</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>fairy green </td><td>fairygreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>fakir</td><td>fakir</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>falcon</td><td>falcon</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>fallow</td><td>fallow</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>fandango</td><td>fandango</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>faon</td><td>faon</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>faon</td><td>faon</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>faon</td><td>faon</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>faon</td><td>faon</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>fashion gray</td><td>fashiongray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>fawn [brown] </td><td>fawnbrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>fawn [brown] </td><td>fawnbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>fawn [brown] </td><td>fawnbrown</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>fawn [brown] </td><td>fawnbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>feldspar</td><td>feldspar</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>fern</td><td>fern</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>fernambucowood</td><td>fernambucowood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>fernambucowood</td><td>fernambucowood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>fern green</td><td>ferngreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>fern green</td><td>ferngreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>ferruginous</td><td>ferruginous</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>ferruginous</td><td>ferruginous</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>feuille</td><td>feuille</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>feuille morte</td><td>feuillemorte</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>feuille morte</td><td>feuillemorte</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>feuille morte</td><td>feuillemorte</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>feulamort</td><td>feulamort</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>feulamort</td><td>feulamort</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>feulamort</td><td>feulamort</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>fez</td><td>fez</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>field's orange vermilion</td><td>fieldsorangevermilion</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>fiery red</td><td>fieryred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>fiesta</td><td>fiesta</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>fieulamort</td><td>fieulamort</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>fieulamort</td><td>fieulamort</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>fieulamort</td><td>fieulamort</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>filbert [brown] </td><td>filbertbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>filbert [brown] </td><td>filbertbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>filemot</td><td>filemot</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>filemot</td><td>filemot</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>filemot</td><td>filemot</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>fillemot</td><td>fillemot</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>fillemot</td><td>fillemot</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>fillemot</td><td>fillemot</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>firecracker</td><td>firecracker</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>firefly</td><td>firefly</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>firefly</td><td>firefly</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>fire red</td><td>firered</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>fire scarlet</td><td>firescarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>fireweed</td><td>fireweed</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>fir [green] </td><td>firgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#173620;width:4em;" /><td>fir [green] </td><td>firgreen</td><td>##173620</td><td>23</td> <td>54</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>fir [green] </td><td>firgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>firmament</td><td>firmament</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>firmament blue</td><td>firmamentblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>fish grey </td><td>fishgrey</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>fish grey </td><td>fishgrey</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>flag</td><td>flag</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>flame blue</td><td>flameblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>flame blue</td><td>flameblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>flame orange</td><td>flameorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>flame [scarlet] </td><td>flamescarlet</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>flaming maple</td><td>flamingmaple</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>flaming maple</td><td>flamingmaple</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>flaming maple</td><td>flamingmaple</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>flaming maple</td><td>flamingmaple</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>flamingo</td><td>flamingo</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>flammeous</td><td>flammeous</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>flash</td><td>flash</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>flash</td><td>flash</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>flash</td><td>flash</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>flash</td><td>flash</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>flax</td><td>flax</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>flaxen</td><td>flaxen</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>flaxflower blossom</td><td>flaxflowerblossom</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>flaxflower blue</td><td>flaxflowerblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>flaxflower blue</td><td>flaxflowerblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>flea</td><td>flea</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>flemish blue</td><td>flemishblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>flesh</td><td>flesh</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>flesh</td><td>flesh</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>flesh blond</td><td>fleshblond</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>flesh blond</td><td>fleshblond</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>flesh blond</td><td>fleshblond</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>flesh ochre</td><td>fleshochre</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>fleur-de-lys</td><td>fleurdelys</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>flint</td><td>flint</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>flint grey</td><td>flintgrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>flirt</td><td>flirt</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>florence brown</td><td>florencebrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>florence earth</td><td>florenceearth</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>florentine</td><td>florentine</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>florentine lake</td><td>florentinelake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>florentine lake</td><td>florentinelake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>florida gold</td><td>floridagold</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>florida gold</td><td>floridagold</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>floss flower blue</td><td>flossflowerblue</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>flower de luce green</td><td>flowerdelucegreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>fluorite green</td><td>fluoritegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>fluorite violet</td><td>fluoriteviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#301934;width:4em;" /><td>fluorite violet</td><td>fluoriteviolet</td><td>##301934</td><td>48</td> <td>25</td> <td>52</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>fog</td><td>fog</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>foliage brown</td><td>foliagebrown</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>foliage brown</td><td>foliagebrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>foliage brown</td><td>foliagebrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>foliage green</td><td>foliagegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>folimort</td><td>folimort</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>folimort</td><td>folimort</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>folimort</td><td>folimort</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>folkstone</td><td>folkstone</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>folly</td><td>folly</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>folly</td><td>folly</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>fontainebleau</td><td>fontainebleau</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>forest</td><td>forest</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>forest green</td><td>forestgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>forest of dean red</td><td>forestofdeanred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>forest of dean red</td><td>forestofdeanred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>forget-me-not [blue] </td><td>forgetmenotblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>forget-me-not [blue] </td><td>forgetmenotblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>formosa</td><td>formosa</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>formosa</td><td>formosa</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>forsythia</td><td>forsythia</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>fox</td><td>fox</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>fox</td><td>fox</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>fox</td><td>fox</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>foxglove</td><td>foxglove</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>foxglove</td><td>foxglove</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>fox trot</td><td>foxtrot</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>fragonard</td><td>fragonard</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>france</td><td>france</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>france rose</td><td>francerose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#282022;width:4em;" /><td>france rose</td><td>francerose</td><td>##282022</td><td>40</td> <td>32</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>freedom</td><td>freedom</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>freestone</td><td>freestone</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>french beige</td><td>frenchbeige</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>french berries</td><td>frenchberries</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>french berries</td><td>frenchberries</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>french blue</td><td>frenchblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>french blue</td><td>frenchblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>french green</td><td>frenchgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>french green</td><td>frenchgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>french grey</td><td>frenchgrey</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>french grey</td><td>frenchgrey</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>french lilac</td><td>frenchlilac</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>french lilac</td><td>frenchlilac</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>french maroon</td><td>frenchmaroon</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>french nude</td><td>frenchnude</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>french nude</td><td>frenchnude</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>french nude</td><td>frenchnude</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>french ochre</td><td>frenchochre</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>french pink</td><td>frenchpink</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>french pink</td><td>frenchpink</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>french purple</td><td>frenchpurple</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>french scarlet</td><td>frenchscarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>french ultramarine</td><td>frenchultramarine</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>french ultramarine</td><td>frenchultramarine</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>french vermilion</td><td>frenchvermilion</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>[french] veronese green </td><td>frenchveronesegreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>[french] veronese green </td><td>frenchveronesegreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>french white</td><td>frenchwhite</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>french white</td><td>frenchwhite</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>french yellow</td><td>frenchyellow</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>french yellow</td><td>frenchyellow</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>french yellow</td><td>frenchyellow</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>friar</td><td>friar</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>friar</td><td>friar</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>frost grey</td><td>frostgrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>frosty green</td><td>frostygreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>fuchsia</td><td>fuchsia</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>fudge</td><td>fudge</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>fujiyama</td><td>fujiyama</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>fuscous</td><td>fuscous</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>fustet</td><td>fustet</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>fustet</td><td>fustet</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>fustic</td><td>fustic</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>fustic</td><td>fustic</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>gage green</td><td>gagegreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>gaiety</td><td>gaiety</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>galleon</td><td>galleon</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>gallstone</td><td>gallstone</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>gambia</td><td>gambia</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>gamboge</td><td>gamboge</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>gardenia green </td><td>gardeniagreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>gargoyle</td><td>gargoyle</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>garland green</td><td>garlandgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>garland green</td><td>garlandgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>garnet</td><td>garnet</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>garnet brown</td><td>garnetbrown</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>garnet brown</td><td>garnetbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>garnet red</td><td>garnetred</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>garnet red</td><td>garnetred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>garter blue</td><td>garterblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>gaude</td><td>gaude</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>gaude</td><td>gaude</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>gaude lake</td><td>gaudelake</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>gaudy green</td><td>gaudygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>gaudy green</td><td>gaudygreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>gay green </td><td>gaygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>gazelle [brown] </td><td>gazellebrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>gazelle [brown] </td><td>gazellebrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>geisha</td><td>geisha</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>geisha</td><td>geisha</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>geisha</td><td>geisha</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>gendarme [blue] </td><td>gendarmeblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>gendarme [blue] </td><td>gendarmeblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>generall</td><td>generall</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>generall</td><td>generall</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>generall</td><td>generall</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>generall</td><td>generall</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>genestrole</td><td>genestrole</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>genestrole</td><td>genestrole</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>genet</td><td>genet</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>genet</td><td>genet</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>geneva blue</td><td>genevablue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>genista</td><td>genista</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>genoa blue</td><td>genoablue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>gentian</td><td>gentian</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>gentian</td><td>gentian</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>gentian blue</td><td>gentianblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>genuine ultramarine [blue] </td><td>genuineultramarineblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>genuine ultramarine [blue] </td><td>genuineultramarineblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>geranium</td><td>geranium</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>geranium lake</td><td>geraniumlake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>geranium petal</td><td>geraniumpetal</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>geranium pink</td><td>geraniumpink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>ghent</td><td>ghent</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>giallolini</td><td>giallolini</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>giallolini</td><td>giallolini</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>giallolini</td><td>giallolini</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>giallolini</td><td>giallolini</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>giallolino</td><td>giallolino</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>giallolino</td><td>giallolino</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>giallolino</td><td>giallolino</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>giallolino</td><td>giallolino</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>gigas</td><td>gigas</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>gild</td><td>gild</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>gild</td><td>gild</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>gilded</td><td>gilded</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>gilded</td><td>gilded</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>gilt</td><td>gilt</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>gilt</td><td>gilt</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>gingeline</td><td>gingeline</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>gingeoline</td><td>gingeoline</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>ginger</td><td>ginger</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>gingerline</td><td>gingerline</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>gingerspice</td><td>gingerspice</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>gingioline</td><td>gingioline</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>giraffe</td><td>giraffe</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>giraffe</td><td>giraffe</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>glacier</td><td>glacier</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>glacier blue</td><td>glacierblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>gladiolus</td><td>gladiolus</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>glaeul</td><td>glaeul</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>glaeul</td><td>glaeul</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>glass green</td><td>glassgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>glass grey</td><td>glassgrey</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>glaucous</td><td>glaucous</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>glaucous-blue</td><td>glaucousblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>glaucous-green</td><td>glaucousgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>glaucous-grey</td><td>glaucousgrey</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>glaucous-grey</td><td>glaucousgrey</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>glint o'gold</td><td>glintogold</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>gloaming</td><td>gloaming</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>glory</td><td>glory</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#32174d;width:4em;" /><td>glory</td><td>glory</td><td>##32174d</td><td>50</td> <td>23</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>gloxinia</td><td>gloxinia</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>gmelin's blue</td><td>gmelinsblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>gmelin's blue</td><td>gmelinsblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>gnaphalium green</td><td>gnaphaliumgreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>goat</td><td>goat</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>gobelin blue</td><td>gobelinblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>gobelin blue</td><td>gobelinblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>gobelin blue</td><td>gobelinblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>gobelin green</td><td>gobelingreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>gobelin scarlet</td><td>gobelinscarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>gold</td><td>gold</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>gold bronze</td><td>goldbronze</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>gold bronze</td><td>goldbronze</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>gold brown</td><td>goldbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>gold earth</td><td>goldearth</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>golden</td><td>golden</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>golden</td><td>golden</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>golden</td><td>golden</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>golden brown</td><td>goldenbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>golden chestnut</td><td>goldenchestnut</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>golden coral</td><td>goldencoral</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>golden corn</td><td>goldencorn</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>golden feather</td><td>goldenfeather</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>golden feather</td><td>goldenfeather</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>golden feather</td><td>goldenfeather</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>golden feather</td><td>goldenfeather</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>golden glow</td><td>goldenglow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>golden glow</td><td>goldenglow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>golden green</td><td>goldengreen</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>golden green</td><td>goldengreen</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>golden ochre</td><td>goldenochre</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>golden poppy</td><td>goldenpoppy</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>golden rod</td><td>goldenrod</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>golden wheat</td><td>goldenwheat</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>golden yellow</td><td>goldenyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>golden yellow</td><td>goldenyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>golden yellow</td><td>goldenyellow</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>golden yellow</td><td>goldenyellow</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>gold leaf</td><td>goldleaf</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>gold leaf</td><td>goldleaf</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>gold ochre</td><td>goldochre</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>gold yellow</td><td>goldyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>gold yellow</td><td>goldyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>golf green</td><td>golfgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>golf [red] </td><td>golfred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>golf [red] </td><td>golfred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>gooseberry</td><td>gooseberry</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>gooseberry green</td><td>gooseberrygreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>goose grey</td><td>goosegrey</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>gorevan</td><td>gorevan</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>goura</td><td>goura</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>goya</td><td>goya</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>grain</td><td>grain</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>grain</td><td>grain</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>grain</td><td>grain</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>grain</td><td>grain</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>grain in grain</td><td>grainingrain</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>granada</td><td>granada</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>granada</td><td>granada</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>granat</td><td>granat</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>granat</td><td>granat</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>granatflower</td><td>granatflower</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>granatflower</td><td>granatflower</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>granite</td><td>granite</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>granite blue</td><td>graniteblue</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>grape</td><td>grape</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>grape blue</td><td>grapeblue</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>grapefruit</td><td>grapefruit</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>grape green</td><td>grapegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>grapejuice</td><td>grapejuice</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>grapenuts</td><td>grapenuts</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>graphite</td><td>graphite</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>graphite</td><td>graphite</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>grass green</td><td>grassgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>grasshopper</td><td>grasshopper</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>gravel</td><td>gravel</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>grayn</td><td>grayn</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>grebe</td><td>grebe</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>grebe</td><td>grebe</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>grecian rose</td><td>grecianrose</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>grecian rose</td><td>grecianrose</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>green ash</td><td>greenash</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>green finch</td><td>greenfinch</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>green slate</td><td>greenslate</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>green slate</td><td>greenslate</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>green stone</td><td>greenstone</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>grenadine red </td><td>grenadinered</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>grenat</td><td>grenat</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>gretna green</td><td>gretnagreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>gretna green</td><td>gretnagreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>grey 31 </td><td>grey31</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>grey dawn</td><td>greydawn</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>grey dawn</td><td>greydawn</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>grey drab</td><td>greydrab</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>greyn</td><td>greyn</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>grey stone</td><td>greystone</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>grey ultramarine ash</td><td>greyultramarineash</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>gridelin</td><td>gridelin</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>griffin</td><td>griffin</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>gris-de-lin</td><td>grisdelin</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>grotto [blue] </td><td>grottoblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>grouse</td><td>grouse</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>grouse</td><td>grouse</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>guignet's green</td><td>guignetsgreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>guimet's blue</td><td>guimetsblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>guimet's blue</td><td>guimetsblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>guinea green</td><td>guineagreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>guinea hen</td><td>guineahen</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gull</td><td>gull</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>gull grey</td><td>gullgrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>gunmetal</td><td>gunmetal</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>gypsy</td><td>gypsy</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>gypsy red</td><td>gypsyred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>haematite red</td><td>haematitered</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>haematite red</td><td>haematitered</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>haematite red</td><td>haematitered</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>hair brown</td><td>hairbrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>hair brown</td><td>hairbrown</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>hamadan</td><td>hamadan</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>hamburg lake</td><td>hamburglake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>hamburg lake</td><td>hamburglake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>hampstead brown</td><td>hampsteadbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>hankow</td><td>hankow</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>hankow</td><td>hankow</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>hankow</td><td>hankow</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>harbor blue</td><td>harborblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>harlem blue</td><td>harlemblue</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>harlem blue</td><td>harlemblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>harlequin</td><td>harlequin</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>harrison red</td><td>harrisonred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>harvard crimson</td><td>harvardcrimson</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>harvest</td><td>harvest</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>harvest</td><td>harvest</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>hathi gray</td><td>hathigray</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>hathor</td><td>hathor</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>hathor</td><td>hathor</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>havana rose</td><td>havanarose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>hay</td><td>hay</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>hazel</td><td>hazel</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>hazel</td><td>hazel</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>hazelnut</td><td>hazelnut</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>hazelnut</td><td>hazelnut</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>hazy blue</td><td>hazyblue</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>hazy blue</td><td>hazyblue</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>hazy blue</td><td>hazyblue</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>heather</td><td>heather</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>hebe</td><td>hebe</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>heliotrope</td><td>heliotrope</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>heliotrope grey </td><td>heliotropegrey</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>heliotrope grey </td><td>heliotropegrey</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>heliotrope grey </td><td>heliotropegrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>hellebore green</td><td>helleboregreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>hellebore green</td><td>helleboregreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>hellebore green</td><td>helleboregreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>hellebore green</td><td>helleboregreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>hellebore green</td><td>helleboregreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>hellebore red</td><td>helleborered</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>helvetia blue</td><td>helvetiablue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>hemlock</td><td>hemlock</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>hemp</td><td>hemp</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>henna</td><td>henna</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>hepatica</td><td>hepatica</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>hermosa pink</td><td>hermosapink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>hermosa pink</td><td>hermosapink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>heron</td><td>heron</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>hibernian green</td><td>hiberniangreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#1e2321;width:4em;" /><td>highland green</td><td>highlandgreen</td><td>##1e2321</td><td>30</td> <td>35</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>hindu</td><td>hindu</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>hispano</td><td>hispano</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>hockey</td><td>hockey</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>holland blue</td><td>hollandblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>holly berry</td><td>hollyberry</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>holly berry</td><td>hollyberry</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>holly green</td><td>hollygreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#00622d;width:4em;" /><td>holly green</td><td>hollygreen</td><td>##00622d</td><td>0</td> <td>98</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>holly green</td><td>hollygreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>hollyhock</td><td>hollyhock</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>hollywood</td><td>hollywood</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>hollywood</td><td>hollywood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>homage blue</td><td>homageblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>honey beige</td><td>honeybeige</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>honey bird</td><td>honeybird</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>honeydew</td><td>honeydew</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>honeydew</td><td>honeydew</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>honeysuckle</td><td>honeysuckle</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>honeysweet</td><td>honeysweet</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>honeysweet</td><td>honeysweet</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>honey [yellow] </td><td>honeyyellow</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>hopi</td><td>hopi</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>horace vernet's blue</td><td>horacevernetsblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>horizon [blue] </td><td>horizonblue</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>horsechestnut</td><td>horsechestnut</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>hortense violet</td><td>hortenseviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>hortensia</td><td>hortensia</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#301934;width:4em;" /><td>hortensia</td><td>hortensia</td><td>##301934</td><td>48</td> <td>25</td> <td>52</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>hortensia</td><td>hortensia</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>hortensia</td><td>hortensia</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>huckleberry</td><td>huckleberry</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>hudson seal</td><td>hudsonseal</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>hudson seal</td><td>hudsonseal</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>hummingbird</td><td>hummingbird</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>hungarian blue</td><td>hungarianblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>hungarian green</td><td>hungariangreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#173620;width:4em;" /><td>hunter [green] </td><td>huntergreen</td><td>##173620</td><td>23</td> <td>54</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#173620;width:4em;" /><td>hunter's green</td><td>huntersgreen</td><td>##173620</td><td>23</td> <td>54</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>huron</td><td>huron</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>hussar</td><td>hussar</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>hyacinth</td><td>hyacinth</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>hyacinth</td><td>hyacinth</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>hyacinth blue</td><td>hyacinthblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>hyacinth red</td><td>hyacinthred</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>hyacinth violet</td><td>hyacinthviolet</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>hydrangea blue</td><td>hydrangeablue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>hydrangea blue</td><td>hydrangeablue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>hydrangea pink</td><td>hydrangeapink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>hydrangea red</td><td>hydrangeared</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>hydro</td><td>hydro</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>hypermic red</td><td>hypermicred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>hyssop violet</td><td>hyssopviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>ibis pink</td><td>ibispink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>ibis pink</td><td>ibispink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>ibis red</td><td>ibisred</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>iceberg</td><td>iceberg</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>immenssee</td><td>immenssee</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>imperial</td><td>imperial</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>imperial</td><td>imperial</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>imperial</td><td>imperial</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>imperial</td><td>imperial</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>imperial blue</td><td>imperialblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>imperial green</td><td>imperialgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>imperial green</td><td>imperialgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>imperial jade</td><td>imperialjade</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>imperial purple</td><td>imperialpurple</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>imperial stone </td><td>imperialstone</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>imperial yellow</td><td>imperialyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>inca gold</td><td>incagold</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>indebaudias</td><td>indebaudias</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>inde blue</td><td>indeblue</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>independence</td><td>independence</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>india ink</td><td>indiaink</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>indian</td><td>indian</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>indiana</td><td>indiana</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>indian blue</td><td>indianblue</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>indian brown</td><td>indianbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>indian brown</td><td>indianbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>indian brown</td><td>indianbrown</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>indian buff</td><td>indianbuff</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>indian lake</td><td>indianlake</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>indian orange</td><td>indianorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>indian pink</td><td>indianpink</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>indian purple</td><td>indianpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>indian red</td><td>indianred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>indian red</td><td>indianred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>indian saffron</td><td>indiansaffron</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>indian tan</td><td>indiantan</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>indian tan</td><td>indiantan</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>indian tan</td><td>indiantan</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>indian turquoise</td><td>indianturquoise</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>indian yellow</td><td>indianyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>indian yellow</td><td>indianyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>india red</td><td>indiared</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>india spice </td><td>indiaspice</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>india tan</td><td>indiatan</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>indico</td><td>indico</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>indico carmine</td><td>indicocarmine</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>indigo</td><td>indigo</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>indigo carmine</td><td>indigocarmine</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>indigo extract</td><td>indigoextract</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>indo</td><td>indo</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>infanta</td><td>infanta</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>infantry </td><td>infantry</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>infernal blue</td><td>infernalblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>ingenue</td><td>ingenue</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>ingenue</td><td>ingenue</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>ink black</td><td>inkblack</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>ink blue</td><td>inkblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>intense blue</td><td>intenseblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>intense blue</td><td>intenseblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>international</td><td>international</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>invisible green</td><td>invisiblegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>invisible green</td><td>invisiblegreen</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>ionian blue</td><td>ionianblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>ionian blue</td><td>ionianblue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>iris</td><td>iris</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>iris</td><td>iris</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>irisglow</td><td>irisglow</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>iris green</td><td>irisgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>iris green</td><td>irisgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>iris mauve</td><td>irismauve</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>iris mauve</td><td>irismauve</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>iris mauve</td><td>irismauve</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>iron</td><td>iron</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>iron</td><td>iron</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>iron blue</td><td>ironblue</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>iron brown</td><td>ironbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>iron brown</td><td>ironbrown</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>iron buff</td><td>ironbuff</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>iron buff</td><td>ironbuff</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>iron crocus</td><td>ironcrocus</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>iron grey </td><td>irongrey</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>iron minium</td><td>ironminium</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>iron minium</td><td>ironminium</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>iron oxide red</td><td>ironoxidered</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>iron oxide red</td><td>ironoxidered</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>iron red</td><td>ironred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>iron saffron</td><td>ironsaffron</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>iron yellow</td><td>ironyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>iron yellow</td><td>ironyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>isabella</td><td>isabella</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>isabella</td><td>isabella</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>isabella</td><td>isabella</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>isabella</td><td>isabella</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>ispahan</td><td>ispahan</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#0085a1;width:4em;" /><td>italian blue</td><td>italianblue</td><td>##0085a1</td><td>0</td> <td>133</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>italian blue</td><td>italianblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>italian lake</td><td>italianlake</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>italian ochre</td><td>italianochre</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>italian ochre</td><td>italianochre</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>italian pink</td><td>italianpink</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>italian pink</td><td>italianpink</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>italian pink</td><td>italianpink</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>italian pink</td><td>italianpink</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>italian straw</td><td>italianstraw</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>italian straw</td><td>italianstraw</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>ivory brown</td><td>ivorybrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>ivory brown</td><td>ivorybrown</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ivory white</td><td>ivorywhite</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ivory [yellow] </td><td>ivoryyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>ivy [green] </td><td>ivygreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>ivy [green] </td><td>ivygreen</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>jacaranda brown</td><td>jacarandabrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>jacinthe</td><td>jacinthe</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>jack rabbit</td><td>jackrabbit</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>jack rose</td><td>jackrose</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>jacqueminot</td><td>jacqueminot</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>jadesheen</td><td>jadesheen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>jadesheen</td><td>jadesheen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>jadesheen</td><td>jadesheen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>jaffa orange</td><td>jaffaorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>jaffa orange</td><td>jaffaorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>jaffi</td><td>jaffi</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>jalapa</td><td>jalapa</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>japan blue</td><td>japanblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>japan earth</td><td>japanearth</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>japanese blue</td><td>japaneseblue</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>japanese green</td><td>japanesegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>japanese red</td><td>japanesered</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>japanese yellow</td><td>japaneseyellow</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>japanese yellow</td><td>japaneseyellow</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>japan rose</td><td>japanrose</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>japan rose</td><td>japanrose</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>japonica</td><td>japonica</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>jasmine</td><td>jasmine</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>jasmine</td><td>jasmine</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>jasper</td><td>jasper</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>jasper green</td><td>jaspergreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>jasper pink</td><td>jasperpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>jasper red</td><td>jasperred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>java</td><td>java</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>java brown</td><td>javabrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>javel green</td><td>javelgreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>jay [blue] </td><td>jayblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>jean bart</td><td>jeanbart</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>jew's pitch </td><td>jewspitch</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>jockey</td><td>jockey</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>jonquil [yellow] </td><td>jonquilyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>jonquil [yellow] </td><td>jonquilyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>jonquil [yellow] </td><td>jonquilyellow</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>jonquil [yellow] </td><td>jonquilyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>jonquil [yellow] </td><td>jonquilyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>josephine</td><td>josephine</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>jouvence blue</td><td>jouvenceblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>jouvence blue</td><td>jouvenceblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>judee</td><td>judee</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#1c352d;width:4em;" /><td>jungle green</td><td>junglegreen</td><td>##1c352d</td><td>28</td> <td>53</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>jungle green</td><td>junglegreen</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>juniper</td><td>juniper</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>kabistan</td><td>kabistan</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>kaffa</td><td>kaffa</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>kaiser brown</td><td>kaiserbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>kangaroo</td><td>kangaroo</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>kara</td><td>kara</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>kara dagh</td><td>karadagh</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>kasha-beige</td><td>kashabeige</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>kasha-beige</td><td>kashabeige</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>kashan</td><td>kashan</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>kashmir</td><td>kashmir</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>kashmir</td><td>kashmir</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>kashmir</td><td>kashmir</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>kazak</td><td>kazak</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>kentucky green</td><td>kentuckygreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>kermanshah</td><td>kermanshah</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>kermes</td><td>kermes</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>kermes berries</td><td>kermesberries</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>kesseler yellow</td><td>kesseleryellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>kesseler yellow</td><td>kesseleryellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>kesseler yellow</td><td>kesseleryellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>kesseler yellow</td><td>kesseleryellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>kettledrum</td><td>kettledrum</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>khaki</td><td>khaki</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>khaki</td><td>khaki</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>khiva</td><td>khiva</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>kildare green</td><td>kildaregreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>killarney [green] </td><td>killarneygreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>killarney [green] </td><td>killarneygreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>kinema red</td><td>kinemared</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>kingfisher </td><td>kingfisher</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>king's blue</td><td>kingsblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>king's blue</td><td>kingsblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>king's blue</td><td>kingsblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>king's blue</td><td>kingsblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>king's yellow</td><td>kingsyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>king's yellow</td><td>kingsyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>king's yellow</td><td>kingsyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>king's yellow</td><td>kingsyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>kirchberger green</td><td>kirchbergergreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>kis kilim</td><td>kiskilim</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>kobe</td><td>kobe</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>kolinsky</td><td>kolinsky</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>korea</td><td>korea</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>korea</td><td>korea</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>kork</td><td>kork</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>korkir</td><td>korkir</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>kremlin</td><td>kremlin</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>kronberg's green</td><td>kronbergsgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>kurdistan</td><td>kurdistan</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202428;width:4em;" /><td>kurdistan</td><td>kurdistan</td><td>##202428</td><td>32</td> <td>36</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>kurdistan</td><td>kurdistan</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>kurdistan</td><td>kurdistan</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>kyoto</td><td>kyoto</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>kyoto</td><td>kyoto</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>kyoto</td><td>kyoto</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>labrador</td><td>labrador</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>labrador</td><td>labrador</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>lac lake</td><td>laclake</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>lacquer red</td><td>lacquerred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>laelia pink</td><td>laeliapink</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>laelia pink</td><td>laeliapink</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>la france pink</td><td>lafrancepink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>lagoon</td><td>lagoon</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>lake</td><td>lake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>lake</td><td>lake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>lake blue</td><td>lakeblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>lama</td><td>lama</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>lambert's blue</td><td>lambertsblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>lapis</td><td>lapis</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>lariat</td><td>lariat</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>lariat</td><td>lariat</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>lark</td><td>lark</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>lark</td><td>lark</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>lark</td><td>lark</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>larkspur</td><td>larkspur</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>latericeous</td><td>latericeous</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>latericeous</td><td>latericeous</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>lateritious</td><td>lateritious</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>lateritious</td><td>lateritious</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>latoun</td><td>latoun</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>latten</td><td>latten</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>laundry blue</td><td>laundryblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>laundry blue</td><td>laundryblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>laurel green</td><td>laurelgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>laurel oak</td><td>laureloak</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>laurel pink</td><td>laurelpink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>laurel pink</td><td>laurelpink</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>lava</td><td>lava</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>la vallire </td><td>lavallire</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>lavender</td><td>lavender</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>lawn green</td><td>lawngreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>lead</td><td>lead</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>lead</td><td>lead</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>lead grey </td><td>leadgrey</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>lead ochre </td><td>leadochre</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>leadville</td><td>leadville</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>leaf mold</td><td>leafmold</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>leaf red</td><td>leafred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>leather</td><td>leather</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>leather brown</td><td>leatherbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>leather lake</td><td>leatherlake</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>leather lake</td><td>leatherlake</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>leather lake</td><td>leatherlake</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>leek green</td><td>leekgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>leek green</td><td>leekgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>leghorn</td><td>leghorn</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>leghorn</td><td>leghorn</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>legion blue</td><td>legionblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>leitch's blue</td><td>leitchsblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>leithner's blue</td><td>leithnersblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>lemmian earth</td><td>lemmianearth</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>lemnian ruddle</td><td>lemnianruddle</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>lemnos</td><td>lemnos</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>lemon chrome</td><td>lemonchrome</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>lettuce green</td><td>lettucegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>levant red</td><td>levantred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>leyden blue</td><td>leydenblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>liberia</td><td>liberia</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>liberty</td><td>liberty</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>liberty</td><td>liberty</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>liberty blue</td><td>libertyblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>liberty green</td><td>libertygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>lichen</td><td>lichen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>lichen green</td><td>lichengreen</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>lido</td><td>lido</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>lierre</td><td>lierre</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>lierre</td><td>lierre</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>light blue 1</td><td>lightblue1</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>light blue 2, light blue 3</td><td>lightblue2lightblue3</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>light blue 2, light blue 3</td><td>lightblue2lightblue3</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>light blue 4</td><td>lightblue4</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>light blue 6</td><td>lightblue6</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>light blue,, light blue 5</td><td>lightbluelightblue5</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>light brunswick green</td><td>lightbrunswickgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>light chrome green</td><td>lightchromegreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>light chrome yellow</td><td>lightchromeyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>light grge</td><td>lightgrge</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>light gunmetal</td><td>lightgunmetal</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>light red</td><td>lightred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>light stone</td><td>lightstone</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>light stone</td><td>lightstone</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>light wedgwood [blue] </td><td>lightwedgwoodblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>lilac</td><td>lilac</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>lilac</td><td>lilac</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>lilac</td><td>lilac</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>lilaceous</td><td>lilaceous</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>lilaceous</td><td>lilaceous</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>lilac gray</td><td>lilacgray</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>lilac gray</td><td>lilacgray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>lilas</td><td>lilas</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>lilas</td><td>lilas</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>lilium</td><td>lilium</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>lilium</td><td>lilium</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>lily green</td><td>lilygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>lily green</td><td>lilygreen</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>limawood</td><td>limawood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>limawood</td><td>limawood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>lime blue</td><td>limeblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>lime green</td><td>limegreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>lime green</td><td>limegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>limestone</td><td>limestone</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>limestone</td><td>limestone</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>lime [yellow] </td><td>limeyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>lime [yellow] </td><td>limeyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>limoges</td><td>limoges</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>limoges</td><td>limoges</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>lincoln green</td><td>lincolngreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>lincoln red</td><td>lincolnred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>linden green</td><td>lindengreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>linden yellow</td><td>lindenyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>linoleum brown</td><td>linoleumbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>lint</td><td>lint</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>lint-white</td><td>lintwhite</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>lint-white</td><td>lintwhite</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>lion</td><td>lion</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>lion</td><td>lion</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>lion tawny</td><td>liontawny</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>lion tawny</td><td>liontawny</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>liqueur green</td><td>liqueurgreen</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>liqueur green</td><td>liqueurgreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>liseran purple</td><td>liseranpurple</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>litho purple</td><td>lithopurple</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>litho purple</td><td>lithopurple</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>litho purple</td><td>lithopurple</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>liver</td><td>liver</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>liver brown</td><td>liverbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>liver maroon</td><td>livermaroon</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>livid</td><td>livid</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>livid</td><td>livid</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>livid brown</td><td>lividbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>livid pink</td><td>lividpink</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>livid purple</td><td>lividpurple</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>livid violet</td><td>lividviolet</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>lizard bronze</td><td>lizardbronze</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>lizard [green] </td><td>lizardgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>loam</td><td>loam</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>lobelia [blue] </td><td>lobeliablue</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>lobelia violet</td><td>lobeliaviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>lobster</td><td>lobster</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>lobster</td><td>lobster</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>locarno green</td><td>locarnogreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>loganberry</td><td>loganberry</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>log cabin</td><td>logcabin</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>logwood</td><td>logwood</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>logwood</td><td>logwood</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>logwood blue</td><td>logwoodblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>lo-kao</td><td>lokao</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>lo-kao</td><td>lokao</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>london brown</td><td>londonbrown</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>london smoke</td><td>londonsmoke</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>long beach </td><td>longbeach</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>longchamps</td><td>longchamps</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>longchamps</td><td>longchamps</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>lotus</td><td>lotus</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>lotus</td><td>lotus</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>lotus</td><td>lotus</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>louis philippe</td><td>louisphilippe</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>loutre</td><td>loutre</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>loutre</td><td>loutre</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>louvain</td><td>louvain</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>louvain</td><td>louvain</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>love bird</td><td>lovebird</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>love-in-a-mist</td><td>loveinamist</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>lucerne blue</td><td>lucerneblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>luciole</td><td>luciole</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>lucky stone</td><td>luckystone</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>lumiere blue</td><td>lumiereblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>lumiere green</td><td>lumieregreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>lupine</td><td>lupine</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>lupine</td><td>lupine</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>luteous</td><td>luteous</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>luteous</td><td>luteous</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>luxor</td><td>luxor</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>lyons blue</td><td>lyonsblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>macaroon</td><td>macaroon</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>madder</td><td>madder</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>madder</td><td>madder</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>madder</td><td>madder</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>madder</td><td>madder</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>madder blue</td><td>madderblue</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>madder blue</td><td>madderblue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>madder brown</td><td>madderbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>madder carmine</td><td>maddercarmine</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>madder carmine</td><td>maddercarmine</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>madder indian red</td><td>madderindianred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>madder lake</td><td>madderlake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>madder lake</td><td>madderlake</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>madder pink</td><td>madderpink</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>madder red</td><td>madderred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>madder red</td><td>madderred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>madder red</td><td>madderred</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>madder red</td><td>madderred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>madder violet</td><td>madderviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>madeline blue</td><td>madelineblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>madonna</td><td>madonna</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>madonna</td><td>madonna</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>madrid </td><td>madrid</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>madrid </td><td>madrid</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>madura</td><td>madura</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>magenta</td><td>magenta</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>magenta rose</td><td>magentarose</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>magnolia</td><td>magnolia</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>magnolia</td><td>magnolia</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>magnolia</td><td>magnolia</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mahogany</td><td>mahogany</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mahogany brown</td><td>mahoganybrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mahogany red</td><td>mahoganyred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>maiden's blush </td><td>maidensblush</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>maintenon</td><td>maintenon</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>maise</td><td>maise</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>maise</td><td>maise</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>maise</td><td>maise</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>majolica</td><td>majolica</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>majolica blue</td><td>majolicablue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>majolica blue</td><td>majolicablue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>majolica blue</td><td>majolicablue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>majolica earth</td><td>majolicaearth</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>malabar</td><td>malabar</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>malacca</td><td>malacca</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>malacca</td><td>malacca</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>malachite green</td><td>malachitegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>malaga</td><td>malaga</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>malaga</td><td>malaga</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>malay</td><td>malay</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>mallard</td><td>mallard</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>mallow pink</td><td>mallowpink</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>mallow purple</td><td>mallowpurple</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>mallow red</td><td>mallowred</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>malmaison</td><td>malmaison</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>malmaison</td><td>malmaison</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>malmaison rose</td><td>malmaisonrose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>malmaison rose</td><td>malmaisonrose</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>manchu</td><td>manchu</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>mandalay</td><td>mandalay</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>mandalay</td><td>mandalay</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>mandarin orange</td><td>mandarinorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>mandarin red</td><td>mandarinred</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>manganese brown</td><td>manganesebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>manganese velvet brown</td><td>manganesevelvetbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>manganese velvet brown</td><td>manganesevelvetbrown</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>manganese violet</td><td>manganeseviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>mango</td><td>mango</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>mango</td><td>mango</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>manila </td><td>manila</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>manon</td><td>manon</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>manzanita </td><td>manzanita</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>maple</td><td>maple</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>maple sugar</td><td>maplesugar</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>maracaibo</td><td>maracaibo</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>marathon</td><td>marathon</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#1e2321;width:4em;" /><td>marble green </td><td>marblegreen</td><td>##1e2321</td><td>30</td> <td>35</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>marguerite yellow</td><td>margueriteyellow</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>marie antoinette</td><td>marieantoinette</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>marie antoinette</td><td>marieantoinette</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>marine [blue] </td><td>marineblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>marine [blue] </td><td>marineblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>marine [blue] </td><td>marineblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>marine corps</td><td>marinecorps</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>marine green</td><td>marinegreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>marine green</td><td>marinegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>maris</td><td>maris</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>maris</td><td>maris</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>marmora</td><td>marmora</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>marocain</td><td>marocain</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>marone</td><td>marone</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>maroon</td><td>maroon</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>maroon</td><td>maroon</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>maroon</td><td>maroon</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>marron</td><td>marron</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>marrone </td><td>marrone</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>marron glac</td><td>marronglac</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>marsala</td><td>marsala</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mars brown</td><td>marsbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>marsh rose</td><td>marshrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>mars orange</td><td>marsorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>mars red</td><td>marsred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>mars violet</td><td>marsviolet</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>mars yellow</td><td>marsyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>mars yellow</td><td>marsyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>martinique</td><td>martinique</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>martinique</td><td>martinique</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>martius yellow</td><td>martiusyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>marygold</td><td>marygold</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mascara</td><td>mascara</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>mascot</td><td>mascot</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>mascot</td><td>mascot</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>mascot</td><td>mascot</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>mascot</td><td>mascot</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>massicot [yellow] </td><td>massicotyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>mast colour</td><td>mastcolour</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>mastic</td><td>mastic</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>matelot</td><td>matelot</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>matrix</td><td>matrix</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>mauve blush </td><td>mauveblush</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>mauve blush </td><td>mauveblush</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>mauve blush </td><td>mauveblush</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>mauve castor</td><td>mauvecastor</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>mauve dust</td><td>mauvedust</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>mauveglow</td><td>mauveglow</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>mauverose</td><td>mauverose</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>mauve taupe</td><td>mauvetaupe</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>mauvette</td><td>mauvette</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mauvewood</td><td>mauvewood</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>mauvewood</td><td>mauvewood</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>mavis</td><td>mavis</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>maya</td><td>maya</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>maya</td><td>maya</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>mayfair tan</td><td>mayfairtan</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>mayfair tan</td><td>mayfairtan</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>mayfair tan</td><td>mayfairtan</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>mayflower</td><td>mayflower</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>mazarine blue</td><td>mazarineblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>meadowbrook</td><td>meadowbrook</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>meadowbrook</td><td>meadowbrook</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>meadowgrass</td><td>meadowgrass</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>meadowgrass</td><td>meadowgrass</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>meadow [green] </td><td>meadowgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>meadowlark</td><td>meadowlark</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>meadowpink</td><td>meadowpink</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>meadowpink</td><td>meadowpink</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>meadowsweet</td><td>meadowsweet</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>meadow violet</td><td>meadowviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>meadow violet</td><td>meadowviolet</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mecca</td><td>mecca</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mecca</td><td>mecca</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>medal bronze</td><td>medalbronze</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>medal bronze</td><td>medalbronze</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>medici blue</td><td>mediciblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>mediterranian</td><td>mediterranian</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>medium chrome green</td><td>mediumchromegreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>medium chrome green</td><td>mediumchromegreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>meerschaum</td><td>meerschaum</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mehal</td><td>mehal</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>melilot</td><td>melilot</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>meline</td><td>meline</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>mello-mauve</td><td>mellomauve</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>mellowglow</td><td>mellowglow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>melon</td><td>melon</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>mephisto </td><td>mephisto</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>merida </td><td>merida</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>merida </td><td>merida</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>merida </td><td>merida</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>merle </td><td>merle</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>mermaid </td><td>mermaid</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mesa </td><td>mesa</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>metal </td><td>metal</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>metal brown </td><td>metalbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>metal brown </td><td>metalbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>metallic green </td><td>metallicgreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>metallic grey </td><td>metallicgrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>mexican </td><td>mexican</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>mexican </td><td>mexican</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>mexican red </td><td>mexicanred</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>mexican red </td><td>mexicanred</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mexico </td><td>mexico</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>mexico </td><td>mexico</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>miami sand </td><td>miamisand</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>miami sand </td><td>miamisand</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>michigan </td><td>michigan</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>microcline green </td><td>microclinegreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>middle brunswick green</td><td>middlebrunswickgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>middle stone </td><td>middlestone</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>middy </td><td>middy</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>midnight </td><td>midnight</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>midnight sun </td><td>midnightsun</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>mignon </td><td>mignon</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>mignonette [green] </td><td>mignonettegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>mignon green </td><td>mignongreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>mikado </td><td>mikado</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>mikado </td><td>mikado</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mikado brown </td><td>mikadobrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>mikado orange </td><td>mikadoorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>milano blue </td><td>milanoblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>milk white </td><td>milkwhite</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>milwaukee brick </td><td>milwaukeebrick</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>milwaukee brick </td><td>milwaukeebrick</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>mimosa </td><td>mimosa</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>mindoro </td><td>mindoro</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mineral bister </td><td>mineralbister</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>mineral blue </td><td>mineralblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>mineral blue </td><td>mineralblue</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>mineral blue </td><td>mineralblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>mineral green </td><td>mineralgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>mineral grey </td><td>mineralgrey</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>mineral orange </td><td>mineralorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>mineral pitch </td><td>mineralpitch</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>mineral purple </td><td>mineralpurple</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>mineral red </td><td>mineralred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>mineral rouge </td><td>mineralrouge</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>mineral rouge </td><td>mineralrouge</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>mineral violet </td><td>mineralviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>mineral yellow </td><td>mineralyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>mineral yellow </td><td>mineralyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>mineral yellow </td><td>mineralyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>mineral yellow </td><td>mineralyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>mineral yellow </td><td>mineralyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>ming green </td><td>minggreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>miniature pink </td><td>miniaturepink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>miniature pink </td><td>miniaturepink</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>minium </td><td>minium</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>mint </td><td>mint</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>mint </td><td>mint</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>minuet </td><td>minuet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>mirabelle </td><td>mirabelle</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>mirabelle </td><td>mirabelle</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>mirador </td><td>mirador</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>mirage </td><td>mirage</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>mist blue </td><td>mistblue</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>mist blue </td><td>mistblue</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>mist blue </td><td>mistblue</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>mist [grey] </td><td>mistgrey</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>mistletoe </td><td>mistletoe</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>misty blue </td><td>mistyblue</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>misty blue </td><td>mistyblue</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>misty blue </td><td>mistyblue</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>misty morn </td><td>mistymorn</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>misty morn </td><td>mistymorn</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>mitis green </td><td>mitisgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>mittler's green </td><td>mittlersgreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>moccasin </td><td>moccasin</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>mocha </td><td>mocha</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mocha bisque </td><td>mochabisque</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>mode beige </td><td>modebeige</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mohawk </td><td>mohawk</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mohawk </td><td>mohawk</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>monaco </td><td>monaco</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>monet blue </td><td>monetblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>monet blue </td><td>monetblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>monicon </td><td>monicon</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>monicon </td><td>monicon</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>monicon </td><td>monicon</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>monicon </td><td>monicon</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>monkey skin </td><td>monkeyskin</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>monkshood </td><td>monkshood</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>monsignor </td><td>monsignor</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>monsignor </td><td>monsignor</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>monsoreau </td><td>monsoreau</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>monte carlo </td><td>montecarlo</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>monte carlo </td><td>montecarlo</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>montella </td><td>montella</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>montella </td><td>montella</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>monterey </td><td>monterey</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>monticello green </td><td>monticellogreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>montpellier green </td><td>montpelliergreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>montpellier yellow </td><td>montpellieryellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>montpellier yellow </td><td>montpellieryellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>montpellier yellow </td><td>montpellieryellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>montpellier yellow </td><td>montpellieryellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>moonbeam </td><td>moonbeam</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>moonlight </td><td>moonlight</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>moonlight </td><td>moonlight</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>moonlight blue </td><td>moonlightblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>moonmist </td><td>moonmist</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>moorish red </td><td>moorishred</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#363527;width:4em;" /><td>moose </td><td>moose</td><td>##363527</td><td>54</td> <td>53</td> <td>39</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mordor </td><td>mordor</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mordor </td><td>mordor</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>morea berries </td><td>moreaberries</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>morea berries </td><td>moreaberries</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>morello </td><td>morello</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>moresco </td><td>moresco</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>moresco </td><td>moresco</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>morillon </td><td>morillon</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>morning blue </td><td>morningblue</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>morning blue </td><td>morningblue</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>morning dawning yellow </td><td>morningdawningyellow</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>morning dawning yellow </td><td>morningdawningyellow</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>morning dawning yellow </td><td>morningdawningyellow</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>morning glory </td><td>morningglory</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>moroccan </td><td>moroccan</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>moroccan </td><td>moroccan</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>morocco </td><td>morocco</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>morocco red </td><td>moroccored</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>morocco red </td><td>moroccored</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>morocco red </td><td>moroccored</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>morocco sand </td><td>moroccosand</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>moro red </td><td>morored</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>morro </td><td>morro</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>morro </td><td>morro</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mort d'ore </td><td>mortdore</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mort d'ore </td><td>mortdore</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>mosaic blue </td><td>mosaicblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>mosque </td><td>mosque</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>moss [green] </td><td>mossgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>moss [green] </td><td>mossgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>moss grey </td><td>mossgrey</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>moss pink </td><td>mosspink</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>moss rose </td><td>mossrose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>moss rose </td><td>mossrose</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>mosul </td><td>mosul</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mosul </td><td>mosul</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>mosul </td><td>mosul</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>moth [grey] </td><td>mothgrey</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>motmot blue </td><td>motmotblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>motmot green </td><td>motmotgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>motmot green </td><td>motmotgreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>mountain blue </td><td>mountainblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>mountain green </td><td>mountaingreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>mountain green </td><td>mountaingreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>mountain yellow </td><td>mountainyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>mount vernon green or mt. vernon green </td><td>mountvernongreenormtvernongreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>mouse-dun </td><td>mousedun</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>mouse [grey] </td><td>mousegrey</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>mousse </td><td>mousse</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>mousse </td><td>mousse</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>msange </td><td>msange</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>mtallique </td><td>mtallique</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>muffin </td><td>muffin</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>muffin </td><td>muffin</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>mulberry </td><td>mulberry</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>mulberry fruit </td><td>mulberryfruit</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#2e1d21;width:4em;" /><td>mulberry fruit </td><td>mulberryfruit</td><td>##2e1d21</td><td>46</td> <td>29</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>mulberry purple </td><td>mulberrypurple</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>mummy </td><td>mummy</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>mummy </td><td>mummy</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mummy brown </td><td>mummybrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>mummy brown </td><td>mummybrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>mummy brown </td><td>mummybrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>muraille </td><td>muraille</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>murillo </td><td>murillo</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>murinus </td><td>murinus</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>murrey </td><td>murrey</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>muscade </td><td>muscade</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>muscovite </td><td>muscovite</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>mushroom </td><td>mushroom</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>musk </td><td>musk</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>musketeer </td><td>musketeer</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>musketeer </td><td>musketeer</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>musketeer </td><td>musketeer</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>muskmelon </td><td>muskmelon</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>muskmelon </td><td>muskmelon</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>muskrat </td><td>muskrat</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>mustang </td><td>mustang</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mustard brown </td><td>mustardbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>mustard [yellow] </td><td>mustardyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd300;width:4em;" /><td>mutrie yellow </td><td>mutrieyellow</td><td>##dcd300</td><td>220</td> <td>211</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>mutrie yellow </td><td>mutrieyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>myosotis blue </td><td>myosotisblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>myosotis blue </td><td>myosotisblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>myrtle [green] </td><td>myrtlegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>myrtle [green] </td><td>myrtlegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>mytho green </td><td>mythogreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>mytho green </td><td>mythogreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>nacarat </td><td>nacarat</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>nacarine </td><td>nacarine</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>naiad </td><td>naiad</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>nankeen [yellow] </td><td>nankeenyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>nankeen [yellow] </td><td>nankeenyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>nankeen [yellow] </td><td>nankeenyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>nankeen [yellow] </td><td>nankeenyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>naples red </td><td>naplesred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>naples red </td><td>naplesred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>naples yellow </td><td>naplesyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>naples yellow </td><td>naplesyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>naples yellow </td><td>naplesyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>naples yellow </td><td>naplesyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>napoleon blue </td><td>napoleonblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>napoli </td><td>napoli</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>narcissus </td><td>narcissus</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>narcissus </td><td>narcissus</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>narrawood </td><td>narrawood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>narva </td><td>narva</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>nasturtium [red] </td><td>nasturtiumred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>nasturtium [yellow] </td><td>nasturtiumyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>nasturtium [yellow] </td><td>nasturtiumyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>nasturtium [yellow] </td><td>nasturtiumyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>nasturtium [yellow] </td><td>nasturtiumyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>natal brown</td><td>natalbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>national [blue] </td><td>nationalblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>national [blue] </td><td>nationalblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>national grey </td><td>nationalgrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>nattier</td><td>nattier</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>natural</td><td>natural</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>natural</td><td>natural</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>navaho</td><td>navaho</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>navaho</td><td>navaho</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>navy 1 </td><td>navy1</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>navy 2 </td><td>navy2</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>navy 3 </td><td>navy3</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>navy 3 </td><td>navy3</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>navy blue</td><td>navyblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>navy blue</td><td>navyblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>neapolitan blue</td><td>neapolitanblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>neapolitan yellow</td><td>neapolitanyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>neapolitan yellow</td><td>neapolitanyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>neapolitan yellow</td><td>neapolitanyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>neapolitan yellow</td><td>neapolitanyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>nectar</td><td>nectar</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>nectarine</td><td>nectarine</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>nectarine</td><td>nectarine</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>negro</td><td>negro</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>negro</td><td>negro</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>neptune [green] </td><td>neptunegreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>neptune [green] </td><td>neptunegreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>neutral orange</td><td>neutralorange</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>neutral red</td><td>neutralred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>neutral red</td><td>neutralred</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>neutral tint</td><td>neutraltint</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>neuvider green</td><td>neuvidergreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>neuvider green</td><td>neuvidergreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>neuwied blue</td><td>neuwiedblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>neuwieder blue</td><td>neuwiederblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>neuwieder green</td><td>neuwiedergreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>neuwieder green</td><td>neuwiedergreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>neva green</td><td>nevagreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>neva green</td><td>nevagreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>new blue</td><td>newblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>new blue</td><td>newblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>new bronze</td><td>newbronze</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>new bronze</td><td>newbronze</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>new bronze</td><td>newbronze</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>new bronze</td><td>newbronze</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>new cocoa</td><td>newcocoa</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>new hay</td><td>newhay</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>newport</td><td>newport</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>new silver</td><td>newsilver</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>new silver</td><td>newsilver</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>new silver</td><td>newsilver</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>new silver</td><td>newsilver</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>new silver</td><td>newsilver</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>niagara</td><td>niagara</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>niagara green</td><td>niagaragreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>nicaraguawood </td><td>nicaraguawood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>nicaraguawood </td><td>nicaraguawood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>nice</td><td>nice</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>nightshade</td><td>nightshade</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>nightshade</td><td>nightshade</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>nikko</td><td>nikko</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>nikko</td><td>nikko</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>nile blue</td><td>nileblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>nile [green] </td><td>nilegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>nile [green] </td><td>nilegreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>nile [green] </td><td>nilegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>nimbus</td><td>nimbus</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>nippon</td><td>nippon</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>noisette</td><td>noisette</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>noisette</td><td>noisette</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>nomad brown</td><td>nomadbrown</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>norfolk</td><td>norfolk</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>normandy</td><td>normandy</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>normandy</td><td>normandy</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>normandy</td><td>normandy</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>normandy blue</td><td>normandyblue</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>nougat</td><td>nougat</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>nougat</td><td>nougat</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>nubian</td><td>nubian</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>nude</td><td>nude</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>nude</td><td>nude</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>nude</td><td>nude</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>nude</td><td>nude</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>nugget</td><td>nugget</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>nugget</td><td>nugget</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>nuncio</td><td>nuncio</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>nuremberg red </td><td>nurembergred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>nuremberg violet</td><td>nurembergviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>nutmeg</td><td>nutmeg</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>nutmeg</td><td>nutmeg</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>nutria</td><td>nutria</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>nymphea</td><td>nymphea</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>nymph green</td><td>nymphgreen</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>nymph green</td><td>nymphgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>nymph [pink] </td><td>nymphpink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>nymph [pink] </td><td>nymphpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>oad </td><td>oad</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>oak [brown] </td><td>oakbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>oak [brown] </td><td>oakbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>oakbuff</td><td>oakbuff</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>oakbuff</td><td>oakbuff</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>oakbuff</td><td>oakbuff</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>oak [green] </td><td>oakgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>oakheart</td><td>oakheart</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>oakheart</td><td>oakheart</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>oakleaf brown</td><td>oakleafbrown</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>oakleaf brown</td><td>oakleafbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>oakleaf brown</td><td>oakleafbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>oakwood</td><td>oakwood</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>oasis</td><td>oasis</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>oasis</td><td>oasis</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>ocean green</td><td>oceangreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>ocher red</td><td>ocherred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>ochraceous</td><td>ochraceous</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>ochre</td><td>ochre</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>ochre de ru</td><td>ochrederu</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>ochre de ru</td><td>ochrederu</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>ochre red</td><td>ochrered</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>oil blue</td><td>oilblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>oil green</td><td>oilgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>oil yellow</td><td>oilyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>oil yellow</td><td>oilyellow</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>oker de luce</td><td>okerdeluce</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>oker de luce</td><td>okerdeluce</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>oker de luke</td><td>okerdeluke</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>oker de luke</td><td>okerdeluke</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>oker de rouse</td><td>okerderouse</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>oker de rouse</td><td>okerderouse</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>old amethyst</td><td>oldamethyst</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>old amethyst</td><td>oldamethyst</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>old blue</td><td>oldblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>old blue</td><td>oldblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>old blue</td><td>oldblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>old bronze</td><td>oldbronze</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>old bronze</td><td>oldbronze</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>old burgundy</td><td>oldburgundy</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>old burgundy</td><td>oldburgundy</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>old cedar</td><td>oldcedar</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>old china</td><td>oldchina</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>old china</td><td>oldchina</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>old coral</td><td>oldcoral</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>olde</td><td>olde</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>olde</td><td>olde</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>old english brown</td><td>oldenglishbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>old english brown</td><td>oldenglishbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>old english brown</td><td>oldenglishbrown</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>old gold</td><td>oldgold</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>old helio</td><td>oldhelio</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>old ivory</td><td>oldivory</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>old ivory</td><td>oldivory</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>old ivory</td><td>oldivory</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>old lavender</td><td>oldlavender</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>old lilac</td><td>oldlilac</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>old lilac</td><td>oldlilac</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>old mauve</td><td>oldmauve</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>old mauve</td><td>oldmauve</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>old moss [green] </td><td>oldmossgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>old olive </td><td>oldolive</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>old pink</td><td>oldpink</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>old red</td><td>oldred</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>old red</td><td>oldred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>old rose</td><td>oldrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>old roseleaf</td><td>oldroseleaf</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>old silver</td><td>oldsilver</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>old wood</td><td>oldwood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olivaceous</td><td>olivaceous</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive drab</td><td>olivedrab</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olive [green] </td><td>olivegreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>olive grey </td><td>olivegrey</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>olive grey </td><td>olivegrey</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>olivesheen</td><td>olivesheen</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>olive terra verte</td><td>oliveterraverte</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>olive wood</td><td>olivewood</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>olivine</td><td>olivine</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>olympia</td><td>olympia</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>olympia</td><td>olympia</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>olympian blue </td><td>olympianblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>olympian green</td><td>olympiangreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>olympic</td><td>olympic</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>olympic blue</td><td>olympicblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>ondine</td><td>ondine</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>onion-peel </td><td>onionpeel</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>onion red</td><td>onionred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>onion-skin pink</td><td>onionskinpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>onion-skin pink</td><td>onionskinpink</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>onion-skin pink</td><td>onionskinpink</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>ontario violet</td><td>ontarioviolet</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>oold</td><td>oold</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>oold</td><td>oold</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>opal</td><td>opal</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>opal blue</td><td>opalblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>opal grey </td><td>opalgrey</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>opal grey </td><td>opalgrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>opaline green</td><td>opalinegreen</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>opal mauve</td><td>opalmauve</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>opaq</td><td>opaq</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>opera mauve</td><td>operamauve</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>opera pink</td><td>operapink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>opera pink</td><td>operapink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>opera pink</td><td>operapink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>opera pink</td><td>operapink</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>ophelia</td><td>ophelia</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>ophelia</td><td>ophelia</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>ophelia</td><td>ophelia</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>oporto</td><td>oporto</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>oporto</td><td>oporto</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>orange aurora</td><td>orangeaurora</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>orange aurora</td><td>orangeaurora</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>orange aurora</td><td>orangeaurora</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>orange lead</td><td>orangelead</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange madder</td><td>orangemadder</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange ochre</td><td>orangeochre</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange-peel</td><td>orangepeel</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange rufous</td><td>orangerufous</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>orange tawny</td><td>orangetawny</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>orange vermilion</td><td>orangevermilion</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>orchadee</td><td>orchadee</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>orchall</td><td>orchall</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>orchid</td><td>orchid</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>orchid</td><td>orchid</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>orchid pink</td><td>orchidpink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>orchil </td><td>orchil</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>orchil </td><td>orchil</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>orchis</td><td>orchis</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>orient</td><td>orient</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>oriental</td><td>oriental</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>oriental blue</td><td>orientalblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>oriental blue</td><td>orientalblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>oriental blue</td><td>orientalblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>oriental bole </td><td>orientalbole</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>oriental fuchsia</td><td>orientalfuchsia</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>oriental green</td><td>orientalgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>oriental green</td><td>orientalgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>oriental pearl</td><td>orientalpearl</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>oriental pearl</td><td>orientalpearl</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>oriental red</td><td>orientalred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>orient [blue] </td><td>orientblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>orient blue</td><td>orientblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>orient blue</td><td>orientblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>orient pink</td><td>orientpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>orient red</td><td>orientred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orient yellow</td><td>orientyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>orient yellow</td><td>orientyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>orient yellow</td><td>orientyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>orient yellow</td><td>orientyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>orient yellow</td><td>orientyellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>orient yellow</td><td>orientyellow</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>oriole</td><td>oriole</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>orion</td><td>orion</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>orlean</td><td>orlean</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>ormond</td><td>ormond</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>ormond</td><td>ormond</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>ormond</td><td>ormond</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>orpiment</td><td>orpiment</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>orpiment</td><td>orpiment</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>orpiment</td><td>orpiment</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>orpiment</td><td>orpiment</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>orpiment orange</td><td>orpimentorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orpiment orange</td><td>orpimentorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>orpiment red</td><td>orpimentred</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>orpiment red</td><td>orpimentred</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>orpin</td><td>orpin</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>orpin</td><td>orpin</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>orpin</td><td>orpin</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>orpin</td><td>orpin</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>orseille</td><td>orseille</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>otter [brown] </td><td>otterbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>oural green</td><td>ouralgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>oural green</td><td>ouralgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>owl</td><td>owl</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>oxblood [red] </td><td>oxbloodred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>oxford blue</td><td>oxfordblue</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>oxford chrome</td><td>oxfordchrome</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>oxford ochre</td><td>oxfordochre</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>oxford yellow</td><td>oxfordyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>oxgall</td><td>oxgall</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>oxheart</td><td>oxheart</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#0085a1;width:4em;" /><td>oxide blue</td><td>oxideblue</td><td>##0085a1</td><td>0</td> <td>133</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>oxide brown</td><td>oxidebrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>oxide purple</td><td>oxidepurple</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>oxide yellow</td><td>oxideyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>oyster grey </td><td>oystergrey</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>oyster [white] </td><td>oysterwhite</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>pablo</td><td>pablo</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pablo</td><td>pablo</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>pacific</td><td>pacific</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>pacific</td><td>pacific</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>paddock</td><td>paddock</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>pagoda [blue] </td><td>pagodablue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>pagoda [blue] </td><td>pagodablue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>palestine</td><td>palestine</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>palestine</td><td>palestine</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>palm</td><td>palm</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>palmetto</td><td>palmetto</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>palm green</td><td>palmgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>palmleaf</td><td>palmleaf</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>paloma</td><td>paloma</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>paloma</td><td>paloma</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>pampas</td><td>pampas</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>pan</td><td>pan</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>pancy green</td><td>pancygreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>panse</td><td>panse</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>pansy</td><td>pansy</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>pansy-maroon</td><td>pansymaroon</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>pansy purple</td><td>pansypurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>pansy violet</td><td>pansyviolet</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>paon</td><td>paon</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>paper white</td><td>paperwhite</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>paprica</td><td>paprica</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>papyrus</td><td>papyrus</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>paradise green</td><td>paradisegreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>para red</td><td>parared</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>para red</td><td>parared</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>parchment</td><td>parchment</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>parchment</td><td>parchment</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>parchment</td><td>parchment</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>paris green </td><td>parisgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>paris green </td><td>parisgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>paris mud</td><td>parismud</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>paris red</td><td>parisred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>paris yellow</td><td>parisyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>park green</td><td>parkgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>parma red</td><td>parmared</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>parma red</td><td>parmared</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>parme</td><td>parme</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>parrakeet</td><td>parrakeet</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>parrakeet</td><td>parrakeet</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>parroquit green</td><td>parroquitgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>parrot green</td><td>parrotgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>partridge</td><td>partridge</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>partridge</td><td>partridge</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>parula blue</td><td>parulablue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>pastel</td><td>pastel</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>pastel blue</td><td>pastelblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>pastel grey </td><td>pastelgrey</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>pastel parchment</td><td>pastelparchment</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>pastel parchment</td><td>pastelparchment</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>pastel parchment</td><td>pastelparchment</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>patent yellow</td><td>patentyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>patent yellow</td><td>patentyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>patent yellow</td><td>patentyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>patent yellow</td><td>patentyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>patina green</td><td>patinagreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>patina green</td><td>patinagreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>patriarch</td><td>patriarch</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>patricia</td><td>patricia</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>paul veronese green </td><td>paulveronesegreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>pauncy green</td><td>pauncygreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>pavonine</td><td>pavonine</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>pawnee</td><td>pawnee</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>pawnee</td><td>pawnee</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pawnee</td><td>pawnee</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>pawnee</td><td>pawnee</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>payne's grey </td><td>paynesgrey</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>payne's grey </td><td>paynesgrey</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>peach</td><td>peach</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>peach</td><td>peach</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>peachbeige</td><td>peachbeige</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>peach bisque</td><td>peachbisque</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>peach bloom</td><td>peachbloom</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>peach blossom [pink] </td><td>peachblossompink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>peach blossom [pink] </td><td>peachblossompink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>peach blossom [red] </td><td>peachblossomred</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>peach blossom [red] </td><td>peachblossomred</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>peach blow</td><td>peachblow</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>peach blush</td><td>peachblush</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>peach red</td><td>peachred</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>peachwood</td><td>peachwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>peachwood</td><td>peachwood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>peacock [blue] </td><td>peacockblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>peacock green</td><td>peacockgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>pea green</td><td>peagreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>peanut</td><td>peanut</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pearl</td><td>pearl</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pearl blue</td><td>pearlblue</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>pearlblush</td><td>pearlblush</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>pearlblush</td><td>pearlblush</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>pearl gray</td><td>pearlgray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pearl white</td><td>pearlwhite</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>peasant</td><td>peasant</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>peasant</td><td>peasant</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>peasant blue</td><td>peasantblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>peasant blue</td><td>peasantblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>peasant blue</td><td>peasantblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>peasant blue</td><td>peasantblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>pebble</td><td>pebble</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>pecan</td><td>pecan</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>pecan brown</td><td>pecanbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>pekinese</td><td>pekinese</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>pekinese</td><td>pekinese</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>peking blue</td><td>pekingblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>pelican</td><td>pelican</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>peligot's blue</td><td>peligotsblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>pelt</td><td>pelt</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>pencilwood</td><td>pencilwood</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>pencilwood</td><td>pencilwood</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>penguin</td><td>penguin</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>peony</td><td>peony</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>peony red</td><td>peonyred</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>peony red</td><td>peonyred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>pepita</td><td>pepita</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>peppermint</td><td>peppermint</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>pepper red</td><td>pepperred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>peridot</td><td>peridot</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>peridot</td><td>peridot</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>peridot</td><td>peridot</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>peridot</td><td>peridot</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>perilla</td><td>perilla</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>perilla</td><td>perilla</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>perilla purple</td><td>perillapurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>perique</td><td>perique</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>periwinkle</td><td>periwinkle</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>periwinkle</td><td>periwinkle</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>permanent blue</td><td>permanentblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>permanent blue</td><td>permanentblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>permanent red</td><td>permanentred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>permanent red</td><td>permanentred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>permanent violet</td><td>permanentviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>permanent yellow</td><td>permanentyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>perma red</td><td>permared</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>perma red</td><td>permared</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>pernambucowood</td><td>pernambucowood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>pernambucowood</td><td>pernambucowood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>perruche</td><td>perruche</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>persenche</td><td>persenche</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>persian blue</td><td>persianblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>persian blue</td><td>persianblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>persian earth</td><td>persianearth</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>persian green</td><td>persiangreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>persian lilac</td><td>persianlilac</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>persian melon</td><td>persianmelon</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>persian orange</td><td>persianorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>persian pink</td><td>persianpink</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>persian red</td><td>persianred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>persian rose</td><td>persianrose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>persian yellow</td><td>persianyellow</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>persian yellow</td><td>persianyellow</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>persimmon</td><td>persimmon</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>persio</td><td>persio</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>persis</td><td>persis</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>peruvian brown</td><td>peruvianbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>peruvian brown</td><td>peruvianbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>peruvian yellow</td><td>peruvianyellow</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>pervenche</td><td>pervenche</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>petunia</td><td>petunia</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>petunia [violet] </td><td>petuniaviolet</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>pewke</td><td>pewke</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>pewter</td><td>pewter</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>phantom</td><td>phantom</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>phantom red</td><td>phantomred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>pharaoh</td><td>pharaoh</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>pharaoh</td><td>pharaoh</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>pheasant</td><td>pheasant</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>pheasant</td><td>pheasant</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>philamot</td><td>philamot</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>philamot</td><td>philamot</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>philamot</td><td>philamot</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>philimot</td><td>philimot</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>philimot</td><td>philimot</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>philimot</td><td>philimot</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>philomot</td><td>philomot</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>philomot</td><td>philomot</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>philomot</td><td>philomot</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>phlox</td><td>phlox</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>phlox</td><td>phlox</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>phlox pink</td><td>phloxpink</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>phlox purple</td><td>phloxpurple</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>phyliamort </td><td>phyliamort</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>phyliamort </td><td>phyliamort</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>phyliamort </td><td>phyliamort</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>phyllamort</td><td>phyllamort</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>phyllamort</td><td>phyllamort</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>phyllamort</td><td>phyllamort</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>piccadilly</td><td>piccadilly</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>piccadilly</td><td>piccadilly</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>piccaninny</td><td>piccaninny</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>piccolpasso red</td><td>piccolpassored</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>pigeon</td><td>pigeon</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>pigeon blood</td><td>pigeonblood</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>pigeon neck</td><td>pigeonneck</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>pigeon's-breast</td><td>pigeonsbreast</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>pigeon's throat</td><td>pigeonsthroat</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>pigskin</td><td>pigskin</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>pigskin</td><td>pigskin</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>pigskin</td><td>pigskin</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>pilgrim</td><td>pilgrim</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>pilgrim brown</td><td>pilgrimbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>pilgrim brown</td><td>pilgrimbrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>pilot blue</td><td>pilotblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>pimento</td><td>pimento</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>pimlico</td><td>pimlico</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>pinard yellow</td><td>pinardyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>pinchbeck brown</td><td>pinchbeckbrown</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>pinchbeck brown</td><td>pinchbeckbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pinchbeck brown</td><td>pinchbeckbrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>pinchbeck brown</td><td>pinchbeckbrown</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>pinchbeck brown</td><td>pinchbeckbrown</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>pineapple</td><td>pineapple</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>pineapple</td><td>pineapple</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>pinecone</td><td>pinecone</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>pinecone</td><td>pinecone</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>pine frost</td><td>pinefrost</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>pinegrove</td><td>pinegrove</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>pineneedle</td><td>pineneedle</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>pineneedle</td><td>pineneedle</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>pine tree</td><td>pinetree</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pink 1 </td><td>pink1</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>pink 2 </td><td>pink2</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>pink 3 </td><td>pink3</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>pink 3 </td><td>pink3</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>pink 4 </td><td>pink4</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>pink 4 </td><td>pink4</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>pink 5 </td><td>pink5</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>pink coral</td><td>pinkcoral</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>pink coral</td><td>pinkcoral</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>pink pearl</td><td>pinkpearl</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>piping rock</td><td>pipingrock</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>piquant green</td><td>piquantgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>pirate</td><td>pirate</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>pirate</td><td>pirate</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>pistache</td><td>pistache</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>pistache</td><td>pistache</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>pistachio green</td><td>pistachiogreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>pistachio green</td><td>pistachiogreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>pitchpine</td><td>pitchpine</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>piuree</td><td>piuree</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>piuree</td><td>piuree</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>piuri</td><td>piuri</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>piuri</td><td>piuri</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>pi yu</td><td>piyu</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>plantation</td><td>plantation</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>platina yellow</td><td>platinayellow</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>platinum</td><td>platinum</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>plaza grey</td><td>plazagrey</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>pleroma violet</td><td>pleromaviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>plover</td><td>plover</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>plumbaceous</td><td>plumbaceous</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>plumbaceous</td><td>plumbaceous</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>plumbago blue</td><td>plumbagoblue</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>plumbago blue</td><td>plumbagoblue</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>plumbago grey </td><td>plumbagogrey</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>plumbago grey </td><td>plumbagogrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>plumbago slate</td><td>plumbagoslate</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>plumbet</td><td>plumbet</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>plum [purple] </td><td>plumpurple</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>plum purple</td><td>plumpurple</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>plum violet</td><td>plumviolet</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>plum violet</td><td>plumviolet</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>plunket</td><td>plunket</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>plymouth</td><td>plymouth</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>poil d'ours</td><td>poildours</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>poilu</td><td>poilu</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>poinsettia</td><td>poinsettia</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>poinsettia</td><td>poinsettia</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>pois green</td><td>poisgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>polar bear</td><td>polarbear</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>polar bear</td><td>polarbear</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>polignac</td><td>polignac</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>polignac</td><td>polignac</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>polignac</td><td>polignac</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>polo green</td><td>pologreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>polo green</td><td>pologreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>polo tan</td><td>polotan</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>pomegranate</td><td>pomegranate</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>pomegranate blossom</td><td>pomegranateblossom</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>pomegranate blossom</td><td>pomegranateblossom</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>pomegranate purple</td><td>pomegranatepurple</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>pomegranate purple</td><td>pomegranatepurple</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>pomegranate purple</td><td>pomegranatepurple</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>pomegranate purple</td><td>pomegranatepurple</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>pomona green</td><td>pomonagreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>pompadour [green] </td><td>pompadourgreen</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>pomp and power</td><td>pompandpower</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pompeian blue</td><td>pompeianblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>pompeian red</td><td>pompeianred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>pompeian red</td><td>pompeianred</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>pompeian red</td><td>pompeianred</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>pompeian yellow</td><td>pompeianyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>pompeii</td><td>pompeii</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>pompeii</td><td>pompeii</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>ponceau</td><td>ponceau</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>ponceau</td><td>ponceau</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>ponce de leon</td><td>poncedeleon</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>pond lily</td><td>pondlily</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>pond lily</td><td>pondlily</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pongee</td><td>pongee</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>pontiff [purple] </td><td>pontiffpurple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>pony brown</td><td>ponybrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>popcorn</td><td>popcorn</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>popinjay green</td><td>popinjaygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>poplar</td><td>poplar</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>poppy [red] </td><td>poppyred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>poppy [red] </td><td>poppyred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>porcelain</td><td>porcelain</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>porcelain blue</td><td>porcelainblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>porcelain green</td><td>porcelaingreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>porraaceous</td><td>porraaceous</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>porret</td><td>porret</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>port</td><td>port</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>portable red</td><td>portablered</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>portable red</td><td>portablered</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>portable red</td><td>portablered</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>portable red</td><td>portablered</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>portugese red or portuguese red</td><td>portugeseredorportuguesered</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>port wine</td><td>portwine</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>post office red</td><td>postofficered</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>post office red</td><td>postofficered</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>posy green</td><td>posygreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>poudre</td><td>poudre</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>poudre</td><td>poudre</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>poudre</td><td>poudre</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>poudre blue</td><td>poudreblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>poudre blue</td><td>poudreblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>powder blue</td><td>powderblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>powder blue</td><td>powderblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>powder blue</td><td>powderblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>powder blue</td><td>powderblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>powdered gold</td><td>powderedgold</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>powder pink</td><td>powderpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>prairie</td><td>prairie</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>prairie brown</td><td>prairiebrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>praline</td><td>praline</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>praline</td><td>praline</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>prawn [pink] </td><td>prawnpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>prelate</td><td>prelate</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>primrose green</td><td>primrosegreen</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>primrose yellow</td><td>primroseyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>primrose yellow</td><td>primroseyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>primuline yellow</td><td>primulineyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>prince grey </td><td>princegrey</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>princeton orange</td><td>princetonorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>priscilla</td><td>priscilla</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>privet</td><td>privet</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>prout's brown</td><td>proutsbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>prout's brown</td><td>proutsbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>prout's brown</td><td>proutsbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>prout's brown</td><td>proutsbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>prune</td><td>prune</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#32174d;width:4em;" /><td>prunella</td><td>prunella</td><td>##32174d</td><td>50</td> <td>23</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>prunella</td><td>prunella</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>prune purple</td><td>prunepurple</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>prussian brown</td><td>prussianbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>prussian red</td><td>prussianred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>prussian red</td><td>prussianred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>psyche</td><td>psyche</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>pt shell</td><td>ptshell</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pt shell</td><td>ptshell</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>puce</td><td>puce</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>pueblo</td><td>pueblo</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>puke</td><td>puke</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>pumpkin</td><td>pumpkin</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>punjab</td><td>punjab</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>punjab</td><td>punjab</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>puritan grey </td><td>puritangrey</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>puritan grey </td><td>puritangrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>purple aster</td><td>purpleaster</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>purple brown</td><td>purplebrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>purple heather</td><td>purpleheather</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>purple lake</td><td>purplelake</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>purple lake</td><td>purplelake</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>purple madder</td><td>purplemadder</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>purple madder</td><td>purplemadder</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>purple navy</td><td>purplenavy</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>purple navy</td><td>purplenavy</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>purple navy</td><td>purplenavy</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>purple ochre</td><td>purpleochre</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>purple oxide</td><td>purpleoxide</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>purple rubiate</td><td>purplerubiate</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>purple rubiate</td><td>purplerubiate</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>purrea arabica</td><td>purreaarabica</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>purrea arabica</td><td>purreaarabica</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>purree</td><td>purree</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>purree</td><td>purree</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>putty</td><td>putty</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>putty</td><td>putty</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>pygmalion</td><td>pygmalion</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pygmalion</td><td>pygmalion</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>pygmalion</td><td>pygmalion</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>pyrethrum yellow</td><td>pyrethrumyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>pyrethrum yellow</td><td>pyrethrumyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>pyrethrum yellow</td><td>pyrethrumyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>pyrethrum yellow</td><td>pyrethrumyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>pyrite yellow</td><td>pyriteyellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>quail</td><td>quail</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>quail</td><td>quail</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>quaker</td><td>quaker</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>quaker</td><td>quaker</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>quaker blue</td><td>quakerblue</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>quaker drab</td><td>quakerdrab</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>quaker green</td><td>quakergreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>quaker grey </td><td>quakergrey</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>queen anne green</td><td>queenannegreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>queen blue</td><td>queenblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>queen's blue</td><td>queensblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>queen's yellow</td><td>queensyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>quercitron</td><td>quercitron</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>quercitron lake</td><td>quercitronlake</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>quimper</td><td>quimper</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>quince yellow</td><td>quinceyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>rabbit</td><td>rabbit</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>racquet</td><td>racquet</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>racquet</td><td>racquet</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>raddle</td><td>raddle</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>radiance</td><td>radiance</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>radiant yellow</td><td>radiantyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>radiant yellow</td><td>radiantyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>radiant yellow</td><td>radiantyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>radiant yellow</td><td>radiantyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>radio</td><td>radio</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>radio</td><td>radio</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>radio blue</td><td>radioblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>raffia</td><td>raffia</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>raffia</td><td>raffia</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>ragged sailor</td><td>raggedsailor</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>rail</td><td>rail</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>rainette green</td><td>rainettegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>raisin</td><td>raisin</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>raisin black</td><td>raisinblack</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>raisin purple</td><td>raisinpurple</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rambler rose</td><td>ramblerrose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>rambler rose</td><td>ramblerrose</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>rameau</td><td>rameau</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>rameses</td><td>rameses</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>ramier blue</td><td>ramierblue</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>rangoon</td><td>rangoon</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>raphael</td><td>raphael</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>raphael</td><td>raphael</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>rapids</td><td>rapids</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>raspberry</td><td>raspberry</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>raspberry glac</td><td>raspberryglac</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>raspberry glac</td><td>raspberryglac</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>raspberry glac</td><td>raspberryglac</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>raspberry glac</td><td>raspberryglac</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>raspberry red</td><td>raspberryred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>rat</td><td>rat</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>rattan</td><td>rattan</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>raw italian earth</td><td>rawitalianearth</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>raw italian earth</td><td>rawitalianearth</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>raw sienna</td><td>rawsienna</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>raw sienna</td><td>rawsienna</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>raw umber</td><td>rawumber</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>raw umber</td><td>rawumber</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>raw umber</td><td>rawumber</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>rcamier</td><td>rcamier</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>rcamier</td><td>rcamier</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>realgar</td><td>realgar</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>realgar</td><td>realgar</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>red banana</td><td>redbanana</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>red banana</td><td>redbanana</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>red bole</td><td>redbole</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>red chalk</td><td>redchalk</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>red cross</td><td>redcross</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>red cross</td><td>redcross</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>redding</td><td>redding</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>reddle</td><td>reddle</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>red earth</td><td>redearth</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>redfeather</td><td>redfeather</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>redfeather</td><td>redfeather</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>red in plates</td><td>redinplates</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>red lead</td><td>redlead</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>red ochre</td><td>redochre</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>red oxide</td><td>redoxide</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>red oxide</td><td>redoxide</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>red robin</td><td>redrobin</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>redwood</td><td>redwood</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>redwood</td><td>redwood</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>redwood</td><td>redwood</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>redwood redwood -)</td><td>redwoodredwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>redwood redwood -)</td><td>redwoodredwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>redwood redwood -)</td><td>redwoodredwood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>reed green</td><td>reedgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>reed yellow</td><td>reedyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>reed yellow</td><td>reedyellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>regal</td><td>regal</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>regal purple</td><td>regalpurple</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>regatta</td><td>regatta</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>regatta</td><td>regatta</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>regimental</td><td>regimental</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>rejane green</td><td>rejanegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>rembrandt</td><td>rembrandt</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>rembrandt's madder</td><td>rembrandtsmadder</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>rembrandt's madder</td><td>rembrandtsmadder</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>rembrandt's madder</td><td>rembrandtsmadder</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>rembrandt's madder</td><td>rembrandtsmadder</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>renaissance</td><td>renaissance</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>reseda [green] </td><td>resedagreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>resolute</td><td>resolute</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>reveree</td><td>reveree</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>reveree</td><td>reveree</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>rhododendron</td><td>rhododendron</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>rhodonite pink</td><td>rhodonitepink</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>rhone</td><td>rhone</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>rhone</td><td>rhone</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>rhubarb</td><td>rhubarb</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#31362b;width:4em;" /><td>rifle [green] </td><td>riflegreen</td><td>##31362b</td><td>49</td> <td>54</td> <td>43</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>rifle [green] </td><td>riflegreen</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>riga</td><td>riga</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>riga blue</td><td>rigablue</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>riga blue</td><td>rigablue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>rinnemann's green</td><td>rinnemannsgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>ripple green</td><td>ripplegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>ripple green</td><td>ripplegreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>risigal</td><td>risigal</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>risigal</td><td>risigal</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>rivage green</td><td>rivagegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>rivage green</td><td>rivagegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>riviera</td><td>riviera</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>roan</td><td>roan</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>robinhood green</td><td>robinhoodgreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>robin's egg blue</td><td>robinseggblue</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>robin's egg blue</td><td>robinseggblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rocou</td><td>rocou</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>rodent</td><td>rodent</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>roe</td><td>roe</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>roe</td><td>roe</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>roma blue</td><td>romablue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>roma blue</td><td>romablue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>roman earth</td><td>romanearth</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>romanesque</td><td>romanesque</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>roman green</td><td>romangreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>roman lake</td><td>romanlake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>roman lake</td><td>romanlake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>roman ochre</td><td>romanochre</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>roman purple</td><td>romanpurple</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>roman sepia</td><td>romansepia</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>romantic green</td><td>romanticgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>roman umber</td><td>romanumber</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>roman umber</td><td>romanumber</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>roman violet</td><td>romanviolet</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>romany</td><td>romany</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>romany</td><td>romany</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>romany</td><td>romany</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>romany</td><td>romany</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>romarin</td><td>romarin</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>rosalgar</td><td>rosalgar</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>rosalgar</td><td>rosalgar</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>rosario</td><td>rosario</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>rose amber</td><td>roseamber</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>rose amber</td><td>roseamber</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>rose ash</td><td>roseash</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>rose beige</td><td>rosebeige</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>rose beige 2 </td><td>rosebeige2</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>rosebisque</td><td>rosebisque</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>rosebloom</td><td>rosebloom</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>rosebloom</td><td>rosebloom</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>rosebloom</td><td>rosebloom</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>rosebloom</td><td>rosebloom</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>rose blush</td><td>roseblush</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>rose blush 2 </td><td>roseblush2</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>rose breath</td><td>rosebreath</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>rose breath</td><td>rosebreath</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>rosebud</td><td>rosebud</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>rosebud</td><td>rosebud</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rose caroline</td><td>rosecaroline</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>rose carthame</td><td>rosecarthame</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>rose castor</td><td>rosecastor</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rose cendre</td><td>rosecendre</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>rose d'alma</td><td>rosedalma</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>rose d'althoea</td><td>rosedalthoea</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rose dawn</td><td>rosedawn</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>rose dawn</td><td>rosedawn</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>rose de nymphe</td><td>rosedenymphe</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>rose de provence</td><td>rosedeprovence</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rose dore</td><td>rosedore</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rose dore</td><td>rosedore</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>rosedust</td><td>rosedust</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>rosedust</td><td>rosedust</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>rose ebony </td><td>roseebony</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rose france</td><td>rosefrance</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>roseglow</td><td>roseglow</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>rose grey </td><td>rosegrey</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>rose hermosa</td><td>rosehermosa</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>rose hortensia</td><td>rosehortensia</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>rose lake</td><td>roselake</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>roseleaf</td><td>roseleaf</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>roselustre</td><td>roselustre</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>rose madder</td><td>rosemadder</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rose marie</td><td>rosemarie</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>rosemary</td><td>rosemary</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rose morn</td><td>rosemorn</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>rose neyron</td><td>roseneyron</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>rose neyron</td><td>roseneyron</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rose nilsson</td><td>rosenilsson</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rose nude</td><td>rosenude</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>rose nude</td><td>rosenude</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>rose nude</td><td>rosenude</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>rose oak</td><td>roseoak</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rose of picardy</td><td>roseofpicardy</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rose of sharon</td><td>roseofsharon</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>rose petal</td><td>rosepetal</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>rose pink</td><td>rosepink</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>rose-purple </td><td>rosepurple</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>rose-purple </td><td>rosepurple</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>rose quartz</td><td>rosequartz</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rose soire</td><td>rosesoire</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>rosestone</td><td>rosestone</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>roset</td><td>roset</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>rosetan</td><td>rosetan</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>rosetan</td><td>rosetan</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>rose taupe</td><td>rosetaupe</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>rosetta</td><td>rosetta</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rosevale</td><td>rosevale</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>rosevale</td><td>rosevale</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>rosewood</td><td>rosewood</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>roslyn blue</td><td>roslynblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>roucou</td><td>roucou</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>rouge de fer</td><td>rougedefer</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>rouge vegetal</td><td>rougevegetal</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>royal blue</td><td>royalblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>royal blue</td><td>royalblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>royal blue</td><td>royalblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>royal pink</td><td>royalpink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>royal purple</td><td>royalpurple</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>royal yellow</td><td>royalyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>royal yellow</td><td>royalyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>royal yellow</td><td>royalyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>royal yellow</td><td>royalyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>rubaiyat</td><td>rubaiyat</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>rubber</td><td>rubber</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rubelite</td><td>rubelite</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>ruben's madder</td><td>rubensmadder</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>rubient</td><td>rubient</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>rubrica</td><td>rubrica</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>ruby</td><td>ruby</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>ruby of arsenic</td><td>rubyofarsenic</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>ruby of arsenic</td><td>rubyofarsenic</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>ruddle</td><td>ruddle</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>rufous</td><td>rufous</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>rufous</td><td>rufous</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>rugby tan</td><td>rugbytan</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>runnymede</td><td>runnymede</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>ru ochre</td><td>ruochre</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>ru ochre</td><td>ruochre</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>russet brown</td><td>russetbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>russet brown</td><td>russetbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>russet green</td><td>russetgreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>russet green</td><td>russetgreen</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>russet green</td><td>russetgreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>russet green</td><td>russetgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>russet orange</td><td>russetorange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>russian blue</td><td>russianblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>russian blue</td><td>russianblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>russian calf</td><td>russiancalf</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>russian green</td><td>russiangreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>russian green</td><td>russiangreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>russian green</td><td>russiangreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>russian grey </td><td>russiangrey</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>russian grey </td><td>russiangrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#32174d;width:4em;" /><td>russian violet</td><td>russianviolet</td><td>##32174d</td><td>50</td> <td>23</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>rust</td><td>rust</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>rustic brown</td><td>rusticbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>rustic drab</td><td>rusticdrab</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>rut ochre</td><td>rutochre</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>rut ochre</td><td>rutochre</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>sable</td><td>sable</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>saddle</td><td>saddle</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>saddle</td><td>saddle</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>safaran</td><td>safaran</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>safaran</td><td>safaran</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>safflor</td><td>safflor</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>safflower red</td><td>safflowerred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>saffor</td><td>saffor</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>saffron yellow</td><td>saffronyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>saffron yellow</td><td>saffronyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>safrano pink</td><td>safranopink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>sagebrush green</td><td>sagebrushgreen</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>sage drab</td><td>sagedrab</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>sage [green] </td><td>sagegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>sage grey </td><td>sagegrey</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>sahara</td><td>sahara</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>sailor</td><td>sailor</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>sailor</td><td>sailor</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>sailor blue</td><td>sailorblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>sakkara</td><td>sakkara</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>sallow</td><td>sallow</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>salmon [pink] </td><td>salmonpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>salvia</td><td>salvia</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>salvia blue</td><td>salviablue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>samara</td><td>samara</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>samovar</td><td>samovar</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>samurai</td><td>samurai</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>sand</td><td>sand</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>sand</td><td>sand</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>sandalwood</td><td>sandalwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>sandalwood</td><td>sandalwood</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>sandalwood</td><td>sandalwood</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>sandalwood</td><td>sandalwood</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>sandalwood</td><td>sandalwood</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>sandarach</td><td>sandarach</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>sandarach</td><td>sandarach</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>sandarach</td><td>sandarach</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>sandaracha</td><td>sandaracha</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>sandaracha</td><td>sandaracha</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>sandaracha</td><td>sandaracha</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>sand dune</td><td>sanddune</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>sander's blue</td><td>sandersblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>sanderswood</td><td>sanderswood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>sandix</td><td>sandix</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>sandrift</td><td>sandrift</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>sandstone</td><td>sandstone</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sandstone</td><td>sandstone</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>sandstone</td><td>sandstone</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>sandust</td><td>sandust</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>sandy-beige</td><td>sandybeige</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>sandyx</td><td>sandyx</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>sang de boeuf</td><td>sangdeboeuf</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>sanguine</td><td>sanguine</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>sanguine</td><td>sanguine</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>sanguineus</td><td>sanguineus</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>sanguineus</td><td>sanguineus</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>sanguineus</td><td>sanguineus</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>sanguineus</td><td>sanguineus</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>sanguineus</td><td>sanguineus</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>sanguineus</td><td>sanguineus</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>santalwood</td><td>santalwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>santos</td><td>santos</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>santos</td><td>santos</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>saona</td><td>saona</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>sappanwood</td><td>sappanwood</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>sappanwood</td><td>sappanwood</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>sapphire [blue] </td><td>sapphireblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>sappho</td><td>sappho</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>saraband</td><td>saraband</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>saratoga</td><td>saratoga</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>saravan</td><td>saravan</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>saravan</td><td>saravan</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>sarouk</td><td>sarouk</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>satinwood</td><td>satinwood</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>satsuma</td><td>satsuma</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>saturnine red</td><td>saturninered</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>saturn red</td><td>saturnred</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>saul</td><td>saul</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>saunder's blue</td><td>saundersblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>sauterne</td><td>sauterne</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sauterne</td><td>sauterne</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>saxe blue</td><td>saxeblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>saxon blue</td><td>saxonblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>saxon blue</td><td>saxonblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>saxon green</td><td>saxongreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>saxony blue</td><td>saxonyblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>saxony blue</td><td>saxonyblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>saxony blue</td><td>saxonyblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>saxony blue</td><td>saxonyblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>saxony green</td><td>saxonygreen</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>sayal brown</td><td>sayalbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sayal brown</td><td>sayalbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>sayal brown</td><td>sayalbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>scabiosa </td><td>scabiosa</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>scarab</td><td>scarab</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>scarlet in grain</td><td>scarletingrain</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>scarlet lake</td><td>scarletlake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>scarlet lake</td><td>scarletlake</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>scarlet madder</td><td>scarletmadder</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>scarlet ochre</td><td>scarletochre</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>scarlet red</td><td>scarletred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>scarlet vermilion</td><td>scarletvermilion</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>scheele's green</td><td>scheelesgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>scheele's green</td><td>scheelesgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>schoenfeld's purple</td><td>schoenfeldspurple</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>schoenfeld's purple</td><td>schoenfeldspurple</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>schweinfurt green</td><td>schweinfurtgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>scotch blue</td><td>scotchblue</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>scotch grey </td><td>scotchgrey</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>scotch grey </td><td>scotchgrey</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>seabird</td><td>seabird</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>sea blue</td><td>seablue</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>seacrest</td><td>seacrest</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>seafoam</td><td>seafoam</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>seafoam</td><td>seafoam</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>seafoam green</td><td>seafoamgreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>seafoam yellow</td><td>seafoamyellow</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>sea green</td><td>seagreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>sea hawk</td><td>seahawk</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>seal [brown] </td><td>sealbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>seaman blue</td><td>seamanblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>sea mist</td><td>seamist</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>sea mist</td><td>seamist</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>sea moss </td><td>seamoss</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>sea moss </td><td>seamoss</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>sea pink</td><td>seapink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>sea pink</td><td>seapink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>seasan not seasand</td><td>seasannotseasand</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>seasan not seasand</td><td>seasannotseasand</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>seasan not seasand</td><td>seasannotseasand</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>seasan not seasand</td><td>seasannotseasand</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>sea shell</td><td>seashell</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>sea shell</td><td>seashell</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sea shell</td><td>seashell</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>seashell pink</td><td>seashellpink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>seashell pink</td><td>seashellpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>seaside</td><td>seaside</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>seaside</td><td>seaside</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>seaside</td><td>seaside</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>seaside</td><td>seaside</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>seaspray</td><td>seaspray</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>seaspray</td><td>seaspray</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>seaspray</td><td>seaspray</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>sea-water green</td><td>seawatergreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>seaweed green</td><td>seaweedgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>sedge</td><td>sedge</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>seed pearl</td><td>seedpearl</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>seed pearl</td><td>seedpearl</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>seered green</td><td>seeredgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>seladon green</td><td>seladongreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>seminole</td><td>seminole</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>sepia</td><td>sepia</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>serapi</td><td>serapi</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>serpent</td><td>serpent</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>serpentine</td><td>serpentine</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>serpentine green</td><td>serpentinegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#00543d;width:4em;" /><td>service corps</td><td>servicecorps</td><td>##00543d</td><td>0</td> <td>84</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#32174d;width:4em;" /><td>seville</td><td>seville</td><td>##32174d</td><td>50</td> <td>23</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>seville orange</td><td>sevilleorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>sevres [blue] </td><td>sevresblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>shadow</td><td>shadow</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>shadow green</td><td>shadowgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>shagbark</td><td>shagbark</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>shagbark</td><td>shagbark</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>shale green</td><td>shalegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>shamrock</td><td>shamrock</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>shamrock [green] </td><td>shamrockgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>shark</td><td>shark</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>shark</td><td>shark</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>sheepskin</td><td>sheepskin</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>sheik</td><td>sheik</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>sheik</td><td>sheik</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>shell grey </td><td>shellgrey</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>shirvan</td><td>shirvan</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>shrimp [pink] </td><td>shrimppink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>shrimp [red] </td><td>shrimpred</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>siam</td><td>siam</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>siam</td><td>siam</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>siam</td><td>siam</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>siam</td><td>siam</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>siberian brown</td><td>siberianbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>siberien</td><td>siberien</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>sicilian umber</td><td>sicilianumber</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>sicilian umber</td><td>sicilianumber</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>siderin yellow</td><td>siderinyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>siderin yellow</td><td>siderinyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>siena</td><td>siena</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>sienna brown</td><td>siennabrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>sienna yellow</td><td>siennayellow</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>sienna yellow</td><td>siennayellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>siennese drab</td><td>siennesedrab</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>siennese drab</td><td>siennesedrab</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>sierra</td><td>sierra</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>signal red</td><td>signalred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>sil</td><td>sil</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>silurian gray</td><td>siluriangray</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>silver fern</td><td>silverfern</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>silver fern</td><td>silverfern</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>silver green</td><td>silvergreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>silverpine</td><td>silverpine</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>silver-wing</td><td>silverwing</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>sinbad</td><td>sinbad</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202428;width:4em;" /><td>sinbad</td><td>sinbad</td><td>##202428</td><td>32</td> <td>36</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>sinbad</td><td>sinbad</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>sinbad</td><td>sinbad</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>sirocco</td><td>sirocco</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>siskin green</td><td>siskingreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>sistine</td><td>sistine</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>sistine</td><td>sistine</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>sistine</td><td>sistine</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>sistine</td><td>sistine</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>skating</td><td>skating</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>ski</td><td>ski</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>ski</td><td>ski</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>skimmed-milk white</td><td>skimmedmilkwhite</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>skobeloff green</td><td>skobeloffgreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>sky</td><td>sky</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>sky</td><td>sky</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>sky blue</td><td>skyblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>sky blue</td><td>skyblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>sky colour</td><td>skycolour</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>sky colour</td><td>skycolour</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>sky green</td><td>skygreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>slag</td><td>slag</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>slate</td><td>slate</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>slate-black</td><td>slateblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>slate blue</td><td>slateblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>slate-blue </td><td>slateblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>slate [color] </td><td>slatecolor</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>slate-green</td><td>slategreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>slate-green</td><td>slategreen</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>slate-grey </td><td>slategrey</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>slate-grey </td><td>slategrey</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>slate-olive</td><td>slateolive</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>slate-purple</td><td>slatepurple</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>slate-purple</td><td>slatepurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>slate-violet</td><td>slateviolet</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>smalt</td><td>smalt</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>smalt</td><td>smalt</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>smalt green</td><td>smaltgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>smaltino</td><td>smaltino</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>smaltino</td><td>smaltino</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>smoke blue</td><td>smokeblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>smoke brown</td><td>smokebrown</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>smoked pearl</td><td>smokedpearl</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>smoke grey </td><td>smokegrey</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>smoke yellow</td><td>smokeyellow</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>smoke yellow</td><td>smokeyellow</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>snapdragon</td><td>snapdragon</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>snapdragon</td><td>snapdragon</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>snowshoe</td><td>snowshoe</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>snowshoe</td><td>snowshoe</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>soapstone</td><td>soapstone</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>solferino</td><td>solferino</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>solitaire</td><td>solitaire</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>solitaire</td><td>solitaire</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>somalis</td><td>somalis</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>somalis</td><td>somalis</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>sombrero</td><td>sombrero</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>sonora</td><td>sonora</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sonora</td><td>sonora</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>soot brown</td><td>sootbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>soot brown</td><td>sootbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>sooty black</td><td>sootyblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>sorbier</td><td>sorbier</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>sorghum brown</td><td>sorghumbrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>sorghum brown</td><td>sorghumbrown</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>sorolla brown</td><td>sorollabrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>sorrel</td><td>sorrel</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sorrel</td><td>sorrel</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>sorrento green</td><td>sorrentogreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>souci</td><td>souci</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>source</td><td>source</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>source</td><td>source</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>source</td><td>source</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>spalte</td><td>spalte</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>spaltum</td><td>spaltum</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>spanish brown</td><td>spanishbrown</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>spanish cedar</td><td>spanishcedar</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>spanish cedar</td><td>spanishcedar</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>spanish flesh</td><td>spanishflesh</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>spanish flesh</td><td>spanishflesh</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>spanish green</td><td>spanishgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>spanish ochre</td><td>spanishochre</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>spanish raisin</td><td>spanishraisin</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>spanish red</td><td>spanishred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>spanish red</td><td>spanishred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>spanish red</td><td>spanishred</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>spanish wine</td><td>spanishwine</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>spanish yellow</td><td>spanishyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>spanish yellow</td><td>spanishyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>spark</td><td>spark</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>sparrow</td><td>sparrow</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>spa-tan</td><td>spatan</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>spearmint</td><td>spearmint</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>sphinx</td><td>sphinx</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>spice</td><td>spice</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>spinach green</td><td>spinachgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>spinach green</td><td>spinachgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>spinel pink</td><td>spinelpink</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>spinel red</td><td>spinelred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>spinel red</td><td>spinelred</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>sponge</td><td>sponge</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>spray</td><td>spray</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>spring beauty</td><td>springbeauty</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>spring beauty</td><td>springbeauty</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>spring green</td><td>springgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>spring green</td><td>springgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>springtime</td><td>springtime</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>sprite</td><td>sprite</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>sprite</td><td>sprite</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>spruce</td><td>spruce</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#1e2321;width:4em;" /><td>spruce</td><td>spruce</td><td>##1e2321</td><td>30</td> <td>35</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>spruce ochre</td><td>spruceochre</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>spruce ochre</td><td>spruceochre</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>spruce yellow</td><td>spruceyellow</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>spruce yellow</td><td>spruceyellow</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>squill blue</td><td>squillblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>squirrel</td><td>squirrel</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>squirrel</td><td>squirrel</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>stag</td><td>stag</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>starch blue</td><td>starchblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>starch blue</td><td>starchblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>stardew</td><td>stardew</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>starflower</td><td>starflower</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>starlight</td><td>starlight</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>starling</td><td>starling</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>st. benoit or saint benoit</td><td>stbenoitorsaintbenoit</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>st. benoit or saint benoit</td><td>stbenoitorsaintbenoit</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>steel</td><td>steel</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>steel grey </td><td>steelgrey</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>steeplechase</td><td>steeplechase</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>stil de grain brown</td><td>stildegrainbrown</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>stil de grain brown</td><td>stildegrainbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>stil de grain yellow</td><td>stildegrainyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>stil de grain yellow</td><td>stildegrainyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>stil de grain yellow</td><td>stildegrainyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>stil de grain yellow</td><td>stildegrainyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>stone blue</td><td>stoneblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>stone grey </td><td>stonegrey</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>storm grey </td><td>stormgrey</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>strawberry</td><td>strawberry</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>strawberry pink</td><td>strawberrypink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>strawberry pink</td><td>strawberrypink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>strawberry pink</td><td>strawberrypink</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>straw [yellow] </td><td>strawyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>striegau earth</td><td>striegauearth</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>stroller tan</td><td>strollertan</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>strontian yellow </td><td>strontianyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>stucco</td><td>stucco</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>stucco</td><td>stucco</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>succory blue</td><td>succoryblue</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>sudan</td><td>sudan</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>sudan</td><td>sudan</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>sudan</td><td>sudan</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>sudan brown</td><td>sudanbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>sudan brown</td><td>sudanbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>suede</td><td>suede</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>suede</td><td>suede</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>suede</td><td>suede</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>sugar cane</td><td>sugarcane</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>sugar cane</td><td>sugarcane</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>sulphate green</td><td>sulphategreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>sulphate green</td><td>sulphategreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>sulphine yellow</td><td>sulphineyellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>sulphur</td><td>sulphur</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>sulphur [yellow] </td><td>sulphuryellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>sultan</td><td>sultan</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>sultana</td><td>sultana</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>sultana</td><td>sultana</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>sumac</td><td>sumac</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>sumac</td><td>sumac</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>sumac</td><td>sumac</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>sumac</td><td>sumac</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>sumac</td><td>sumac</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>sumac</td><td>sumac</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>sumac</td><td>sumac</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>sunbeam</td><td>sunbeam</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sunburn</td><td>sunburn</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>sunburst</td><td>sunburst</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>sunburst</td><td>sunburst</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>sundown</td><td>sundown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>sunflower [yellow] </td><td>sunfloweryellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>sunglow</td><td>sunglow</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>sunglow</td><td>sunglow</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>sungod</td><td>sungod</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>sunkiss </td><td>sunkiss</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>sunlight</td><td>sunlight</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>sunni</td><td>sunni</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>sunni</td><td>sunni</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>sunray</td><td>sunray</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>sunrise yellow</td><td>sunriseyellow</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>sunrise yellow</td><td>sunriseyellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>sunset</td><td>sunset</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>sunstone</td><td>sunstone</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>suntan</td><td>suntan</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>suntan</td><td>suntan</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>suntan</td><td>suntan</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>superior</td><td>superior</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>surf green</td><td>surfgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>surrey green</td><td>surreygreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>surrey green</td><td>surreygreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>swamp</td><td>swamp</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>swedish green</td><td>swedishgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>swedish green</td><td>swedishgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>sweet briar</td><td>sweetbriar</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>sweetmeat</td><td>sweetmeat</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>sweet pea</td><td>sweetpea</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>sweet william</td><td>sweetwilliam</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>swiss blue</td><td>swissblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>swiss rose</td><td>swissrose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>syrup</td><td>syrup</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>syrup</td><td>syrup</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>taffy</td><td>taffy</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>talavera</td><td>talavera</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>tamarach</td><td>tamarach</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>tamarach</td><td>tamarach</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>ta-ming</td><td>taming</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>ta-ming</td><td>taming</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>tan</td><td>tan</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>tanagra</td><td>tanagra</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>tanaura </td><td>tanaura</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>tanbark</td><td>tanbark</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>tangerine</td><td>tangerine</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>tangier</td><td>tangier</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>tango pink</td><td>tangopink</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>tansan</td><td>tansan</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>tansan</td><td>tansan</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>tapestry</td><td>tapestry</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>tapestry</td><td>tapestry</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>tapestry</td><td>tapestry</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>tapestry</td><td>tapestry</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>tapestry red</td><td>tapestryred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>tapis vert</td><td>tapisvert</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>tarragon</td><td>tarragon</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>tarragon</td><td>tarragon</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>tarragon</td><td>tarragon</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>tarragona</td><td>tarragona</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>tarragona</td><td>tarragona</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>tartan green</td><td>tartangreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>taupe</td><td>taupe</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>tawny</td><td>tawny</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>tawny</td><td>tawny</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>tawny birch</td><td>tawnybirch</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>tawny birch</td><td>tawnybirch</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>tawny birch</td><td>tawnybirch</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>tea</td><td>tea</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>tea</td><td>tea</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>tea green</td><td>teagreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>teak [brown] </td><td>teakbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>teakwood</td><td>teakwood</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>teakwood</td><td>teakwood</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>teal blue</td><td>tealblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>teal blue</td><td>tealblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>teal duck </td><td>tealduck</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>tea time</td><td>teatime</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>telegraph blue</td><td>telegraphblue</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>tennis</td><td>tennis</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>tennis</td><td>tennis</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>terra cotta</td><td>terracotta</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>terra cotta</td><td>terracotta</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>terra japonica</td><td>terrajaponica</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>terra lemnia</td><td>terralemnia</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>terra merita</td><td>terramerita</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>terra orellana</td><td>terraorellana</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>terra orellano </td><td>terraorellano</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>terrapin</td><td>terrapin</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>terra pozzuoli</td><td>terrapozzuoli</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>terra rosa</td><td>terrarosa</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>terra siena </td><td>terrasiena</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>terra siena </td><td>terrasiena</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>terra sigillata</td><td>terrasigillata</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>terrasse</td><td>terrasse</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>terra umber</td><td>terraumber</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>terra umber</td><td>terraumber</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>testaceous</td><td>testaceous</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>testaceous</td><td>testaceous</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>thenard's blue</td><td>thenardsblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>thistle</td><td>thistle</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>thistle bloom</td><td>thistlebloom</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>thistletuft</td><td>thistletuft</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>thrush</td><td>thrush</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>thrush</td><td>thrush</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>thulite pink</td><td>thulitepink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>thyme</td><td>thyme</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>tiber</td><td>tiber</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>tiber green</td><td>tibergreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>tiffin</td><td>tiffin</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>tigerlily</td><td>tigerlily</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>tigerlily</td><td>tigerlily</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>tile blue</td><td>tileblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>tile red</td><td>tilered</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>tilleul buff</td><td>tilleulbuff</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>tilleul buff</td><td>tilleulbuff</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>tilleul [green] </td><td>tilleulgreen</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>tinsel</td><td>tinsel</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>tinsel</td><td>tinsel</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>tinsel</td><td>tinsel</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>titania</td><td>titania</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>titania</td><td>titania</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>titian</td><td>titian</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>titian gold</td><td>titiangold</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>titmouse blue </td><td>titmouseblue</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>toast</td><td>toast</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>toasted almond</td><td>toastedalmond</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>toboggan</td><td>toboggan</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>toboggan</td><td>toboggan</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>toga</td><td>toga</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>tokay</td><td>tokay</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>tokyo</td><td>tokyo</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>tokyo</td><td>tokyo</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>tokyo</td><td>tokyo</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>toltec</td><td>toltec</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>tomato [red] </td><td>tomatored</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>tommy red</td><td>tommyred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>topaz</td><td>topaz</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>topaz</td><td>topaz</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>topaz</td><td>topaz</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>toquet</td><td>toquet</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>toreador</td><td>toreador</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>torino blue</td><td>torinoblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>tortoise</td><td>tortoise</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>tortoise shell</td><td>tortoiseshell</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>totem</td><td>totem</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>tourmaline</td><td>tourmaline</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>tourmaline pink</td><td>tourmalinepink</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>tourterelle</td><td>tourterelle</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>transparent chromium oxide</td><td>transparentchromiumoxide</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>transparent chromium oxide</td><td>transparentchromiumoxide</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>transparent gold ochre</td><td>transparentgoldochre</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>transparent gold ochre</td><td>transparentgoldochre</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>traprock</td><td>traprock</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>travertine </td><td>travertine</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>trentanel</td><td>trentanel</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>trentanel</td><td>trentanel</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>trianon</td><td>trianon</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>trianon</td><td>trianon</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>triton</td><td>triton</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>triumph blue</td><td>triumphblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>triumph blue</td><td>triumphblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>trooper</td><td>trooper</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>trooper</td><td>trooper</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>trooper</td><td>trooper</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>trotteur tan</td><td>trotteurtan</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>troubador red</td><td>troubadorred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>trublu</td><td>trublu</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>tuileries</td><td>tuileries</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>tulipwood</td><td>tulipwood</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>tunis</td><td>tunis</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>tunis</td><td>tunis</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>turbith mineral</td><td>turbithmineral</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>turkey blue</td><td>turkeyblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>turkey red</td><td>turkeyred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>turkey umber</td><td>turkeyumber</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>turkey umber</td><td>turkeyumber</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>turkish blue</td><td>turkishblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>turkish crescent red </td><td>turkishcrescentred</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>turkish crescent red </td><td>turkishcrescentred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>turkish red</td><td>turkishred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>turmeric</td><td>turmeric</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>turner's yellow</td><td>turnersyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>turner's yellow</td><td>turnersyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>turner's yellow</td><td>turnersyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>turner's yellow</td><td>turnersyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>turquoise [blue] </td><td>turquoiseblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>turquoise green</td><td>turquoisegreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>turtle</td><td>turtle</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>turtledove</td><td>turtledove</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>turtledove</td><td>turtledove</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>turtle green</td><td>turtlegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>tuscan</td><td>tuscan</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>tuscan brown</td><td>tuscanbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>tuscan brown</td><td>tuscanbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>tuscan red</td><td>tuscanred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>tuscan tan</td><td>tuscantan</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>tuscany</td><td>tuscany</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>tussore</td><td>tussore</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>tussore</td><td>tussore</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>twilight [blue] </td><td>twilightblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>twine</td><td>twine</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>twinkle blue</td><td>twinkleblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>tyrian blue</td><td>tyrianblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>tyrian blue</td><td>tyrianblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>tyrian pink</td><td>tyrianpink</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>tyrian violet</td><td>tyrianviolet</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>tyrol</td><td>tyrol</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>tyrolese green</td><td>tyrolesegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>tyrolian</td><td>tyrolian</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>tyrolite green</td><td>tyrolitegreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#1e2321;width:4em;" /><td>tzarine</td><td>tzarine</td><td>##1e2321</td><td>30</td> <td>35</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#1e2321;width:4em;" /><td>ultramarine green</td><td>ultramarinegreen</td><td>##1e2321</td><td>30</td> <td>35</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>ultramarine yellow </td><td>ultramarineyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>urania blue</td><td>uraniablue</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>vagabond green</td><td>vagabondgreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>valencia</td><td>valencia</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>vanda</td><td>vanda</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>vanda</td><td>vanda</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>vandyke brown</td><td>vandykebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>vandyke madder</td><td>vandykemadder</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>vandyke red</td><td>vandykered</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>vanilla</td><td>vanilla</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>vanilla</td><td>vanilla</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>vanity</td><td>vanity</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>variscite green</td><td>variscitegreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>varley's grey </td><td>varleysgrey</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>vassar rose</td><td>vassarrose</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>vassar rose</td><td>vassarrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>vassar tan</td><td>vassartan</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>vassar tan</td><td>vassartan</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>vatican</td><td>vatican</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#301934;width:4em;" /><td>vatican</td><td>vatican</td><td>##301934</td><td>48</td> <td>25</td> <td>52</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>veau d'or</td><td>veaudor</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>veau d'or</td><td>veaudor</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>vegetable red</td><td>vegetablered</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>vegetable rouge</td><td>vegetablerouge</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>velasquez </td><td>velasquez</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>velvet brown</td><td>velvetbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>velvet brown</td><td>velvetbrown</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>velvet green</td><td>velvetgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>venet</td><td>venet</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>venetian blue</td><td>venetianblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>venetian fuchsia</td><td>venetianfuchsia</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>venetian lake</td><td>venetianlake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>venetian lake</td><td>venetianlake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>venetian pink</td><td>venetianpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>venetian red</td><td>venetianred</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>venetian rose</td><td>venetianrose</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>venetian rose</td><td>venetianrose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>venetian scarlet</td><td>venetianscarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>venetian yellow</td><td>venetianyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>venetian yellow</td><td>venetianyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>venezia</td><td>venezia</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>venice berries</td><td>veniceberries</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>venice berries</td><td>veniceberries</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>venice [blue] </td><td>veniceblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>venice green</td><td>venicegreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>venice red</td><td>venicered</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>venus</td><td>venus</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>venus</td><td>venus</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>verbena</td><td>verbena</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>verbena [violet] </td><td>verbenaviolet</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>verbena [violet] </td><td>verbenaviolet</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>verdant green</td><td>verdantgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>verdet</td><td>verdet</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>verde vessie</td><td>verdevessie</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>verd gay</td><td>verdgay</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>verdigris [green] </td><td>verdigrisgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>verditer green</td><td>verditergreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>verdure</td><td>verdure</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>veridine green</td><td>veridinegreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>vernonia purple</td><td>vernoniapurple</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>verona brown</td><td>veronabrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>verona yellow</td><td>veronayellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>verona yellow</td><td>veronayellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>verona yellow</td><td>veronayellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>verona yellow</td><td>veronayellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>veronese yellow</td><td>veroneseyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>veronese yellow</td><td>veroneseyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>veronese yellow</td><td>veroneseyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>veronese yellow</td><td>veroneseyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>veronica</td><td>veronica</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>versailles</td><td>versailles</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>vert russe</td><td>vertrusse</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>vert russe</td><td>vertrusse</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>vert russe</td><td>vertrusse</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>vervain</td><td>vervain</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>vervain</td><td>vervain</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>vestal</td><td>vestal</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>vestal</td><td>vestal</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>veteran</td><td>veteran</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>vetiver green</td><td>vetivergreen</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>victoria</td><td>victoria</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>victoria blue</td><td>victoriablue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>victoria green</td><td>victoriagreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>victoria green</td><td>victoriagreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>victoria green</td><td>victoriagreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>victoria lake</td><td>victorialake</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>vienna blue</td><td>viennablue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>vienna brown</td><td>viennabrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>vienna brown</td><td>viennabrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>vienna green</td><td>viennagreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>vienna lake</td><td>viennalake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>vienna lake</td><td>viennalake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>vienna smoke</td><td>viennasmoke</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>vineyard</td><td>vineyard</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>vineyard</td><td>vineyard</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>viola</td><td>viola</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>violet-carmine</td><td>violetcarmine</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>violine</td><td>violine</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>violine</td><td>violine</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>virgin</td><td>virgin</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>viridian</td><td>viridian</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>viridian</td><td>viridian</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>viridine green</td><td>viridinegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>viridine yellow</td><td>viridineyellow</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>vitelline yellow</td><td>vitellineyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>vitellinous</td><td>vitellinous</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>vitreous</td><td>vitreous</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>wad</td><td>wad</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>wald</td><td>wald</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>wald</td><td>wald</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>wallflower [brown] </td><td>wallflowerbrown</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>wallflower [brown] </td><td>wallflowerbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>wall green</td><td>wallgreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>walnut [brown] </td><td>walnutbrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>warbler green</td><td>warblergreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>warm sepia </td><td>warmsepia</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>water blue</td><td>waterblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>water-color</td><td>watercolor</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>water cress</td><td>watercress</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>waterfall</td><td>waterfall</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>water green</td><td>watergreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>water green</td><td>watergreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>water green</td><td>watergreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>water grey </td><td>watergrey</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>waterloo</td><td>waterloo</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>watermelon</td><td>watermelon</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>watermelon</td><td>watermelon</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>water sprite</td><td>watersprite</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>watteau</td><td>watteau</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>wau</td><td>wau</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>wau</td><td>wau</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>wax brown</td><td>waxbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>wax color</td><td>waxcolor</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>wax color</td><td>waxcolor</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>waxen</td><td>waxen</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>waxen</td><td>waxen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>wax red</td><td>waxred</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>wax white</td><td>waxwhite</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>wax white</td><td>waxwhite</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>wax yellow</td><td>waxyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#422518;width:4em;" /><td>weathered oak</td><td>weatheredoak</td><td>##422518</td><td>66</td> <td>37</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>weigelia</td><td>weigelia</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>weld</td><td>weld</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>weld</td><td>weld</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>westminster</td><td>westminster</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>westminster</td><td>westminster</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>west point</td><td>westpoint</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>wheat</td><td>wheat</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>wheat</td><td>wheat</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>whippet</td><td>whippet</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>whirlpool</td><td>whirlpool</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>white blue</td><td>whiteblue</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>white jade</td><td>whitejade</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>white jade</td><td>whitejade</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>wield</td><td>wield</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>wield</td><td>wield</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>wigwam</td><td>wigwam</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>wild aster</td><td>wildaster</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>wild aster</td><td>wildaster</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>wild cherry</td><td>wildcherry</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>wild cherry</td><td>wildcherry</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>wild dove grey </td><td>wilddovegrey</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>wild honey</td><td>wildhoney</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>wild honey</td><td>wildhoney</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>wild iris</td><td>wildiris</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>wild orchid</td><td>wildorchid</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>wild pigeon</td><td>wildpigeon</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>wild raspberry</td><td>wildraspberry</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>wild raspberry</td><td>wildraspberry</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>wild rose</td><td>wildrose</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>wild strawberry</td><td>wildstrawberry</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>wild strawberry</td><td>wildstrawberry</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>willow</td><td>willow</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>willow green</td><td>willowgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>windflower</td><td>windflower</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>windsor</td><td>windsor</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>windsor blue</td><td>windsorblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>windsor green</td><td>windsorgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>windsor tan</td><td>windsortan</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>wineberry</td><td>wineberry</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>wine dregs</td><td>winedregs</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>wine dregs</td><td>winedregs</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>wine dregs</td><td>winedregs</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>wine lees</td><td>winelees</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>wine lees</td><td>winelees</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>wine lees</td><td>winelees</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>wine yellow</td><td>wineyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>wine yellow</td><td>wineyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>winter green</td><td>wintergreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>wintergreen </td><td>wintergreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>winter leaf</td><td>winterleaf</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>wireless</td><td>wireless</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>wistaria [blue] </td><td>wistariablue</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>wistaria blue</td><td>wistariablue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>wistaria [violet] </td><td>wistariaviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>witchwood</td><td>witchwood</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>withered leaf</td><td>witheredleaf</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>withered leaf</td><td>witheredleaf</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>withered leaf</td><td>witheredleaf</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>withered rose</td><td>witheredrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>withered rose</td><td>witheredrose</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>woad</td><td>woad</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>woald</td><td>woald</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>woald</td><td>woald</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>wod</td><td>wod</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>wod</td><td>wod</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>wode</td><td>wode</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>wold</td><td>wold</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>wold</td><td>wold</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>woodash</td><td>woodash</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>woodbark</td><td>woodbark</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>woodbine green</td><td>woodbinegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>woodbine green</td><td>woodbinegreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>woodbine green</td><td>woodbinegreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>woodbine green</td><td>woodbinegreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>woodland brown</td><td>woodlandbrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>woodland brown</td><td>woodlandbrown</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>woodland green </td><td>woodlandgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>woodland rose</td><td>woodlandrose</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>wood rose</td><td>woodrose</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>wood rose</td><td>woodrose</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>wood violet</td><td>woodviolet</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#363527;width:4em;" /><td>wren</td><td>wren</td><td>##363527</td><td>54</td> <td>53</td> <td>39</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>wren</td><td>wren</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>wrought iron</td><td>wroughtiron</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>yacht</td><td>yacht</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>yale blue</td><td>yaleblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>yama</td><td>yama</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>yellow beige</td><td>yellowbeige</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>yellow beige</td><td>yellowbeige</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>yellow berries</td><td>yellowberries</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow berries</td><td>yellowberries</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow brazil wood</td><td>yellowbrazilwood</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>yellow brazil wood</td><td>yellowbrazilwood</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>yellow carmine</td><td>yellowcarmine</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow carmine</td><td>yellowcarmine</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>yellow daisy</td><td>yellowdaisy</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>yellow daisy</td><td>yellowdaisy</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>yellow daisy</td><td>yellowdaisy</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow daisy</td><td>yellowdaisy</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow earth</td><td>yellowearth</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>yellow madder</td><td>yellowmadder</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>yellow madder</td><td>yellowmadder</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>yellow madder</td><td>yellowmadder</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow madder</td><td>yellowmadder</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow ochre</td><td>yellowochre</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>yellow realgar</td><td>yellowrealgar</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>yellow realgar</td><td>yellowrealgar</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>yellow realgar</td><td>yellowrealgar</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow realgar</td><td>yellowrealgar</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow sienna</td><td>yellowsienna</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>yellow stone</td><td>yellowstone</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>yellowstone</td><td>yellowstone</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow wash</td><td>yellowwash</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow wood</td><td>yellowwood</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>yellow wood</td><td>yellowwood</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>yew green</td><td>yewgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>yolk yellow</td><td>yolkyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>yosemite</td><td>yosemite</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>yucatan</td><td>yucatan</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>yucatan</td><td>yucatan</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>yucca</td><td>yucca</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>yu chi</td><td>yuchi</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>yvette violet</td><td>yvetteviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>zaffre blue </td><td>zaffreblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>zaffre blue </td><td>zaffreblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>zanzibar</td><td>zanzibar</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>zedoary wash</td><td>zedoarywash</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>zenith [blue] </td><td>zenithblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>zenith [blue] </td><td>zenithblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>zephyr</td><td>zephyr</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>zephyr</td><td>zephyr</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>zinc</td><td>zinc</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>zinc</td><td>zinc</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>zinc green</td><td>zincgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>zinc orange</td><td>zincorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>zinc orange</td><td>zincorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>zinc yellow</td><td>zincyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>zinnia</td><td>zinnia</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>zulu</td><td>zulu</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>zuni brown</td><td>zunibrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item abbey                                   abbey                           #604e97

=item absinthe [green]                        absinthegreen                   #8a9a5b

=item absinthe yellow                         absintheyellow                  #b9b57d

=item acacia                                  acacia                          #eae679

=item acacia                                  acacia                          #b9b459

=item academy blue                            academyblue                     #367588

=item acajou                                  acajou                          #79443b

=item acanthe                                 acanthe                         #6c541e

=item acier                                   acier                           #8c8767

=item ackermann's green                       ackermannsgreen                 #355e3b

=item aconite violet                          aconiteviolet                   #86608e

=item acorn                                   acorn                           #7e6d5a

=item adamia                                  adamia                          #563c5c

=item adelaide                                adelaide                        #32174d

=item aden                                    aden                            #6aab8e

=item admiral                                 admiral                         #291e29

=item admiral                                 admiral                         #242124

=item adobe                                   adobe                           #826644

=item adrianople red                          adrianoplered                   #ab4e52

=item adriatic                                adriatic                        #317873

=item adust                                   adust                           #ae6938

=item aero                                    aero                            #536878

=item afghan                                  afghan                          #3e322c

=item afghan red                              afghanred                       #be0032

=item african                                 african                         #222222

=item african brown                           africanbrown                    #3e322c

=item afterglow                               afterglow                       #9690ab

=item agate                                   agate                           #882d17

=item agate                                   agate                           #80461b

=item agate grey                              agategrey                       #b9b8b5

=item ageratum blue                           ageratumblue                    #aa98a9

=item ageratum violet                         ageratumviolet                  #796878

=item air blue                                airblue                         #436b95

=item airedale                                airedale                        #826644

=item airedale                                airedale                        #7e6d5a

=item airway                                  airway                          #70a3cc

=item akbar                                   akbar                           #56070c

=item akbar                                   akbar                           #79443b

=item alabaster                               alabaster                       #ecd5c5

=item alabaster                               alabaster                       #bfb8a5

=item alamo                                   alamo                           #80461b

=item alcanna                                 alcanna                         #882d17

=item alcazar                                 alcazar                         #722f37

=item alcazar                                 alcazar                         #882d17

=item alderney                                alderney                        #826644

=item alesan                                  alesan                          #977f73

=item alesan                                  alesan                          #a67b5b

=item alesan                                  alesan                          #958070

=item alexandria blue                         alexandriablue                  #00a1c2

=item alexandria blue                         alexandriablue                  #0067a5

=item alfalfa                                 alfalfa                         #355e3b

=item algerian                                algerian                        #6f4e37

=item algerian red                            algerianred                     #56070c

=item algonquin                               algonquin                       #be6516

=item algonquin                               algonquin                       #ae6938

=item alhambra                                alhambra                        #3a4b47

=item alhambra                                alhambra                        #004b49

=item alice blue                              aliceblue                       #91a3b0

=item alkermes                                alkermes                        #be0032

=item almond                                  almond                          #a67b5b

=item almond                                  almond                          #958070

=item almond                                  almond                          #c19a6b

=item almond                                  almond                          #ae9b82

=item almond blossom                          almondblossom                   #f9ccca

=item almond blossom                          almondblossom                   #dea5a4

=item almond blossom                          almondblossom                   #ead8d7

=item almond blossom                          almondblossom                   #c4aead

=item almond brown                            almondbrown                     #a67b5b

=item almond brown                            almondbrown                     #958070

=item almond brown                            almondbrown                     #c19a6b

=item almond brown                            almondbrown                     #ae9b82

=item almond green                            almondgreen                     #5e716a

=item almond [pink]                           almondpink                      #f9ccca

=item almond [pink]                           almondpink                      #dea5a4

=item almond [pink]                           almondpink                      #ead8d7

=item almond [pink]                           almondpink                      #c4aead

=item aloes [green]                           aloesgreen                      #8da399

=item aloma                                   aloma                           #a67b5b

=item aloma                                   aloma                           #c19a6b

=item aloma                                   aloma                           #826644

=item alpine                                  alpine                          #536878

=item alpine green                            alpinegreen                     #3a4b47

=item aluminum                                aluminum                        #b9b8b5

=item aluminum                                aluminum                        #848482

=item amaranth                                amaranth                        #702963

=item amaranthine                             amaranthine                     #673147

=item amaranth pink                           amaranthpink                    #de6fa1

=item amaranth purple                         amaranthpurple                  #78184a

=item amarna                                  amarna                          #00543d

=item amarna                                  amarna                          #1b4d3e

=item amarylis                                amarylis                        #ab4e52

=item amarylis                                amarylis                        #905d5d

=item amazon                                  amazon                          #3b7861

=item amber brown                             amberbrown                      #ae6938

=item amberglow                               amberglow                       #ae6938

=item amberglow                               amberglow                       #a67b5b

=item amber white                             amberwhite                      #f3e5ab

=item amber white                             amberwhite                      #c2b280

=item amber white                             amberwhite                      #ebe8a4

=item amber white                             amberwhite                      #b9b57d

=item amber white                             amberwhite                      #dadfb7

=item amber [yellow]                          amberyellow                     #f8de7e

=item amber [yellow]                          amberyellow                     #c9ae5d

=item ambrosia                                ambrosia                        #79443b

=item ambulance                               ambulance                       #43302e

=item amelie                                  amelie                          #3e322c

=item american beauty                         americanbeauty                  #722f37

=item american green                          americangreen                   #679267

=item american green                          americangreen                   #355e3b

=item american green                          americangreen                   #5e716a

=item amethyst [violet]                       amethystviolet                  #86608e

=item amethyst [violet]                       amethystviolet                  #563c5c

=item amethyst [violet]                       amethystviolet                  #796878

=item amparo blue                             amparoblue                      #0067a5

=item amparo blue                             amparoblue                      #6c79b8

=item amparo purple                           amparopurple                    #86608e

=item amulet                                  amulet                          #004b49

=item anamite                                 anamite                         #8c8767

=item anatolia                                anatolia                        #56070c

=item anatta                                  anatta                          #d9a6a9

=item andorra                                 andorra                         #3e1d1e

=item andorra                                 andorra                         #43302e

=item andorre                                 andorre                         #679267

=item andorre                                 andorre                         #5e716a

=item andover green                           andovergreen                    #515744

=item andrinople berries                      andrinopleberries               #eaa221

=item andrinople berries                      andrinopleberries               #e3a857

=item anemone                                 anemone                         #aa8a9e

=item angel red                               angelred                        #79443b

=item animal rouge                            animalrouge                     #be0032

=item animal rouge                            animalrouge                     #bc3f4a

=item annapolis                               annapolis                       #555555

=item annatto                                 annatto                         #d9a6a9

=item annotto                                 annotto                         #d9a6a9

=item antelope                                antelope                        #967117

=item antimony yellow                         antimonyyellow                  #e3a857

=item antique                                 antique                         #967117

=item antique                                 antique                         #6c541e

=item antique brass                           antiquebrass                    #867e36

=item antique brass                           antiquebrass                    #8c8767

=item antique bronze                          antiquebronze                   #826644

=item antique brown                           antiquebrown                    #6f4e37

=item antique drab                            antiquedrab                     #826644

=item antique drab                            antiquedrab                     #967117

=item antique drab                            antiquedrab                     #6c541e

=item antique fuchsia                         antiquefuchsia                  #86608e

=item antique fuchsia                         antiquefuchsia                  #915c83

=item antique gold                            antiquegold                     #be8a3d

=item antique gold                            antiquegold                     #996515

=item antique green                           antiquegreen                    #3a4b47

=item antique red                             antiquered                      #cb6d51

=item antique red                             antiquered                      #9e4732

=item antique red                             antiquered                      #b4745e

=item antique red                             antiquered                      #79443b

=item antique ruby                            antiqueruby                     #841b2d

=item antwerp blue                            antwerpblue                     #2e8495

=item antwerp blue                            antwerpblue                     #436b95

=item antwerp brown                           antwerpbrown                    #483c32

=item antwerp red                             antwerpred                      #79443b

=item apache                                  apache                          #6f4e37

=item aphrodite                               aphrodite                       #66ada4

=item appleblossom [pink]                     appleblossompink                #905d5d

=item apple-fallow                            applefallow                     #841b2d

=item apple-fallow                            applefallow                     #ab4e52

=item apple green                             applegreen                      #8a9a5b

=item apricot                                 apricot                         #d99058

=item apricot yellow                          apricotyellow                   #f8de7e

=item apricot yellow                          apricotyellow                   #c9ae5d

=item aquagreen                               aquagreen                       #93c592

=item aquamarine                              aquamarine                      #66aabc

=item aquamarine                              aquamarine                      #91a3b0

=item arab [brown]                            arabbrown                       #80461b

=item arabesque                               arabesque                       #cb6d51

=item arabian brown                           arabianbrown                    #80461b

=item arabian brown                           arabianbrown                    #6f4e37

=item arabian red                             arabianred                      #56070c

=item araby                                   araby                           #b4745e

=item araby                                   araby                           #a87c6d

=item aragon                                  aragon                          #79443b

=item arbutus                                 arbutus                         #ea9399

=item arbutus                                 arbutus                         #e4717a

=item arbutus                                 arbutus                         #e68fac

=item arbutus                                 arbutus                         #de6fa1

=item arcadian green                          arcadiangreen                   #93c592

=item archel                                  archel                          #a8516e

=item archil                                  archil                          #a8516e

=item arctic                                  arctic                          #222222

=item arctic blue                             arcticblue                      #536878

=item ardoise                                 ardoise                         #536878

=item ardoise                                 ardoise                         #796878

=item argali                                  argali                          #5b504f

=item argali                                  argali                          #555555

=item argent                                  argent                          #848482

=item argentina                               argentina                       #422518

=item argus brown                             argusbrown                      #6f4e37

=item argyle purple                           argylepurple                    #aa8a9e

=item argyle purple                           argylepurple                    #836479

=item arizona                                 arizona                         #c19a6b

=item armada                                  armada                          #43302e

=item armada                                  armada                          #3e322c

=item armenian blue                           armenianblue                    #00a1c2

=item armenian blue                           armenianblue                    #0067a5

=item armenian bole                           armenianbole                    #79443b

=item armenian red                            armenianred                     #80461b

=item armenian stone                          armenianstone                   #436b95

=item army brown                              armybrown                       #a67b5b

=item arno blue                               arnoblue                        #367588

=item arno blue                               arnoblue                        #004958

=item arnotto                                 arnotto                         #d9a6a9

=item arona                                   arona                           #36454f

=item arrowwood                               arrowwood                       #967117

=item arsenate                                arsenate                        #007959

=item art brown                               artbrown                        #422518

=item artemesia green                         artemesiagreen                  #7d8984

=item art gray, art grey                      artgrayartgrey                  #8b8589

=item art gray, art grey                      artgrayartgrey                  #848482

=item art green                               artgreen                        #8a9a5b

=item art green                               artgreen                        #4a5d23

=item artichoke green                         artichokegreen                  #8f9779

=item artificial vermilion                    artificialvermilion             #915f6d

=item artillery                               artillery                       #be0032

=item ascot tan                               ascottan                        #635147

=item ashes of rose                           ashesofrose                     #915f6d

=item ash [grey]                              ashgrey                         #b2beb5

=item asmalte                                 asmalte                         #00416a

=item asmalte                                 asmalte                         #436b95

=item asparagus green                         asparagusgreen                  #dadfb7

=item aspen green                             aspengreen                      #5e716a

=item asphalt                                 asphalt                         #555555

=item asphaltum                               asphaltum                       #483c32

=item asphodel green                          asphodelgreen                   #8a9a5b

=item aster                                   aster                           #796878

=item aster purple                            asterpurple                     #78184a

=item athenia                                 athenia                         #905d5d

=item atlantic                                atlantic                        #36454f

=item atlantis                                atlantis                        #004958

=item atlantis                                atlantis                        #36454f

=item atmosphere                              atmosphere                      #c2ac99

=item atmosphere                              atmosphere                      #ae9b82

=item atmosphere                              atmosphere                      #bfb8a5

=item atramentous                             atramentous                     #51585e

=item attar of roses                          attarofroses                    #b4745e

=item attar of roses                          attarofroses                    #a87c6d

=item aubergine                               aubergine                       #291e29

=item aubergine                               aubergine                       #242124

=item auburn                                  auburn                          #6f4e37

=item aubusson                                aubusson                        #722f37

=item aucuba                                  aucuba                          #867e36

=item aureolin                                aureolin                        #fada5e

=item aureolin                                aureolin                        #d4af37

=item auricula purple                         auriculapurple                  #702963

=item auripigmentum                           auripigmentum                   #fada5e

=item auripigmentum                           auripigmentum                   #d4af37

=item auripigmentum                           auripigmentum                   #f8de7e

=item auripigmentum                           auripigmentum                   #c9ae5d

=item aurora [orange]                         auroraorange                    #f88379

=item aurora [orange]                         auroraorange                    #e66761

=item aurora [orange]                         auroraorange                    #cb6d51

=item aurora red                              aurorared                       #ab4e52

=item aurora red                              aurorared                       #e66761

=item aurora red                              aurorared                       #cb6d51

=item aurora yellow                           aurorayellow                    #ed872d

=item aurora yellow                           aurorayellow                    #d99058

=item aurora yellow                           aurorayellow                    #eaa221

=item aurora yellow                           aurorayellow                    #e3a857

=item aurore                                  aurore                          #dea5a4

=item aurum                                   aurum                           #967117

=item australian pine                         australianpine                  #355e3b

=item auteuil                                 auteuil                         #e3a857

=item autumn                                  autumn                          #5b5842

=item autumn                                  autumn                          #363527

=item autumn blonde                           autumnblonde                    #977f73

=item autumn blonde                           autumnblonde                    #6f4e37

=item autumn blonde                           autumnblonde                    #958070

=item autumn blonde                           autumnblonde                    #635147

=item autumn brown                            autumnbrown                     #483c32

=item autumn glory                            autumnglory                     #722f37

=item autumn glory                            autumnglory                     #9e4732

=item autumn green                            autumngreen                     #8a9a5b

=item autumn green                            autumngreen                     #4a5d23

=item autumn leaf                             autumnleaf                      #be6516

=item autumn leaf                             autumnleaf                      #ae6938

=item autumn leaf                             autumnleaf                      #80461b

=item autumn oak                              autumnoak                       #674c47

=item avellaneous                             avellaneous                     #a67b5b

=item avellaneous                             avellaneous                     #996515

=item avignon berries                         avignonberries                  #eaa221

=item avignon berries                         avignonberries                  #e3a857

=item azalea                                  azalea                          #905d5d

=item aztec                                   aztec                           #996515

=item aztec                                   aztec                           #c19a6b

=item aztec                                   aztec                           #826644

=item aztec maroon                            aztecmaroon                     #915f6d

=item azulin                                  azulin                          #536878

=item baby blue                               babyblue                        #91a3b0

=item baby blue                               babyblue                        #b4bcc0

=item baby blue                               babyblue                        #81878b

=item baby pink                               babypink                        #f4c2c2

=item baby pink                               babypink                        #d9a6a9

=item baby rose                               babyrose                        #f88379

=item bacchus                                 bacchus                         #a8516e

=item bachelor button                         bachelorbutton                  #e4717a

=item bagdad                                  bagdad                          #00304e

=item bagdad                                  bagdad                          #36454f

=item bagdad                                  bagdad                          #202830

=item bakst green                             bakstgreen                      #1b4d3e

=item balge yellow                            balgeyellow                     #fada5e

=item ball lake                               balllake                        #be0032

=item ball lake                               balllake                        #bc3f4a

=item balsam                                  balsam                          #36454f

=item balsam green                            balsamgreen                     #222222

=item baltic                                  baltic                          #3a4b47

=item baltic                                  baltic                          #004b49

=item bambino                                 bambino                         #91a3b0

=item bamboo                                  bamboo                          #c19a6b

=item bamboo                                  bamboo                          #826644

=item banana                                  banana                          #c2b280

=item banner                                  banner                          #4c516d

=item banshee                                 banshee                         #3a4b47

=item barberry                                barberry                        #841b2d

=item barberry                                barberry                        #ab4e52

=item bark                                    bark                            #3b3121

=item barwood                                 barwood                         #ab4e52

=item basketball                              basketball                      #9065ca

=item bastard saffron                         bastardsaffron                  #be0032

=item bat                                     bat                             #555555

=item bath stone                              bathstone                       #fad6a5

=item battleship grey                         battleshipgrey                  #848482

=item bay                                     bay                             #6f4e37

=item bayou                                   bayou                           #3a4b47

=item beach                                   beach                           #8c8767

=item beach                                   beach                           #8a8776

=item beach tan                               beachtan                        #635147

=item bear                                    bear                            #555555

=item bear's hair                             bearshair                       #555555

=item bearskin [grey]                         bearskingrey                    #555555

=item beaucaire                               beaucaire                       #007791

=item beaucaire                               beaucaire                       #367588

=item beaver                                  beaver                          #5b504f

=item beaverpelt                              beaverpelt                      #57554c

=item beech                                   beech                           #5b5842

=item beech                                   beech                           #57554c

=item beechnut                                beechnut                        #635147

=item beef's blood                            beefsblood                      #79443b

=item beeswax                                 beeswax                         #826644

=item beetle                                  beetle                          #515744

=item begonia                                 begonia                         #e4717a

=item begonia rose                            begoniarose                     #ab4e52

=item beige                                   beige                           #f3e5ab

=item beige                                   beige                           #c2b280

=item beige soire                            beigesoire                      #c19a6b

=item belladonna                              belladonna                      #563c5c

=item belleek                                 belleek                         #fad6a5

=item belleek                                 belleek                         #ae9b82

=item belleek                                 belleek                         #c2b280

=item belleek                                 belleek                         #bfb8a5

=item bellemonte                              bellemonte                      #ab4e52

=item bellflower                              bellflower                      #272458

=item berlin brown                            berlinbrown                     #905d5d

=item berlin brown                            berlinbrown                     #674c47

=item berlin red                              berlinred                       #79443b

=item bermuda                                 bermuda                         #e4717a

=item beryl                                   beryl                           #66aabc

=item beryl blue                              berylblue                       #66aabc

=item beryl green                             berylgreen                      #66ada4

=item biarritz                                biarritz                        #ae9b82

=item biarritz                                biarritz                        #967117

=item big four yellow, big 4 yellow           bigfouryellowbig4yellow         #f38400

=item big four yellow, big 4 yellow           bigfouryellowbig4yellow         #ed872d

=item billiard                                billiard                        #1b4d3e

=item biscay green                            biscaygreen                     #8a9a5b

=item biscuit                                 biscuit                         #a67b5b

=item biscuit                                 biscuit                         #958070

=item biscuit                                 biscuit                         #c19a6b

=item biscuit                                 biscuit                         #ae9b82

=item bishop                                  bishop                          #604e81

=item bishop's purple                         bishopspurple                   #915c83

=item bishop's violet                         bishopsviolet                   #915c83

=item biskra                                  biskra                          #483c32

=item bismarck                                bismarck                        #79443b

=item bismarck brown                          bismarckbrown                   #826644

=item bison                                   bison                           #483c32

=item bisque                                  bisque                          #fad6a5

=item bisque                                  bisque                          #bfb8a5

=item bister                                  bister                          #635147

=item bister                                  bister                          #7e6d5a

=item bistre                                  bistre                          #635147

=item bistre                                  bistre                          #7e6d5a

=item bistre green                            bistregreen                     #ab9144

=item bistre green                            bistregreen                     #a18f60

=item bittersweet                             bittersweet                     #aa381e

=item bittersweet                             bittersweet                     #9e4732

=item bittersweet orange                      bittersweetorange               #be6516

=item bittersweet pink                        bittersweetpink                 #f88379

=item bitumen                                 bitumen                         #483c32

=item bladder green                           bladdergreen                    #867e36

=item blaze                                   blaze                           #ab4e52

=item blaze                                   blaze                           #9e4732

=item bleu de lyons                           bleudelyons                     #00416a

=item bleu de lyons                           bleudelyons                     #436b95

=item bleu d'orient                           bleudorient                     #0067a5

=item bleu louise                             bleulouise                      #317873

=item bleu louise                             bleulouise                      #367588

=item bleu pass                              bleupass                        #91a3b0

=item bleu pass                              bleupass                        #536878

=item bleu pass                              bleupass                        #81878b

=item blond                                   blond                           #c19a6b

=item blond                                   blond                           #a18f60

=item blondine                                blondine                        #7e6d5a

=item blonket                                 blonket                         #b4bcc0

=item blood red                               bloodred                        #bc3f4a

=item blood red                               bloodred                        #ab4e52

=item blossom                                 blossom                         #dea5a4

=item blue ashes                              blueashes                       #436b95

=item blue aster                              blueaster                       #436b95

=item bluebell                                bluebell                        #436b95

=item bluebell                                bluebell                        #00304e

=item blue bice                               bluebice                        #436b95

=item blue bird, bluebird                     bluebirdbluebird                #436b95

=item blue devil                              bluedevil                       #4c516d

=item blue fox                                bluefox                         #5c504f

=item blue grass                              bluegrass                       #004b49

=item blue haze                               bluehaze                        #555555

=item bluejay                                 bluejay                         #00416a

=item bluejay                                 bluejay                         #00304e

=item blue jewel                              bluejewel                       #007791

=item blue lavender                           bluelavender                    #8c92ac

=item blue lotus                              bluelotus                       #70a3cc

=item blue ochre                              blueochre                       #5e716a

=item blue ochre                              blueochre                       #536878

=item blue orchid                             blueorchid                      #536878

=item blue sapphire                           bluesapphire                    #367588

=item blue spruce                             bluespruce                      #3b7861

=item blue spruce                             bluespruce                      #5e716a

=item bluet                                   bluet                           #436b95

=item blue turquoise                          blueturquoise                   #66ada4

=item blue turquoise                          blueturquoise                   #66aabc

=item blue untramarine ash                    blueuntramarineash              #436b95

=item blue verditer                           blueverditer                    #436b95

=item blunket                                 blunket                         #b4bcc0

=item blush                                   blush                           #d9a6a9

=item blush                                   blush                           #a67b5b

=item blush rose                              blushrose                       #905d5d

=item boa                                     boa                             #8a9a5b

=item boa                                     boa                             #dadfb7

=item boa                                     boa                             #93c592

=item bobolink                                bobolink                        #7e6d5a

=item bois de rose                            boisderose                      #905d5d

=item bokhara                                 bokhara                         #673147

=item bole                                    bole                            #79443b

=item bole armoniack                          bolearmoniack                   #79443b

=item bolus                                   bolus                           #79443b

=item bombay                                  bombay                          #80461b

=item bombay                                  bombay                          #6f4e37

=item bone brown                              bonebrown                       #6c541e

=item bone brown                              bonebrown                       #3b3121

=item bonfire                                 bonfire                         #bc3f4a

=item bonito                                  bonito                          #5b504f

=item bonnie blue                             bonnieblue                      #00a1c2

=item boreal                                  boreal                          #79443b

=item bosphorus                               bosphorus                       #3a4b47

=item botticelli                              botticelli                      #702963

=item bottle green                            bottlegreen                     #3a4b47

=item bottle green                            bottlegreen                     #004b49

=item bougainville                            bougainville                    #86608e

=item bougainville                            bougainville                    #915c83

=item boulevard                               boulevard                       #5b504f

=item bouquet green                           bouquetgreen                    #6aab8e

=item bourgeon                                bourgeon                        #8a9a5b

=item box green                               boxgreen                        #8a9a5b

=item bracken                                 bracken                         #6c541e

=item bracken                                 bracken                         #3b3121

=item bramble                                 bramble                         #2f2140

=item bran                                    bran                            #a67b5b

=item bran                                    bran                            #c19a6b

=item brass                                   brass                           #c9ae5d

=item brazen yellow                           brazenyellow                    #c9ae5d

=item brazil brown                            brazilbrown                     #43302e

=item brazil [red]                            brazilred                       #9e4732

=item brazilwood                              brazilwood                      #ab4e52

=item brazilwood                              brazilwood                      #905d5d

=item bremen blue                             bremenblue                      #317873

=item bremen green                            bremengreen                     #679267

=item brewster green                          brewstergreen                   #4a5d23

=item briar                                   briar                           #80461b

=item briar                                   briar                           #6f4e37

=item briarwood                               briarwood                       #3e322c

=item brickdust                               brickdust                       #841b2d

=item brick red                               brickred                        #80461b

=item brick red                               brickred                        #6f4e37

=item bridal rose                             bridalrose                      #c08081

=item brigand                                 brigand                         #bc3f4a

=item brigand                                 brigand                         #ab4e52

=item brigand                                 brigand                         #d9603b

=item brigand                                 brigand                         #cb6d51

=item brimstone [yellow]                      brimstoneyellow                 #eae679

=item brittany                                brittany                        #367588

=item brittany                                brittany                        #436b95

=item brittany                                brittany                        #536878

=item broccoli brown                          broccolibrown                   #5b504f

=item broncho                                 broncho                         #483c32

=item broncho                                 broncho                         #6c541e

=item broncho                                 broncho                         #3b3121

=item bronze                                  bronze                          #826644

=item bronze brown                            bronzebrown                     #5b504f

=item bronze clair                            bronzeclair                     #ae9b82

=item bronze green                            bronzegreen                     #515744

=item bronze lustre                           bronzelustre                    #5b5842

=item bronze nude                             bronzenude                      #6c541e

=item bronze red                              bronzered                       #ab4e52

=item bronzesheen                             bronzesheen                     #5b5842

=item bronze yellow                           bronzeyellow                    #d99058

=item bronze yellow                           bronzeyellow                    #be8a3d

=item brown bay                               brownbay                        #635147

=item brown bread                             brownbread                      #80461b

=item brown bread                             brownbread                      #6f4e37

=item brown madder                            brownmadder                     #79443b

=item brown ochre                             brownochre                      #d99058

=item brown pink                              brownpink                       #be8a3d

=item brown pink                              brownpink                       #996515

=item brown red                               brownred                        #79443b

=item brown stone                             brownstone                      #635147

=item brownstone                              brownstone                      #635147

=item brown sugar                             brownsugar                      #6f4e37

=item brown sugar                             brownsugar                      #635147

=item brown sugar                             brownsugar                      #826644

=item brown sugar                             brownsugar                      #7e6d5a

=item bruges                                  bruges                          #004958

=item bruges                                  bruges                          #36454f

=item brushwood                               brushwood                       #635147

=item brussels brown                          brusselsbrown                   #6f4e37

=item brussels brown                          brusselsbrown                   #635147

=item brussels brown                          brusselsbrown                   #826644

=item brussels brown                          brusselsbrown                   #7e6d5a

=item buccaneer                               buccaneer                       #bc3f4a

=item buccaneer                               buccaneer                       #ab4e52

=item buccaneer                               buccaneer                       #aa381e

=item buccaneer                               buccaneer                       #9e4732

=item buckskin                                buckskin                        #977f73

=item buckskin                                buckskin                        #958070

=item buckthorn berries                       buckthornberries                #eaa221

=item buckthorn berries                       buckthornberries                #e3a857

=item buckthorn brown                         buckthornbrown                  #be8a3d

=item buckthorn brown                         buckthornbrown                  #996515

=item buckthorn brown                         buckthornbrown                  #c19a6b

=item buckthorn brown                         buckthornbrown                  #826644

=item buckthorn brown                         buckthornbrown                  #ab9144

=item buckthorn brown                         buckthornbrown                  #a18f60

=item buckthorn brown                         buckthornbrown                  #967117

=item buddha                                  buddha                          #bc3f4a

=item buddha                                  buddha                          #ab4e52

=item bud green                               budgreen                        #44944a

=item buff                                    buff                            #e3a857

=item buffalo                                 buffalo                         #826644

=item bulgare                                 bulgare                         #905d5d

=item bunny                                   bunny                           #826644

=item bure                                    bure                            #996515

=item bure                                    bure                            #c19a6b

=item bure                                    bure                            #826644

=item burel                                   burel                           #6f4e37

=item burgundy                                burgundy                        #50404d

=item burgundy                                burgundy                        #291e29

=item burgundy violet                         burgundyviolet                  #875692

=item burlwood                                burlwood                        #958070

=item burlwood                                burlwood                        #ae9b82

=item burma                                   burma                           #ae6938

=item burmese gold                            burmesegold                     #cb6d51

=item burmese ruby                            burmeseruby                     #722f37

=item burn blue                               burnblue                        #bcd4e6

=item burn blue                               burnblue                        #91a3b0

=item burn blue                               burnblue                        #c0c8e1

=item burn blue                               burnblue                        #8c92ac

=item burnished gold                          burnishedgold                   #be8a3d

=item burnished gold                          burnishedgold                   #996515

=item burnished gold                          burnishedgold                   #c19a6b

=item burnished gold                          burnishedgold                   #ab9144

=item burnished gold                          burnishedgold                   #967117

=item burnous                                 burnous                         #fad6a5

=item burnt                                   burnt                           #a18f60

=item burnt almond                            burntalmond                     #6f4e37

=item burnt carmine                           burntcarmine                    #841b2d

=item burnt carmine                           burntcarmine                    #ab4e52

=item burnt coral                             burntcoral                      #cb6d51

=item burnt crimson lake                      burntcrimsonlake                #841b2d

=item burnt crimson lake                      burntcrimsonlake                #ab4e52

=item burnt italian earth                     burntitalianearth               #9e4732

=item burnt italian ochre                     burntitalianochre               #9e4732

=item burnt lake                              burntlake                       #841b2d

=item burnt lake                              burntlake                       #ab4e52

=item burnt ochre                             burntochre                      #cb6d51

=item burnt orange                            burntorange                     #cb6d51

=item burnt roman ochre                       burntromanochre                 #ed872d

=item burnt rose                              burntrose                       #56070c

=item burnt rose                              burntrose                       #79443b

=item burnt russet                            burntrusset                     #722f37

=item burnt russet                            burntrusset                     #79443b

=item burnt sienna                            burntsienna                     #9e4732

=item burnt terre verte                       burntterreverte                 #6f4e37

=item burnt umber                             burntumber                      #6f4e37

=item buttercup [yellow]                      buttercupyellow                 #c2b280

=item butterfly                               butterfly                       #b9b459

=item butternut                               butternut                       #6c541e

=item butterscotch                            butterscotch                    #6f4e37

=item butterscotch                            butterscotch                    #826644

=item byron                                   byron                           #483c32

=item byzantine                               byzantine                       #ce4676

=item byzantium                               byzantium                       #702963

=item byzantium                               byzantium                       #5d3954

=item cabaret                                 cabaret                         #6aab8e

=item cabbage green                           cabbagegreen                    #7d8984

=item cacao                                   cacao                           #826644

=item cacao brown                             cacaobrown                      #80461b

=item cacha                                   cacha                           #6f4e37

=item cachou                                  cachou                          #6f4e37

=item cactus                                  cactus                          #355e3b

=item cadet                                   cadet                           #536878

=item cadet blue                              cadetblue                       #436b95

=item cadet grey                              cadetgrey                       #81878b

=item cadmium carmine                         cadmiumcarmine                  #bc3f4a

=item cadmium green                           cadmiumgreen                    #007959

=item cadmium lemon                           cadmiumlemon                    #dcd300

=item cadmium lemon                           cadmiumlemon                    #e9e450

=item cadmium orange                          cadmiumorange                   #ed872d

=item cadmium purple                          cadmiumpurple                   #841b2d

=item cadmium purple                          cadmiumpurple                   #ab4e52

=item cadmium vermilion                       cadmiumvermilion                #bc3f4a

=item cadmium vermilion                       cadmiumvermilion                #ab4e52

=item cadmium yellow                          cadmiumyellow                   #ed872d

=item cadmium yellow                          cadmiumyellow                   #d99058

=item cadmium yellow                          cadmiumyellow                   #eaa221

=item cadmium yellow                          cadmiumyellow                   #e3a857

=item caen stone                              caenstone                       #fad6a5

=item caeruleum                               caeruleum                       #0085a1

=item caeruleum                               caeruleum                       #00a1c2

=item caf-au-lait                            cafaulait                       #977f73

=item caf-au-lait                            cafaulait                       #a67b5b

=item caf-au-lait                            cafaulait                       #958070

=item caf crme                              cafcrme                         #a67b5b

=item caf crme                              cafcrme                         #6f4e37

=item caf crme                              cafcrme                         #826644

=item caf noir                               cafnoir                         #483c32

=item cairo                                   cairo                           #00416a

=item calabash                                calabash                        #826644

=item calabash                                calabash                        #967117

=item calamine blue                           calamineblue                    #66aabc

=item caldera                                 caldera                         #79443b

=item caledonian brown                        caledonianbrown                 #80461b

=item caliaturwood                            caliaturwood                    #ab4e52

=item california color                        californiacolor                 #6f4e37

=item california green                        californiagreen                 #a18f60

=item calla green                             callagreen                      #8a9a5b

=item calliste green                          callistegreen                   #7e9f2e

=item calliste green                          callistegreen                   #8a9a5b

=item cambridge blue                          cambridgeblue                   #66ada4

=item cambridge red                           cambridgered                    #ab4e52

=item cambridge red                           cambridgered                    #905d5d

=item camel                                   camel                           #5b504f

=item camellia                                camellia                        #bc3f4a

=item camellia                                camellia                        #ab4e52

=item camels hair or camel's hair             camelshairorcamelshair          #7e6d5a

=item cameo blue                              cameoblue                       #66ada4

=item cameo brown                             cameobrown                      #905d5d

=item cameo brown                             cameobrown                      #a87c6d

=item cameo brown                             cameobrown                      #79443b

=item cameo brown                             cameobrown                      #674c47

=item cameo green                             cameogreen                      #93c592

=item cameo green                             cameogreen                      #6aab8e

=item cameo green                             cameogreen                      #8da399

=item cameo pink                              cameopink                       #c3a6b1

=item cameo yellow                            cameoyellow                     #f3e5ab

=item campanula                               campanula                       #604e97

=item campanula                               campanula                       #604e81

=item campanula blue                          campanulablue                   #8791bf

=item campanula blue                          campanulablue                   #6c79b8

=item campanula blue                          campanulablue                   #7e73b8

=item campanula purple                        campanulapurple                 #836479

=item campanula violet                        campanulaviolet                 #836479

=item camrier                                camrier                         #563c5c

=item camwood                                 camwood                         #ab4e52

=item canard                                  canard                          #004b49

=item canard                                  canard                          #004958

=item canary-bird green                       canarybirdgreen                 #ab9144

=item canary green                            canarygreen                     #ab9144

=item canary [yellow]                         canaryyellow                    #c9ae5d

=item candida                                 candida                         #af868e

=item candy pink                              candypink                       #e4717a

=item candy pink                              candypink                       #f88379

=item candy pink                              candypink                       #e66761

=item canna                                   canna                           #cb6d51

=item canna                                   canna                           #9e4732

=item canna                                   canna                           #b4745e

=item canna                                   canna                           #79443b

=item cannon                                  cannon                          #1a2421

=item canterbury                              canterbury                      #604e97

=item canton [blue]                           cantonblue                      #00304e

=item canton jade                             cantonjade                      #317873

=item canyon                                  canyon                          #722f37

=item canyon                                  canyon                          #673147

=item cappagh                                 cappagh                         #6f4e37

=item cappah brown                            cappahbrown                     #6f4e37

=item capri                                   capri                           #007791

=item caprice                                 caprice                         #870074

=item caprice                                 caprice                         #d6cadd

=item capucine                                capucine                        #c9ae5d

=item capucine buff                           capucinebuff                    #fad6a5

=item capucine lake                           capucinelake                    #f88379

=item capucine lake                           capucinelake                    #cb6d51

=item capucine lake                           capucinelake                    #ed872d

=item capucine lake                           capucinelake                    #d99058

=item capucine madder                         capucinemadder                  #d99058

=item capucine orange                         capucineorange                  #d99058

=item capucine red                            capucinered                     #ffb7a5

=item capucine red                            capucinered                     #d9603b

=item capucine yellow                         capucineyellow                  #d99058

=item caput mortuum                           caputmortuum                    #79443b

=item caraibe                                 caraibe                         #6f4e37

=item caraibe                                 caraibe                         #635147

=item caraibe                                 caraibe                         #826644

=item caraibe                                 caraibe                         #7e6d5a

=item caramel                                 caramel                         #ae6938

=item caramel                                 caramel                         #a67b5b

=item carbuncle                               carbuncle                       #43302e

=item cardinal [red]                          cardinalred                     #be0032

=item carmine                                 carmine                         #be0032

=item carmine                                 carmine                         #bc3f4a

=item carmine lake                            carminelake                     #be0032

=item carmine lake                            carminelake                     #bc3f4a

=item carnation                               carnation                       #f3e5ab

=item carnation                               carnation                       #c2b280

=item carnation [red]                         carnationred                    #ab4e52

=item carnation rose                          carnationrose                   #ea9399

=item carnelian                               carnelian                       #b4745e

=item carnelian red                           carnelianred                    #cb6d51

=item carnival red                            carnivalred                     #bc3f4a

=item carob brown                             carobbrown                      #6f4e37

=item caroubier                               caroubier                       #6f4e37

=item carrara green                           carraragreen                    #1b4d3e

=item carrot red                              carrotred                       #ed872d

=item carrot red                              carrotred                       #d99058

=item carthamus red                           carthamusred                    #be0032

=item carthamus rose                          carthamusrose                   #be0032

=item cartouche                               cartouche                       #6f4e37

=item cartridge buff                          cartridgebuff                   #f3e5ab

=item cartridge buff                          cartridgebuff                   #c2b280

=item cascade                                 cascade                         #66ada4

=item cashew                                  cashew                          #6f4e37

=item cashew lake                             cashewlake                      #6f4e37

=item cashew nut                              cashewnut                       #635147

=item cashoo                                  cashoo                          #6f4e37

=item casino pink                             casinopink                      #b3446c

=item cassel brown                            casselbrown                     #6f4e37

=item cassel earth                            casselearth                     #6f4e37

=item cassel yellow                           casselyellow                    #fada5e

=item cassel yellow                           casselyellow                    #d4af37

=item cassel yellow                           casselyellow                    #f8de7e

=item cassel yellow                           casselyellow                    #c9ae5d

=item casserole                               casserole                       #79443b

=item castaneous                              castaneous                      #635147

=item castellon                               castellon                       #79443b

=item castile earth                           castileearth                    #6f4e37

=item castilian brown                         castilianbrown                  #79443b

=item castilian red                           castilianred                    #be0032

=item castor                                  castor                          #5b504f

=item castor grey                             castorgrey                      #4e5755

=item catalpa                                 catalpa                         #796878

=item catawba                                 catawba                         #3f1728

=item catawba                                 catawba                         #2e1d21

=item cate                                    cate                            #6f4e37

=item catechu                                 catechu                         #6f4e37

=item cathay                                  cathay                          #ae6938

=item cathay                                  cathay                          #996515

=item cathedral                               cathedral                       #2f2140

=item cathedral blue                          cathedralblue                   #436b95

=item cathedral blue                          cathedralblue                   #4e5180

=item cattail                                 cattail                         #483c32

=item cattleya                                cattleya                        #86608e

=item caucasia                                caucasia                        #7e6d5a

=item cauldron                                cauldron                        #722f37

=item cauldron                                cauldron                        #882d17

=item cauldron                                cauldron                        #79443b

=item cavalry                                 cavalry                         #e3a857

=item cedar                                   cedar                           #674c47

=item cedarbark                               cedarbark                       #905d5d

=item cedarbark                               cedarbark                       #79443b

=item cedar green                             cedargreen                      #4a5d23

=item cedar wood                              cedarwood                       #79443b

=item cedre                                   cedre                           #4a5d23

=item celadon green                           celadongreen                    #8f9779

=item celandine green                         celandinegreen                  #5e716a

=item celest                                  celest                          #536878

=item celest                                  celest                          #8c92ac

=item celestial                               celestial                       #436b95

=item celestial blue                          celestialblue                   #91a3b0

=item cellini                                 cellini                         #870074

=item cellini                                 cellini                         #ce4676

=item cement                                  cement                          #848482

=item cendrillon                              cendrillon                      #3a4b47

=item cendrillon                              cendrillon                      #51585e

=item centennial brown                        centennialbrown                 #996515

=item centennial brown                        centennialbrown                 #c19a6b

=item centennial brown                        centennialbrown                 #826644

=item centre blue                             centreblue                      #436b95

=item ceramic                                 ceramic                         #436b95

=item ceres                                   ceres                           #d99058

=item cerise                                  cerise                          #ab4e52

=item cerro green                             cerrogreen                      #8a9a5b

=item cerro green                             cerrogreen                      #4a5d23

=item certosa                                 certosa                         #98943e

=item certosa                                 certosa                         #867e36

=item certosa                                 certosa                         #8a9a5b

=item cerulean                                cerulean                        #70a3cc

=item cerulean                                cerulean                        #8791bf

=item cerulean blue                           ceruleanblue                    #0085a1

=item cerulean blue                           ceruleanblue                    #00a1c2

=item ceylon blue                             ceylonblue                      #004958

=item chaetura black                          chaeturablack                   #222222

=item chaetura drab                           chaeturadrab                    #555555

=item chalcedony yellow                       chalcedonyyellow                #eae679

=item chalet red                              chaletred                       #905d5d

=item chamois                                 chamois                         #c2b280

=item chamois skin                            chamoisskin                     #c2b280

=item chamoline                               chamoline                       #be8a3d

=item chamoline                               chamoline                       #996515

=item chamoline                               chamoline                       #c19a6b

=item chamoline                               chamoline                       #826644

=item chamoline                               chamoline                       #ab9144

=item chamoline                               chamoline                       #a18f60

=item chamoline                               chamoline                       #967117

=item champagne                               champagne                       #fad6a5

=item champagne                               champagne                       #ae9b82

=item champagne                               champagne                       #c2b280

=item champagne                               champagne                       #bfb8a5

=item chantilly                               chantilly                       #6aab8e

=item charcoal grey                           charcoalgrey                    #555555

=item chardon                                 chardon                         #673147

=item charles x                               charlesx                        #673147

=item chartreuse                              chartreuse                      #e9e450

=item chartreuse                              chartreuse                      #beb72e

=item chartreuse                              chartreuse                      #eae679

=item chartreuse                              chartreuse                      #b9b459

=item chartreuse green                        chartreusegreen                 #98943e

=item chartreuse yellow                       chartreuseyellow                #eae679

=item chartreuse yellow                       chartreuseyellow                #b9b459

=item chasseur                                chasseur                        #173620

=item chatemuc                                chatemuc                        #ab4e52

=item chatenay pink                           chatenaypink                    #f4c2c2

=item chatenay pink                           chatenaypink                    #d9a6a9

=item chaudron                                chaudron                        #cb6d51

=item chaudron                                chaudron                        #9e4732

=item chaudron                                chaudron                        #b4745e

=item chaudron                                chaudron                        #79443b

=item checkerberry                            checkerberry                    #be0032

=item chemic blue                             chemicblue                      #004958

=item chemic green                            chemicgreen                     #317873

=item cherokee                                cherokee                        #cb6d51

=item cherry                                  cherry                          #e25822

=item cherry bloom                            cherrybloom                     #f88379

=item cherry blossom                          cherryblossom                   #ab4e52

=item cherry red                              cherryred                       #e25822

=item cherub                                  cherub                          #d9a6a9

=item chessylite blue                         chessyliteblue                  #436b95

=item chestnut                                chestnut                        #635147

=item chevreuse                               chevreuse                       #905d5d

=item chevreuse                               chevreuse                       #79443b

=item chianti                                 chianti                         #841b2d

=item chickadee gray                          chickadeegray                   #57554c

=item chicle                                  chicle                          #635147

=item chicory                                 chicory                         #8c92ac

=item chicory blue                            chicoryblue                     #dadfb7

=item chicory blue                            chicoryblue                     #8c92ac

=item chimney red                             chimneyred                      #841b2d

=item chimney red                             chimneyred                      #ab4e52

=item china blue                              chinablue                       #436b95

=item china blue                              chinablue                       #536878

=item china rose                              chinarose                       #a8516e

=item chinchilla                              chinchilla                      #848482

=item chin-chin blue                          chinchinblue                    #536878

=item chinese gold                            chinesegold                     #ae6938

=item chinese green                           chinesegreen                    #93c592

=item chinese green                           chinesegreen                    #6aab8e

=item chinese green                           chinesegreen                    #1b4d3e

=item chinese green                           chinesegreen                    #004b49

=item chinese lake                            chineselake                     #be0032

=item chinese lake                            chineselake                     #bc3f4a

=item chinese orange                          chineseorange                   #ffb7a5

=item chinese orange                          chineseorange                   #d9603b

=item chinese red                             chinesered                      #aa381e

=item chinese red                             chinesered                      #9e4732

=item chinese red                             chinesered                      #882d17

=item chinese rouge                           chineserouge                    #be0032

=item chinese vermilion                       chinesevermilion                #be0032

=item chinese violet                          chineseviolet                   #86608e

=item chinese yellow                          chineseyellow                   #fada5e

=item chinese yellow                          chineseyellow                   #d4af37

=item chinese yellow                          chineseyellow                   #f8de7e

=item chinese yellow                          chineseyellow                   #c9ae5d

=item chinese yellow                          chineseyellow                   #e3a857

=item ch'ing                                  ching                           #00a1c2

=item chinook                                 chinook                         #9e4732

=item chip                                    chip                            #8c8767

=item chip                                    chip                            #8a8776

=item chipmunk                                chipmunk                        #996515

=item chippendale                             chippendale                     #3e322c

=item chiswick                                chiswick                        #00304e

=item chocolate                               chocolate                       #3e322c

=item chocolate brown                         chocolatebrown                  #3e322c

=item chocolate maroon                        chocolatemaroon                 #722f37

=item chrome citron                           chromecitron                    #f8de7e

=item chrome green                            chromegreen                     #007959

=item chrome green                            chromegreen                     #3b7861

=item chrome lemon                            chromelemon                     #f8de7e

=item chrome orange                           chromeorange                    #e25822

=item chrome orange                           chromeorange                    #f38400

=item chrome primrose                         chromeprimrose                  #e9e450

=item chrome primrose                         chromeprimrose                  #eae679

=item chrome scarlet                          chromescarlet                   #d9603b

=item chromium green                          chromiumgreen                   #8a9a5b

=item chromium oxide                          chromiumoxide                   #679267

=item chrysanthemum                           chrysanthemum                   #841b2d

=item chrysanthemum                           chrysanthemum                   #722f37

=item chrysocollo                             chrysocollo                     #679267

=item chrysolite green                        chrysolitegreen                 #b9b459

=item chrysolite green                        chrysolitegreen                 #b9b57d

=item chrysolite green                        chrysolitegreen                 #8a9a5b

=item chrysopraise [green]                    chrysopraisegreen               #3eb489

=item chrysopraise [green]                    chrysopraisegreen               #6aab8e

=item chukker brown                           chukkerbrown                    #635147

=item chukker brown                           chukkerbrown                    #7e6d5a

=item chutney                                 chutney                         #79443b

=item cigarette                               cigarette                       #6f4e37

=item cinder [grey]                           cindergrey                      #8b8589

=item cineraria                               cineraria                       #ce4676

=item cinereous                               cinereous                       #b9b8b5

=item cinnamon                                cinnamon                        #a67b5b

=item cinnamon                                cinnamon                        #c19a6b

=item cinnamon brown                          cinnamonbrown                   #6f4e37

=item cinnamon brown                          cinnamonbrown                   #826644

=item cinnamon pink                           cinnamonpink                    #a87c6d

=item circassian                              circassian                      #6f4e37

=item citrine                                 citrine                         #867e36

=item citronelle                              citronelle                      #e9e450

=item citronelle                              citronelle                      #beb72e

=item citronelle                              citronelle                      #eae679

=item citronelle                              citronelle                      #b9b459

=item citron green                            citrongreen                     #b9b459

=item citron green                            citrongreen                     #b9b57d

=item citron [yellow]                         citronyellow                    #f8de7e

=item citrus                                  citrus                          #eae679

=item civette green                           civettegreen                    #355e3b

=item clair de lune                           clairdelune                     #8da399

=item claret cup                              claretcup                       #915f6d

=item claret lees                             claretlees                      #673147

=item claret [red]                            claretred                       #ab4e52

=item claver                                  claver                          #915c83

=item clay                                    clay                            #996515

=item clay                                    clay                            #c19a6b

=item clay                                    clay                            #826644

=item clay bank                               claybank                        #ae6938

=item clay drab                               claydrab                        #826644

=item clay drab                               claydrab                        #967117

=item clematis                                clematis                        #604e97

=item cleopatra                               cleopatra                       #00a1c2

=item clochette                               clochette                       #4e5180

=item clochette                               clochette                       #604e81

=item cloisonn                               cloisonn                        #00a1c2

=item cloisonn                               cloisonn                        #30267a

=item cloud                                   cloud                           #536878

=item cloud grey                              cloudgrey                       #8b8589

=item cloud grey                              cloudgrey                       #848482

=item cloudy amber                            cloudyamber                     #c2b280

=item cloudy amber                            cloudyamber                     #a18f60

=item clove                                   clove                           #6f4e37

=item clove brown                             clovebrown                      #5b504f

=item clove pink                              clovepink                       #722f37

=item clover                                  clover                          #915c83

=item cobalt blue                             cobaltblue                      #007791

=item cobalt glass                            cobaltglass                     #00416a

=item cobalt glass                            cobaltglass                     #436b95

=item cobalt green                            cobaltgreen                     #679267

=item cobalt red                              cobaltred                       #ce4676

=item cobalt red                              cobaltred                       #b3446c

=item cobalt ultramarine                      cobaltultramarine               #007791

=item cobalt violet                           cobaltviolet                    #86608e

=item cobalt yellow                           cobaltyellow                    #fada5e

=item cobalt yellow                           cobaltyellow                    #d4af37

=item cobblestone                             cobblestone                     #555555

=item cobweb                                  cobweb                          #ae9b82

=item coccineous                              coccineous                      #be0032

=item cocher                                  cocher                          #6c541e

=item cochin                                  cochin                          #6f4e37

=item cochineal                               cochineal                       #be0032

=item cockatoo                                cockatoo                        #f8de7e

=item cocoa                                   cocoa                           #6f4e37

=item cocoa brown                             cocoabrown                      #6f4e37

=item cocobala                                cocobala                        #905d5d

=item cocobala                                cocobala                        #674c47

=item coconut                                 coconut                         #635147

=item coconut brown                           coconutbrown                    #6f4e37

=item cod grey                                codgrey                         #5b5842

=item cod grey                                codgrey                         #57554c

=item coeruleum                               coeruleum                       #0085a1

=item coeruleum                               coeruleum                       #00a1c2

=item coffee                                  coffee                          #6f4e37

=item cognac                                  cognac                          #6f4e37

=item colcothar                               colcothar                       #79443b

=item colewort green                          colewortgreen                   #7d8984

=item colibri                                 colibri                         #317873

=item collie                                  collie                          #7e6d5a

=item cologne brown                           colognebrown                    #6f4e37

=item cologne earth                           cologneearth                    #6f4e37

=item cologne yellow                          cologneyellow                   #d4af37

=item colonial                                colonial                        #00416a

=item colonial                                colonial                        #00304e

=item colonial                                colonial                        #272458

=item colonial                                colonial                        #4e5180

=item colonial buff                           colonialbuff                    #f8de7e

=item colonial buff                           colonialbuff                    #f3e5ab

=item colonial yellow                         colonialyellow                  #c9ae5d

=item columbia                                columbia                        #0067a5

=item columbia blue                           columbiablue                    #91a3b0

=item columbian red                           columbianred                    #79443b

=item columbine blue                          columbineblue                   #4e5180

=item columbine blue                          columbineblue                   #604e81

=item columbine red                           columbinered                    #673147

=item comet                                   comet                           #00304e

=item commelina blue                          commelinablue                   #436b95

=item commodore                               commodore                       #30267a

=item como                                    como                            #367588

=item conch shell                             conchshell                      #f88379

=item concord                                 concord                         #2f2140

=item condor                                  condor                          #826644

=item confetti                                confetti                        #e4717a

=item confetti                                confetti                        #ab4e52

=item congo [brown]                           congobrown                      #483c32

=item congo pink                              congopink                       #b4745e

=item continental blue                        continentalblue                 #50404d

=item continental blue                        continentalblue                 #242124

=item cookie                                  cookie                          #6f4e37

=item coolie                                  coolie                          #4e5180

=item coolie                                  coolie                          #252440

=item copenhagen [blue]                       copenhagenblue                  #536878

=item copenhagen [blue]                       copenhagenblue                  #4c516d

=item copper                                  copper                          #b4745e

=item copper blue                             copperblue                      #436b95

=item copper brown                            copperbrown                     #80461b

=item copper green                            coppergreen                     #679267

=item copperleaf                              copperleaf                      #79443b

=item copper lustre                           copperlustre                    #80461b

=item copper red                              copperred                       #b4745e

=item copper rose                             copperrose                      #ab4e52

=item copper yellow                           copperyellow                    #c9ae5d

=item copra                                   copra                           #5c504f

=item coptic                                  coptic                          #79443b

=item coquelicot                              coquelicot                      #be0032

=item coquelicot                              coquelicot                      #e25822

=item coquette                                coquette                        #f88379

=item coquette                                coquette                        #d9a6a9

=item coralbell                               coralbell                       #ab4e52

=item coralbell                               coralbell                       #cb6d51

=item coral blush                             coralblush                      #f88379

=item coral blush                             coralblush                      #e66761

=item coral blush                             coralblush                      #cb6d51

=item coral pink                              coralpink                       #d9a6a9

=item coral [red]                             coralred                        #e4717a

=item coral sands                             coralsands                      #d9a6a9

=item coral sands                             coralsands                      #c7ada3

=item corcir                                  corcir                          #a8516e

=item cordova                                 cordova                         #79443b

=item cordovan                                cordovan                        #483c32

=item cordovan                                cordovan                        #222222

=item corial                                  corial                          #d9a6a9

=item corial                                  corial                          #a87c6d

=item corinth                                 corinth                         #915f6d

=item corinthian pink                         corinthianpink                  #dea5a4

=item corinthian pink                         corinthianpink                  #ad8884

=item corinthian purple                       corinthianpurple                #673147

=item corinthian purple                       corinthianpurple                #915f6d

=item corinthian red                          corinthianred                   #905d5d

=item cork                                    cork                            #a67b5b

=item cork                                    cork                            #a8516e

=item corker                                  corker                          #a8516e

=item corkur                                  corkur                          #a8516e

=item corn                                    corn                            #c9ae5d

=item cornelian red                           cornelianred                    #b4745e

=item cornflower [blue]                       cornflowerblue                  #4e5180

=item cornhusk                                cornhusk                        #fad6a5

=item cornhusk                                cornhusk                        #c19a6b

=item cornsilk                                cornsilk                        #f8de7e

=item coromandel                              coromandel                      #79443b

=item coronation                              coronation                      #5d3954

=item coronation                              coronation                      #673147

=item corsage green                           corsagegreen                    #6aab8e

=item corsage green                           corsagegreen                    #66ada4

=item corsair                                 corsair                         #00304e

=item corsican blue                           corsicanblue                    #4e5180

=item corsican blue                           corsicanblue                    #252440

=item corsican blue                           corsicanblue                    #2f2140

=item corydalis green                         corydalisgreen                  #8f9779

=item cosmos                                  cosmos                          #c17e91

=item cossack                                 cossack                         #5e716a

=item cossack green                           cossackgreen                    #355e3b

=item cosse green                             cossegreen                      #8a9a5b

=item cotch                                   cotch                           #6f4e37

=item cotinga purple                          cotingapurple                   #602f6b

=item cotinga purple                          cotingapurple                   #563c5c

=item cotinga purple                          cotingapurple                   #702963

=item cotinga purple                          cotingapurple                   #5d3954

=item cotrine                                 cotrine                         #be8a3d

=item cotrine                                 cotrine                         #c19a6b

=item courge green                            courgegreen                     #98943e

=item courge green                            courgegreen                     #867e36

=item courge green                            courgegreen                     #8a9a5b

=item cowboy                                  cowboy                          #6f4e37

=item cowboy                                  cowboy                          #635147

=item cowboy                                  cowboy                          #826644

=item cowboy                                  cowboy                          #7e6d5a

=item cowslip                                 cowslip                         #ed872d

=item cowslip                                 cowslip                         #d99058

=item crabapple                               crabapple                       #cb6d51

=item cracker                                 cracker                         #c19a6b

=item crag                                    crag                            #57554c

=item crane                                   crane                           #8b8589

=item crash                                   crash                           #c2b280

=item crash                                   crash                           #a18f60

=item crash                                   crash                           #967117

=item crash                                   crash                           #8c8767

=item crawshay red                            crawshayred                     #9e4732

=item crawshay red                            crawshayred                     #80461b

=item crayon blue                             crayonblue                      #536878

=item cream                                   cream                           #f3e5ab

=item cream beige                             creambeige                      #a87c6d

=item cream beige                             creambeige                      #a67b5b

=item cream beige                             creambeige                      #958070

=item cream buff                              creambuff                       #f3e5ab

=item cream buff                              creambuff                       #c2b280

=item creole                                  creole                          #ae6938

=item creole                                  creole                          #a67b5b

=item cress green                             cressgreen                      #8a9a5b

=item cresson                                 cresson                         #8a9a5b

=item crevette                                crevette                        #f88379

=item crimson lake                            crimsonlake                     #ab4e52

=item crimson madder                          crimsonmadder                   #be0032

=item crimson maple                           crimsonmaple                    #56070c

=item croceus                                 croceus                         #d99058

=item croceus                                 croceus                         #e3a857

=item crocreal                                crocreal                        #d99058

=item crocreal                                crocreal                        #e3a857

=item crocus                                  crocus                          #d99058

=item crocus                                  crocus                          #e3a857

=item crocus                                  crocus                          #aa8a9e

=item crocus                                  crocus                          #836479

=item crocus martis                           crocusmartis                    #79443b

=item crostil                                 crostil                         #a8516e

=item crotal                                  crotal                          #a8516e

=item crottle                                 crottle                         #a8516e

=item crowshay red                            crowshayred                     #9e4732

=item crowshay red                            crowshayred                     #80461b

=item cruiser                                 cruiser                         #555555

=item crushed berry                           crushedberry                    #905d5d

=item crushed strawberry                      crushedstrawberry               #e4717a

=item crushed violets                         crushedviolets                  #796878

=item crystal grey                            crystalgrey                     #8b8589

=item crystal palace blue                     crystalpalaceblue               #00304e

=item crystal palace green                    crystalpalacegreen              #57554c

=item crystals of venus                       crystalsofvenus                 #679267

=item cub                                     cub                             #57554c

=item cuba                                    cuba                            #722f37

=item cuba                                    cuba                            #79443b

=item cuban sand                              cubansand                       #ae9b82

=item cudbear                                 cudbear                         #a8516e

=item cuir                                    cuir                            #c19a6b

=item cuisse de nymphe                        cuissedenymphe                  #f3e5ab

=item cullen earth                            cullenearth                     #6f4e37

=item cupid pink                              cupidpink                       #d9a6a9

=item cupreous                                cupreous                        #f8de7e

=item curcuma                                 curcuma                         #f8de7e

=item currant [red]                           currantred                      #bc3f4a

=item cutch                                   cutch                           #6f4e37

=item cuyahoga red                            cuyahogared                     #722f37

=item cyan blue                               cyanblue                        #317873

=item cyan blue                               cyanblue                        #367588

=item cyanine blue                            cyanineblue                     #00a1c2

=item cyanine blue                            cyanineblue                     #4e5180

=item cyanine blue                            cyanineblue                     #252440

=item cyclamen                                cyclamen                        #341731

=item cygnet                                  cygnet                          #673147

=item cypress [green]                         cypressgreen                    #4a5d23

=item cypress green                           cypressgreen                    #44944a

=item cyprus earth                            cyprusearth                     #826644

=item cyprus earth                            cyprusearth                     #4b3621

=item cyprus umber                            cyprusumber                     #826644

=item cyprus umber                            cyprusumber                     #4b3621

=item daffodile [yellow]                      daffodileyellow                 #e3a857

=item daffodil yellow                         daffodilyellow                  #ed872d

=item daffodil yellow                         daffodilyellow                  #d99058

=item daffodil yellow                         daffodilyellow                  #eaa221

=item daffodil yellow                         daffodilyellow                  #e3a857

=item dagestan                                dagestan                        #00304e

=item dahlia                                  dahlia                          #86608e

=item dahlia carmine                          dahliacarmine                   #673147

=item dahlia mauve                            dahliamauve                     #915c83

=item dahlia purple                           dahliapurple                    #673147

=item dahlia purple                           dahliapurple                    #38152c

=item damascen                                damascen                        #604e81

=item damascen                                damascen                        #2f2140

=item damask                                  damask                          #905d5d

=item damonico                                damonico                        #f88379

=item damonico                                damonico                        #cb6d51

=item damonico                                damonico                        #ed872d

=item damonico                                damonico                        #d99058

=item damson                                  damson                          #604e81

=item damson                                  damson                          #2f2140

=item dana                                   dana                            #ed872d

=item dana                                   dana                            #d99058

=item dana                                   dana                            #536878

=item dandelion                               dandelion                       #fada5e

=item dante                                   dante                           #50404d

=item dante                                   dante                           #5d3954

=item dante                                   dante                           #673147

=item danube green                            danubegreen                     #355e3b

=item danube green                            danubegreen                     #3a4b47

=item daphne                                  daphne                          #436b95

=item daphne pink                             daphnepink                      #915f6d

=item daphne red                              daphnered                       #a8516e

=item daphne red                              daphnered                       #915f6d

=item dark beaver                             darkbeaver                      #6f4e37

=item dark beaver                             darkbeaver                      #635147

=item dark cardinal                           darkcardinal                    #722f37

=item dark gobelin blue                       darkgobelinblue                 #367588

=item dark gobelin blue                       darkgobelinblue                 #536878

=item dark wedgwood [blue]                    darkwedgwoodblue                #4e5180

=item dark wedgwood [blue]                    darkwedgwoodblue                #4c516d

=item date                                    date                            #483c32

=item datura                                  datura                          #86608e

=item dauphine                                dauphine                        #ad8884

=item davy's grey                             davysgrey                       #555555

=item dawn                                    dawn                            #dea5a4

=item dawn grey                               dawngrey                        #848482

=item daybreak                                daybreak                        #8c82b6

=item daybreak                                daybreak                        #b695c0

=item daytona                                 daytona                         #8e8279

=item dbutante pink                          dbutantepink                    #dea5a4

=item dead carnations                         deadcarnations                  #a8516e

=item dead leaf                               deadleaf                        #be6516

=item dead leaf                               deadleaf                        #ae6938

=item dead leaf                               deadleaf                        #80461b

=item deauville sand                          deauvillesand                   #977f73

=item deauville sand                          deauvillesand                   #958070

=item deep brunswick green                    deepbrunswickgreen              #1b4d3e

=item deep chrome green                       deepchromegreen                 #355e3b

=item deep chrome yellow                      deepchromeyellow                #e3a857

=item deep stone                              deepstone                       #ab9144

=item deep stone                              deepstone                       #a18f60

=item deep stone                              deepstone                       #967117

=item deer                                    deer                            #7e6d5a

=item delft blue                              delftblue                       #4c516d

=item della robbia                            dellarobbia                     #545aa7

=item del monte                               delmonte                        #796878

=item delphinium                              delphinium                      #4997d0

=item delphinium                              delphinium                      #0067a5

=item delphinium                              delphinium                      #70a3cc

=item de'medici                               demedici                        #673147

=item denmark                                 denmark                         #536878

=item denver                                  denver                          #848482

=item derby blue                              derbyblue                       #2f2140

=item desert                                  desert                          #c19a6b

=item devil's red                             devilsred                       #bc3f4a

=item devil's red                             devilsred                       #ab4e52

=item devon [brown]                           devonbrown                      #905d5d

=item dewey red                               deweyred                        #bc3f4a

=item dewey red                               deweyred                        #ab4e52

=item dewkiss                                 dewkiss                         #5e716a

=item diadem                                  diadem                          #aa98a9

=item diana                                   diana                           #70a3cc

=item dianthus                                dianthus                        #ab4e52

=item dianthus                                dianthus                        #905d5d

=item diavolo                                 diavolo                         #905d5d

=item digitalis                               digitalis                       #796878

=item di palito                               dipalito                        #e3a857

=item directoire blue                         directoireblue                  #00a1c2

=item directoire blue                         directoireblue                  #0067a5

=item distilled green                         distilledgreen                  #679267

=item diva blue                               divablue                        #0067a5

=item diva blue                               divablue                        #436b95

=item doe                                     doe                             #a67b5b

=item doe                                     doe                             #958070

=item doe                                     doe                             #c19a6b

=item doe                                     doe                             #ae9b82

=item doe-skin brown                          doeskinbrown                    #a87c6d

=item doge                                    doge                            #ab4e52

=item dogwood                                 dogwood                         #a67b5b

=item dogwood                                 dogwood                         #6f4e37

=item dogwood                                 dogwood                         #826644

=item dolly pink                              dollypink                       #ab4e52

=item domingo                                 domingo                         #79443b

=item domingo brown                           domingobrown                    #422518

=item dorado                                  dorado                          #c19a6b

=item doubloon                                doubloon                        #d99058

=item dove                                    dove                            #555555

=item dove                                    dove                            #673147

=item dove grey                               dovegrey                        #8b8589

=item dover grey                              dovergrey                       #555555

=item dozer                                   dozer                           #00304e

=item drab                                    drab                            #967117

=item drabolive                               drabolive                       #5b5842

=item dragonfly                               dragonfly                       #004958

=item dragon's blood                          dragonsblood                    #905d5d

=item dragon's blood                          dragonsblood                    #b4745e

=item dragon's blood                          dragonsblood                    #a87c6d

=item drake                                   drake                           #004958

=item drake's-neck green                      drakesneckgreen                 #004958

=item dregs of wine                           dregsofwine                     #722f37

=item dregs of wine                           dregsofwine                     #56070c

=item dregs of wine                           dregsofwine                     #3e1d1e

=item dresden blue                            dresdenblue                     #436b95

=item dresden brown                           dresdenbrown                    #826644

=item dresden brown                           dresdenbrown                    #967117

=item dresden brown                           dresdenbrown                    #6c541e

=item dryad                                   dryad                           #5e716a

=item dry rose                                dryrose                         #905d5d

=item dry rose                                dryrose                         #79443b

=item du barry                                dubarry                         #f88379

=item duck blue                               duckblue                        #007791

=item duck green                              duckgreen                       #004b49

=item duckling                                duckling                        #004958

=item duckling                                duckling                        #36454f

=item duck-wing                               duckwing                        #4c516d

=item du gueslin                              dugueslin                       #00304e

=item du gueslin                              dugueslin                       #252440

=item du gueslin                              dugueslin                       #4c516d

=item dumont's blue                           dumontsblue                     #00416a

=item dumont's blue                           dumontsblue                     #436b95

=item dune                                    dune                            #8c8767

=item durango                                 durango                         #6f4e37

=item dusk                                    dusk                            #5d555b

=item dust                                    dust                            #967117

=item dusty green                             dustygreen                      #8c8767

=item dutch azure                             dutchazure                      #00416a

=item dutch azure                             dutchazure                      #436b95

=item dutch blue                              dutchblue                       #536878

=item dutch orange                            dutchorange                     #eaa221

=item dutch orange                            dutchorange                     #e3a857

=item dutch pink                              dutchpink                       #fada5e

=item dutch pink                              dutchpink                       #d4af37

=item dutch pink                              dutchpink                       #f8de7e

=item dutch pink                              dutchpink                       #c9ae5d

=item dutch scarlet                           dutchscarlet                    #be0032

=item dutch vermilion                         dutchvermilion                  #e25822

=item dutch ware blue                         dutchwareblue                   #4c516d

=item dyer's broom                            dyersbroom                      #eae679

=item dyer's broom                            dyersbroom                      #b9b459

=item dyer's greenwood                        dyersgreenwood                  #eae679

=item dyer's greenwood                        dyersgreenwood                  #b9b459

=item dyer's saffron                          dyerssaffron                    #be0032

=item eagle                                   eagle                           #5b504f

=item eau-de-javel green                      eaudejavelgreen                 #b9b459

=item eau-de-nile                             eaudenile                       #8a9a5b

=item eau-de-nile                             eaudenile                       #dadfb7

=item eau-de-nile                             eaudenile                       #93c592

=item eburnean                                eburnean                        #f3e5ab

=item ecclesiastic                            ecclesiastic                    #870074

=item ecclesiastic                            ecclesiastic                    #9e4f88

=item ecru                                    ecru                            #f3e5ab

=item ecru                                    ecru                            #c2b280

=item eden green                              edengreen                       #44944a

=item eden green                              edengreen                       #679267

=item eggplant                                eggplant                        #291e29

=item eggplant                                eggplant                        #242124

=item eggshell blue                           eggshellblue                    #8da399

=item eggshell blue                           eggshellblue                    #66ada4

=item eggshell green                          eggshellgreen                   #8da399

=item eggshell green                          eggshellgreen                   #66ada4

=item eglantine                               eglantine                       #ce4676

=item egypt                                   egypt                           #0067a5

=item egyptian                                egyptian                        #905d5d

=item egyptian blue                           egyptianblue                    #00a1c2

=item egyptian blue                           egyptianblue                    #0067a5

=item egyptian brown                          egyptianbrown                   #483c32

=item egyptian green                          egyptiangreen                   #3b7861

=item egyptian red                            egyptianred                     #722f37

=item egyptian red                            egyptianred                     #882d17

=item eifel                                   eifel                           #905d5d

=item eifel                                   eifel                           #79443b

=item elderberry                              elderberry                      #2f2140

=item eldorado                                eldorado                        #ae6938

=item electric [blue]                         electricblue                    #536878

=item electric green                          electricgreen                   #536878

=item elephant green                          elephantgreen                   #173620

=item elephant skin                           elephantskin                    #5b504f

=item elf                                     elf                             #6aab8e

=item elf                                     elf                             #8da399

=item elfin green                             elfingreen                      #6aab8e

=item elk                                     elk                             #483c32

=item elm green                               elmgreen                        #4a5d23

=item elmwood                                 elmwood                         #ae9b82

=item elmwood                                 elmwood                         #967117

=item email                                   email                           #317873

=item email                                   email                           #367588

=item ember                                   ember                           #ab4e52

=item emberglow                               emberglow                       #ab4e52

=item emberglow                               emberglow                       #e66761

=item emberglow                               emberglow                       #cb6d51

=item emerald green                           emeraldgreen                    #679267

=item emerald green                           emeraldgreen                    #3eb489

=item emeraude                                emeraude                        #679267

=item emeraude                                emeraude                        #007959

=item emeraude                                emeraude                        #3b7861

=item eminence                                eminence                        #563c5c

=item emperor green                           emperorgreen                    #3eb489

=item empire                                  empire                          #007959

=item empire blue                             empireblue                      #436b95

=item empire green                            empiregreen                     #355e3b

=item empire green                            empiregreen                     #3a4b47

=item empire yellow                           empireyellow                    #fada5e

=item empire yellow                           empireyellow                    #f8de7e

=item enamel blue                             enamelblue                      #00416a

=item enamel blue                             enamelblue                      #436b95

=item endive                                  endive                          #e9e450

=item endive                                  endive                          #eae679

=item endive blue                             endiveblue                      #91a3b0

=item endive blue                             endiveblue                      #aa98a9

=item english blue                            englishblue                     #436b95

=item english green                           englishgreen                    #7e9f2e

=item english green                           englishgreen                    #44944a

=item english green                           englishgreen                    #1b4d3e

=item english grey                            englishgrey                     #57554c

=item english inde                            englishinde                     #50404d

=item english ivy                             englishivy                      #355e3b

=item english oak                             englishoak                      #6f4e37

=item english ochre                           englishochre                    #e3a857

=item english pink                            englishpink                     #fada5e

=item english pink                            englishpink                     #d4af37

=item english pink                            englishpink                     #f8de7e

=item english pink                            englishpink                     #c9ae5d

=item english red                             englishred                      #bc3f4a

=item english red                             englishred                      #ab4e52

=item english red                             englishred                      #d9603b

=item english red                             englishred                      #cb6d51

=item english red                             englishred                      #9e4732

=item english red                             englishred                      #80461b

=item english red                             englishred                      #79443b

=item english vermilion                       englishvermilion                #bc3f4a

=item english violet                          englishviolet                   #563c5c

=item ensign                                  ensign                          #00304e

=item epinauche                               epinauche                       #3a4b47

=item epsom                                   epsom                           #8a9a5b

=item erin                                    erin                            #3b7861

=item erlau green                             erlaugreen                      #679267

=item escadre                                 escadre                         #536878

=item eschel                                  eschel                          #00416a

=item eschel                                  eschel                          #436b95

=item eskimo                                  eskimo                          #79443b

=item esthetic grey                           estheticgrey                    #7d8984

=item etain blue                              etainblue                       #c7e6d7

=item etain blue                              etainblue                       #bcd4e6

=item etain blue                              etainblue                       #c7e6d7

=item etain blue                              etainblue                       #96ded1

=item etain blue                              etainblue                       #9cd1dc

=item etain blue                              etainblue                       #bcd4e6

=item etang                                   etang                           #8da399

=item etang                                   etang                           #b2beb5

=item ether                                   ether                           #66aabc

=item ethereal blue                           etherealblue                    #70a3cc

=item ethereal blue                           etherealblue                    #8791bf

=item eton blue                               etonblue                        #66ada4

=item etruscan                                etruscan                        #79443b

=item etruscan                                etruscan                        #6f4e37

=item etruscan red                            etruscanred                     #b4745e

=item eucalyptus [green]                      eucalyptusgreen                 #c2b280

=item eucalyptus [green]                      eucalyptusgreen                 #8f9779

=item eugenia red                             eugeniared                      #ab4e52

=item eugenie                                 eugenie                         #796878

=item eupatorium purple                       eupatoriumpurple                #915c83

=item eureka red                              eurekared                       #722f37

=item eve green                               evegreen                        #e9e450

=item eve green                               evegreen                        #83d37d

=item eve green                               evegreen                        #44944a

=item evenglow                                evenglow                        #8f817f

=item eventide                                eventide                        #9690ab

=item everglade                               everglade                       #222222

=item evergreen                               evergreen                       #355e3b

=item evque                                  evque                           #563c5c

=item faded rose                              fadedrose                       #905d5d

=item faience                                 faience                         #007791

=item faience                                 faience                         #367588

=item fairway                                 fairway                         #1a2421

=item fairy green                             fairygreen                      #679267

=item fakir                                   fakir                           #fad6a5

=item falcon                                  falcon                          #3e322c

=item fallow                                  fallow                          #c19a6b

=item fandango                                fandango                        #ce4676

=item faon                                    faon                            #977f73

=item faon                                    faon                            #6f4e37

=item faon                                    faon                            #958070

=item faon                                    faon                            #635147

=item fashion gray                            fashiongray                     #555555

=item fawn [brown]                            fawnbrown                       #977f73

=item fawn [brown]                            fawnbrown                       #6f4e37

=item fawn [brown]                            fawnbrown                       #958070

=item fawn [brown]                            fawnbrown                       #635147

=item feldspar                                feldspar                        #6aab8e

=item fern                                    fern                            #8a9a5b

=item fernambucowood                          fernambucowood                  #ab4e52

=item fernambucowood                          fernambucowood                  #905d5d

=item fern green                              ferngreen                       #8a9a5b

=item fern green                              ferngreen                       #8f9779

=item ferruginous                             ferruginous                     #9e4732

=item ferruginous                             ferruginous                     #80461b

=item feuille                                 feuille                         #6f4e37

=item feuille morte                           feuillemorte                    #be6516

=item feuille morte                           feuillemorte                    #ae6938

=item feuille morte                           feuillemorte                    #80461b

=item feulamort                               feulamort                       #be6516

=item feulamort                               feulamort                       #ae6938

=item feulamort                               feulamort                       #80461b

=item fez                                     fez                             #be0032

=item field's orange vermilion                fieldsorangevermilion           #d9603b

=item fiery red                               fieryred                        #e25822

=item fiesta                                  fiesta                          #e4717a

=item fieulamort                              fieulamort                      #be6516

=item fieulamort                              fieulamort                      #ae6938

=item fieulamort                              fieulamort                      #80461b

=item filbert [brown]                         filbertbrown                    #a67b5b

=item filbert [brown]                         filbertbrown                    #996515

=item filemot                                 filemot                         #be6516

=item filemot                                 filemot                         #ae6938

=item filemot                                 filemot                         #80461b

=item fillemot                                fillemot                        #be6516

=item fillemot                                fillemot                        #ae6938

=item fillemot                                fillemot                        #80461b

=item firecracker                             firecracker                     #e25822

=item firefly                                 firefly                         #bc3f4a

=item firefly                                 firefly                         #ab4e52

=item fire red                                firered                         #e25822

=item fire scarlet                            firescarlet                     #be0032

=item fireweed                                fireweed                        #602f6b

=item fir [green]                             firgreen                        #355e3b

=item fir [green]                             firgreen                        #173620

=item fir [green]                             firgreen                        #3a4b47

=item firmament                               firmament                       #536878

=item firmament blue                          firmamentblue                   #66aabc

=item fish grey                               fishgrey                        #5b5842

=item fish grey                               fishgrey                        #57554c

=item flag                                    flag                            #2f2140

=item flame blue                              flameblue                       #4e5180

=item flame blue                              flameblue                       #4c516d

=item flame orange                            flameorange                     #e25822

=item flame [scarlet]                         flamescarlet                    #e25822

=item flaming maple                           flamingmaple                    #be0032

=item flaming maple                           flamingmaple                    #bc3f4a

=item flaming maple                           flamingmaple                    #841b2d

=item flaming maple                           flamingmaple                    #ab4e52

=item flamingo                                flamingo                        #cb6d51

=item flammeous                               flammeous                       #d9603b

=item flash                                   flash                           #bc3f4a

=item flash                                   flash                           #ab4e52

=item flash                                   flash                           #aa381e

=item flash                                   flash                           #9e4732

=item flax                                    flax                            #c2b280

=item flaxen                                  flaxen                          #c2b280

=item flaxflower blossom                      flaxflowerblossom               #536878

=item flaxflower blue                         flaxflowerblue                  #436b95

=item flaxflower blue                         flaxflowerblue                  #8791bf

=item flea                                    flea                            #722f37

=item flemish blue                            flemishblue                     #36454f

=item flesh                                   flesh                           #fad6a5

=item flesh                                   flesh                           #bfb8a5

=item flesh blond                             fleshblond                      #d9a6a9

=item flesh blond                             fleshblond                      #c7ada3

=item flesh blond                             fleshblond                      #c2ac99

=item flesh ochre                             fleshochre                      #9e4732

=item fleur-de-lys                            fleurdelys                      #86608e

=item flint                                   flint                           #222222

=item flint grey                              flintgrey                       #848482

=item flirt                                   flirt                           #ab4e52

=item florence brown                          florencebrown                   #905d5d

=item florence earth                          florenceearth                   #79443b

=item florentine                              florentine                      #e25822

=item florentine lake                         florentinelake                  #be0032

=item florentine lake                         florentinelake                  #bc3f4a

=item florida gold                            floridagold                     #eaa221

=item florida gold                            floridagold                     #e3a857

=item floss flower blue                       flossflowerblue                 #aa98a9

=item flower de luce green                    flowerdelucegreen               #355e3b

=item fluorite green                          fluoritegreen                   #679267

=item fluorite violet                         fluoriteviolet                  #563c5c

=item fluorite violet                         fluoriteviolet                  #301934

=item fog                                     fog                             #b9b8b5

=item foliage brown                           foliagebrown                    #be6516

=item foliage brown                           foliagebrown                    #ae6938

=item foliage brown                           foliagebrown                    #80461b

=item foliage green                           foliagegreen                    #8a9a5b

=item folimort                                folimort                        #be6516

=item folimort                                folimort                        #ae6938

=item folimort                                folimort                        #80461b

=item folkstone                               folkstone                       #ae9b82

=item folly                                   folly                           #be0032

=item folly                                   folly                           #bc3f4a

=item fontainebleau                           fontainebleau                   #905d5d

=item forest                                  forest                          #3a4b47

=item forest green                            forestgreen                     #4a5d23

=item forest of dean red                      forestofdeanred                 #9e4732

=item forest of dean red                      forestofdeanred                 #80461b

=item forget-me-not [blue]                    forgetmenotblue                 #91a3b0

=item forget-me-not [blue]                    forgetmenotblue                 #536878

=item formosa                                 formosa                         #d99058

=item formosa                                 formosa                         #a67b5b

=item forsythia                               forsythia                       #e3a857

=item fox                                     fox                             #826644

=item fox                                     fox                             #967117

=item fox                                     fox                             #6c541e

=item foxglove                                foxglove                        #604e97

=item foxglove                                foxglove                        #604e81

=item fox trot                                foxtrot                         #66ada4

=item fragonard                               fragonard                       #ab4e52

=item france                                  france                          #00304e

=item france rose                             francerose                      #e4717a

=item france rose                             francerose                      #282022

=item freedom                                 freedom                         #00304e

=item freestone                               freestone                       #fad6a5

=item french beige                            frenchbeige                     #a67b5b

=item french berries                          frenchberries                   #eaa221

=item french berries                          frenchberries                   #e3a857

=item french blue                             frenchblue                      #0067a5

=item french blue                             frenchblue                      #545aa7

=item french green                            frenchgreen                     #679267

=item french green                            frenchgreen                     #3b7861

=item french grey                             frenchgrey                      #b2beb5

=item french grey                             frenchgrey                      #b9b8b5

=item french lilac                            frenchlilac                     #86608e

=item french lilac                            frenchlilac                     #796878

=item french maroon                           frenchmaroon                    #905d5d

=item french nude                             frenchnude                      #977f73

=item french nude                             frenchnude                      #a67b5b

=item french nude                             frenchnude                      #958070

=item french ochre                            frenchochre                     #e3a857

=item french pink                             frenchpink                      #fad6a5

=item french pink                             frenchpink                      #c9ae5d

=item french purple                           frenchpurple                    #a8516e

=item french scarlet                          frenchscarlet                   #be0032

=item french ultramarine                      frenchultramarine               #0067a5

=item french ultramarine                      frenchultramarine               #545aa7

=item french vermilion                        frenchvermilion                 #e25822

=item [french] veronese green                 frenchveronesegreen             #007959

=item [french] veronese green                 frenchveronesegreen             #3b7861

=item french white                            frenchwhite                     #bfb9bd

=item french white                            frenchwhite                     #e8ccd7

=item french yellow                           frenchyellow                    #ae6938

=item french yellow                           frenchyellow                    #996515

=item french yellow                           frenchyellow                    #a67b5b

=item friar                                   friar                           #635147

=item friar                                   friar                           #3e322c

=item frost grey                              frostgrey                       #848482

=item frosty green                            frostygreen                     #3a4b47

=item fuchsia                                 fuchsia                         #870074

=item fudge                                   fudge                           #6f4e37

=item fujiyama                                fujiyama                        #79443b

=item fuscous                                 fuscous                         #5b504f

=item fustet                                  fustet                          #fada5e

=item fustet                                  fustet                          #d4af37

=item fustic                                  fustic                          #c9ae5d

=item fustic                                  fustic                          #c2b280

=item gage green                              gagegreen                       #8f9779

=item gaiety                                  gaiety                          #e4717a

=item galleon                                 galleon                         #3e322c

=item gallstone                               gallstone                       #d4af37

=item gambia                                  gambia                          #6f4e37

=item gamboge                                 gamboge                         #d4af37

=item gardenia green                          gardeniagreen                   #3a4b47

=item gargoyle                                gargoyle                        #555555

=item garland green                           garlandgreen                    #4a5d23

=item garland green                           garlandgreen                    #355e3b

=item garnet                                  garnet                          #722f37

=item garnet brown                            garnetbrown                     #722f37

=item garnet brown                            garnetbrown                     #79443b

=item garnet red                              garnetred                       #841b2d

=item garnet red                              garnetred                       #722f37

=item garter blue                             garterblue                      #4c516d

=item gaude                                   gaude                           #eae679

=item gaude                                   gaude                           #b9b459

=item gaude lake                              gaudelake                       #f8de7e

=item gaudy green                             gaudygreen                      #8a9a5b

=item gaudy green                             gaudygreen                      #4a5d23

=item gay green                               gaygreen                        #8a9a5b

=item gazelle [brown]                         gazellebrown                    #635147

=item gazelle [brown]                         gazellebrown                    #7e6d5a

=item geisha                                  geisha                          #915c83

=item geisha                                  geisha                          #a8516e

=item geisha                                  geisha                          #915f6d

=item gendarme [blue]                         gendarmeblue                    #317873

=item gendarme [blue]                         gendarmeblue                    #367588

=item generall                                generall                        #fada5e

=item generall                                generall                        #d4af37

=item generall                                generall                        #f8de7e

=item generall                                generall                        #c9ae5d

=item genestrole                              genestrole                      #eae679

=item genestrole                              genestrole                      #b9b459

=item genet                                   genet                           #eae679

=item genet                                   genet                           #b9b459

=item geneva blue                             genevablue                      #4c516d

=item genista                                 genista                         #d99058

=item genoa blue                              genoablue                       #536878

=item gentian                                 gentian                         #436b95

=item gentian                                 gentian                         #8791bf

=item gentian blue                            gentianblue                     #4e5180

=item genuine ultramarine [blue]              genuineultramarineblue          #00a1c2

=item genuine ultramarine [blue]              genuineultramarineblue          #0067a5

=item geranium                                geranium                        #bc3f4a

=item geranium lake                           geraniumlake                    #be0032

=item geranium petal                          geraniumpetal                   #be0032

=item geranium pink                           geraniumpink                    #e4717a

=item ghent                                   ghent                           #00304e

=item giallolini                              giallolini                      #f8de7e

=item giallolini                              giallolini                      #c9ae5d

=item giallolini                              giallolini                      #f3e5ab

=item giallolini                              giallolini                      #c2b280

=item giallolino                              giallolino                      #f8de7e

=item giallolino                              giallolino                      #c9ae5d

=item giallolino                              giallolino                      #f3e5ab

=item giallolino                              giallolino                      #c2b280

=item gigas                                   gigas                           #86608e

=item gild                                    gild                            #eaa221

=item gild                                    gild                            #e3a857

=item gilded                                  gilded                          #eaa221

=item gilded                                  gilded                          #e3a857

=item gilt                                    gilt                            #eaa221

=item gilt                                    gilt                            #e3a857

=item gingeline                               gingeline                       #80461b

=item gingeoline                              gingeoline                      #80461b

=item ginger                                  ginger                          #80461b

=item gingerline                              gingerline                      #80461b

=item gingerspice                             gingerspice                     #79443b

=item gingioline                              gingioline                      #80461b

=item giraffe                                 giraffe                         #ae6938

=item giraffe                                 giraffe                         #a67b5b

=item glacier                                 glacier                         #36454f

=item glacier blue                            glacierblue                     #536878

=item gladiolus                               gladiolus                       #bc3f4a

=item glaeul                                 glaeul                          #ad8884

=item glaeul                                 glaeul                          #c48379

=item glass green                             glassgreen                      #c9dc89

=item glass grey                              glassgrey                       #b4bcc0

=item glaucous                                glaucous                        #dadfb7

=item glaucous-blue                           glaucousblue                    #536878

=item glaucous-green                          glaucousgreen                   #c7e6d7

=item glaucous-grey                           glaucousgrey                    #b4bcc0

=item glaucous-grey                           glaucousgrey                    #b9b8b5

=item glint o'gold                            glintogold                      #c9ae5d

=item gloaming                                gloaming                        #ad8884

=item glory                                   glory                           #272458

=item glory                                   glory                           #32174d

=item gloxinia                                gloxinia                        #602f6b

=item gmelin's blue                           gmelinsblue                     #0067a5

=item gmelin's blue                           gmelinsblue                     #545aa7

=item gnaphalium green                        gnaphaliumgreen                 #8da399

=item goat                                    goat                            #5b504f

=item gobelin blue                            gobelinblue                     #536878

=item gobelin blue                            gobelinblue                     #367588

=item gobelin blue                            gobelinblue                     #536878

=item gobelin green                           gobelingreen                    #3b7861

=item gobelin scarlet                         gobelinscarlet                  #be0032

=item gold                                    gold                            #967117

=item gold bronze                             goldbronze                      #635147

=item gold bronze                             goldbronze                      #7e6d5a

=item gold brown                              goldbrown                       #80461b

=item gold earth                              goldearth                       #e3a857

=item golden                                  golden                          #c19a6b

=item golden                                  golden                          #a18f60

=item golden                                  golden                          #967117

=item golden brown                            goldenbrown                     #80461b

=item golden chestnut                         goldenchestnut                  #6f4e37

=item golden coral                            goldencoral                     #f88379

=item golden corn                             goldencorn                      #e3a857

=item golden feather                          goldenfeather                   #fada5e

=item golden feather                          goldenfeather                   #d4af37

=item golden feather                          goldenfeather                   #f8de7e

=item golden feather                          goldenfeather                   #c9ae5d

=item golden glow                             goldenglow                      #e3a857

=item golden glow                             goldenglow                      #d4af37

=item golden green                            goldengreen                     #c2b280

=item golden green                            goldengreen                     #a18f60

=item golden ochre                            goldenochre                     #d99058

=item golden poppy                            goldenpoppy                     #e25822

=item golden rod                              goldenrod                       #d4af37

=item golden wheat                            goldenwheat                     #e3a857

=item golden yellow                           goldenyellow                    #eaa221

=item golden yellow                           goldenyellow                    #e3a857

=item golden yellow                           goldenyellow                    #be8a3d

=item golden yellow                           goldenyellow                    #996515

=item gold leaf                               goldleaf                        #d99058

=item gold leaf                               goldleaf                        #be8a3d

=item gold ochre                              goldochre                       #d99058

=item gold yellow                             goldyellow                      #eaa221

=item gold yellow                             goldyellow                      #e3a857

=item golf green                              golfgreen                       #355e3b

=item golf [red]                              golfred                         #bc3f4a

=item golf [red]                              golfred                         #ab4e52

=item gooseberry                              gooseberry                      #673147

=item gooseberry green                        gooseberrygreen                 #679267

=item goose grey                              goosegrey                       #483c32

=item gorevan                                 gorevan                         #6f4e37

=item goura                                   goura                           #50404d

=item goya                                    goya                            #bc3f4a

=item grain                                   grain                           #fad6a5

=item grain                                   grain                           #c19a6b

=item grain                                   grain                           #ae9b82

=item grain                                   grain                           #be0032

=item grain in grain                          grainingrain                    #be0032

=item granada                                 granada                         #43302e

=item granada                                 granada                         #3e322c

=item granat                                  granat                          #be0032

=item granat                                  granat                          #e25822

=item granatflower                            granatflower                    #be0032

=item granatflower                            granatflower                    #e25822

=item granite                                 granite                         #8b8589

=item granite blue                            graniteblue                     #b9b8b5

=item grape                                   grape                           #2f2140

=item grape blue                              grapeblue                       #2f2140

=item grapefruit                              grapefruit                      #b9b459

=item grape green                             grapegreen                      #867e36

=item grapejuice                              grapejuice                      #602f6b

=item grapenuts                               grapenuts                       #6f4e37

=item graphite                                graphite                        #50404d

=item graphite                                graphite                        #222222

=item grass green                             grassgreen                      #8a9a5b

=item grasshopper                             grasshopper                     #8a9a5b

=item gravel                                  gravel                          #ae9b82

=item grayn                                   grayn                           #be0032

=item grebe                                   grebe                           #5d555b

=item grebe                                   grebe                           #555555

=item grecian rose                            grecianrose                     #ad8884

=item grecian rose                            grecianrose                     #c48379

=item green ash                               greenash                        #93c592

=item green finch                             greenfinch                      #867e36

=item green slate                             greenslate                      #5e716a

=item green slate                             greenslate                      #4e5755

=item green stone                             greenstone                      #8f9779

=item grenadine red                           grenadinered                    #cb6d51

=item grenat                                  grenat                          #722f37

=item gretna green                            gretnagreen                     #679267

=item gretna green                            gretnagreen                     #3b7861

=item grey 31                                 grey31                          #5b504f

=item grey dawn                               greydawn                        #8b8589

=item grey dawn                               greydawn                        #848482

=item grey drab                               greydrab                        #8c8767

=item greyn                                   greyn                           #be0032

=item grey stone                              greystone                       #8a8776

=item grey ultramarine ash                    greyultramarineash              #b2beb5

=item gridelin                                gridelin                        #a8516e

=item griffin                                 griffin                         #555555

=item gris-de-lin                             grisdelin                       #a8516e

=item grotto [blue]                           grottoblue                      #007791

=item grouse                                  grouse                          #635147

=item grouse                                  grouse                          #7e6d5a

=item guignet's green                         guignetsgreen                   #004b49

=item guimet's blue                           guimetsblue                     #0067a5

=item guimet's blue                           guimetsblue                     #545aa7

=item guinea green                            guineagreen                     #007a74

=item guinea hen                              guineahen                       #555555

=item gull                                    gull                            #848482

=item gull grey                               gullgrey                        #8b8589

=item gunmetal                                gunmetal                        #555555

=item gypsy                                   gypsy                           #80461b

=item gypsy red                               gypsyred                        #ab4e52

=item haematite red                           haematitered                    #722f37

=item haematite red                           haematitered                    #905d5d

=item haematite red                           haematitered                    #543d3f

=item hair brown                              hairbrown                       #5b504f

=item hair brown                              hairbrown                       #555555

=item hamadan                                 hamadan                         #967117

=item hamburg lake                            hamburglake                     #be0032

=item hamburg lake                            hamburglake                     #bc3f4a

=item hampstead brown                         hampsteadbrown                  #674c47

=item hankow                                  hankow                          #00304e

=item hankow                                  hankow                          #252440

=item hankow                                  hankow                          #4c516d

=item harbor blue                             harborblue                      #51585e

=item harlem blue                             harlemblue                      #2e8495

=item harlem blue                             harlemblue                      #436b95

=item harlequin                               harlequin                       #44944a

=item harrison red                            harrisonred                     #be0032

=item harvard crimson                         harvardcrimson                  #ab4e52

=item harvest                                 harvest                         #ae6938

=item harvest                                 harvest                         #a67b5b

=item hathi gray                              hathigray                       #7d8984

=item hathor                                  hathor                          #00a1c2

=item hathor                                  hathor                          #0067a5

=item havana rose                             havanarose                      #905d5d

=item hay                                     hay                             #b9b57d

=item hazel                                   hazel                           #a67b5b

=item hazel                                   hazel                           #996515

=item hazelnut                                hazelnut                        #a67b5b

=item hazelnut                                hazelnut                        #996515

=item hazy blue                               hazyblue                        #93c592

=item hazy blue                               hazyblue                        #6aab8e

=item hazy blue                               hazyblue                        #8da399

=item heather                                 heather                         #915f6d

=item hebe                                    hebe                            #ab4e52

=item heliotrope                              heliotrope                      #5d3954

=item heliotrope grey                         heliotropegrey                  #aa98a9

=item heliotrope grey                         heliotropegrey                  #796878

=item heliotrope grey                         heliotropegrey                  #8b8589

=item hellebore green                         helleboregreen                  #4a5d23

=item hellebore green                         helleboregreen                  #8a9a5b

=item hellebore green                         helleboregreen                  #8f9779

=item hellebore green                         helleboregreen                  #4a5d23

=item hellebore green                         helleboregreen                  #515744

=item hellebore red                           helleborered                    #a8516e

=item helvetia blue                           helvetiablue                    #00416a

=item hemlock                                 hemlock                         #1a2421

=item hemp                                    hemp                            #8c8767

=item henna                                   henna                           #882d17

=item hepatica                                hepatica                        #86608e

=item hermosa pink                            hermosapink                     #ea9399

=item hermosa pink                            hermosapink                     #dea5a4

=item heron                                   heron                           #536878

=item hibernian green                         hiberniangreen                  #355e3b

=item highland green                          highlandgreen                   #1e2321

=item hindu                                   hindu                           #3e322c

=item hispano                                 hispano                         #80461b

=item hockey                                  hockey                          #be0032

=item holland blue                            hollandblue                     #00304e

=item holly berry                             hollyberry                      #bc3f4a

=item holly berry                             hollyberry                      #ab4e52

=item holly green                             hollygreen                      #4a5d23

=item holly green                             hollygreen                      #00622d

=item holly green                             hollygreen                      #355e3b

=item hollyhock                               hollyhock                       #78184a

=item hollywood                               hollywood                       #841b2d

=item hollywood                               hollywood                       #ab4e52

=item homage blue                             homageblue                      #252440

=item honey beige                             honeybeige                      #c19a6b

=item honey bird                              honeybird                       #239eba

=item honeydew                                honeydew                        #f88379

=item honeydew                                honeydew                        #d99058

=item honeysuckle                             honeysuckle                     #c19a6b

=item honeysweet                              honeysweet                      #c9ae5d

=item honeysweet                              honeysweet                      #c2b280

=item honey [yellow]                          honeyyellow                     #a18f60

=item hopi                                    hopi                            #a67b5b

=item horace vernet's blue                    horacevernetsblue               #30267a

=item horizon [blue]                          horizonblue                     #dfede8

=item horsechestnut                           horsechestnut                   #3e322c

=item hortense violet                         hortenseviolet                  #86608e

=item hortensia                               hortensia                       #563c5c

=item hortensia                               hortensia                       #301934

=item hortensia                               hortensia                       #50404d

=item hortensia                               hortensia                       #291e29

=item huckleberry                             huckleberry                     #2f2140

=item hudson seal                             hudsonseal                      #555555

=item hudson seal                             hudsonseal                      #222222

=item hummingbird                             hummingbird                     #317873

=item hungarian blue                          hungarianblue                   #436b95

=item hungarian green                         hungariangreen                  #679267

=item hunter [green]                          huntergreen                     #173620

=item hunter's green                          huntersgreen                    #173620

=item huron                                   huron                           #317873

=item hussar                                  hussar                          #536878

=item hyacinth                                hyacinth                        #8c82b6

=item hyacinth                                hyacinth                        #86608e

=item hyacinth blue                           hyacinthblue                    #272458

=item hyacinth red                            hyacinthred                     #b4745e

=item hyacinth violet                         hyacinthviolet                  #602f6b

=item hydrangea blue                          hydrangeablue                   #536878

=item hydrangea blue                          hydrangeablue                   #8c92ac

=item hydrangea pink                          hydrangeapink                   #dea5a4

=item hydrangea red                           hydrangeared                    #905d5d

=item hydro                                   hydro                           #536878

=item hypermic red                            hypermicred                     #be0032

=item hyssop violet                           hyssopviolet                    #796878

=item ibis pink                               ibispink                        #f88379

=item ibis pink                               ibispink                        #d9a6a9

=item ibis red                                ibisred                         #43302e

=item iceberg                                 iceberg                         #536878

=item immenssee                               immenssee                       #5e716a

=item imperial                                imperial                        #602f6b

=item imperial                                imperial                        #563c5c

=item imperial                                imperial                        #702963

=item imperial                                imperial                        #5d3954

=item imperial blue                           imperialblue                    #00416a

=item imperial green                          imperialgreen                   #679267

=item imperial green                          imperialgreen                   #3eb489

=item imperial jade                           imperialjade                    #355e3b

=item imperial purple                         imperialpurple                  #554c69

=item imperial stone                          imperialstone                   #967117

=item imperial yellow                         imperialyellow                  #e3a857

=item inca gold                               incagold                        #e3a857

=item indebaudias                             indebaudias                     #50404d

=item inde blue                               indeblue                        #50404d

=item independence                            independence                    #2f2140

=item india ink                               indiaink                        #555555

=item indian                                  indian                          #ae6938

=item indiana                                 indiana                         #ce4676

=item indian blue                             indianblue                      #50404d

=item indian brown                            indianbrown                     #483c32

=item indian brown                            indianbrown                     #6c541e

=item indian brown                            indianbrown                     #3b3121

=item indian buff                             indianbuff                      #c19a6b

=item indian lake                             indianlake                      #a8516e

=item indian orange                           indianorange                    #e25822

=item indian pink                             indianpink                      #a87c6d

=item indian purple                           indianpurple                    #673147

=item indian red                              indianred                       #79443b

=item indian red                              indianred                       #882d17

=item indian saffron                          indiansaffron                   #f8de7e

=item indian tan                              indiantan                       #996515

=item indian tan                              indiantan                       #c19a6b

=item indian tan                              indiantan                       #826644

=item indian turquoise                        indianturquoise                 #317873

=item indian yellow                           indianyellow                    #eaa221

=item indian yellow                           indianyellow                    #e3a857

=item india red                               indiared                        #56070c

=item india spice                             indiaspice                      #a67b5b

=item india tan                               indiatan                        #6f4e37

=item indico                                  indico                          #50404d

=item indico carmine                          indicocarmine                   #007791

=item indigo                                  indigo                          #50404d

=item indigo carmine                          indigocarmine                   #007791

=item indigo extract                          indigoextract                   #007791

=item indo                                    indo                            #536878

=item infanta                                 infanta                         #436b95

=item infantry                                infantry                        #536878

=item infernal blue                           infernalblue                    #252440

=item ingenue                                 ingenue                         #dadfb7

=item ingenue                                 ingenue                         #8f9779

=item ink black                               inkblack                        #51585e

=item ink blue                                inkblue                         #36454f

=item intense blue                            intenseblue                     #4e5180

=item intense blue                            intenseblue                     #252440

=item international                           international                   #536878

=item invisible green                         invisiblegreen                  #004b49

=item invisible green                         invisiblegreen                  #1a2421

=item ionian blue                             ionianblue                      #36454f

=item ionian blue                             ionianblue                      #202830

=item iris                                    iris                            #91a3b0

=item iris                                    iris                            #aa98a9

=item irisglow                                irisglow                        #8b8589

=item iris green                              irisgreen                       #355e3b

=item iris green                              irisgreen                       #679267

=item iris mauve                              irismauve                       #ecd5c5

=item iris mauve                              irismauve                       #c7ada3

=item iris mauve                              irismauve                       #c2ac99

=item iron                                    iron                            #483c32

=item iron                                    iron                            #222222

=item iron blue                               ironblue                        #555555

=item iron brown                              ironbrown                       #483c32

=item iron brown                              ironbrown                       #222222

=item iron buff                               ironbuff                        #c19a6b

=item iron buff                               ironbuff                        #c2b280

=item iron crocus                             ironcrocus                      #79443b

=item iron grey                               irongrey                        #555555

=item iron minium                             ironminium                      #905d5d

=item iron minium                             ironminium                      #674c47

=item iron oxide red                          ironoxidered                    #882d17

=item iron oxide red                          ironoxidered                    #80461b

=item iron red                                ironred                         #882d17

=item iron saffron                            ironsaffron                     #79443b

=item iron yellow                             ironyellow                      #ed872d

=item iron yellow                             ironyellow                      #d99058

=item isabella                                isabella                        #c19a6b

=item isabella                                isabella                        #826644

=item isabella                                isabella                        #a18f60

=item isabella                                isabella                        #967117

=item ispahan                                 ispahan                         #36454f

=item italian blue                            italianblue                     #0085a1

=item italian blue                            italianblue                     #007791

=item italian lake                            italianlake                     #e3a857

=item italian ochre                           italianochre                    #ae6938

=item italian ochre                           italianochre                    #a67b5b

=item italian pink                            italianpink                     #fada5e

=item italian pink                            italianpink                     #d4af37

=item italian pink                            italianpink                     #f8de7e

=item italian pink                            italianpink                     #c9ae5d

=item italian straw                           italianstraw                    #f3e5ab

=item italian straw                           italianstraw                    #c2b280

=item ivory brown                             ivorybrown                      #6c541e

=item ivory brown                             ivorybrown                      #3b3121

=item ivory white                             ivorywhite                      #f3e5ab

=item ivory [yellow]                          ivoryyellow                     #f3e5ab

=item ivy [green]                             ivygreen                        #665d1e

=item ivy [green]                             ivygreen                        #5b5842

=item jacaranda brown                         jacarandabrown                  #483c32

=item jacinthe                                jacinthe                        #d99058

=item jack rabbit                             jackrabbit                      #555555

=item jack rose                               jackrose                        #be0032

=item jacqueminot                             jacqueminot                     #ab4e52

=item jadesheen                               jadesheen                       #679267

=item jadesheen                               jadesheen                       #355e3b

=item jadesheen                               jadesheen                       #5e716a

=item jaffa orange                            jaffaorange                     #cb6d51

=item jaffa orange                            jaffaorange                     #d99058

=item jaffi                                   jaffi                           #57554c

=item jalapa                                  jalapa                          #80461b

=item japan blue                              japanblue                       #00304e

=item japan earth                             japanearth                      #6f4e37

=item japanese blue                           japaneseblue                    #5e716a

=item japanese green                          japanesegreen                   #5e716a

=item japanese red                            japanesered                     #882d17

=item japanese yellow                         japaneseyellow                  #ffb7a5

=item japanese yellow                         japaneseyellow                  #d9603b

=item japan rose                              japanrose                       #d9a6a9

=item japan rose                              japanrose                       #d99058

=item japonica                                japonica                        #905d5d

=item jasmine                                 jasmine                         #fada5e

=item jasmine                                 jasmine                         #f8de7e

=item jasper                                  jasper                          #1a2421

=item jasper green                            jaspergreen                     #3b7861

=item jasper pink                             jasperpink                      #f88379

=item jasper red                              jasperred                       #ab4e52

=item java                                    java                            #422518

=item java brown                              javabrown                       #3e322c

=item javel green                             javelgreen                      #b9b459

=item jay [blue]                              jayblue                         #436b95

=item jean bart                               jeanbart                        #2f2140

=item jew's pitch                             jewspitch                       #483c32

=item jockey                                  jockey                          #ab4e52

=item jonquil [yellow]                        jonquilyellow                   #fbc97f

=item jonquil [yellow]                        jonquilyellow                   #e3a857

=item jonquil [yellow]                        jonquilyellow                   #fad6a5

=item jonquil [yellow]                        jonquilyellow                   #f8de7e

=item jonquil [yellow]                        jonquilyellow                   #c9ae5d

=item josephine                               josephine                       #a67b5b

=item jouvence blue                           jouvenceblue                    #317873

=item jouvence blue                           jouvenceblue                    #367588

=item judee                                   judee                           #796878

=item jungle green                            junglegreen                     #1c352d

=item jungle green                            junglegreen                     #1a2421

=item juniper                                 juniper                         #3a4b47

=item kabistan                                kabistan                        #3a4b47

=item kaffa                                   kaffa                           #674c47

=item kaiser brown                            kaiserbrown                     #80461b

=item kangaroo                                kangaroo                        #57554c

=item kara                                    kara                            #317873

=item kara dagh                               karadagh                        #222222

=item kasha-beige                             kashabeige                      #8a8776

=item kasha-beige                             kashabeige                      #848482

=item kashan                                  kashan                          #007791

=item kashmir                                 kashmir                         #355e3b

=item kashmir                                 kashmir                         #3b7861

=item kashmir                                 kashmir                         #5e716a

=item kazak                                   kazak                           #79443b

=item kentucky green                          kentuckygreen                   #665d1e

=item kermanshah                              kermanshah                      #635147

=item kermes                                  kermes                          #be0032

=item kermes berries                          kermesberries                   #be0032

=item kesseler yellow                         kesseleryellow                  #fada5e

=item kesseler yellow                         kesseleryellow                  #d4af37

=item kesseler yellow                         kesseleryellow                  #f8de7e

=item kesseler yellow                         kesseleryellow                  #c9ae5d

=item kettledrum                              kettledrum                      #79443b

=item khaki                                   khaki                           #c19a6b

=item khaki                                   khaki                           #826644

=item khiva                                   khiva                           #9e4732

=item kildare green                           kildaregreen                    #8a9a5b

=item killarney [green]                       killarneygreen                  #679267

=item killarney [green]                       killarneygreen                  #3b7861

=item kinema red                              kinemared                       #bc3f4a

=item kingfisher                              kingfisher                      #00304e

=item king's blue                             kingsblue                       #70a3cc

=item king's blue                             kingsblue                       #00416a

=item king's blue                             kingsblue                       #436b95

=item king's blue                             kingsblue                       #436b95

=item king's yellow                           kingsyellow                     #fada5e

=item king's yellow                           kingsyellow                     #d4af37

=item king's yellow                           kingsyellow                     #f8de7e

=item king's yellow                           kingsyellow                     #c9ae5d

=item kirchberger green                       kirchbergergreen                #3eb489

=item kis kilim                               kiskilim                        #6f4e37

=item kobe                                    kobe                            #882d17

=item kolinsky                                kolinsky                        #422518

=item korea                                   korea                           #9e4732

=item korea                                   korea                           #79443b

=item kork                                    kork                            #a8516e

=item korkir                                  korkir                          #a8516e

=item kremlin                                 kremlin                         #004b49

=item kronberg's green                        kronbergsgreen                  #4a5d23

=item kurdistan                               kurdistan                       #36454f

=item kurdistan                               kurdistan                       #202428

=item kurdistan                               kurdistan                       #50404d

=item kurdistan                               kurdistan                       #242124

=item kyoto                                   kyoto                           #f88379

=item kyoto                                   kyoto                           #ed872d

=item kyoto                                   kyoto                           #d99058

=item labrador                                labrador                        #00304e

=item labrador                                labrador                        #36454f

=item lac lake                                laclake                         #a8516e

=item lacquer red                             lacquerred                      #9e4732

=item laelia pink                             laeliapink                      #c17e91

=item laelia pink                             laeliapink                      #af868e

=item la france pink                          lafrancepink                    #dea5a4

=item lagoon                                  lagoon                          #66ada4

=item lake                                    lake                            #be0032

=item lake                                    lake                            #bc3f4a

=item lake blue                               lakeblue                        #317873

=item lama                                    lama                            #483c32

=item lambert's blue                          lambertsblue                    #436b95

=item lapis                                   lapis                           #317873

=item lariat                                  lariat                          #a67b5b

=item lariat                                  lariat                          #c19a6b

=item lark                                    lark                            #c2b280

=item lark                                    lark                            #a18f60

=item lark                                    lark                            #967117

=item larkspur                                larkspur                        #367588

=item latericeous                             latericeous                     #80461b

=item latericeous                             latericeous                     #6f4e37

=item lateritious                             lateritious                     #80461b

=item lateritious                             lateritious                     #6f4e37

=item latoun                                  latoun                          #c9ae5d

=item latten                                  latten                          #c9ae5d

=item laundry blue                            laundryblue                     #00416a

=item laundry blue                            laundryblue                     #436b95

=item laurel green                            laurelgreen                     #867e36

=item laurel oak                              laureloak                       #79443b

=item laurel pink                             laurelpink                      #e4717a

=item laurel pink                             laurelpink                      #ab4e52

=item lava                                    lava                            #222222

=item la vallire                             lavallire                       #796878

=item lavender                                lavender                        #aa98a9

=item lawn green                              lawngreen                       #8a9a5b

=item lead                                    lead                            #5d555b

=item lead                                    lead                            #555555

=item lead grey                               leadgrey                        #8c8767

=item lead ochre                              leadochre                       #f3e5ab

=item leadville                               leadville                       #5d555b

=item leaf mold                               leafmold                        #422518

=item leaf red                                leafred                         #be0032

=item leather                                 leather                         #ae6938

=item leather brown                           leatherbrown                    #6f4e37

=item leather lake                            leatherlake                     #be6516

=item leather lake                            leatherlake                     #ae6938

=item leather lake                            leatherlake                     #80461b

=item leek green                              leekgreen                       #867e36

=item leek green                              leekgreen                       #8a9a5b

=item leghorn                                 leghorn                         #f3e5ab

=item leghorn                                 leghorn                         #c2b280

=item legion blue                             legionblue                      #00304e

=item leitch's blue                           leitchsblue                     #00a1c2

=item leithner's blue                         leithnersblue                   #007791

=item lemmian earth                           lemmianearth                    #79443b

=item lemnian ruddle                          lemnianruddle                   #79443b

=item lemnos                                  lemnos                          #79443b

=item lemon chrome                            lemonchrome                     #fada5e

=item lemon yellow                            lemonyellow                     #fada5e

=item lemon yellow                            lemonyellow                     #d4af37

=item lemon yellow                            lemonyellow                     #f8de7e

=item lemon yellow                            lemonyellow                     #c9ae5d

=item lettuce green                           lettucegreen                    #8a9a5b

=item levant red                              levantred                       #ab4e52

=item leyden blue                             leydenblue                      #007791

=item liberia                                 liberia                         #3e322c

=item liberty                                 liberty                         #0067a5

=item liberty                                 liberty                         #545aa7

=item liberty blue                            libertyblue                     #4e5180

=item liberty green                           libertygreen                    #8a9a5b

=item lichen                                  lichen                          #515744

=item lichen green                            lichengreen                     #b2beb5

=item lido                                    lido                            #967117

=item lierre                                  lierre                          #665d1e

=item lierre                                  lierre                          #5b5842

=item light blue 1                            lightblue1                      #dadfb7

=item light blue 2, light blue 3              lightblue2lightblue3            #c7e6d7

=item light blue 2, light blue 3              lightblue2lightblue3            #bcd4e6

=item light blue 4                            lightblue4                      #bcd4e6

=item light blue 6                            lightblue6                      #91a3b0

=item light blue,, light blue 5               lightbluelightblue5             #c7e6d7

=item light brunswick green                   lightbrunswickgreen             #355e3b

=item light chrome green                      lightchromegreen                #355e3b

=item light chrome yellow                     lightchromeyellow               #d4af37

=item light grge                             lightgrge                       #8a8776

=item light gunmetal                          lightgunmetal                   #555555

=item light red                               lightred                        #cb6d51

=item light stone                             lightstone                      #c2b280

=item light stone                             lightstone                      #a18f60

=item light wedgwood [blue]                   lightwedgwoodblue               #536878

=item lilac                                   lilac                           #dea5a4

=item lilac                                   lilac                           #ad8884

=item lilac                                   lilac                           #aa98a9

=item lilaceous                               lilaceous                       #dea5a4

=item lilaceous                               lilaceous                       #ad8884

=item lilac gray                              lilacgray                       #c2ac99

=item lilac gray                              lilacgray                       #bfb8a5

=item lilas                                   lilas                           #dea5a4

=item lilas                                   lilas                           #ad8884

=item lilium                                  lilium                          #86608e

=item lilium                                  lilium                          #915c83

=item lily green                              lilygreen                       #8a9a5b

=item lily green                              lilygreen                       #4e5755

=item limawood                                limawood                        #ab4e52

=item limawood                                limawood                        #905d5d

=item lime blue                               limeblue                        #436b95

=item lime green                              limegreen                       #b9b57d

=item lime green                              limegreen                       #867e36

=item limestone                               limestone                       #5b504f

=item limestone                               limestone                       #555555

=item lime [yellow]                           limeyellow                      #c9ae5d

=item lime [yellow]                           limeyellow                      #c2b280

=item limoges                                 limoges                         #0067a5

=item limoges                                 limoges                         #436b95

=item lincoln green                           lincolngreen                    #4a5d23

=item lincoln red                             lincolnred                      #be0032

=item linden green                            lindengreen                     #b9b459

=item linden yellow                           lindenyellow                    #b9b459

=item linoleum brown                          linoleumbrown                   #826644

=item lint                                    lint                            #8c8767

=item lint-white                              lintwhite                       #f3e5ab

=item lint-white                              lintwhite                       #c2b280

=item lion                                    lion                            #c19a6b

=item lion                                    lion                            #826644

=item lion tawny                              liontawny                       #c19a6b

=item lion tawny                              liontawny                       #826644

=item liqueur green                           liqueurgreen                    #eae679

=item liqueur green                           liqueurgreen                    #b9b459

=item liseran purple                          liseranpurple                   #9e4f88

=item litho purple                            lithopurple                     #86608e

=item litho purple                            lithopurple                     #563c5c

=item litho purple                            lithopurple                     #796878

=item liver                                   liver                           #674c47

=item liver brown                             liverbrown                      #674c47

=item liver maroon                            livermaroon                     #674c47

=item livid                                   livid                           #5d555b

=item livid                                   livid                           #555555

=item livid brown                             lividbrown                      #905d5d

=item livid pink                              lividpink                       #c4aead

=item livid purple                            lividpurple                     #836479

=item livid violet                            lividviolet                     #ad8884

=item lizard bronze                           lizardbronze                    #867e36

=item lizard [green]                          lizardgreen                     #3b7861

=item loam                                    loam                            #5b504f

=item lobelia [blue]                          lobeliablue                     #604e97

=item lobelia violet                          lobeliaviolet                   #796878

=item lobster                                 lobster                         #aa381e

=item lobster                                 lobster                         #9e4732

=item locarno green                           locarnogreen                    #3b7861

=item loganberry                              loganberry                      #563c5c

=item log cabin                               logcabin                        #5b504f

=item logwood                                 logwood                         #291e29

=item logwood                                 logwood                         #242124

=item logwood blue                            logwoodblue                     #51585e

=item lo-kao                                  lokao                           #93c592

=item lo-kao                                  lokao                           #6aab8e

=item london brown                            londonbrown                     #43302e

=item london smoke                            londonsmoke                     #222222

=item long beach                              longbeach                       #c19a6b

=item longchamps                              longchamps                      #a67b5b

=item longchamps                              longchamps                      #958070

=item lotus                                   lotus                           #c08081

=item lotus                                   lotus                           #ad8884

=item lotus                                   lotus                           #c48379

=item louis philippe                          louisphilippe                   #8791bf

=item loutre                                  loutre                          #6c541e

=item loutre                                  loutre                          #3b3121

=item louvain                                 louvain                         #536878

=item louvain                                 louvain                         #51585e

=item love bird                               lovebird                        #7e9f2e

=item love-in-a-mist                          loveinamist                     #66aabc

=item lucerne blue                            lucerneblue                     #8791bf

=item luciole                                 luciole                         #81878b

=item lucky stone                             luckystone                      #91a3b0

=item lumiere blue                            lumiereblue                     #66ada4

=item lumiere green                           lumieregreen                    #c9dc89

=item lupine                                  lupine                          #70a3cc

=item lupine                                  lupine                          #8791bf

=item luteous                                 luteous                         #eae679

=item luteous                                 luteous                         #b9b459

=item luxor                                   luxor                           #545aa7

=item lyons blue                              lyonsblue                       #0067a5

=item macaroon                                macaroon                        #c19a6b

=item madder                                  madder                          #bc3f4a

=item madder                                  madder                          #ab4e52

=item madder                                  madder                          #d9603b

=item madder                                  madder                          #cb6d51

=item madder blue                             madderblue                      #9690ab

=item madder blue                             madderblue                      #554c69

=item madder brown                            madderbrown                     #79443b

=item madder carmine                          maddercarmine                   #ab4e52

=item madder carmine                          maddercarmine                   #a8516e

=item madder indian red                       madderindianred                 #79443b

=item madder lake                             madderlake                      #bc3f4a

=item madder lake                             madderlake                      #b3446c

=item madder pink                             madderpink                      #b3446c

=item madder red                              madderred                       #bc3f4a

=item madder red                              madderred                       #ab4e52

=item madder red                              madderred                       #d9603b

=item madder red                              madderred                       #cb6d51

=item madder violet                           madderviolet                    #563c5c

=item madeline blue                           madelineblue                    #4c516d

=item madonna                                 madonna                         #436b95

=item madonna                                 madonna                         #536878

=item madrid                                  madrid                          #635147

=item madrid                                  madrid                          #7e6d5a

=item madura                                  madura                          #826644

=item magenta                                 magenta                         #78184a

=item magenta rose                            magentarose                     #78184a

=item magnolia                                magnolia                        #c08081

=item magnolia                                magnolia                        #905d5d

=item magnolia                                magnolia                        #c48379

=item mahogany                                mahogany                        #79443b

=item mahogany brown                          mahoganybrown                   #79443b

=item mahogany red                            mahoganyred                     #79443b

=item maiden's blush                          maidensblush                    #a87c6d

=item maintenon                               maintenon                       #cb6d51

=item maise                                   maise                           #e3a857

=item maise                                   maise                           #fad6a5

=item maise                                   maise                           #c9ae5d

=item majolica                                majolica                        #00304e

=item majolica blue                           majolicablue                    #00304e

=item majolica blue                           majolicablue                    #252440

=item majolica blue                           majolicablue                    #4c516d

=item majolica earth                          majolicaearth                   #882d17

=item malabar                                 malabar                         #6f4e37

=item malacca                                 malacca                         #c19a6b

=item malacca                                 malacca                         #c2b280

=item malachite green                         malachitegreen                  #679267

=item malaga                                  malaga                          #722f37

=item malaga                                  malaga                          #56070c

=item malay                                   malay                           #6f4e37

=item mallard                                 mallard                         #004958

=item mallow pink                             mallowpink                      #d597ae

=item mallow purple                           mallowpurple                    #a8516e

=item mallow red                              mallowred                       #a8516e

=item malmaison                               malmaison                       #f8de7e

=item malmaison                               malmaison                       #c9ae5d

=item malmaison rose                          malmaisonrose                   #ce4676

=item malmaison rose                          malmaisonrose                   #b3446c

=item manchu                                  manchu                          #6f4e37

=item mandalay                                mandalay                        #635147

=item mandalay                                mandalay                        #3e322c

=item mandarin orange                         mandarinorange                  #ed872d

=item mandarin red                            mandarinred                     #d9603b

=item manganese brown                         manganesebrown                  #6f4e37

=item manganese velvet brown                  manganesevelvetbrown            #826644

=item manganese velvet brown                  manganesevelvetbrown            #4b3621

=item manganese violet                        manganeseviolet                 #875692

=item mango                                   mango                           #ae6938

=item mango                                   mango                           #a67b5b

=item manila                                  manila                          #c19a6b

=item manon                                   manon                           #958070

=item manzanita                               manzanita                       #79443b

=item maple                                   maple                           #c2b280

=item maple sugar                             maplesugar                      #826644

=item maracaibo                               maracaibo                       #422518

=item marathon                                marathon                        #ed872d

=item marble green                            marblegreen                     #1e2321

=item marguerite yellow                       margueriteyellow                #dadfb7

=item marie antoinette                        marieantoinette                 #ad8884

=item marie antoinette                        marieantoinette                 #905d5d

=item marine [blue]                           marineblue                      #00304e

=item marine [blue]                           marineblue                      #4e5180

=item marine [blue]                           marineblue                      #252440

=item marine corps                            marinecorps                     #4c516d

=item marine green                            marinegreen                     #1b4d3e

=item marine green                            marinegreen                     #3a4b47

=item maris                                   maris                           #3a4b47

=item maris                                   maris                           #004b49

=item marmora                                 marmora                         #317873

=item marocain                                marocain                        #635147

=item marone                                  marone                          #635147

=item maroon                                  maroon                          #722f37

=item maroon                                  maroon                          #56070c

=item maroon                                  maroon                          #3e1d1e

=item marron                                  marron                          #635147

=item marrone                                 marrone                         #635147

=item marron glac                            marronglac                      #6f4e37

=item marsala                                 marsala                         #79443b

=item mars brown                              marsbrown                       #6f4e37

=item marsh rose                              marshrose                       #905d5d

=item mars orange                             marsorange                      #cb6d51

=item mars red                                marsred                         #9e4732

=item mars violet                             marsviolet                      #56070c

=item mars yellow                             marsyellow                      #ed872d

=item mars yellow                             marsyellow                      #d99058

=item martinique                              martinique                      #ae6938

=item martinique                              martinique                      #a67b5b

=item martius yellow                          martiusyellow                   #eae679

=item marygold                                marygold                        #ed872d

=item mascara                                 mascara                         #79443b

=item mascot                                  mascot                          #36454f

=item mascot                                  mascot                          #202830

=item mascot                                  mascot                          #252440

=item mascot                                  mascot                          #4c516d

=item massicot [yellow]                       massicotyellow                  #f3e5ab

=item mast colour                             mastcolour                      #ae6938

=item mastic                                  mastic                          #967117

=item matelot                                 matelot                         #00416a

=item matrix                                  matrix                          #317873

=item mauve blush                             mauveblush                      #c2ac99

=item mauve blush                             mauveblush                      #ae9b82

=item mauve blush                             mauveblush                      #bfb8a5

=item mauve castor                            mauvecastor                     #5c504f

=item mauve dust                              mauvedust                       #5c504f

=item mauveglow                               mauveglow                       #ad8884

=item mauverose                               mauverose                       #722f37

=item mauve taupe                             mauvetaupe                      #5c504f

=item mauvette                                mauvette                        #aa98a9

=item mauvewood                               mauvewood                       #79443b

=item mauvewood                               mauvewood                       #674c47

=item mavis                                   mavis                           #ae9b82

=item maya                                    maya                            #ae6938

=item maya                                    maya                            #a67b5b

=item mayfair tan                             mayfairtan                      #a67b5b

=item mayfair tan                             mayfairtan                      #c19a6b

=item mayfair tan                             mayfairtan                      #826644

=item mayflower                               mayflower                       #ab4e52

=item mazarine blue                           mazarineblue                    #272458

=item meadowbrook                             meadowbrook                     #3a4b47

=item meadowbrook                             meadowbrook                     #004b49

=item meadowgrass                             meadowgrass                     #355e3b

=item meadowgrass                             meadowgrass                     #3a4b47

=item meadow [green]                          meadowgreen                     #355e3b

=item meadowlark                              meadowlark                      #7e6d5a

=item meadowpink                              meadowpink                      #a8516e

=item meadowpink                              meadowpink                      #915f6d

=item meadowsweet                             meadowsweet                     #905d5d

=item meadow violet                           meadowviolet                    #875692

=item meadow violet                           meadowviolet                    #9e4f88

=item mecca                                   mecca                           #79443b

=item mecca                                   mecca                           #6f4e37

=item medal bronze                            medalbronze                     #826644

=item medal bronze                            medalbronze                     #967117

=item medici blue                             mediciblue                      #81878b

=item mediterranian                           mediterranian                   #317873

=item medium chrome green                     mediumchromegreen               #355e3b

=item medium chrome green                     mediumchromegreen               #1b4d3e

=item meerschaum                              meerschaum                      #ae9b82

=item mehal                                   mehal                           #6f4e37

=item melilot                                 melilot                         #915c83

=item meline                                  meline                          #c9ae5d

=item mello-mauve                             mellomauve                      #ad8884

=item mellowglow                              mellowglow                      #e3a857

=item melon                                   melon                           #f88379

=item mephisto                                mephisto                        #ab4e52

=item merida                                  merida                          #a67b5b

=item merida                                  merida                          #c19a6b

=item merida                                  merida                          #826644

=item merle                                   merle                           #004958

=item mermaid                                 mermaid                         #8f9779

=item mesa                                    mesa                            #6f4e37

=item metal                                   metal                           #b9b8b5

=item metal brown                             metalbrown                      #79443b

=item metal brown                             metalbrown                      #674c47

=item metallic green                          metallicgreen                   #665d1e

=item metallic grey                           metallicgrey                    #8b8589

=item mexican                                 mexican                         #ae6938

=item mexican                                 mexican                         #996515

=item mexican red                             mexicanred                      #ae6938

=item mexican red                             mexicanred                      #a67b5b

=item mexico                                  mexico                          #79443b

=item mexico                                  mexico                          #80461b

=item miami sand                              miamisand                       #ae9b82

=item miami sand                              miamisand                       #967117

=item michigan                                michigan                        #004b49

=item microcline green                        microclinegreen                 #c7e6d7

=item middle brunswick green                  middlebrunswickgreen            #355e3b

=item middle stone                            middlestone                     #a18f60

=item middy                                   middy                           #00304e

=item midnight                                midnight                        #50404d

=item midnight sun                            midnightsun                     #d9603b

=item mignon                                  mignon                          #86608e

=item mignonette [green]                      mignonettegreen                 #867e36

=item mignon green                            mignongreen                     #8a9a5b

=item mikado                                  mikado                          #d9603b

=item mikado                                  mikado                          #ed872d

=item mikado brown                            mikadobrown                     #6f4e37

=item mikado orange                           mikadoorange                    #d99058

=item milano blue                             milanoblue                      #536878

=item milk white                              milkwhite                       #f0ead6

=item milwaukee brick                         milwaukeebrick                  #fad6a5

=item milwaukee brick                         milwaukeebrick                  #f3e5ab

=item mimosa                                  mimosa                          #f8de7e

=item mindoro                                 mindoro                         #a67b5b

=item mineral bister                          mineralbister                   #6f4e37

=item mineral blue                            mineralblue                     #436b95

=item mineral blue                            mineralblue                     #2e8495

=item mineral blue                            mineralblue                     #436b95

=item mineral green                           mineralgreen                    #679267

=item mineral grey                            mineralgrey                     #b2beb5

=item mineral orange                          mineralorange                   #e25822

=item mineral pitch                           mineralpitch                    #483c32

=item mineral purple                          mineralpurple                   #56070c

=item mineral red                             mineralred                      #905d5d

=item mineral rouge                           mineralrouge                    #882d17

=item mineral rouge                           mineralrouge                    #80461b

=item mineral violet                          mineralviolet                   #875692

=item mineral yellow                          mineralyellow                   #fada5e

=item mineral yellow                          mineralyellow                   #d4af37

=item mineral yellow                          mineralyellow                   #f8de7e

=item mineral yellow                          mineralyellow                   #c9ae5d

=item mineral yellow                          mineralyellow                   #e3a857

=item ming green                              minggreen                       #007959

=item miniature pink                          miniaturepink                   #ecd5c5

=item miniature pink                          miniaturepink                   #c7ada3

=item minium                                  minium                          #e25822

=item mint                                    mint                            #1b4d3e

=item mint                                    mint                            #004b49

=item minuet                                  minuet                          #8c82b6

=item mirabelle                               mirabelle                       #d99058

=item mirabelle                               mirabelle                       #e3a857

=item mirador                                 mirador                         #422518

=item mirage                                  mirage                          #c19a6b

=item mist blue                               mistblue                        #93c592

=item mist blue                               mistblue                        #6aab8e

=item mist blue                               mistblue                        #8da399

=item mist [grey]                             mistgrey                        #8f817f

=item mistletoe                               mistletoe                       #8f9779

=item misty blue                              mistyblue                       #93c592

=item misty blue                              mistyblue                       #6aab8e

=item misty blue                              mistyblue                       #8da399

=item misty morn                              mistymorn                       #977f73

=item misty morn                              mistymorn                       #958070

=item mitis green                             mitisgreen                      #3eb489

=item mittler's green                         mittlersgreen                   #004b49

=item moccasin                                moccasin                        #6f4e37

=item mocha                                   mocha                           #3b3121

=item mocha bisque                            mochabisque                     #6f4e37

=item mode beige                              modebeige                       #967117

=item mohawk                                  mohawk                          #79443b

=item mohawk                                  mohawk                          #6f4e37

=item monaco                                  monaco                          #317873

=item monet blue                              monetblue                       #272458

=item monet blue                              monetblue                       #4e5180

=item monicon                                 monicon                         #f88379

=item monicon                                 monicon                         #cb6d51

=item monicon                                 monicon                         #ed872d

=item monicon                                 monicon                         #d99058

=item monkey skin                             monkeyskin                      #a87c6d

=item monkshood                               monkshood                       #554c69

=item monsignor                               monsignor                       #875692

=item monsignor                               monsignor                       #602f6b

=item monsoreau                               monsoreau                       #ab4e52

=item monte carlo                             montecarlo                      #007a74

=item monte carlo                             montecarlo                      #317873

=item montella                                montella                        #3e322c

=item montella                                montella                        #483c32

=item monterey                                monterey                        #9e4732

=item monticello green                        monticellogreen                 #355e3b

=item montpellier green                       montpelliergreen                #679267

=item montpellier yellow                      montpellieryellow               #fada5e

=item montpellier yellow                      montpellieryellow               #d4af37

=item montpellier yellow                      montpellieryellow               #f8de7e

=item montpellier yellow                      montpellieryellow               #c9ae5d

=item moonbeam                                moonbeam                        #b9b8b5

=item moonlight                               moonlight                       #fad6a5

=item moonlight                               moonlight                       #bfb8a5

=item moonlight blue                          moonlightblue                   #536878

=item moonmist                                moonmist                        #bfb8a5

=item moorish red                             moorishred                      #ed872d

=item moose                                   moose                           #363527

=item mordor                                 mordor                          #79443b

=item mordor                                 mordor                          #6f4e37

=item morea berries                           moreaberries                    #eaa221

=item morea berries                           moreaberries                    #e3a857

=item morello                                 morello                         #242124

=item moresco                                 moresco                         #ed872d

=item moresco                                 moresco                         #d99058

=item morillon                                morillon                        #8a9a5b

=item morning blue                            morningblue                     #8da399

=item morning blue                            morningblue                     #b2beb5

=item morning dawning yellow                  morningdawningyellow            #f88379

=item morning dawning yellow                  morningdawningyellow            #e66761

=item morning dawning yellow                  morningdawningyellow            #cb6d51

=item morning glory                           morningglory                    #aa8a9e

=item moroccan                                moroccan                        #722f37

=item moroccan                                moroccan                        #9e4732

=item morocco                                 morocco                         #3e322c

=item morocco red                             moroccored                      #722f37

=item morocco red                             moroccored                      #882d17

=item morocco red                             moroccored                      #79443b

=item morocco sand                            moroccosand                     #c19a6b

=item moro red                                morored                         #79443b

=item morro                                   morro                           #43302e

=item morro                                   morro                           #3e322c

=item mort d'ore                              mortdore                        #79443b

=item mort d'ore                              mortdore                        #6f4e37

=item mosaic blue                             mosaicblue                      #436b95

=item mosque                                  mosque                          #80461b

=item moss [green]                            mossgreen                       #867e36

=item moss [green]                            mossgreen                       #8a9a5b

=item moss grey                               mossgrey                        #8c8767

=item moss pink                               mosspink                        #915f6d

=item moss rose                               mossrose                        #e4717a

=item moss rose                               mossrose                        #c08081

=item mosul                                   mosul                           #a67b5b

=item mosul                                   mosul                           #6f4e37

=item mosul                                   mosul                           #826644

=item moth [grey]                             mothgrey                        #c2b280

=item motmot blue                             motmotblue                      #007791

=item motmot green                            motmotgreen                     #679267

=item motmot green                            motmotgreen                     #6aab8e

=item mountain blue                           mountainblue                    #436b95

=item mountain green                          mountaingreen                   #3a4b47

=item mountain green                          mountaingreen                   #679267

=item mountain yellow                         mountainyellow                  #e3a857

=item mount vernon green or mt. vernon green  mountvernongreenormtvernongreen #4a5d23

=item mouse-dun                               mousedun                        #5b504f

=item mouse [grey]                            mousegrey                       #5b504f

=item mousse                                  mousse                          #867e36

=item mousse                                  mousse                          #8a9a5b

=item msange                                 msange                          #8da399

=item mtallique                              mtallique                       #57554c

=item muffin                                  muffin                          #a67b5b

=item muffin                                  muffin                          #996515

=item mulberry                                mulberry                        #242124

=item mulberry fruit                          mulberryfruit                   #3f1728

=item mulberry fruit                          mulberryfruit                   #2e1d21

=item mulberry purple                         mulberrypurple                  #563c5c

=item mummy                                   mummy                           #483c32

=item mummy                                   mummy                           #826644

=item mummy brown                             mummybrown                      #6f4e37

=item mummy brown                             mummybrown                      #635147

=item mummy brown                             mummybrown                      #7e6d5a

=item muraille                                muraille                        #6f4e37

=item murillo                                 murillo                         #436b95

=item murinus                                 murinus                         #5b504f

=item murrey                                  murrey                          #242124

=item muscade                                 muscade                         #a67b5b

=item muscovite                               muscovite                       #4e5755

=item mushroom                                mushroom                        #5b504f

=item musk                                    musk                            #483c32

=item musketeer                               musketeer                       #00304e

=item musketeer                               musketeer                       #252440

=item musketeer                               musketeer                       #4c516d

=item muskmelon                               muskmelon                       #b4745e

=item muskmelon                               muskmelon                       #d99058

=item muskrat                                 muskrat                         #3e322c

=item mustang                                 mustang                         #7e6d5a

=item mustard brown                           mustardbrown                    #6f4e37

=item mustard [yellow]                        mustardyellow                   #c9ae5d

=item mutrie yellow                           mutrieyellow                    #dcd300

=item mutrie yellow                           mutrieyellow                    #e9e450

=item myosotis blue                           myosotisblue                    #91a3b0

=item myosotis blue                           myosotisblue                    #536878

=item myrtle [green]                          myrtlegreen                     #3a4b47

=item myrtle [green]                          myrtlegreen                     #004b49

=item mytho green                             mythogreen                      #8a9a5b

=item mytho green                             mythogreen                      #8f9779

=item nacarat                                 nacarat                         #be0032

=item nacarine                                nacarine                        #be0032

=item naiad                                   naiad                           #6aab8e

=item nankeen [yellow]                        nankeenyellow                   #f8de7e

=item nankeen [yellow]                        nankeenyellow                   #c9ae5d

=item nankeen [yellow]                        nankeenyellow                   #f3e5ab

=item nankeen [yellow]                        nankeenyellow                   #c2b280

=item naples red                              naplesred                       #79443b

=item naples red                              naplesred                       #882d17

=item naples yellow                           naplesyellow                    #f8de7e

=item naples yellow                           naplesyellow                    #c9ae5d

=item naples yellow                           naplesyellow                    #f3e5ab

=item naples yellow                           naplesyellow                    #c2b280

=item napoleon blue                           napoleonblue                    #00416a

=item napoli                                  napoli                          #004958

=item narcissus                               narcissus                       #d4af37

=item narcissus                               narcissus                       #c9ae5d

=item narrawood                               narrawood                       #ab4e52

=item narva                                   narva                           #3a4b47

=item nasturtium [red]                        nasturtiumred                   #9e4732

=item nasturtium [yellow]                     nasturtiumyellow                #ed872d

=item nasturtium [yellow]                     nasturtiumyellow                #d99058

=item nasturtium [yellow]                     nasturtiumyellow                #eaa221

=item nasturtium [yellow]                     nasturtiumyellow                #e3a857

=item natal brown                             natalbrown                      #635147

=item national [blue]                         nationalblue                    #00416a

=item national [blue]                         nationalblue                    #436b95

=item national grey                           nationalgrey                    #848482

=item nattier                                 nattier                         #8791bf

=item natural                                 natural                         #fad6a5

=item natural                                 natural                         #bfb8a5

=item navaho                                  navaho                          #f38400

=item navaho                                  navaho                          #ed872d

=item navy 1                                  navy1                           #36454f

=item navy 2                                  navy2                           #291e29

=item navy 3                                  navy3                           #36454f

=item navy 3                                  navy3                           #202830

=item navy blue                               navyblue                        #252440

=item navy blue                               navyblue                        #4c516d

=item neapolitan blue                         neapolitanblue                  #4c516d

=item neapolitan yellow                       neapolitanyellow                #f8de7e

=item neapolitan yellow                       neapolitanyellow                #c9ae5d

=item neapolitan yellow                       neapolitanyellow                #f3e5ab

=item neapolitan yellow                       neapolitanyellow                #c2b280

=item nectar                                  nectar                          #905d5d

=item nectarine                               nectarine                       #f4c2c2

=item nectarine                               nectarine                       #d9a6a9

=item negro                                   negro                           #483c32

=item negro                                   negro                           #222222

=item neptune [green]                         neptunegreen                    #6aab8e

=item neptune [green]                         neptunegreen                    #3b7861

=item neutral orange                          neutralorange                   #be6516

=item neutral red                             neutralred                      #722f37

=item neutral red                             neutralred                      #673147

=item neutral tint                            neutraltint                     #222222

=item neuvider green                          neuvidergreen                   #93c592

=item neuvider green                          neuvidergreen                   #6aab8e

=item neuwied blue                            neuwiedblue                     #317873

=item neuwieder blue                          neuwiederblue                   #317873

=item neuwieder green                         neuwiedergreen                  #93c592

=item neuwieder green                         neuwiedergreen                  #6aab8e

=item neva green                              nevagreen                       #7e9f2e

=item neva green                              nevagreen                       #83d37d

=item new blue                                newblue                         #0067a5

=item new blue                                newblue                         #545aa7

=item new bronze                              newbronze                       #6f4e37

=item new bronze                              newbronze                       #635147

=item new bronze                              newbronze                       #826644

=item new bronze                              newbronze                       #7e6d5a

=item new cocoa                               newcocoa                        #635147

=item new hay                                 newhay                          #515744

=item newport                                 newport                         #004958

=item new silver                              newsilver                       #f3e5ab

=item new silver                              newsilver                       #c2b280

=item new silver                              newsilver                       #bfb8a5

=item new silver                              newsilver                       #dadfb7

=item new silver                              newsilver                       #848482

=item niagara                                 niagara                         #66aabc

=item niagara green                           niagaragreen                    #66ada4

=item nicaraguawood                           nicaraguawood                   #ab4e52

=item nicaraguawood                           nicaraguawood                   #905d5d

=item nice                                    nice                            #536878

=item nightshade                              nightshade                      #2f2140

=item nightshade                              nightshade                      #50404d

=item nikko                                   nikko                           #436b95

=item nikko                                   nikko                           #536878

=item nile blue                               nileblue                        #66ada4

=item nile [green]                            nilegreen                       #8a9a5b

=item nile [green]                            nilegreen                       #8f9779

=item nile [green]                            nilegreen                       #93c592

=item nimbus                                  nimbus                          #848482

=item nippon                                  nippon                          #00304e

=item noisette                                noisette                        #a67b5b

=item noisette                                noisette                        #996515

=item nomad brown                             nomadbrown                      #422518

=item norfolk                                 norfolk                         #3e322c

=item normandy                                normandy                        #00304e

=item normandy                                normandy                        #252440

=item normandy                                normandy                        #4c516d

=item normandy blue                           normandyblue                    #8da399

=item nougat                                  nougat                          #958070

=item nougat                                  nougat                          #ae9b82

=item nubian                                  nubian                          #222222

=item nude                                    nude                            #c2ac99

=item nude                                    nude                            #fad6a5

=item nude                                    nude                            #c19a6b

=item nude                                    nude                            #ae9b82

=item nugget                                  nugget                          #d99058

=item nugget                                  nugget                          #be8a3d

=item nuncio                                  nuncio                          #86608e

=item nuremberg red                           nurembergred                    #79443b

=item nuremberg violet                        nurembergviolet                 #875692

=item nutmeg                                  nutmeg                          #6f4e37

=item nutmeg                                  nutmeg                          #635147

=item nutria                                  nutria                          #57554c

=item nymphea                                 nymphea                         #86608e

=item nymph green                             nymphgreen                      #ebe8a4

=item nymph green                             nymphgreen                      #c9dc89

=item nymph [pink]                            nymphpink                       #ea9399

=item nymph [pink]                            nymphpink                       #dea5a4

=item oad                                     oad                             #536878

=item oak [brown]                             oakbrown                        #80461b

=item oak [brown]                             oakbrown                        #6f4e37

=item oakbuff                                 oakbuff                         #a67b5b

=item oakbuff                                 oakbuff                         #c19a6b

=item oakbuff                                 oakbuff                         #826644

=item oak [green]                             oakgreen                        #867e36

=item oakheart                                oakheart                        #905d5d

=item oakheart                                oakheart                        #79443b

=item oakleaf brown                           oakleafbrown                    #be6516

=item oakleaf brown                           oakleafbrown                    #ae6938

=item oakleaf brown                           oakleafbrown                    #80461b

=item oakwood                                 oakwood                         #6f4e37

=item oasis                                   oasis                           #867e36

=item oasis                                   oasis                           #8a9a5b

=item ocean green                             oceangreen                      #93c592

=item ocher red                               ocherred                        #905d5d

=item ochraceous                              ochraceous                      #e3a857

=item ochre                                   ochre                           #e3a857

=item ochre de ru                             ochrederu                       #ae6938

=item ochre de ru                             ochrederu                       #996515

=item ochre red                               ochrered                        #9e4732

=item oil blue                                oilblue                         #30267a

=item oil green                               oilgreen                        #679267

=item oil yellow                              oilyellow                       #b9b459

=item oil yellow                              oilyellow                       #98943e

=item oker de luce                            okerdeluce                      #ae6938

=item oker de luce                            okerdeluce                      #996515

=item oker de luke                            okerdeluke                      #ae6938

=item oker de luke                            okerdeluke                      #996515

=item oker de rouse                           okerderouse                     #ae6938

=item oker de rouse                           okerderouse                     #996515

=item old amethyst                            oldamethyst                     #722f37

=item old amethyst                            oldamethyst                     #673147

=item old blue                                oldblue                         #91a3b0

=item old blue                                oldblue                         #536878

=item old blue                                oldblue                         #81878b

=item old bronze                              oldbronze                       #967117

=item old bronze                              oldbronze                       #867e36

=item old burgundy                            oldburgundy                     #3e1d1e

=item old burgundy                            oldburgundy                     #43302e

=item old cedar                               oldcedar                        #79443b

=item old china                               oldchina                        #536878

=item old china                               oldchina                        #4c516d

=item old coral                               oldcoral                        #ab4e52

=item olde                                    olde                            #eae679

=item olde                                    olde                            #b9b459

=item old english brown                       oldenglishbrown                 #483c32

=item old english brown                       oldenglishbrown                 #6c541e

=item old english brown                       oldenglishbrown                 #3b3121

=item old gold                                oldgold                         #867e36

=item old helio                               oldhelio                        #563c5c

=item old ivory                               oldivory                        #c2b280

=item old ivory                               oldivory                        #a18f60

=item old ivory                               oldivory                        #967117

=item old lavender                            oldlavender                     #242124

=item old lilac                               oldlilac                        #796878

=item old lilac                               oldlilac                        #836479

=item old mauve                               oldmauve                        #50404d

=item old mauve                               oldmauve                        #673147

=item old moss [green]                        oldmossgreen                    #867e36

=item old olive                               oldolive                        #6c541e

=item old pink                                oldpink                         #a67b5b

=item old red                                 oldred                          #841b2d

=item old red                                 oldred                          #ab4e52

=item old rose                                oldrose                         #905d5d

=item old roseleaf                            oldroseleaf                     #722f37

=item old silver                              oldsilver                       #848482

=item old wood                                oldwood                         #905d5d

=item olivaceous                              olivaceous                      #665d1e

=item olive brown                             olivebrown                      #6c541e

=item olive drab                              olivedrab                       #5b5842

=item olive [green]                           olivegreen                      #665d1e

=item olive grey                              olivegrey                       #8f9779

=item olive grey                              olivegrey                       #7d8984

=item olivesheen                              olivesheen                      #a18f60

=item olive terra verte                       oliveterraverte                 #867e36

=item olive wood                              olivewood                       #7e6d5a

=item olive yellow                            oliveyellow                     #98943e

=item olive yellow                            oliveyellow                     #867e36

=item olivine                                 olivine                         #93c592

=item olympia                                 olympia                         #007a74

=item olympia                                 olympia                         #317873

=item olympian blue                           olympianblue                    #00416a

=item olympian green                          olympiangreen                   #679267

=item olympic                                 olympic                         #36454f

=item olympic blue                            olympicblue                     #007791

=item ondine                                  ondine                          #8da399

=item onion-peel                              onionpeel                       #905d5d

=item onion red                               onionred                        #905d5d

=item onion-skin pink                         onionskinpink                   #d9a6a9

=item onion-skin pink                         onionskinpink                   #d99058

=item onion-skin pink                         onionskinpink                   #a67b5b

=item ontario violet                          ontarioviolet                   #8c92ac

=item oold                                    oold                            #eae679

=item oold                                    oold                            #b9b459

=item opal                                    opal                            #317873

=item opal blue                               opalblue                        #536878

=item opal grey                               opalgrey                        #8f817f

=item opal grey                               opalgrey                        #848482

=item opaline green                           opalinegreen                    #8ed1b2

=item opal mauve                              opalmauve                       #c1b6b3

=item opaq                                    opaq                            #679267

=item opera mauve                             operamauve                      #b784a7

=item opera pink                              operapink                       #f4c2c2

=item opera pink                              operapink                       #d9a6a9

=item opera pink                              operapink                       #ecd5c5

=item opera pink                              operapink                       #c7ada3

=item ophelia                                 ophelia                         #915c83

=item ophelia                                 ophelia                         #915f6d

=item ophelia                                 ophelia                         #836479

=item oporto                                  oporto                          #722f37

=item oporto                                  oporto                          #3f1728

=item orange aurora                           orangeaurora                    #f88379

=item orange aurora                           orangeaurora                    #e66761

=item orange aurora                           orangeaurora                    #cb6d51

=item orange lead                             orangelead                      #e25822

=item orange madder                           orangemadder                    #ed872d

=item orange ochre                            orangeochre                     #ed872d

=item orange-peel                             orangepeel                      #ed872d

=item orange rufous                           orangerufous                    #ed872d

=item orange tawny                            orangetawny                     #cb6d51

=item orange vermilion                        orangevermilion                 #d9603b

=item orchadee                                orchadee                        #b784a7

=item orchall                                 orchall                         #a8516e

=item orchid                                  orchid                          #b695c0

=item orchid                                  orchid                          #aa98a9

=item orchid pink                             orchidpink                      #ea9399

=item orchil                                  orchil                          #ab4e52

=item orchil                                  orchil                          #a8516e

=item orchis                                  orchis                          #905d5d

=item orient                                  orient                          #dea5a4

=item oriental                                oriental                        #536878

=item oriental blue                           orientalblue                    #4c516d

=item oriental blue                           orientalblue                    #0067a5

=item oriental blue                           orientalblue                    #545aa7

=item oriental bole                           orientalbole                    #79443b

=item oriental fuchsia                        orientalfuchsia                 #702963

=item oriental green                          orientalgreen                   #44944a

=item oriental green                          orientalgreen                   #679267

=item oriental pearl                          orientalpearl                   #8a8776

=item oriental pearl                          orientalpearl                   #848482

=item oriental red                            orientalred                     #bc3f4a

=item orient [blue]                           orientblue                      #0067a5

=item orient blue                             orientblue                      #436b95

=item orient blue                             orientblue                      #536878

=item orient pink                             orientpink                      #d9a6a9

=item orient red                              orientred                       #bc3f4a

=item orient yellow                           orientyellow                    #ed872d

=item orient yellow                           orientyellow                    #d99058

=item orient yellow                           orientyellow                    #eaa221

=item orient yellow                           orientyellow                    #e3a857

=item orient yellow                           orientyellow                    #ab9144

=item orient yellow                           orientyellow                    #a18f60

=item oriole                                  oriole                          #ae6938

=item orion                                   orion                           #00304e

=item orlean                                  orlean                          #d9a6a9

=item ormond                                  ormond                          #977f73

=item ormond                                  ormond                          #958070

=item ormond                                  ormond                          #8e8279

=item orpiment                                orpiment                        #fada5e

=item orpiment                                orpiment                        #d4af37

=item orpiment                                orpiment                        #f8de7e

=item orpiment                                orpiment                        #c9ae5d

=item orpiment orange                         orpimentorange                  #f38400

=item orpiment orange                         orpimentorange                  #ed872d

=item orpiment red                            orpimentred                     #eaa221

=item orpiment red                            orpimentred                     #e3a857

=item orpin                                   orpin                           #fada5e

=item orpin                                   orpin                           #d4af37

=item orpin                                   orpin                           #f8de7e

=item orpin                                   orpin                           #c9ae5d

=item orseille                                orseille                        #a8516e

=item otter [brown]                           otterbrown                      #483c32

=item oural green                             ouralgreen                      #93c592

=item oural green                             ouralgreen                      #c7e6d7

=item owl                                     owl                             #5b504f

=item oxblood [red]                           oxbloodred                      #79443b

=item oxford blue                             oxfordblue                      #291e29

=item oxford chrome                           oxfordchrome                    #e3a857

=item oxford ochre                            oxfordochre                     #e3a857

=item oxford yellow                           oxfordyellow                    #e3a857

=item oxgall                                  oxgall                          #d4af37

=item oxheart                                 oxheart                         #841b2d

=item oxide blue                              oxideblue                       #0085a1

=item oxide brown                             oxidebrown                      #79443b

=item oxide purple                            oxidepurple                     #79443b

=item oxide yellow                            oxideyellow                     #e3a857

=item oyster grey                             oystergrey                      #dadfb7

=item oyster [white]                          oysterwhite                     #dadfb7

=item pablo                                   pablo                           #a67b5b

=item pablo                                   pablo                           #c19a6b

=item pacific                                 pacific                         #8da399

=item pacific                                 pacific                         #66ada4

=item paddock                                 paddock                         #004b49

=item pagoda [blue]                           pagodablue                      #004958

=item pagoda [blue]                           pagodablue                      #36454f

=item palestine                               palestine                       #796878

=item palestine                               palestine                       #915f6d

=item palm                                    palm                            #8a9a5b

=item palmetto                                palmetto                        #8f9779

=item palm green                              palmgreen                       #355e3b

=item palmleaf                                palmleaf                        #867e36

=item paloma                                  paloma                          #ae6938

=item paloma                                  paloma                          #a67b5b

=item pampas                                  pampas                          #5b504f

=item pan                                     pan                             #3a4b47

=item pancy green                             pancygreen                      #355e3b

=item panse                                  panse                           #604e97

=item pansy                                   pansy                           #604e97

=item pansy-maroon                            pansymaroon                     #673147

=item pansy purple                            pansypurple                     #673147

=item pansy violet                            pansyviolet                     #5d3954

=item paon                                    paon                            #004958

=item paper white                             paperwhite                      #bfb8a5

=item paprica                                 paprica                         #e25822

=item papyrus                                 papyrus                         #a67b5b

=item paradise green                          paradisegreen                   #355e3b

=item para red                                parared                         #bc3f4a

=item para red                                parared                         #ab4e52

=item parchment                               parchment                       #c2b280

=item parchment                               parchment                       #a18f60

=item parchment                               parchment                       #967117

=item paris green                             parisgreen                      #679267

=item paris green                             parisgreen                      #3eb489

=item paris mud                               parismud                        #543d3f

=item paris red                               parisred                        #e25822

=item paris yellow                            parisyellow                     #d4af37

=item park green                              parkgreen                       #8a9a5b

=item parma red                               parmared                        #bc3f4a

=item parma red                               parmared                        #ab4e52

=item parme                                   parme                           #604e81

=item parrakeet                               parrakeet                       #8a9a5b

=item parrakeet                               parrakeet                       #3eb489

=item parroquit green                         parroquitgreen                  #8a9a5b

=item parrot green                            parrotgreen                     #8a9a5b

=item partridge                               partridge                       #826644

=item partridge                               partridge                       #4b3621

=item parula blue                             parulablue                      #536878

=item pastel                                  pastel                          #536878

=item pastel blue                             pastelblue                      #536878

=item pastel grey                             pastelgrey                      #c2b280

=item pastel parchment                        pastelparchment                 #d9a6a9

=item pastel parchment                        pastelparchment                 #c7ada3

=item pastel parchment                        pastelparchment                 #c2ac99

=item patent yellow                           patentyellow                    #fada5e

=item patent yellow                           patentyellow                    #d4af37

=item patent yellow                           patentyellow                    #f8de7e

=item patent yellow                           patentyellow                    #c9ae5d

=item patina green                            patinagreen                     #93c592

=item patina green                            patinagreen                     #679267

=item patriarch                               patriarch                       #602f6b

=item patricia                                patricia                        #9e4f88

=item paul veronese green                     paulveronesegreen               #3eb489

=item pauncy green                            pauncygreen                     #355e3b

=item pavonine                                pavonine                        #004958

=item pawnee                                  pawnee                          #a67b5b

=item pawnee                                  pawnee                          #958070

=item pawnee                                  pawnee                          #c19a6b

=item pawnee                                  pawnee                          #ae9b82

=item payne's grey                            paynesgrey                      #536878

=item payne's grey                            paynesgrey                      #36454f

=item peach                                   peach                           #f4c2c2

=item peach                                   peach                           #d9a6a9

=item peachbeige                              peachbeige                      #d9a6a9

=item peach bisque                            peachbisque                     #a87c6d

=item peach bloom                             peachbloom                      #d9a6a9

=item peach blossom [pink]                    peachblossompink                #ea9399

=item peach blossom [pink]                    peachblossompink                #dea5a4

=item peach blossom [red]                     peachblossomred                 #ea9399

=item peach blossom [red]                     peachblossomred                 #dea5a4

=item peach blow                              peachblow                       #fad6a5

=item peach blush                             peachblush                      #80461b

=item peach red                               peachred                        #f88379

=item peachwood                               peachwood                       #ab4e52

=item peachwood                               peachwood                       #905d5d

=item peacock [blue]                          peacockblue                     #004958

=item peacock green                           peacockgreen                    #679267

=item pea green                               peagreen                        #8a9a5b

=item peanut                                  peanut                          #c2b280

=item pearl                                   pearl                           #b9b8b5

=item pearl blue                              pearlblue                       #b9b8b5

=item pearlblush                              pearlblush                      #c2ac99

=item pearlblush                              pearlblush                      #958070

=item pearl gray                              pearlgray                       #bfb8a5

=item pearl white                             pearlwhite                      #b9b8b5

=item peasant                                 peasant                         #252440

=item peasant                                 peasant                         #4c516d

=item peasant blue                            peasantblue                     #536878

=item peasant blue                            peasantblue                     #00304e

=item peasant blue                            peasantblue                     #252440

=item peasant blue                            peasantblue                     #4c516d

=item pebble                                  pebble                          #c2b280

=item pecan                                   pecan                           #ae9b82

=item pecan brown                             pecanbrown                      #6f4e37

=item pekinese                                pekinese                        #ae6938

=item pekinese                                pekinese                        #a67b5b

=item peking blue                             pekingblue                      #00304e

=item pelican                                 pelican                         #555555

=item peligot's blue                          peligotsblue                    #317873

=item pelt                                    pelt                            #5b504f

=item pencilwood                              pencilwood                      #79443b

=item pencilwood                              pencilwood                      #6f4e37

=item penguin                                 penguin                         #848482

=item peony                                   peony                           #722f37

=item peony red                               peonyred                        #841b2d

=item peony red                               peonyred                        #722f37

=item pepita                                  pepita                          #967117

=item peppermint                              peppermint                      #44944a

=item pepper red                              pepperred                       #ab4e52

=item peridot                                 peridot                         #8a9a5b

=item peridot                                 peridot                         #8f9779

=item peridot                                 peridot                         #4a5d23

=item peridot                                 peridot                         #515744

=item perilla                                 perilla                         #9065ca

=item perilla                                 perilla                         #604e97

=item perilla purple                          perillapurple                   #673147

=item perique                                 perique                         #483c32

=item periwinkle                              periwinkle                      #8c92ac

=item periwinkle                              periwinkle                      #4c516d

=item permanent blue                          permanentblue                   #0067a5

=item permanent blue                          permanentblue                   #545aa7

=item permanent red                           permanentred                    #bc3f4a

=item permanent red                           permanentred                    #ab4e52

=item permanent violet                        permanentviolet                 #875692

=item permanent yellow                        permanentyellow                 #e3a857

=item perma red                               permared                        #bc3f4a

=item perma red                               permared                        #ab4e52

=item pernambucowood                          pernambucowood                  #ab4e52

=item pernambucowood                          pernambucowood                  #905d5d

=item perruche                                perruche                        #8a9a5b

=item persenche                               persenche                       #9690ab

=item persian blue                            persianblue                     #91a3b0

=item persian blue                            persianblue                     #4c516d

=item persian earth                           persianearth                    #882d17

=item persian green                           persiangreen                    #3a4b47

=item persian lilac                           persianlilac                    #c17e91

=item persian melon                           persianmelon                    #b4745e

=item persian orange                          persianorange                   #d99058

=item persian pink                            persianpink                     #a8516e

=item persian red                             persianred                      #882d17

=item persian rose                            persianrose                     #ce4676

=item persian yellow                          persianyellow                   #e25822

=item persian yellow                          persianyellow                   #f38400

=item persimmon                               persimmon                       #80461b

=item persio                                  persio                          #a8516e

=item persis                                  persis                          #a8516e

=item peruvian brown                          peruvianbrown                   #ae6938

=item peruvian brown                          peruvianbrown                   #a67b5b

=item peruvian yellow                         peruvianyellow                  #cb6d51

=item pervenche                               pervenche                       #4c516d

=item petunia                                 petunia                         #563c5c

=item petunia [violet]                        petuniaviolet                   #602f6b

=item pewke                                   pewke                           #722f37

=item pewter                                  pewter                          #555555

=item phantom                                 phantom                         #555555

=item phantom red                             phantomred                      #e25822

=item pharaoh                                 pharaoh                         #4e5180

=item pharaoh                                 pharaoh                         #252440

=item pheasant                                pheasant                        #d99058

=item pheasant                                pheasant                        #a67b5b

=item philamot                                philamot                        #be6516

=item philamot                                philamot                        #ae6938

=item philamot                                philamot                        #80461b

=item philimot                                philimot                        #be6516

=item philimot                                philimot                        #ae6938

=item philimot                                philimot                        #80461b

=item philomot                                philomot                        #be6516

=item philomot                                philomot                        #ae6938

=item philomot                                philomot                        #80461b

=item phlox                                   phlox                           #702963

=item phlox                                   phlox                           #673147

=item phlox pink                              phloxpink                       #aa98a9

=item phlox purple                            phloxpurple                     #9e4f88

=item phyliamort                              phyliamort                      #be6516

=item phyliamort                              phyliamort                      #ae6938

=item phyliamort                              phyliamort                      #80461b

=item phyllamort                              phyllamort                      #be6516

=item phyllamort                              phyllamort                      #ae6938

=item phyllamort                              phyllamort                      #80461b

=item piccadilly                              piccadilly                      #79443b

=item piccadilly                              piccadilly                      #674c47

=item piccaninny                              piccaninny                      #483c32

=item piccolpasso red                         piccolpassored                  #79443b

=item pigeon                                  pigeon                          #5d555b

=item pigeon blood                            pigeonblood                     #722f37

=item pigeon neck                             pigeonneck                      #555555

=item pigeon's-breast                         pigeonsbreast                   #905d5d

=item pigeon's throat                         pigeonsthroat                   #3b7861

=item pigskin                                 pigskin                         #a67b5b

=item pigskin                                 pigskin                         #6f4e37

=item pigskin                                 pigskin                         #826644

=item pilgrim                                 pilgrim                         #555555

=item pilgrim brown                           pilgrimbrown                    #635147

=item pilgrim brown                           pilgrimbrown                    #3e322c

=item pilot blue                              pilotblue                       #436b95

=item pimento                                 pimento                         #be0032

=item pimlico                                 pimlico                         #554c69

=item pinard yellow                           pinardyellow                    #f8de7e

=item pinchbeck brown                         pinchbeckbrown                  #be8a3d

=item pinchbeck brown                         pinchbeckbrown                  #996515

=item pinchbeck brown                         pinchbeckbrown                  #c19a6b

=item pinchbeck brown                         pinchbeckbrown                  #ab9144

=item pinchbeck brown                         pinchbeckbrown                  #967117

=item pineapple                               pineapple                       #f8de7e

=item pineapple                               pineapple                       #c9ae5d

=item pinecone                                pinecone                        #635147

=item pinecone                                pinecone                        #7e6d5a

=item pine frost                              pinefrost                       #8da399

=item pinegrove                               pinegrove                       #3a4b47

=item pineneedle                              pineneedle                      #1b4d3e

=item pineneedle                              pineneedle                      #3a4b47

=item pine tree                               pinetree                        #004b49

=item pink 1                                  pink1                           #c1b6b3

=item pink 2                                  pink2                           #ead8d7

=item pink 3                                  pink3                           #f9ccca

=item pink 3                                  pink3                           #ead8d7

=item pink 4                                  pink4                           #f9ccca

=item pink 4                                  pink4                           #dea5a4

=item pink 5                                  pink5                           #dea5a4

=item pink coral                              pinkcoral                       #e4717a

=item pink coral                              pinkcoral                       #f88379

=item pink pearl                              pinkpearl                       #dea5a4

=item piping rock                             pipingrock                      #8a8776

=item piquant green                           piquantgreen                    #8a9a5b

=item pirate                                  pirate                          #bc3f4a

=item pirate                                  pirate                          #d9603b

=item pistache                                pistache                        #8a9a5b

=item pistache                                pistache                        #93c592

=item pistachio green                         pistachiogreen                  #8a9a5b

=item pistachio green                         pistachiogreen                  #93c592

=item pitchpine                               pitchpine                       #3a4b47

=item piuree                                  piuree                          #eaa221

=item piuree                                  piuree                          #e3a857

=item piuri                                   piuri                           #eaa221

=item piuri                                   piuri                           #e3a857

=item pi yu                                   piyu                            #3b7861

=item plantation                              plantation                      #79443b

=item platina yellow                          platinayellow                   #ae6938

=item platinum                                platinum                        #848482

=item plaza grey                              plazagrey                       #bfb8a5

=item pleroma violet                          pleromaviolet                   #86608e

=item plover                                  plover                          #5b504f

=item plumbaceous                             plumbaceous                     #5d555b

=item plumbaceous                             plumbaceous                     #555555

=item plumbago blue                           plumbagoblue                    #aa98a9

=item plumbago blue                           plumbagoblue                    #8b8589

=item plumbago grey                           plumbagogrey                    #aa98a9

=item plumbago grey                           plumbagogrey                    #8b8589

=item plumbago slate                          plumbagoslate                   #5d555b

=item plumbet                                 plumbet                         #b4bcc0

=item plum [purple]                           plumpurple                      #563c5c

=item plum purple                             plumpurple                      #2f2140

=item plum violet                             plumviolet                      #722f37

=item plum violet                             plumviolet                      #673147

=item plunket                                 plunket                         #b4bcc0

=item plymouth                                plymouth                        #555555

=item poil d'ours                             poildours                       #555555

=item poilu                                   poilu                           #81878b

=item poinsettia                              poinsettia                      #be0032

=item poinsettia                              poinsettia                      #bc3f4a

=item pois green                              poisgreen                       #8f9779

=item polar bear                              polarbear                       #fad6a5

=item polar bear                              polarbear                       #f0ead6

=item polignac                                polignac                        #ad8884

=item polignac                                polignac                        #a87c6d

=item polignac                                polignac                        #977f73

=item polo green                              pologreen                       #4a5d23

=item polo green                              pologreen                       #355e3b

=item polo tan                                polotan                         #c19a6b

=item pomegranate                             pomegranate                     #722f37

=item pomegranate blossom                     pomegranateblossom              #be0032

=item pomegranate blossom                     pomegranateblossom              #e25822

=item pomegranate purple                      pomegranatepurple               #ab4e52

=item pomegranate purple                      pomegranatepurple               #a8516e

=item pomegranate purple                      pomegranatepurple               #a8516e

=item pomegranate purple                      pomegranatepurple               #915f6d

=item pomona green                            pomonagreen                     #8a9a5b

=item pompadour [green]                       pompadourgreen                  #436b95

=item pomp and power                          pompandpower                    #86608e

=item pompeian blue                           pompeianblue                    #91a3b0

=item pompeian red                            pompeianred                     #905d5d

=item pompeian red                            pompeianred                     #b4745e

=item pompeian red                            pompeianred                     #a87c6d

=item pompeian yellow                         pompeianyellow                  #e3a857

=item pompeii                                 pompeii                         #56070c

=item pompeii                                 pompeii                         #79443b

=item ponceau                                 ponceau                         #be0032

=item ponceau                                 ponceau                         #e25822

=item ponce de leon                           poncedeleon                     #ed872d

=item pond lily                               pondlily                        #f8de7e

=item pond lily                               pondlily                        #c9ae5d

=item pongee                                  pongee                          #c19a6b

=item pontiff [purple]                        pontiffpurple                   #602f6b

=item pony brown                              ponybrown                       #635147

=item popcorn                                 popcorn                         #f8de7e

=item popinjay green                          popinjaygreen                   #8a9a5b

=item poplar                                  poplar                          #3a4b47

=item poppy [red]                             poppyred                        #be0032

=item poppy [red]                             poppyred                        #e25822

=item porcelain                               porcelain                       #436b95

=item porcelain blue                          porcelainblue                   #536878

=item porcelain green                         porcelaingreen                  #317873

=item porraaceous                             porraaceous                     #8a9a5b

=item porret                                  porret                          #8a9a5b

=item port                                    port                            #3f1728

=item portable red                            portablered                     #bc3f4a

=item portable red                            portablered                     #ab4e52

=item portable red                            portablered                     #aa381e

=item portable red                            portablered                     #9e4732

=item portugese red or portuguese red         portugeseredorportuguesered     #be0032

=item port wine                               portwine                        #43302e

=item post office red                         postofficered                   #aa381e

=item post office red                         postofficered                   #9e4732

=item posy green                              posygreen                       #5e716a

=item poudre                                  poudre                          #91a3b0

=item poudre                                  poudre                          #81878b

=item poudre                                  poudre                          #b4bcc0

=item poudre blue                             poudreblue                      #91a3b0

=item poudre blue                             poudreblue                      #81878b

=item powder blue                             powderblue                      #91a3b0

=item powder blue                             powderblue                      #81878b

=item powder blue                             powderblue                      #00416a

=item powder blue                             powderblue                      #436b95

=item powdered gold                           powderedgold                    #a18f60

=item powder pink                             powderpink                      #d9a6a9

=item prairie                                 prairie                         #c19a6b

=item prairie brown                           prairiebrown                    #ae6938

=item praline                                 praline                         #6f4e37

=item praline                                 praline                         #635147

=item prawn [pink]                            prawnpink                       #f88379

=item prelate                                 prelate                         #604e81

=item primrose green                          primrosegreen                   #ebe8a4

=item primrose yellow                         primroseyellow                  #f8de7e

=item primrose yellow                         primroseyellow                  #c9ae5d

=item primuline yellow                        primulineyellow                 #d4af37

=item prince grey                             princegrey                      #8b8589

=item princeton orange                        princetonorange                 #ed872d

=item priscilla                               priscilla                       #b9b8b5

=item privet                                  privet                          #515744

=item prout's brown                           proutsbrown                     #6f4e37

=item prout's brown                           proutsbrown                     #635147

=item prout's brown                           proutsbrown                     #826644

=item prout's brown                           proutsbrown                     #7e6d5a

=item prune                                   prune                           #5d3954

=item prunella                                prunella                        #32174d

=item prunella                                prunella                        #2f2140

=item prune purple                            prunepurple                     #563c5c

=item prussian brown                          prussianbrown                   #ae6938

=item prussian red                            prussianred                     #882d17

=item prussian red                            prussianred                     #79443b

=item psyche                                  psyche                          #93c592

=item pt shell                              ptshell                         #fad6a5

=item pt shell                              ptshell                         #c19a6b

=item puce                                    puce                            #722f37

=item pueblo                                  pueblo                          #6f4e37

=item puke                                    puke                            #722f37

=item pumpkin                                 pumpkin                         #ed872d

=item punjab                                  punjab                          #be6516

=item punjab                                  punjab                          #ae6938

=item puritan grey                            puritangrey                     #81878b

=item puritan grey                            puritangrey                     #848482

=item purple aster                            purpleaster                     #86608e

=item purple brown                            purplebrown                     #79443b

=item purple heather                          purpleheather                   #86608e

=item purple lake                             purplelake                      #841b2d

=item purple lake                             purplelake                      #ab4e52

=item purple madder                           purplemadder                    #ab4e52

=item purple madder                           purplemadder                    #722f37

=item purple navy                             purplenavy                      #00304e

=item purple navy                             purplenavy                      #4e5180

=item purple navy                             purplenavy                      #252440

=item purple ochre                            purpleochre                     #882d17

=item purple oxide                            purpleoxide                     #79443b

=item purple rubiate                          purplerubiate                   #ab4e52

=item purple rubiate                          purplerubiate                   #722f37

=item purrea arabica                          purreaarabica                   #eaa221

=item purrea arabica                          purreaarabica                   #e3a857

=item purree                                  purree                          #eaa221

=item purree                                  purree                          #e3a857

=item putty                                   putty                           #f3e5ab

=item putty                                   putty                           #c2b280

=item pygmalion                               pygmalion                       #996515

=item pygmalion                               pygmalion                       #c19a6b

=item pygmalion                               pygmalion                       #826644

=item pyrethrum yellow                        pyrethrumyellow                 #fada5e

=item pyrethrum yellow                        pyrethrumyellow                 #d4af37

=item pyrethrum yellow                        pyrethrumyellow                 #f8de7e

=item pyrethrum yellow                        pyrethrumyellow                 #c9ae5d

=item pyrite yellow                           pyriteyellow                    #ab9144

=item quail                                   quail                           #5b504f

=item quail                                   quail                           #555555

=item quaker                                  quaker                          #8b8589

=item quaker                                  quaker                          #848482

=item quaker blue                             quakerblue                      #222222

=item quaker drab                             quakerdrab                      #848482

=item quaker green                            quakergreen                     #4a5d23

=item quaker grey                             quakergrey                      #8c8767

=item queen anne green                        queenannegreen                  #8f9779

=item queen blue                              queenblue                       #436b95

=item queen's blue                            queensblue                      #436b95

=item queen's yellow                          queensyellow                    #f8de7e

=item quercitron                              quercitron                      #f8de7e

=item quercitron lake                         quercitronlake                  #e3a857

=item quimper                                 quimper                         #536878

=item quince yellow                           quinceyellow                    #c9ae5d

=item rabbit                                  rabbit                          #5b504f

=item racquet                                 racquet                         #635147

=item racquet                                 racquet                         #7e6d5a

=item raddle                                  raddle                          #79443b

=item radiance                                radiance                        #e4717a

=item radiant yellow                          radiantyellow                   #ed872d

=item radiant yellow                          radiantyellow                   #d99058

=item radiant yellow                          radiantyellow                   #eaa221

=item radiant yellow                          radiantyellow                   #e3a857

=item radio                                   radio                           #00304e

=item radio                                   radio                           #536878

=item radio blue                              radioblue                       #36454f

=item raffia                                  raffia                          #c19a6b

=item raffia                                  raffia                          #c2b280

=item ragged sailor                           raggedsailor                    #4e5180

=item rail                                    rail                            #555555

=item rainette green                          rainettegreen                   #8a9a5b

=item raisin                                  raisin                          #673147

=item raisin black                            raisinblack                     #242124

=item raisin purple                           raisinpurple                    #702963

=item rambler rose                            ramblerrose                     #e4717a

=item rambler rose                            ramblerrose                     #a8516e

=item rameau                                  rameau                          #222222

=item rameses                                 rameses                         #00416a

=item ramier blue                             ramierblue                      #796878

=item rangoon                                 rangoon                         #6f4e37

=item raphael                                 raphael                         #436b95

=item raphael                                 raphael                         #00304e

=item rapids                                  rapids                          #436b95

=item raspberry                               raspberry                       #722f37

=item raspberry glac                         raspberryglac                   #ab4e52

=item raspberry glac                         raspberryglac                   #905d5d

=item raspberry glac                         raspberryglac                   #a8516e

=item raspberry glac                         raspberryglac                   #915f6d

=item raspberry red                           raspberryred                    #ab4e52

=item rat                                     rat                             #57554c

=item rattan                                  rattan                          #c9ae5d

=item raw italian earth                       rawitalianearth                 #ae6938

=item raw italian earth                       rawitalianearth                 #a67b5b

=item raw sienna                              rawsienna                       #ae6938

=item raw sienna                              rawsienna                       #a67b5b

=item raw umber                               rawumber                        #826644

=item raw umber                               rawumber                        #4b3621

=item raw umber                               rawumber                        #6f4e37

=item rcamier                                rcamier                         #dea5a4

=item rcamier                                rcamier                         #f88379

=item realgar                                 realgar                         #eaa221

=item realgar                                 realgar                         #e3a857

=item red banana                              redbanana                       #841b2d

=item red banana                              redbanana                       #ab4e52

=item red bole                                redbole                         #79443b

=item red chalk                               redchalk                        #79443b

=item red cross                               redcross                        #be0032

=item red cross                               redcross                        #bc3f4a

=item redding                                 redding                         #79443b

=item reddle                                  reddle                          #79443b

=item red earth                               redearth                        #79443b

=item redfeather                              redfeather                      #bc3f4a

=item redfeather                              redfeather                      #ab4e52

=item red in plates                           redinplates                     #be0032

=item red lead                                redlead                         #e25822

=item red ochre                               redochre                        #79443b

=item red oxide                               redoxide                        #882d17

=item red oxide                               redoxide                        #80461b

=item red robin                               redrobin                        #56070c

=item redwood                                 redwood                         #722f37

=item redwood                                 redwood                         #882d17

=item redwood                                 redwood                         #79443b

=item redwood redwood -)                      redwoodredwood                  #ab4e52

=item redwood redwood -)                      redwoodredwood                  #ab4e52

=item redwood redwood -)                      redwoodredwood                  #905d5d

=item reed green                              reedgreen                       #c9dc89

=item reed yellow                             reedyellow                      #eae679

=item reed yellow                             reedyellow                      #ebe8a4

=item regal                                   regal                           #272458

=item regal purple                            regalpurple                     #604e97

=item regatta                                 regatta                         #0067a5

=item regatta                                 regatta                         #545aa7

=item regimental                              regimental                      #4c516d

=item rejane green                            rejanegreen                     #679267

=item rembrandt                               rembrandt                       #3e322c

=item rembrandt's madder                      rembrandtsmadder                #cb6d51

=item rembrandt's madder                      rembrandtsmadder                #9e4732

=item rembrandt's madder                      rembrandtsmadder                #b4745e

=item rembrandt's madder                      rembrandtsmadder                #79443b

=item renaissance                             renaissance                     #ce4676

=item reseda [green]                          resedagreen                     #867e36

=item resolute                                resolute                        #436b95

=item reveree                                 reveree                         #ecd5c5

=item reveree                                 reveree                         #c7ada3

=item rhododendron                            rhododendron                    #673147

=item rhodonite pink                          rhodonitepink                   #c17e91

=item rhone                                   rhone                           #c9dc89

=item rhone                                   rhone                           #dadfb7

=item rhubarb                                 rhubarb                         #867e36

=item rifle [green]                           riflegreen                      #31362b

=item rifle [green]                           riflegreen                      #222222

=item riga                                    riga                            #317873

=item riga blue                               rigablue                        #3a4b47

=item riga blue                               rigablue                        #536878

=item rinnemann's green                       rinnemannsgreen                 #679267

=item ripple green                            ripplegreen                     #5e716a

=item ripple green                            ripplegreen                     #317873

=item risigal                                 risigal                         #eaa221

=item risigal                                 risigal                         #e3a857

=item rivage green                            rivagegreen                     #8a9a5b

=item rivage green                            rivagegreen                     #93c592

=item riviera                                 riviera                         #0067a5

=item roan                                    roan                            #79443b

=item robinhood green                         robinhoodgreen                  #1b4d3e

=item robin's egg blue                        robinseggblue                   #8da399

=item robin's egg blue                        robinseggblue                   #66ada4

=item rocou                                   rocou                           #d9a6a9

=item rodent                                  rodent                          #555555

=item roe                                     roe                             #c19a6b

=item roe                                     roe                             #a18f60

=item roma blue                               romablue                        #4c516d

=item roma blue                               romablue                        #554c69

=item roman earth                             romanearth                      #d99058

=item romanesque                              romanesque                      #5d3954

=item roman green                             romangreen                      #665d1e

=item roman lake                              romanlake                       #be0032

=item roman lake                              romanlake                       #bc3f4a

=item roman ochre                             romanochre                      #d99058

=item roman purple                            romanpurple                     #604e81

=item roman sepia                             romansepia                      #6f4e37

=item romantic green                          romanticgreen                   #867e36

=item roman umber                             romanumber                      #826644

=item roman umber                             romanumber                      #4b3621

=item roman violet                            romanviolet                     #5d3954

=item romany                                  romany                          #36454f

=item romany                                  romany                          #202830

=item romany                                  romany                          #252440

=item romany                                  romany                          #4c516d

=item romarin                                 romarin                         #3a4b47

=item rosalgar                                rosalgar                        #eaa221

=item rosalgar                                rosalgar                        #e3a857

=item rosario                                 rosario                         #a67b5b

=item rose amber                              roseamber                       #ae6938

=item rose amber                              roseamber                       #a67b5b

=item rose ash                                roseash                         #905d5d

=item rose beige                              rosebeige                       #7e6d5a

=item rose beige 2                            rosebeige2                      #a67b5b

=item rosebisque                              rosebisque                      #a87c6d

=item rosebloom                               rosebloom                       #ad8884

=item rosebloom                               rosebloom                       #c48379

=item rosebloom                               rosebloom                       #b4745e

=item rosebloom                               rosebloom                       #a87c6d

=item rose blush                              roseblush                       #a87c6d

=item rose blush 2                            roseblush2                      #a67b5b

=item rose breath                             rosebreath                      #f9ccca

=item rose breath                             rosebreath                      #ead8d7

=item rosebud                                 rosebud                         #de6fa1

=item rosebud                                 rosebud                         #c17e91

=item rose caroline                           rosecaroline                    #d9a6a9

=item rose carthame                           rosecarthame                    #be0032

=item rose castor                             rosecastor                      #8f817f

=item rose cendre                             rosecendre                      #d9a6a9

=item rose d'alma                             rosedalma                       #915f6d

=item rose d'althoea                          rosedalthoea                    #ea9399

=item rose dawn                               rosedawn                        #d9a6a9

=item rose dawn                               rosedawn                        #a87c6d

=item rose de nymphe                          rosedenymphe                    #f3e5ab

=item rose de provence                        rosedeprovence                  #b3446c

=item rose dore                              rosedore                        #e4717a

=item rose dore                              rosedore                        #ab4e52

=item rosedust                                rosedust                        #905d5d

=item rosedust                                rosedust                        #674c47

=item rose ebony                              roseebony                       #43302e

=item rose france                             rosefrance                      #d9a6a9

=item roseglow                                roseglow                        #a87c6d

=item rose grey                               rosegrey                        #5b504f

=item rose hermosa                            rosehermosa                     #dea5a4

=item rose hortensia                          rosehortensia                   #a87c6d

=item rose lake                               roselake                        #9e4732

=item roseleaf                                roseleaf                        #dea5a4

=item roselustre                              roselustre                      #722f37

=item rose madder                             rosemadder                      #b3446c

=item rose marie                              rosemarie                       #e4717a

=item rosemary                                rosemary                        #836479

=item rose morn                               rosemorn                        #d9a6a9

=item rose neyron                             roseneyron                      #bc3f4a

=item rose neyron                             roseneyron                      #b3446c

=item rose nilsson                            rosenilsson                     #e4717a

=item rose nude                               rosenude                        #d9a6a9

=item rose nude                               rosenude                        #c7ada3

=item rose nude                               rosenude                        #c2ac99

=item rose oak                                roseoak                         #79443b

=item rose of picardy                         roseofpicardy                   #ab4e52

=item rose of sharon                          roseofsharon                    #ab4e52

=item rose petal                              rosepetal                       #905d5d

=item rose pink                               rosepink                        #9e4732

=item rose-purple                             rosepurple                      #b695c0

=item rose-purple                             rosepurple                      #b784a7

=item rose quartz                             rosequartz                      #aa98a9

=item rose soire                             rosesoire                       #e4717a

=item rosestone                               rosestone                       #977f73

=item roset                                   roset                           #9e4732

=item rosetan                                 rosetan                         #c2ac99

=item rosetan                                 rosetan                         #958070

=item rose taupe                              rosetaupe                       #555555

=item rosetta                                 rosetta                         #5c504f

=item rosevale                                rosevale                        #ab4e52

=item rosevale                                rosevale                        #905d5d

=item rosewood                                rosewood                        #79443b

=item roslyn blue                             roslynblue                      #272458

=item roucou                                  roucou                          #d9a6a9

=item rouge de fer                            rougedefer                      #79443b

=item rouge vegetal                           rougevegetal                    #be0032

=item royal blue                              royalblue                       #00416a

=item royal blue                              royalblue                       #436b95

=item royal blue                              royalblue                       #00416a

=item royal pink                              royalpink                       #e4717a

=item royal purple                            royalpurple                     #604e97

=item royal yellow                            royalyellow                     #fada5e

=item royal yellow                            royalyellow                     #d4af37

=item royal yellow                            royalyellow                     #f8de7e

=item royal yellow                            royalyellow                     #c9ae5d

=item rubaiyat                                rubaiyat                        #722f37

=item rubber                                  rubber                          #6c541e

=item rubelite                                rubelite                        #ce4676

=item ruben's madder                          rubensmadder                    #9e4732

=item rubient                                 rubient                         #722f37

=item rubrica                                 rubrica                         #79443b

=item ruby                                    ruby                            #722f37

=item ruby of arsenic                         rubyofarsenic                   #eaa221

=item ruby of arsenic                         rubyofarsenic                   #e3a857

=item ruddle                                  ruddle                          #79443b

=item rufous                                  rufous                          #f88379

=item rufous                                  rufous                          #d99058

=item rugby tan                               rugbytan                        #80461b

=item runnymede                               runnymede                       #3b7861

=item ru ochre                                ruochre                         #ae6938

=item ru ochre                                ruochre                         #996515

=item russet brown                            russetbrown                     #80461b

=item russet brown                            russetbrown                     #6f4e37

=item russet green                            russetgreen                     #b9b459

=item russet green                            russetgreen                     #98943e

=item russet green                            russetgreen                     #b9b57d

=item russet green                            russetgreen                     #867e36

=item russet orange                           russetorange                    #d9603b

=item russian blue                            russianblue                     #91a3b0

=item russian blue                            russianblue                     #81878b

=item russian calf                            russiancalf                     #6f4e37

=item russian green                           russiangreen                    #679267

=item russian green                           russiangreen                    #355e3b

=item russian green                           russiangreen                    #5e716a

=item russian grey                            russiangrey                     #8a8776

=item russian grey                            russiangrey                     #848482

=item russian violet                          russianviolet                   #32174d

=item rust                                    rust                            #80461b

=item rustic brown                            rusticbrown                     #79443b

=item rustic drab                             rusticdrab                      #967117

=item rut ochre                               rutochre                        #ae6938

=item rut ochre                               rutochre                        #996515

=item sable                                   sable                           #7e6d5a

=item saddle                                  saddle                          #635147

=item saddle                                  saddle                          #7e6d5a

=item safaran                                 safaran                         #d99058

=item safaran                                 safaran                         #e3a857

=item safflor                                 safflor                         #be0032

=item safflower red                           safflowerred                    #be0032

=item saffor                                  saffor                          #be0032

=item saffron yellow                          saffronyellow                   #d99058

=item saffron yellow                          saffronyellow                   #e3a857

=item safrano pink                            safranopink                     #d9a6a9

=item sagebrush green                         sagebrushgreen                  #4e5755

=item sage drab                               sagedrab                        #515744

=item sage [green]                            sagegreen                       #8a9a5b

=item sage grey                               sagegrey                        #8c8767

=item sahara                                  sahara                          #6f4e37

=item sailor                                  sailor                          #291e29

=item sailor                                  sailor                          #242124

=item sailor blue                             sailorblue                      #4e5180

=item sakkara                                 sakkara                         #5b504f

=item sallow                                  sallow                          #b9b57d

=item salmon [pink]                           salmonpink                      #d9a6a9

=item salvia                                  salvia                          #be0032

=item salvia blue                             salviablue                      #0067a5

=item samara                                  samara                          #317873

=item samovar                                 samovar                         #c19a6b

=item samurai                                 samurai                         #b4745e

=item sand                                    sand                            #8c8767

=item sand                                    sand                            #8a8776

=item sandalwood                              sandalwood                      #ab4e52

=item sandalwood                              sandalwood                      #977f73

=item sandalwood                              sandalwood                      #6f4e37

=item sandalwood                              sandalwood                      #958070

=item sandalwood                              sandalwood                      #635147

=item sandarach                               sandarach                       #e25822

=item sandarach                               sandarach                       #eaa221

=item sandarach                               sandarach                       #e3a857

=item sandaracha                              sandaracha                      #e25822

=item sandaracha                              sandaracha                      #eaa221

=item sandaracha                              sandaracha                      #e3a857

=item sand dune                               sanddune                        #967117

=item sander's blue                           sandersblue                     #436b95

=item sanderswood                             sanderswood                     #ab4e52

=item sandix                                  sandix                          #e25822

=item sandrift                                sandrift                        #8e8279

=item sandstone                               sandstone                       #a87c6d

=item sandstone                               sandstone                       #a67b5b

=item sandstone                               sandstone                       #958070

=item sandust                                 sandust                         #d9a6a9

=item sandy-beige                             sandybeige                      #8e8279

=item sandyx                                  sandyx                          #e25822

=item sang de boeuf                           sangdeboeuf                     #79443b

=item sanguine                                sanguine                        #bc3f4a

=item sanguine                                sanguine                        #ab4e52

=item sanguineus                              sanguineus                      #841b2d

=item sanguineus                              sanguineus                      #722f37

=item sanguineus                              sanguineus                      #3f1728

=item sanguineus                              sanguineus                      #3e1d1e

=item sanguineus                              sanguineus                      #5d3954

=item sanguineus                              sanguineus                      #673147

=item santalwood                              santalwood                      #ab4e52

=item santos                                  santos                          #6f4e37

=item santos                                  santos                          #635147

=item saona                                   saona                           #79443b

=item sappanwood                              sappanwood                      #ab4e52

=item sappanwood                              sappanwood                      #905d5d

=item sapphire [blue]                         sapphireblue                    #00304e

=item sappho                                  sappho                          #ad8884

=item saraband                                saraband                        #905d5d

=item saratoga                                saratoga                        #d99058

=item saravan                                 saravan                         #80461b

=item saravan                                 saravan                         #6f4e37

=item sarouk                                  sarouk                          #635147

=item satinwood                               satinwood                       #a67b5b

=item satsuma                                 satsuma                         #cb6d51

=item saturnine red                           saturninered                    #e25822

=item saturn red                              saturnred                       #e25822

=item saul                                    saul                            #4e5755

=item saunder's blue                          saundersblue                    #436b95

=item sauterne                                sauterne                        #c9ae5d

=item sauterne                                sauterne                        #a67b5b

=item saxe blue                               saxeblue                        #536878

=item saxon blue                              saxonblue                       #007791

=item saxon blue                              saxonblue                       #004958

=item saxon green                             saxongreen                      #317873

=item saxony blue                             saxonyblue                      #007791

=item saxony blue                             saxonyblue                      #004958

=item saxony blue                             saxonyblue                      #00416a

=item saxony blue                             saxonyblue                      #436b95

=item saxony green                            saxonygreen                     #008856

=item sayal brown                             sayalbrown                      #ae6938

=item sayal brown                             sayalbrown                      #a67b5b

=item sayal brown                             sayalbrown                      #996515

=item scabiosa                                scabiosa                        #796878

=item scarab                                  scarab                          #3b7861

=item scarlet                                 scarlet                         #be0032

=item scarlet in grain                        scarletingrain                  #be0032

=item scarlet lake                            scarletlake                     #bc3f4a

=item scarlet lake                            scarletlake                     #ab4e52

=item scarlet madder                          scarletmadder                   #f88379

=item scarlet ochre                           scarletochre                    #882d17

=item scarlet red                             scarletred                      #be0032

=item scarlet vermilion                       scarletvermilion                #e25822

=item scheele's green                         scheelesgreen                   #7e9f2e

=item scheele's green                         scheelesgreen                   #44944a

=item schoenfeld's purple                     schoenfeldspurple               #78184a

=item schoenfeld's purple                     schoenfeldspurple               #a8516e

=item schweinfurt green                       schweinfurtgreen                #3eb489

=item scotch blue                             scotchblue                      #252440

=item scotch grey                             scotchgrey                      #8f9779

=item scotch grey                             scotchgrey                      #7d8984

=item seabird                                 seabird                         #555555

=item sea blue                                seablue                         #004b49

=item seacrest                                seacrest                        #93c592

=item seafoam                                 seafoam                         #3eb489

=item seafoam                                 seafoam                         #6aab8e

=item seafoam green                           seafoamgreen                    #dadfb7

=item seafoam yellow                          seafoamyellow                   #dadfb7

=item sea green                               seagreen                        #8a9a5b

=item sea hawk                                seahawk                         #57554c

=item seal [brown]                            sealbrown                       #483c32

=item seaman blue                             seamanblue                      #4c516d

=item sea mist                                seamist                         #8b8589

=item sea mist                                seamist                         #848482

=item sea moss                                seamoss                         #867e36

=item sea moss                                seamoss                         #3a4b47

=item sea pink                                seapink                         #ea9399

=item sea pink                                seapink                         #dea5a4

=item seasan not seasand                      seasannotseasand                #c2ac99

=item seasan not seasand                      seasannotseasand                #fad6a5

=item seasan not seasand                      seasannotseasand                #c19a6b

=item seasan not seasand                      seasannotseasand                #ae9b82

=item sea shell                               seashell                        #d9a6a9

=item sea shell                               seashell                        #d99058

=item sea shell                               seashell                        #a67b5b

=item seashell pink                           seashellpink                    #f4c2c2

=item seashell pink                           seashellpink                    #d9a6a9

=item seaside                                 seaside                         #967117

=item seaside                                 seaside                         #977f73

=item seaside                                 seaside                         #958070

=item seaside                                 seaside                         #8e8279

=item seaspray                                seaspray                        #8f9779

=item seaspray                                seaspray                        #679267

=item seaspray                                seaspray                        #8da399

=item sea-water green                         seawatergreen                   #8a9a5b

=item seaweed green                           seaweedgreen                    #8f9779

=item sedge                                   sedge                           #635147

=item seed pearl                              seedpearl                       #f3e5ab

=item seed pearl                              seedpearl                       #c2b280

=item seered green                            seeredgreen                     #8a9a5b

=item seladon green                           seladongreen                    #8f9779

=item seminole                                seminole                        #6f4e37

=item sepia                                   sepia                           #3b3121

=item serapi                                  serapi                          #536878

=item serpent                                 serpent                         #8da399

=item serpentine                              serpentine                      #6aab8e

=item serpentine green                        serpentinegreen                 #867e36

=item service corps                           servicecorps                    #00543d

=item seville                                 seville                         #32174d

=item seville orange                          sevilleorange                   #d99058

=item sevres [blue]                           sevresblue                      #0067a5

=item shadow                                  shadow                          #8f817f

=item shadow green                            shadowgreen                     #8a9a5b

=item shagbark                                shagbark                        #826644

=item shagbark                                shagbark                        #7e6d5a

=item shale green                             shalegreen                      #679267

=item shamrock                                shamrock                        #44944a

=item shamrock [green]                        shamrockgreen                   #44944a

=item shark                                   shark                           #796878

=item shark                                   shark                           #5d555b

=item sheepskin                               sheepskin                       #c2b280

=item sheik                                   sheik                           #ab4e52

=item sheik                                   sheik                           #9e4732

=item shell grey                              shellgrey                       #bfb8a5

=item shirvan                                 shirvan                         #3a4b47

=item shrimp [pink]                           shrimppink                      #f88379

=item shrimp [red]                            shrimpred                       #f88379

=item siam                                    siam                            #6f4e37

=item siam                                    siam                            #635147

=item siam                                    siam                            #826644

=item siam                                    siam                            #7e6d5a

=item siberian brown                          siberianbrown                   #6c541e

=item siberien                                siberien                        #3a4b47

=item sicilian umber                          sicilianumber                   #826644

=item sicilian umber                          sicilianumber                   #4b3621

=item siderin yellow                          siderinyellow                   #ed872d

=item siderin yellow                          siderinyellow                   #d99058

=item siena                                   siena                           #882d17

=item sienna brown                            siennabrown                     #6f4e37

=item sienna yellow                           siennayellow                    #fad6a5

=item sienna yellow                           siennayellow                    #c9ae5d

=item siennese drab                           siennesedrab                    #977f73

=item siennese drab                           siennesedrab                    #958070

=item sierra                                  sierra                          #882d17

=item signal red                              signalred                       #be0032

=item sil                                     sil                             #e3a857

=item silurian gray                           siluriangray                    #dadfb7

=item silver fern                             silverfern                      #867e36

=item silver fern                             silverfern                      #8c8767

=item silver green                            silvergreen                     #8f9779

=item silverpine                              silverpine                      #5e716a

=item silver-wing                             silverwing                      #8b8589

=item sinbad                                  sinbad                          #36454f

=item sinbad                                  sinbad                          #202428

=item sinbad                                  sinbad                          #50404d

=item sinbad                                  sinbad                          #242124

=item sirocco                                 sirocco                         #8c8767

=item siskin green                            siskingreen                     #b9b57d

=item sistine                                 sistine                         #66aabc

=item sistine                                 sistine                         #367588

=item sistine                                 sistine                         #91a3b0

=item sistine                                 sistine                         #536878

=item skating                                 skating                         #004958

=item ski                                     ski                             #355e3b

=item ski                                     ski                             #3b7861

=item skimmed-milk white                      skimmedmilkwhite                #dadfb7

=item skobeloff green                         skobeloffgreen                  #007a74

=item sky                                     sky                             #70a3cc

=item sky                                     sky                             #8791bf

=item sky blue                                skyblue                         #70a3cc

=item sky blue                                skyblue                         #8791bf

=item sky colour                              skycolour                       #70a3cc

=item sky colour                              skycolour                       #8791bf

=item sky green                               skygreen                        #c9dc89

=item slag                                    slag                            #555555

=item slate                                   slate                           #51585e

=item slate-black                             slateblack                      #222222

=item slate blue                              slateblue                       #536878

=item slate-blue                              slateblue                       #536878

=item slate [color]                           slatecolor                      #5d555b

=item slate-green                             slategreen                      #5e716a

=item slate-green                             slategreen                      #4e5755

=item slate-grey                              slategrey                       #8a8776

=item slate-grey                              slategrey                       #848482

=item slate-olive                             slateolive                      #4e5755

=item slate-purple                            slatepurple                     #50404d

=item slate-purple                            slatepurple                     #5d3954

=item slate-violet                            slateviolet                     #905d5d

=item smalt                                   smalt                           #00416a

=item smalt                                   smalt                           #436b95

=item smalt green                             smaltgreen                      #679267

=item smaltino                                smaltino                        #00416a

=item smaltino                                smaltino                        #436b95

=item smoke blue                              smokeblue                       #51585e

=item smoke brown                             smokebrown                      #555555

=item smoked pearl                            smokedpearl                     #555555

=item smoke grey                              smokegrey                       #dadfb7

=item smoke yellow                            smokeyellow                     #8c8767

=item smoke yellow                            smokeyellow                     #8a8776

=item snapdragon                              snapdragon                      #f8de7e

=item snapdragon                              snapdragon                      #c9ae5d

=item snowshoe                                snowshoe                        #eaa221

=item snowshoe                                snowshoe                        #e3a857

=item soapstone                               soapstone                       #635147

=item solferino                               solferino                       #a8516e

=item solitaire                               solitaire                       #43302e

=item solitaire                               solitaire                       #3e322c

=item somalis                                 somalis                         #9e4732

=item somalis                                 somalis                         #79443b

=item sombrero                                sombrero                        #c2b280

=item sonora                                  sonora                          #ae6938

=item sonora                                  sonora                          #a67b5b

=item soot brown                              sootbrown                       #635147

=item soot brown                              sootbrown                       #7e6d5a

=item sooty black                             sootyblack                      #222222

=item sorbier                                 sorbier                         #915f6d

=item sorghum brown                           sorghumbrown                    #977f73

=item sorghum brown                           sorghumbrown                    #958070

=item sorolla brown                           sorollabrown                    #80461b

=item sorrel                                  sorrel                          #ae6938

=item sorrel                                  sorrel                          #a67b5b

=item sorrento green                          sorrentogreen                   #317873

=item souci                                   souci                           #ed872d

=item source                                  source                          #679267

=item source                                  source                          #6aab8e

=item source                                  source                          #8da399

=item spalte                                  spalte                          #483c32

=item spaltum                                 spaltum                         #483c32

=item spanish brown                           spanishbrown                    #882d17

=item spanish cedar                           spanishcedar                    #905d5d

=item spanish cedar                           spanishcedar                    #79443b

=item spanish flesh                           spanishflesh                    #f3e5ab

=item spanish flesh                           spanishflesh                    #c2b280

=item spanish green                           spanishgreen                    #679267

=item spanish ochre                           spanishochre                    #ed872d

=item spanish raisin                          spanishraisin                   #43302e

=item spanish red                             spanishred                      #be0032

=item spanish red                             spanishred                      #882d17

=item spanish red                             spanishred                      #80461b

=item spanish wine                            spanishwine                     #722f37

=item spanish yellow                          spanishyellow                   #eaa221

=item spanish yellow                          spanishyellow                   #e3a857

=item spark                                   spark                           #be0032

=item sparrow                                 sparrow                         #5b504f

=item spa-tan                                 spatan                          #ae6938

=item spearmint                               spearmint                       #008856

=item sphinx                                  sphinx                          #7e6d5a

=item spice                                   spice                           #ae6938

=item spinach green                           spinachgreen                    #8a9a5b

=item spinach green                           spinachgreen                    #4a5d23

=item spinel pink                             spinelpink                      #a8516e

=item spinel red                              spinelred                       #bc3f4a

=item spinel red                              spinelred                       #b3446c

=item sponge                                  sponge                          #967117

=item spray                                   spray                           #96ded1

=item spring beauty                           springbeauty                    #ce4676

=item spring beauty                           springbeauty                    #b3446c

=item spring green                            springgreen                     #8a9a5b

=item spring green                            springgreen                     #93c592

=item springtime                              springtime                      #e4717a

=item sprite                                  sprite                          #00a693

=item sprite                                  sprite                          #66ada4

=item spruce                                  spruce                          #3a4b47

=item spruce                                  spruce                          #1e2321

=item spruce ochre                            spruceochre                     #ae6938

=item spruce ochre                            spruceochre                     #996515

=item spruce yellow                           spruceyellow                    #be8a3d

=item spruce yellow                           spruceyellow                    #c19a6b

=item squill blue                             squillblue                      #70a3cc

=item squirrel                                squirrel                        #5d555b

=item squirrel                                squirrel                        #555555

=item stag                                    stag                            #826644

=item starch blue                             starchblue                      #00416a

=item starch blue                             starchblue                      #436b95

=item stardew                                 stardew                         #536878

=item starflower                              starflower                      #c17e91

=item starlight                               starlight                       #91a3b0

=item starling                                starling                        #5b504f

=item st. benoit or saint benoit              stbenoitorsaintbenoit           #483c32

=item st. benoit or saint benoit              stbenoitorsaintbenoit           #222222

=item steel                                   steel                           #555555

=item steel grey                              steelgrey                       #555555

=item steeplechase                            steeplechase                    #545aa7

=item stil de grain brown                     stildegrainbrown                #be8a3d

=item stil de grain brown                     stildegrainbrown                #996515

=item stil de grain yellow                    stildegrainyellow               #fada5e

=item stil de grain yellow                    stildegrainyellow               #d4af37

=item stil de grain yellow                    stildegrainyellow               #f8de7e

=item stil de grain yellow                    stildegrainyellow               #c9ae5d

=item stone blue                              stoneblue                       #436b95

=item stone grey                              stonegrey                       #57554c

=item storm grey                              stormgrey                       #7d8984

=item strawberry                              strawberry                      #905d5d

=item strawberry pink                         strawberrypink                  #e4717a

=item strawberry pink                         strawberrypink                  #f88379

=item strawberry pink                         strawberrypink                  #e66761

=item straw [yellow]                          strawyellow                     #f3e5ab

=item striegau earth                          striegauearth                   #79443b

=item stroller tan                            strollertan                     #6f4e37

=item strontian yellow                        strontianyellow                 #e9e450

=item stucco                                  stucco                          #977f73

=item stucco                                  stucco                          #958070

=item succory blue                            succoryblue                     #dadfb7

=item sudan                                   sudan                           #a18f60

=item sudan                                   sudan                           #967117

=item sudan                                   sudan                           #8c8767

=item sudan brown                             sudanbrown                      #80461b

=item sudan brown                             sudanbrown                      #6f4e37

=item suede                                   suede                           #a67b5b

=item suede                                   suede                           #6f4e37

=item suede                                   suede                           #826644

=item sugar cane                              sugarcane                       #fad6a5

=item sugar cane                              sugarcane                       #c19a6b

=item sulphate green                          sulphategreen                   #66ada4

=item sulphate green                          sulphategreen                   #317873

=item sulphine yellow                         sulphineyellow                  #ab9144

=item sulphur                                 sulphur                         #eae679

=item sulphur [yellow]                        sulphuryellow                   #eae679

=item sultan                                  sultan                          #ab4e52

=item sultana                                 sultana                         #722f37

=item sultana                                 sultana                         #673147

=item sumac                                   sumac                           #be8a3d

=item sumac                                   sumac                           #996515

=item sumac                                   sumac                           #c19a6b

=item sumac                                   sumac                           #826644

=item sumac                                   sumac                           #ab9144

=item sumac                                   sumac                           #a18f60

=item sumac                                   sumac                           #967117

=item sunbeam                                 sunbeam                         #c2b280

=item sunburn                                 sunburn                         #a67b5b

=item sunburst                                sunburst                        #ed872d

=item sunburst                                sunburst                        #d99058

=item sundown                                 sundown                         #c19a6b

=item sunflower [yellow]                      sunfloweryellow                 #fada5e

=item sunglow                                 sunglow                         #e4717a

=item sunglow                                 sunglow                         #ab4e52

=item sungod                                  sungod                          #e25822

=item sunkiss                                 sunkiss                         #d99058

=item sunlight                                sunlight                        #c9ae5d

=item sunni                                   sunni                           #f8de7e

=item sunni                                   sunni                           #c9ae5d

=item sunray                                  sunray                          #e3a857

=item sunrise yellow                          sunriseyellow                   #d9a6a9

=item sunrise yellow                          sunriseyellow                   #d99058

=item sunset                                  sunset                          #fad6a5

=item sunstone                                sunstone                        #ae6938

=item suntan                                  suntan                          #a67b5b

=item suntan                                  suntan                          #c19a6b

=item suntan                                  suntan                          #826644

=item superior                                superior                        #004b49

=item surf green                              surfgreen                       #679267

=item surrey green                            surreygreen                     #8f9779

=item surrey green                            surreygreen                     #8da399

=item swamp                                   swamp                           #3a4b47

=item swedish green                           swedishgreen                    #7e9f2e

=item swedish green                           swedishgreen                    #44944a

=item sweet briar                             sweetbriar                      #de6fa1

=item sweetmeat                               sweetmeat                       #c19a6b

=item sweet pea                               sweetpea                        #c7ada3

=item sweet william                           sweetwilliam                    #e4717a

=item swiss blue                              swissblue                       #536878

=item swiss rose                              swissrose                       #ab4e52

=item syrup                                   syrup                           #967117

=item syrup                                   syrup                           #6c541e

=item taffy                                   taffy                           #c19a6b

=item talavera                                talavera                        #ae6938

=item tamarach                                tamarach                        #635147

=item tamarach                                tamarach                        #7e6d5a

=item ta-ming                                 taming                          #eaa221

=item ta-ming                                 taming                          #e3a857

=item tan                                     tan                             #ae6938

=item tanagra                                 tanagra                         #79443b

=item tanaura                                 tanaura                         #c2b280

=item tanbark                                 tanbark                         #6f4e37

=item tangerine                               tangerine                       #cb6d51

=item tangier                                 tangier                         #ed872d

=item tango pink                              tangopink                       #905d5d

=item tansan                                  tansan                          #a67b5b

=item tansan                                  tansan                          #c19a6b

=item tapestry                                tapestry                        #00304e

=item tapestry                                tapestry                        #252440

=item tapestry                                tapestry                        #4c516d

=item tapestry                                tapestry                        #8b8589

=item tapestry red                            tapestryred                     #722f37

=item tapis vert                              tapisvert                       #8a9a5b

=item tarragon                                tarragon                        #8a9a5b

=item tarragon                                tarragon                        #8f9779

=item tarragon                                tarragon                        #679267

=item tarragona                               tarragona                       #882d17

=item tarragona                               tarragona                       #80461b

=item tartan green                            tartangreen                     #3a4b47

=item taupe                                   taupe                           #483c32

=item tawny                                   tawny                           #ae6938

=item tawny                                   tawny                           #a67b5b

=item tawny birch                             tawnybirch                      #a87c6d

=item tawny birch                             tawnybirch                      #a67b5b

=item tawny birch                             tawnybirch                      #958070

=item tea                                     tea                             #8f9779

=item tea                                     tea                             #8da399

=item tea green                               teagreen                        #8f9779

=item teak [brown]                            teakbrown                       #6f4e37

=item teakwood                                teakwood                        #635147

=item teakwood                                teakwood                        #7e6d5a

=item teal blue                               tealblue                        #004958

=item teal blue                               tealblue                        #36454f

=item teal duck                               tealduck                        #004958

=item tea time                                teatime                         #967117

=item telegraph blue                          telegraphblue                   #796878

=item tennis                                  tennis                          #ab9144

=item tennis                                  tennis                          #a18f60

=item terra cotta                             terracotta                      #be6516

=item terra cotta                             terracotta                      #ae6938

=item terra japonica                          terrajaponica                   #6f4e37

=item terra lemnia                            terralemnia                     #79443b

=item terra merita                            terramerita                     #f8de7e

=item terra orellana                          terraorellana                   #d9a6a9

=item terra orellano                          terraorellano                   #d9a6a9

=item terrapin                                terrapin                        #6f4e37

=item terra pozzuoli                          terrapozzuoli                   #79443b

=item terra rosa                              terrarosa                       #79443b

=item terra siena                             terrasiena                      #ae6938

=item terra siena                             terrasiena                      #a67b5b

=item terra sigillata                         terrasigillata                  #79443b

=item terrasse                                terrasse                        #8a9a5b

=item terra umber                             terraumber                      #826644

=item terra umber                             terraumber                      #4b3621

=item testaceous                              testaceous                      #d99058

=item testaceous                              testaceous                      #a67b5b

=item thenard's blue                          thenardsblue                    #007791

=item thistle                                 thistle                         #86608e

=item thistle bloom                           thistlebloom                    #9e4f88

=item thistletuft                             thistletuft                     #702963

=item thrush                                  thrush                          #826644

=item thrush                                  thrush                          #7e6d5a

=item thulite pink                            thulitepink                     #de6fa1

=item thyme                                   thyme                           #3a4b47

=item tiber                                   tiber                           #1b4d3e

=item tiber green                             tibergreen                      #93c592

=item tiffin                                  tiffin                          #826644

=item tigerlily                               tigerlily                       #d9603b

=item tigerlily                               tigerlily                       #cb6d51

=item tile blue                               tileblue                        #367588

=item tile red                                tilered                         #cb6d51

=item tilleul buff                            tilleulbuff                     #ecd5c5

=item tilleul buff                            tilleulbuff                     #bfb8a5

=item tilleul [green]                         tilleulgreen                    #ebe8a4

=item tinsel                                  tinsel                          #ab9144

=item tinsel                                  tinsel                          #a18f60

=item tinsel                                  tinsel                          #967117

=item titania                                 titania                         #5d3954

=item titania                                 titania                         #673147

=item titian                                  titian                          #ae6938

=item titian gold                             titiangold                      #ae6938

=item titmouse blue                           titmouseblue                    #8da399

=item toast                                   toast                           #a67b5b

=item toasted almond                          toastedalmond                   #a67b5b

=item toboggan                                toboggan                        #e25822

=item toboggan                                toboggan                        #f38400

=item toga                                    toga                            #2f2140

=item tokay                                   tokay                           #79443b

=item tokyo                                   tokyo                           #ffb7a5

=item tokyo                                   tokyo                           #f88379

=item tokyo                                   tokyo                           #ed872d

=item toltec                                  toltec                          #e3a857

=item tomato [red]                            tomatored                       #9e4732

=item tommy red                               tommyred                        #bc3f4a

=item topaz                                   topaz                           #a67b5b

=item topaz                                   topaz                           #be8a3d

=item topaz                                   topaz                           #c19a6b

=item toquet                                  toquet                          #c7ada3

=item toreador                                toreador                        #e25822

=item torino blue                             torinoblue                      #536878

=item tortoise                                tortoise                        #80461b

=item tortoise shell                          tortoiseshell                   #6f4e37

=item totem                                   totem                           #9e4732

=item tourmaline                              tourmaline                      #66ada4

=item tourmaline pink                         tourmalinepink                  #915f6d

=item tourterelle                             tourterelle                     #967117

=item transparent chromium oxide              transparentchromiumoxide        #007959

=item transparent chromium oxide              transparentchromiumoxide        #3b7861

=item transparent gold ochre                  transparentgoldochre            #ae6938

=item transparent gold ochre                  transparentgoldochre            #996515

=item traprock                                traprock                        #555555

=item travertine                              travertine                      #967117

=item trentanel                               trentanel                       #eae679

=item trentanel                               trentanel                       #b9b459

=item trianon                                 trianon                         #d9a6a9

=item trianon                                 trianon                         #d99058

=item triton                                  triton                          #1b4d3e

=item triumph blue                            triumphblue                     #436b95

=item triumph blue                            triumphblue                     #00304e

=item trooper                                 trooper                         #00304e

=item trooper                                 trooper                         #36454f

=item trooper                                 trooper                         #202830

=item trotteur tan                            trotteurtan                     #6f4e37

=item troubador red                           troubadorred                    #bc3f4a

=item trublu                                  trublu                          #536878

=item tuileries                               tuileries                       #436b95

=item tulipwood                               tulipwood                       #6f4e37

=item tunis                                   tunis                           #36454f

=item tunis                                   tunis                           #202830

=item turbith mineral                         turbithmineral                  #f8de7e

=item turkey blue                             turkeyblue                      #4c516d

=item turkey red                              turkeyred                       #ab4e52

=item turkey umber                            turkeyumber                     #826644

=item turkey umber                            turkeyumber                     #4b3621

=item turkish blue                            turkishblue                     #4c516d

=item turkish crescent red                    turkishcrescentred              #841b2d

=item turkish crescent red                    turkishcrescentred              #722f37

=item turkish red                             turkishred                      #ab4e52

=item turmeric                                turmeric                        #f8de7e

=item turner's yellow                         turnersyellow                   #fada5e

=item turner's yellow                         turnersyellow                   #d4af37

=item turner's yellow                         turnersyellow                   #f8de7e

=item turner's yellow                         turnersyellow                   #c9ae5d

=item turquoise [blue]                        turquoiseblue                   #66ada4

=item turquoise green                         turquoisegreen                  #66ada4

=item turtle                                  turtle                          #6f4e37

=item turtledove                              turtledove                      #5c504f

=item turtledove                              turtledove                      #555555

=item turtle green                            turtlegreen                     #8a9a5b

=item tuscan                                  tuscan                          #fad6a5

=item tuscan brown                            tuscanbrown                     #79443b

=item tuscan brown                            tuscanbrown                     #6f4e37

=item tuscan red                              tuscanred                       #79443b

=item tuscan tan                              tuscantan                       #a67b5b

=item tuscany                                 tuscany                         #79443b

=item tussore                                 tussore                         #f4c2c2

=item tussore                                 tussore                         #d9a6a9

=item twilight [blue]                         twilightblue                    #536878

=item twine                                   twine                           #8c8767

=item twinkle blue                            twinkleblue                     #66aabc

=item tyrian blue                             tyrianblue                      #536878

=item tyrian blue                             tyrianblue                      #4c516d

=item tyrian pink                             tyrianpink                      #ce4676

=item tyrian violet                           tyrianviolet                    #a8516e

=item tyrol                                   tyrol                           #826644

=item tyrolese green                          tyrolesegreen                   #679267

=item tyrolian                                tyrolian                        #1a2421

=item tyrolite green                          tyrolitegreen                   #66ada4

=item tzarine                                 tzarine                         #1e2321

=item ultramarine green                       ultramarinegreen                #1e2321

=item ultramarine yellow                      ultramarineyellow               #d4af37

=item urania blue                             uraniablue                      #2f2140

=item vagabond green                          vagabondgreen                   #004b49

=item valencia                                valencia                        #de6fa1

=item vanda                                   vanda                           #796878

=item vanda                                   vanda                           #836479

=item vandyke brown                           vandykebrown                    #6f4e37

=item vandyke madder                          vandykemadder                   #a8516e

=item vandyke red                             vandykered                      #905d5d

=item vanilla                                 vanilla                         #f3e5ab

=item vanilla                                 vanilla                         #c2b280

=item vanity                                  vanity                          #d9a6a9

=item variscite green                         variscitegreen                  #6aab8e

=item varley's grey                           varleysgrey                     #796878

=item vassar rose                             vassarrose                      #c08081

=item vassar rose                             vassarrose                      #905d5d

=item vassar tan                              vassartan                       #80461b

=item vassar tan                              vassartan                       #6f4e37

=item vatican                                 vatican                         #563c5c

=item vatican                                 vatican                         #301934

=item veau d'or                               veaudor                         #fad6a5

=item veau d'or                               veaudor                         #c19a6b

=item vegetable red                           vegetablered                    #be0032

=item vegetable rouge                         vegetablerouge                  #be0032

=item velasquez                               velasquez                       #673147

=item velvet brown                            velvetbrown                     #826644

=item velvet brown                            velvetbrown                     #4b3621

=item velvet green                            velvetgreen                     #4a5d23

=item venet                                   venet                           #66ada4

=item venetian blue                           venetianblue                    #007791

=item venetian fuchsia                        venetianfuchsia                 #ce4676

=item venetian lake                           venetianlake                    #be0032

=item venetian lake                           venetianlake                    #bc3f4a

=item venetian pink                           venetianpink                    #dea5a4

=item venetian red                            venetianred                     #882d17

=item venetian rose                           venetianrose                    #841b2d

=item venetian rose                           venetianrose                    #ab4e52

=item venetian scarlet                        venetianscarlet                 #be0032

=item venetian yellow                         venetianyellow                  #f8de7e

=item venetian yellow                         venetianyellow                  #c9ae5d

=item venezia                                 venezia                         #317873

=item venice berries                          veniceberries                   #eaa221

=item venice berries                          veniceberries                   #e3a857

=item venice [blue]                           veniceblue                      #66ada4

=item venice green                            venicegreen                     #66ada4

=item venice red                              venicered                       #79443b

=item venus                                   venus                           #ab9144

=item venus                                   venus                           #a18f60

=item verbena                                 verbena                         #915c83

=item verbena [violet]                        verbenaviolet                   #9690ab

=item verbena [violet]                        verbenaviolet                   #aa98a9

=item verdant green                           verdantgreen                    #8a9a5b

=item verdet                                  verdet                          #679267

=item verde vessie                            verdevessie                     #867e36

=item verd gay                                verdgay                         #8a9a5b

=item verdigris [green]                       verdigrisgreen                  #679267

=item verditer green                          verditergreen                   #679267

=item verdure                                 verdure                         #355e3b

=item veridine green                          veridinegreen                   #6aab8e

=item vernonia purple                         vernoniapurple                  #915f6d

=item verona brown                            veronabrown                     #6f4e37

=item verona yellow                           veronayellow                    #fada5e

=item verona yellow                           veronayellow                    #d4af37

=item verona yellow                           veronayellow                    #f8de7e

=item verona yellow                           veronayellow                    #c9ae5d

=item veronese yellow                         veroneseyellow                  #fada5e

=item veronese yellow                         veroneseyellow                  #d4af37

=item veronese yellow                         veroneseyellow                  #f8de7e

=item veronese yellow                         veroneseyellow                  #c9ae5d

=item veronica                                veronica                        #604e81

=item versailles                              versailles                      #66aabc

=item vert russe                              vertrusse                       #679267

=item vert russe                              vertrusse                       #355e3b

=item vert russe                              vertrusse                       #5e716a

=item vervain                                 vervain                         #9690ab

=item vervain                                 vervain                         #aa98a9

=item vestal                                  vestal                          #796878

=item vestal                                  vestal                          #836479

=item veteran                                 veteran                         #36454f

=item vetiver green                           vetivergreen                    #8c8767

=item victoria                                victoria                        #563c5c

=item victoria blue                           victoriablue                    #0067a5

=item victoria green                          victoriagreen                   #6aab8e

=item victoria green                          victoriagreen                   #8da399

=item victoria green                          victoriagreen                   #66ada4

=item victoria lake                           victorialake                    #722f37

=item vienna blue                             viennablue                      #007791

=item vienna brown                            viennabrown                     #635147

=item vienna brown                            viennabrown                     #7e6d5a

=item vienna green                            viennagreen                     #3eb489

=item vienna lake                             viennalake                      #be0032

=item vienna lake                             viennalake                      #bc3f4a

=item vienna smoke                            viennasmoke                     #555555

=item vineyard                                vineyard                        #722f37

=item vineyard                                vineyard                        #3f1728

=item viola                                   viola                           #86608e

=item violet-carmine                          violetcarmine                   #5d3954

=item violine                                 violine                         #604e97

=item violine                                 violine                         #604e81

=item virgin                                  virgin                          #436b95

=item viridian                                viridian                        #007959

=item viridian                                viridian                        #3b7861

=item viridine green                          viridinegreen                   #c9dc89

=item viridine yellow                         viridineyellow                  #7e9f2e

=item vitelline yellow                        vitellineyellow                 #d4af37

=item vitellinous                             vitellinous                     #d4af37

=item vitreous                                vitreous                        #c9dc89

=item wad                                     wad                             #536878

=item wald                                    wald                            #eae679

=item wald                                    wald                            #b9b459

=item wallflower [brown]                      wallflowerbrown                 #722f37

=item wallflower [brown]                      wallflowerbrown                 #79443b

=item wall green                              wallgreen                       #007a74

=item walnut [brown]                          walnutbrown                     #c19a6b

=item warbler green                           warblergreen                    #867e36

=item warm sepia                              warmsepia                       #635147

=item water blue                              waterblue                       #317873

=item water-color                             watercolor                      #66ada4

=item water cress                             watercress                      #8a9a5b

=item waterfall                               waterfall                       #317873

=item water green                             watergreen                      #b9b57d

=item water green                             watergreen                      #c9dc89

=item water green                             watergreen                      #dadfb7

=item water grey                              watergrey                       #8a8776

=item waterloo                                waterloo                        #4c516d

=item watermelon                              watermelon                      #e4717a

=item watermelon                              watermelon                      #ab4e52

=item water sprite                            watersprite                     #93c592

=item watteau                                 watteau                         #70a3cc

=item wau                                     wau                             #eae679

=item wau                                     wau                             #b9b459

=item wax brown                               waxbrown                        #826644

=item wax color                               waxcolor                        #ebe8a4

=item wax color                               waxcolor                        #b9b57d

=item waxen                                   waxen                           #ebe8a4

=item waxen                                   waxen                           #b9b57d

=item wax red                                 waxred                          #b4745e

=item wax white                               waxwhite                        #ebe8a4

=item wax white                               waxwhite                        #b9b57d

=item wax yellow                              waxyellow                       #c9ae5d

=item weathered oak                           weatheredoak                    #422518

=item weigelia                                weigelia                        #ab4e52

=item weld                                    weld                            #eae679

=item weld                                    weld                            #b9b459

=item westminster                             westminster                     #30267a

=item westminster                             westminster                     #9065ca

=item west point                              westpoint                       #51585e

=item wheat                                   wheat                           #e3a857

=item wheat                                   wheat                           #fad6a5

=item whippet                                 whippet                         #6c541e

=item whirlpool                               whirlpool                       #004958

=item white blue                              whiteblue                       #b4bcc0

=item white jade                              whitejade                       #ecd5c5

=item white jade                              whitejade                       #bfb8a5

=item wield                                   wield                           #eae679

=item wield                                   wield                           #b9b459

=item wigwam                                  wigwam                          #6f4e37

=item wild aster                              wildaster                       #602f6b

=item wild aster                              wildaster                       #702963

=item wild cherry                             wildcherry                      #722f37

=item wild cherry                             wildcherry                      #673147

=item wild dove grey                          wilddovegrey                    #5b504f

=item wild honey                              wildhoney                       #ae6938

=item wild honey                              wildhoney                       #a67b5b

=item wild iris                               wildiris                        #8b8589

=item wild orchid                             wildorchid                      #836479

=item wild pigeon                             wildpigeon                      #5b504f

=item wild raspberry                          wildraspberry                   #722f37

=item wild raspberry                          wildraspberry                   #673147

=item wild rose                               wildrose                        #c08081

=item wild strawberry                         wildstrawberry                  #841b2d

=item wild strawberry                         wildstrawberry                  #722f37

=item willow                                  willow                          #665d1e

=item willow green                            willowgreen                     #867e36

=item windflower                              windflower                      #915f6d

=item windsor                                 windsor                         #563c5c

=item windsor blue                            windsorblue                     #4c516d

=item windsor green                           windsorgreen                    #355e3b

=item windsor tan                             windsortan                      #ae6938

=item wineberry                               wineberry                       #673147

=item wine dregs                              winedregs                       #722f37

=item wine dregs                              winedregs                       #56070c

=item wine dregs                              winedregs                       #3e1d1e

=item wine lees                               winelees                        #722f37

=item wine lees                               winelees                        #56070c

=item wine lees                               winelees                        #3e1d1e

=item wine yellow                             wineyellow                      #f3e5ab

=item wine yellow                             wineyellow                      #c2b280

=item winter green                            wintergreen                     #679267

=item wintergreen                             wintergreen                     #355e3b

=item winter leaf                             winterleaf                      #635147

=item wireless                                wireless                        #436b95

=item wistaria [blue]                         wistariablue                    #8c82b6

=item wistaria blue                           wistariablue                    #8791bf

=item wistaria [violet]                       wistariaviolet                  #8c82b6

=item witchwood                               witchwood                       #6f4e37

=item withered leaf                           witheredleaf                    #be6516

=item withered leaf                           witheredleaf                    #ae6938

=item withered leaf                           witheredleaf                    #80461b

=item withered rose                           witheredrose                    #905d5d

=item withered rose                           witheredrose                    #79443b

=item woad                                    woad                            #536878

=item woald                                   woald                           #eae679

=item woald                                   woald                           #b9b459

=item wod                                     wod                             #eae679

=item wod                                     wod                             #b9b459

=item wode                                    wode                            #536878

=item wold                                    wold                            #eae679

=item wold                                    wold                            #b9b459

=item woodash                                 woodash                         #bfb8a5

=item woodbark                                woodbark                        #7e6d5a

=item woodbine green                          woodbinegreen                   #8a9a5b

=item woodbine green                          woodbinegreen                   #8f9779

=item woodbine green                          woodbinegreen                   #4a5d23

=item woodbine green                          woodbinegreen                   #515744

=item woodland brown                          woodlandbrown                   #483c32

=item woodland brown                          woodlandbrown                   #222222

=item woodland green                          woodlandgreen                   #4a5d23

=item woodland rose                           woodlandrose                    #a67b5b

=item wood rose                               woodrose                        #977f73

=item wood rose                               woodrose                        #958070

=item wood violet                             woodviolet                      #602f6b

=item wren                                    wren                            #363527

=item wren                                    wren                            #57554c

=item wrought iron                            wroughtiron                     #555555

=item yacht                                   yacht                           #0067a5

=item yale blue                               yaleblue                        #00416a

=item yama                                    yama                            #66ada4

=item yellow beige                            yellowbeige                     #c19a6b

=item yellow beige                            yellowbeige                     #826644

=item yellow berries                          yellowberries                   #eaa221

=item yellow berries                          yellowberries                   #e3a857

=item yellow brazil wood                      yellowbrazilwood                #c9ae5d

=item yellow brazil wood                      yellowbrazilwood                #c2b280

=item yellow carmine                          yellowcarmine                   #eaa221

=item yellow carmine                          yellowcarmine                   #e3a857

=item yellow daisy                            yellowdaisy                     #fada5e

=item yellow daisy                            yellowdaisy                     #d4af37

=item yellow daisy                            yellowdaisy                     #f8de7e

=item yellow daisy                            yellowdaisy                     #c9ae5d

=item yellow earth                            yellowearth                     #e3a857

=item yellow madder                           yellowmadder                    #fada5e

=item yellow madder                           yellowmadder                    #d4af37

=item yellow madder                           yellowmadder                    #f8de7e

=item yellow madder                           yellowmadder                    #c9ae5d

=item yellow ochre                            yellowochre                     #e3a857

=item yellow realgar                          yellowrealgar                   #fada5e

=item yellow realgar                          yellowrealgar                   #d4af37

=item yellow realgar                          yellowrealgar                   #f8de7e

=item yellow realgar                          yellowrealgar                   #c9ae5d

=item yellow sienna                           yellowsienna                    #e3a857

=item yellow stone                            yellowstone                     #b9b57d

=item yellowstone                             yellowstone                     #a18f60

=item yellow wash                             yellowwash                      #e3a857

=item yellow wood                             yellowwood                      #c9ae5d

=item yellow wood                             yellowwood                      #c2b280

=item yew green                               yewgreen                        #4a5d23

=item yolk yellow                             yolkyellow                      #d4af37

=item yosemite                                yosemite                        #c19a6b

=item yucatan                                 yucatan                         #ae6938

=item yucatan                                 yucatan                         #996515

=item yucca                                   yucca                           #5e716a

=item yu chi                                  yuchi                           #1b4d3e

=item yvette violet                           yvetteviolet                    #796878

=item zaffre blue                             zaffreblue                      #00416a

=item zaffre blue                             zaffreblue                      #436b95

=item zanzibar                                zanzibar                        #43302e

=item zedoary wash                            zedoarywash                     #e3a857

=item zenith [blue]                           zenithblue                      #8791bf

=item zenith [blue]                           zenithblue                      #8c92ac

=item zephyr                                  zephyr                          #ead8d7

=item zephyr                                  zephyr                          #c4aead

=item zinc                                    zinc                            #8b8589

=item zinc                                    zinc                            #848482

=item zinc green                              zincgreen                       #679267

=item zinc orange                             zincorange                      #ed872d

=item zinc orange                             zincorange                      #d99058

=item zinc yellow                             zincyellow                      #d4af37

=item zinnia                                  zinnia                          #ab4e52

=item zulu                                    zulu                            #43302e

=item zuni brown                              zunibrown                       #6f4e37


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-m:abbey.207','abbey','abbey',[96,78,151],'604e97',6311575],
['nbs-iscc-m:absinthegreen.120','absinthegreen','absinthe [green] ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:absintheyellow.105','absintheyellow','absinthe yellow',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:acacia.101','acacia','acacia',[234,230,121],'eae679',15394425],
['nbs-iscc-m:acacia.102','acacia','acacia',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:academyblue.173','academyblue','academy blue',[54,117,136],'367588',3569032],
['nbs-iscc-m:acajou.43','acajou','acajou',[121,68,59],'79443b',7947323],
['nbs-iscc-m:acanthe.95','acanthe','acanthe',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:acier.109','acier','acier',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:ackermannsgreen.137','ackermannsgreen','ackermann\'s green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:aconiteviolet.223','aconiteviolet','aconite violet',[134,96,142],'86608e',8806542],
['nbs-iscc-m:acorn.80','acorn','acorn',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:adamia.224','adamia','adamia',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:adelaide.208','adelaide','adelaide',[50,23,77],'32174d',3282765],
['nbs-iscc-m:aden.144','aden','aden',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:admiral.230','admiral','admiral',[41,30,41],'291e29',2694697],
['nbs-iscc-m:admiral.235','admiral','admiral',[36,33,36],'242124',2367780],
['nbs-iscc-m:adobe.77','adobe','adobe',[130,102,68],'826644',8545860],
['nbs-iscc-m:adrianoplered.15','adrianoplered','adrianople red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:adriatic.164','adriatic','adriatic',[49,120,115],'317873',3242099],
['nbs-iscc-m:adust.54','adust','adust',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:aero.186','aero','aero',[83,104,120],'536878',5466232],
['nbs-iscc-m:afghan.62','afghan','afghan',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:afghanred.11','afghanred','afghan red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:african.267','african','african',[34,34,34],'222222',2236962],
['nbs-iscc-m:africanbrown.62','africanbrown','african brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:afterglow.214','afterglow','afterglow',[150,144,171],'9690ab',9867435],
['nbs-iscc-m:agate.40','agate','agate',[136,45,23],'882d17',8924439],
['nbs-iscc-m:agate.55','agate','agate',[128,70,27],'80461b',8406555],
['nbs-iscc-m:agategrey.264','agategrey','agate grey',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:ageratumblue.227','ageratumblue','ageratum blue',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:ageratumviolet.228','ageratumviolet','ageratum violet',[121,104,120],'796878',7956600],
['nbs-iscc-m:airblue.182','airblue','air blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:airedale.77','airedale','airedale',[130,102,68],'826644',8545860],
['nbs-iscc-m:airedale.80','airedale','airedale',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:airway.181','airway','airway',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:akbar.41','akbar','akbar',[86,7,12],'56070c',5637900],
['nbs-iscc-m:akbar.43','akbar','akbar',[121,68,59],'79443b',7947323],
['nbs-iscc-m:alabaster.31','alabaster','alabaster',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-m:alabaster.93','alabaster','alabaster',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:alamo.55','alamo','alamo',[128,70,27],'80461b',8406555],
['nbs-iscc-m:alcanna.40','alcanna','alcanna',[136,45,23],'882d17',8924439],
['nbs-iscc-m:alcazar.16','alcazar','alcazar',[114,47,55],'722f37',7483191],
['nbs-iscc-m:alcazar.40','alcazar','alcazar',[136,45,23],'882d17',8924439],
['nbs-iscc-m:alderney.77','alderney','alderney',[130,102,68],'826644',8545860],
['nbs-iscc-m:alesan.45','alesan','alesan',[151,127,115],'977f73',9928563],
['nbs-iscc-m:alesan.57','alesan','alesan',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:alesan.60','alesan','alesan',[149,128,112],'958070',9797744],
['nbs-iscc-m:alexandriablue.176','alexandriablue','alexandria blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:alexandriablue.178','alexandriablue','alexandria blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:alfalfa.137','alfalfa','alfalfa',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:algerian.58','algerian','algerian',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:algerianred.41','algerianred','algerian red',[86,7,12],'56070c',5637900],
['nbs-iscc-m:algonquin.51','algonquin','algonquin',[190,101,22],'be6516',12477718],
['nbs-iscc-m:algonquin.54','algonquin','algonquin',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:alhambra.151','alhambra','alhambra',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:alhambra.165','alhambra','alhambra',[0,75,73],'004b49',19273],
['nbs-iscc-m:aliceblue.185','aliceblue','alice blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:alkermes.11','alkermes','alkermes',[190,0,50],'be0032',12451890],
['nbs-iscc-m:almond.57','almond','almond',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:almond.60','almond','almond',[149,128,112],'958070',9797744],
['nbs-iscc-m:almond.76','almond','almond',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:almond.79','almond','almond',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:almondblossom.4','almondblossom','almond blossom',[249,204,202],'f9ccca',16370890],
['nbs-iscc-m:almondblossom.5','almondblossom','almond blossom',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:almondblossom.7','almondblossom','almond blossom',[234,216,215],'ead8d7',15390935],
['nbs-iscc-m:almondblossom.8','almondblossom','almond blossom',[196,174,173],'c4aead',12889773],
['nbs-iscc-m:almondbrown.57','almondbrown','almond brown ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:almondbrown.60','almondbrown','almond brown ',[149,128,112],'958070',9797744],
['nbs-iscc-m:almondbrown.76','almondbrown','almond brown ',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:almondbrown.79','almondbrown','almond brown ',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:almondgreen.150','almondgreen','almond green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:almondpink.4','almondpink','almond [pink] ',[249,204,202],'f9ccca',16370890],
['nbs-iscc-m:almondpink.5','almondpink','almond [pink] ',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:almondpink.7','almondpink','almond [pink] ',[234,216,215],'ead8d7',15390935],
['nbs-iscc-m:almondpink.8','almondpink','almond [pink] ',[196,174,173],'c4aead',12889773],
['nbs-iscc-m:aloesgreen.149','aloesgreen','aloes [green] ',[141,163,153],'8da399',9282457],
['nbs-iscc-m:aloma.57','aloma','aloma',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:aloma.76','aloma','aloma',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:aloma.77','aloma','aloma',[130,102,68],'826644',8545860],
['nbs-iscc-m:alpine.186','alpine','alpine',[83,104,120],'536878',5466232],
['nbs-iscc-m:alpinegreen.151','alpinegreen','alpine green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:aluminum.264','aluminum','aluminum',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:aluminum.265','aluminum','aluminum',[132,132,130],'848482',8684674],
['nbs-iscc-m:amaranth.238','amaranth','amaranth',[112,41,99],'702963',7350627],
['nbs-iscc-m:amaranthine.259','amaranthine','amaranthine',[103,49,71],'673147',6762823],
['nbs-iscc-m:amaranthpink.248','amaranthpink','amaranth pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-m:amaranthpurple.256','amaranthpurple','amaranth purple',[120,24,74],'78184a',7870538],
['nbs-iscc-m:amarna.142','amarna','amarna',[0,84,61],'00543d',21565],
['nbs-iscc-m:amarna.146','amarna','amarna',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:amarylis.15','amarylis','amarylis',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:amarylis.19','amarylis','amarylis',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:amazon.145','amazon','amazon',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:amberbrown.54','amberbrown','amber brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:amberglow.54','amberglow','amberglow',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:amberglow.57','amberglow','amberglow',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:amberwhite.89','amberwhite','amber white',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:amberwhite.90','amberwhite','amber white',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:amberwhite.104','amberwhite','amber white',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-m:amberwhite.105','amberwhite','amber white',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:amberwhite.121','amberwhite','amber white',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:amberyellow.86','amberyellow','amber [yellow] ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:amberyellow.87','amberyellow','amber [yellow] ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:ambrosia.43','ambrosia','ambrosia',[121,68,59],'79443b',7947323],
['nbs-iscc-m:ambulance.47','ambulance','ambulance',[67,48,46],'43302e',4403246],
['nbs-iscc-m:amelie.62','amelie','amelie',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:americanbeauty.16','americanbeauty','american beauty',[114,47,55],'722f37',7483191],
['nbs-iscc-m:americangreen.136','americangreen','american green',[103,146,103],'679267',6787687],
['nbs-iscc-m:americangreen.137','americangreen','american green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:americangreen.150','americangreen','american green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:amethystviolet.223','amethystviolet','amethyst [violet] ',[134,96,142],'86608e',8806542],
['nbs-iscc-m:amethystviolet.224','amethystviolet','amethyst [violet] ',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:amethystviolet.228','amethystviolet','amethyst [violet] ',[121,104,120],'796878',7956600],
['nbs-iscc-m:amparoblue.178','amparoblue','amparo blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:amparoblue.195','amparoblue','amparo blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-m:amparopurple.223','amparopurple','amparo purple',[134,96,142],'86608e',8806542],
['nbs-iscc-m:amulet.165','amulet','amulet',[0,75,73],'004b49',19273],
['nbs-iscc-m:anamite.109','anamite','anamite',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:anatolia.41','anatolia','anatolia',[86,7,12],'56070c',5637900],
['nbs-iscc-m:anatta.29','anatta','anatta',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:andorra.44','andorra','andorra',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-m:andorra.47','andorra','andorra',[67,48,46],'43302e',4403246],
['nbs-iscc-m:andorre.136','andorre','andorre',[103,146,103],'679267',6787687],
['nbs-iscc-m:andorre.150','andorre','andorre',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:andovergreen.127','andovergreen','andover green',[81,87,68],'515744',5330756],
['nbs-iscc-m:andrinopleberries.68','andrinopleberries','andrinople berries',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:andrinopleberries.71','andrinopleberries','andrinople berries',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:anemone.244','anemone','anemone',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-m:angelred.43','angelred','angel red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:animalrouge.11','animalrouge','animal rouge',[190,0,50],'be0032',12451890],
['nbs-iscc-m:animalrouge.12','animalrouge','animal rouge',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:annapolis.266','annapolis','annapolis',[85,85,85],'555555',5592405],
['nbs-iscc-m:annatto.29','annatto','annatto',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:annotto.29','annotto','annotto',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:antelope.94','antelope','antelope',[150,113,23],'967117',9859351],
['nbs-iscc-m:antimonyyellow.71','antimonyyellow','antimony yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:antique.94','antique','antique',[150,113,23],'967117',9859351],
['nbs-iscc-m:antique.95','antique','antique',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:antiquebrass.106','antiquebrass','antique brass',[134,126,54],'867e36',8814134],
['nbs-iscc-m:antiquebrass.109','antiquebrass','antique brass',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:antiquebronze.77','antiquebronze','antique bronze',[130,102,68],'826644',8545860],
['nbs-iscc-m:antiquebrown.58','antiquebrown','antique brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:antiquedrab.77','antiquedrab','antique drab',[130,102,68],'826644',8545860],
['nbs-iscc-m:antiquedrab.94','antiquedrab','antique drab',[150,113,23],'967117',9859351],
['nbs-iscc-m:antiquedrab.95','antiquedrab','antique drab',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:antiquefuchsia.223','antiquefuchsia','antique fuchsia',[134,96,142],'86608e',8806542],
['nbs-iscc-m:antiquefuchsia.241','antiquefuchsia','antique fuchsia',[145,92,131],'915c83',9526403],
['nbs-iscc-m:antiquegold.72','antiquegold','antique gold',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:antiquegold.74','antiquegold','antique gold',[153,101,21],'996515',10052885],
['nbs-iscc-m:antiquegreen.151','antiquegreen','antique green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:antiquered.37','antiquered','antique red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:antiquered.38','antiquered','antique red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:antiquered.39','antiquered','antique red',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:antiquered.43','antiquered','antique red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:antiqueruby.13','antiqueruby','antique ruby',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:antwerpblue.170','antwerpblue','antwerp blue',[46,132,149],'2e8495',3048597],
['nbs-iscc-m:antwerpblue.182','antwerpblue','antwerp blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:antwerpbrown.81','antwerpbrown','antwerp brown',[72,60,50],'483c32',4734002],
['nbs-iscc-m:antwerpred.43','antwerpred','antwerp red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:apache.58','apache','apache',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:aphrodite.163','aphrodite','aphrodite',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:appleblossompink.19','appleblossompink','appleblossom [pink] ',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:applefallow.13','applefallow','apple-fallow',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:applefallow.15','applefallow','apple-fallow',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:applegreen.120','applegreen','apple green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:apricot.53','apricot','apricot',[217,144,88],'d99058',14258264],
['nbs-iscc-m:apricotyellow.86','apricotyellow','apricot yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:apricotyellow.87','apricotyellow','apricot yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:aquagreen.135','aquagreen','aquagreen',[147,197,146],'93c592',9684370],
['nbs-iscc-m:aquamarine.172','aquamarine','aquamarine',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:aquamarine.185','aquamarine','aquamarine',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:arabbrown.55','arabbrown','arab [brown] ',[128,70,27],'80461b',8406555],
['nbs-iscc-m:arabesque.37','arabesque','arabesque',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:arabianbrown.55','arabianbrown','arabian brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:arabianbrown.58','arabianbrown','arabian brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:arabianred.41','arabianred','arabian red',[86,7,12],'56070c',5637900],
['nbs-iscc-m:araby.39','araby','araby',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:araby.42','araby','araby',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:aragon.43','aragon','aragon',[121,68,59],'79443b',7947323],
['nbs-iscc-m:arbutus.2','arbutus','arbutus',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:arbutus.3','arbutus','arbutus',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:arbutus.247','arbutus','arbutus',[230,143,172],'e68fac',15110060],
['nbs-iscc-m:arbutus.248','arbutus','arbutus',[222,111,161],'de6fa1',14577569],
['nbs-iscc-m:arcadiangreen.135','arcadiangreen','arcadian green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:archel.258','archel','archel',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:archil.258','archil','archil ',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:arctic.267','arctic','arctic',[34,34,34],'222222',2236962],
['nbs-iscc-m:arcticblue.186','arcticblue','arctic blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:ardoise.186','ardoise','ardoise',[83,104,120],'536878',5466232],
['nbs-iscc-m:ardoise.228','ardoise','ardoise',[121,104,120],'796878',7956600],
['nbs-iscc-m:argali.64','argali','argali',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:argali.266','argali','argali',[85,85,85],'555555',5592405],
['nbs-iscc-m:argent.265','argent','argent',[132,132,130],'848482',8684674],
['nbs-iscc-m:argentina.59','argentina','argentina',[66,37,24],'422518',4334872],
['nbs-iscc-m:argusbrown.58','argusbrown','argus brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:argylepurple.244','argylepurple','argyle purple',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-m:argylepurple.245','argylepurple','argyle purple',[131,100,121],'836479',8610937],
['nbs-iscc-m:arizona.76','arizona','arizona',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:armada.47','armada','armada',[67,48,46],'43302e',4403246],
['nbs-iscc-m:armada.62','armada','armada',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:armenianblue.176','armenianblue','armenian blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:armenianblue.178','armenianblue','armenian blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:armenianbole.43','armenianbole','armenian bole',[121,68,59],'79443b',7947323],
['nbs-iscc-m:armenianred.55','armenianred','armenian red',[128,70,27],'80461b',8406555],
['nbs-iscc-m:armenianstone.182','armenianstone','armenian stone',[67,107,149],'436b95',4418453],
['nbs-iscc-m:armybrown.57','armybrown','army brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:arnoblue.173','arnoblue','arno blue',[54,117,136],'367588',3569032],
['nbs-iscc-m:arnoblue.174','arnoblue','arno blue',[0,73,88],'004958',18776],
['nbs-iscc-m:arnotto.29','arnotto','arnotto',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:arona.187','arona','arona',[54,69,79],'36454f',3556687],
['nbs-iscc-m:arrowwood.94','arrowwood','arrowwood',[150,113,23],'967117',9859351],
['nbs-iscc-m:arsenate.141','arsenate','arsenate',[0,121,89],'007959',31065],
['nbs-iscc-m:artbrown.59','artbrown','art brown',[66,37,24],'422518',4334872],
['nbs-iscc-m:artemesiagreen.155','artemesiagreen','artemesia green',[125,137,132],'7d8984',8227204],
['nbs-iscc-m:artgrayartgrey.233','artgrayartgrey','art gray, art grey',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:artgrayartgrey.265','artgrayartgrey','art gray, art grey',[132,132,130],'848482',8684674],
['nbs-iscc-m:artgreen.120','artgreen','art green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:artgreen.125','artgreen','art green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:artichokegreen.122','artichokegreen','artichoke green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:artificialvermilion.262','artificialvermilion','artificial vermilion',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:artillery.11','artillery','artillery',[190,0,50],'be0032',12451890],
['nbs-iscc-m:ascottan.61','ascottan','ascot tan',[99,81,71],'635147',6508871],
['nbs-iscc-m:ashesofrose.262','ashesofrose','ashes of rose',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:ashgrey.154','ashgrey','ash [grey] ',[178,190,181],'b2beb5',11714229],
['nbs-iscc-m:asmalte.179','asmalte','asmalte',[0,65,106],'00416a',16746],
['nbs-iscc-m:asmalte.182','asmalte','asmalte',[67,107,149],'436b95',4418453],
['nbs-iscc-m:asparagusgreen.121','asparagusgreen','asparagus green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:aspengreen.150','aspengreen','aspen green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:asphalt.266','asphalt','asphalt',[85,85,85],'555555',5592405],
['nbs-iscc-m:asphaltum.81','asphaltum','asphaltum',[72,60,50],'483c32',4734002],
['nbs-iscc-m:asphodelgreen.120','asphodelgreen','asphodel green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:aster.228','aster','aster',[121,104,120],'796878',7956600],
['nbs-iscc-m:asterpurple.256','asterpurple','aster purple',[120,24,74],'78184a',7870538],
['nbs-iscc-m:athenia.19','athenia','athenia',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:atlantic.187','atlantic','atlantic',[54,69,79],'36454f',3556687],
['nbs-iscc-m:atlantis.174','atlantis','atlantis',[0,73,88],'004958',18776],
['nbs-iscc-m:atlantis.187','atlantis','atlantis',[54,69,79],'36454f',3556687],
['nbs-iscc-m:atmosphere.33','atmosphere','atmosphere',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:atmosphere.79','atmosphere','atmosphere',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:atmosphere.93','atmosphere','atmosphere',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:atramentous.192','atramentous','atramentous',[81,88,94],'51585e',5331038],
['nbs-iscc-m:attarofroses.39','attarofroses','attar of roses',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:attarofroses.42','attarofroses','attar of roses',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:aubergine.230','aubergine','aubergine',[41,30,41],'291e29',2694697],
['nbs-iscc-m:aubergine.235','aubergine','aubergine',[36,33,36],'242124',2367780],
['nbs-iscc-m:auburn.58','auburn','auburn',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:aubusson.16','aubusson','aubusson',[114,47,55],'722f37',7483191],
['nbs-iscc-m:aucuba.106','aucuba','aucuba',[134,126,54],'867e36',8814134],
['nbs-iscc-m:aureolin.83','aureolin','aureolin',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:aureolin.84','aureolin','aureolin',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:auriculapurple.238','auriculapurple','auricula purple',[112,41,99],'702963',7350627],
['nbs-iscc-m:auripigmentum.83','auripigmentum','auripigmentum',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:auripigmentum.84','auripigmentum','auripigmentum',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:auripigmentum.86','auripigmentum','auripigmentum',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:auripigmentum.87','auripigmentum','auripigmentum',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:auroraorange.26','auroraorange','aurora [orange] ',[248,131,121],'f88379',16286585],
['nbs-iscc-m:auroraorange.27','auroraorange','aurora [orange] ',[230,103,97],'e66761',15099745],
['nbs-iscc-m:auroraorange.37','auroraorange','aurora [orange] ',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:aurorared.15','aurorared','aurora red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:aurorared.27','aurorared','aurora red',[230,103,97],'e66761',15099745],
['nbs-iscc-m:aurorared.37','aurorared','aurora red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:aurorayellow.50','aurorayellow','aurora yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:aurorayellow.53','aurorayellow','aurora yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:aurorayellow.68','aurorayellow','aurora yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:aurorayellow.71','aurorayellow','aurora yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:aurore.5','aurore','aurore',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:aurum.94','aurum','aurum',[150,113,23],'967117',9859351],
['nbs-iscc-m:australianpine.137','australianpine','australian pine',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:auteuil.71','auteuil','auteuil',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:autumn.110','autumn','autumn',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:autumn.111','autumn','autumn',[54,53,39],'363527',3552551],
['nbs-iscc-m:autumnblonde.45','autumnblonde','autumn blonde',[151,127,115],'977f73',9928563],
['nbs-iscc-m:autumnblonde.58','autumnblonde','autumn blonde',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:autumnblonde.60','autumnblonde','autumn blonde',[149,128,112],'958070',9797744],
['nbs-iscc-m:autumnblonde.61','autumnblonde','autumn blonde',[99,81,71],'635147',6508871],
['nbs-iscc-m:autumnbrown.81','autumnbrown','autumn brown',[72,60,50],'483c32',4734002],
['nbs-iscc-m:autumnglory.16','autumnglory','autumn glory',[114,47,55],'722f37',7483191],
['nbs-iscc-m:autumnglory.38','autumnglory','autumn glory',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:autumngreen.120','autumngreen','autumn green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:autumngreen.125','autumngreen','autumn green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:autumnleaf.51','autumnleaf','autumn leaf',[190,101,22],'be6516',12477718],
['nbs-iscc-m:autumnleaf.54','autumnleaf','autumn leaf',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:autumnleaf.55','autumnleaf','autumn leaf',[128,70,27],'80461b',8406555],
['nbs-iscc-m:autumnoak.46','autumnoak','autumn oak',[103,76,71],'674c47',6769735],
['nbs-iscc-m:avellaneous.57','avellaneous','avellaneous',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:avellaneous.74','avellaneous','avellaneous',[153,101,21],'996515',10052885],
['nbs-iscc-m:avignonberries.68','avignonberries','avignon berries',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:avignonberries.71','avignonberries','avignon berries',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:azalea.19','azalea','azalea',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:aztec.74','aztec','aztec',[153,101,21],'996515',10052885],
['nbs-iscc-m:aztec.76','aztec','aztec',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:aztec.77','aztec','aztec',[130,102,68],'826644',8545860],
['nbs-iscc-m:aztecmaroon.262','aztecmaroon','aztec maroon',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:azulin.186','azulin','azulin',[83,104,120],'536878',5466232],
['nbs-iscc-m:babyblue.185','babyblue','baby blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:babyblue.190','babyblue','baby blue',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:babyblue.191','babyblue','baby blue',[129,135,139],'81878b',8488843],
['nbs-iscc-m:babypink.28','babypink','baby pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-m:babypink.29','babypink','baby pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:babyrose.26','babyrose','baby rose',[248,131,121],'f88379',16286585],
['nbs-iscc-m:bacchus.258','bacchus','bacchus',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:bachelorbutton.3','bachelorbutton','bachelor button',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:bagdad.183','bagdad','bagdad',[0,48,78],'00304e',12366],
['nbs-iscc-m:bagdad.187','bagdad','bagdad',[54,69,79],'36454f',3556687],
['nbs-iscc-m:bagdad.188','bagdad','bagdad',[32,40,48],'202830',2107440],
['nbs-iscc-m:bakstgreen.146','bakstgreen','bakst green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:balgeyellow.83','balgeyellow','balge yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:balllake.11','balllake','ball lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:balllake.12','balllake','ball lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:balsam.187','balsam','balsam',[54,69,79],'36454f',3556687],
['nbs-iscc-m:balsamgreen.267','balsamgreen','balsam green',[34,34,34],'222222',2236962],
['nbs-iscc-m:baltic.151','baltic','baltic',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:baltic.165','baltic','baltic',[0,75,73],'004b49',19273],
['nbs-iscc-m:bambino.185','bambino','bambino',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:bamboo.76','bamboo','bamboo',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:bamboo.77','bamboo','bamboo',[130,102,68],'826644',8545860],
['nbs-iscc-m:banana.90','banana','banana',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:banner.204','banner','banner',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:banshee.151','banshee','banshee',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:barberry.13','barberry','barberry',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:barberry.15','barberry','barberry',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:bark.96','bark','bark',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:barwood.15','barwood','barwood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:basketball.205','basketball','basketball',[144,101,202],'9065ca',9463242],
['nbs-iscc-m:bastardsaffron.11','bastardsaffron','bastard saffron',[190,0,50],'be0032',12451890],
['nbs-iscc-m:bat.266','bat','bat',[85,85,85],'555555',5592405],
['nbs-iscc-m:bathstone.73','bathstone','bath stone',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:battleshipgrey.265','battleshipgrey','battleship grey',[132,132,130],'848482',8684674],
['nbs-iscc-m:bay.58','bay','bay',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:bayou.151','bayou','bayou',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:beach.109','beach','beach',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:beach.112','beach','beach',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:beachtan.61','beachtan','beach tan ',[99,81,71],'635147',6508871],
['nbs-iscc-m:bear.266','bear','bear',[85,85,85],'555555',5592405],
['nbs-iscc-m:bearshair.266','bearshair','bear\'s hair',[85,85,85],'555555',5592405],
['nbs-iscc-m:bearskingrey.266','bearskingrey','bearskin [grey] ',[85,85,85],'555555',5592405],
['nbs-iscc-m:beaucaire.169','beaucaire','beaucaire',[0,119,145],'007791',30609],
['nbs-iscc-m:beaucaire.173','beaucaire','beaucaire',[54,117,136],'367588',3569032],
['nbs-iscc-m:beaver.64','beaver','beaver',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:beaverpelt.113','beaverpelt','beaverpelt',[87,85,76],'57554c',5723468],
['nbs-iscc-m:beech.110','beech','beech',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:beech.113','beech','beech',[87,85,76],'57554c',5723468],
['nbs-iscc-m:beechnut.61','beechnut','beechnut',[99,81,71],'635147',6508871],
['nbs-iscc-m:beefsblood.43','beefsblood','beef\'s blood',[121,68,59],'79443b',7947323],
['nbs-iscc-m:beeswax.77','beeswax','beeswax',[130,102,68],'826644',8545860],
['nbs-iscc-m:beetle.127','beetle','beetle',[81,87,68],'515744',5330756],
['nbs-iscc-m:begonia.3','begonia','begonia',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:begoniarose.15','begoniarose','begonia rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:beige.89','beige','beige',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:beige.90','beige','beige',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:beigesoire.76','beigesoire','beige soire',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:belladonna.224','belladonna','belladonna',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:belleek.73','belleek','belleek',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:belleek.79','belleek','belleek',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:belleek.90','belleek','belleek',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:belleek.93','belleek','belleek',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:bellemonte.15','bellemonte','bellemonte',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:bellflower.197','bellflower','bellflower',[39,36,88],'272458',2565208],
['nbs-iscc-m:berlinbrown.19','berlinbrown','berlin brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:berlinbrown.46','berlinbrown','berlin brown',[103,76,71],'674c47',6769735],
['nbs-iscc-m:berlinred.43','berlinred','berlin red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:bermuda.3','bermuda','bermuda',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:beryl.172','beryl','beryl',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:berylblue.172','berylblue','beryl blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:berylgreen.163','berylgreen','beryl green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:biarritz.79','biarritz','biarritz',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:biarritz.94','biarritz','biarritz',[150,113,23],'967117',9859351],
['nbs-iscc-m:bigfouryellowbig4yellow.48','bigfouryellowbig4yellow','big four yellow, big 4 yellow',[243,132,0],'f38400',15959040],
['nbs-iscc-m:bigfouryellowbig4yellow.50','bigfouryellowbig4yellow','big four yellow, big 4 yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:billiard.146','billiard','billiard',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:biscaygreen.120','biscaygreen','biscay green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:biscuit.57','biscuit','biscuit',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:biscuit.60','biscuit','biscuit',[149,128,112],'958070',9797744],
['nbs-iscc-m:biscuit.76','biscuit','biscuit',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:biscuit.79','biscuit','biscuit',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:bishop.211','bishop','bishop',[96,78,129],'604e81',6311553],
['nbs-iscc-m:bishopspurple.241','bishopspurple','bishop\'s purple',[145,92,131],'915c83',9526403],
['nbs-iscc-m:bishopsviolet.241','bishopsviolet','bishop\'s violet',[145,92,131],'915c83',9526403],
['nbs-iscc-m:biskra.81','biskra','biskra',[72,60,50],'483c32',4734002],
['nbs-iscc-m:bismarck.43','bismarck','bismarck',[121,68,59],'79443b',7947323],
['nbs-iscc-m:bismarckbrown.77','bismarckbrown','bismarck brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:bison.81','bison','bison',[72,60,50],'483c32',4734002],
['nbs-iscc-m:bisque.73','bisque','bisque',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:bisque.93','bisque','bisque',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:bister.61','bister','bister',[99,81,71],'635147',6508871],
['nbs-iscc-m:bister.80','bister','bister',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:bistre.61','bistre','bistre',[99,81,71],'635147',6508871],
['nbs-iscc-m:bistre.80','bistre','bistre',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:bistregreen.88','bistregreen','bistre green',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:bistregreen.91','bistregreen','bistre green',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:bittersweet.36','bittersweet','bittersweet',[170,56,30],'aa381e',11155486],
['nbs-iscc-m:bittersweet.38','bittersweet','bittersweet',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:bittersweetorange.51','bittersweetorange','bittersweet orange',[190,101,22],'be6516',12477718],
['nbs-iscc-m:bittersweetpink.26','bittersweetpink','bittersweet pink',[248,131,121],'f88379',16286585],
['nbs-iscc-m:bitumen.81','bitumen','bitumen',[72,60,50],'483c32',4734002],
['nbs-iscc-m:bladdergreen.106','bladdergreen','bladder green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:blaze.15','blaze','blaze ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:blaze.38','blaze','blaze ',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:bleudelyons.179','bleudelyons','bleu de lyons',[0,65,106],'00416a',16746],
['nbs-iscc-m:bleudelyons.182','bleudelyons','bleu de lyons',[67,107,149],'436b95',4418453],
['nbs-iscc-m:bleudorient.178','bleudorient','bleu d\'orient',[0,103,165],'0067a5',26533],
['nbs-iscc-m:bleulouise.164','bleulouise','bleu louise',[49,120,115],'317873',3242099],
['nbs-iscc-m:bleulouise.173','bleulouise','bleu louise',[54,117,136],'367588',3569032],
['nbs-iscc-m:bleupass.185','bleupass','bleu pass ',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:bleupass.186','bleupass','bleu pass ',[83,104,120],'536878',5466232],
['nbs-iscc-m:bleupass.191','bleupass','bleu pass ',[129,135,139],'81878b',8488843],
['nbs-iscc-m:blond.76','blond','blond',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:blond.91','blond','blond',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:blondine.80','blondine','blondine',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:blonket.190','blonket','blonket',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:bloodred.12','bloodred','blood red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:bloodred.15','bloodred','blood red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:blossom.5','blossom','blossom',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:blueashes.182','blueashes','blue ashes',[67,107,149],'436b95',4418453],
['nbs-iscc-m:blueaster.182','blueaster','blue aster',[67,107,149],'436b95',4418453],
['nbs-iscc-m:bluebell.182','bluebell','bluebell',[67,107,149],'436b95',4418453],
['nbs-iscc-m:bluebell.183','bluebell','bluebell',[0,48,78],'00304e',12366],
['nbs-iscc-m:bluebice.182','bluebice','blue bice',[67,107,149],'436b95',4418453],
['nbs-iscc-m:bluebirdbluebird.182','bluebirdbluebird','blue bird, bluebird',[67,107,149],'436b95',4418453],
['nbs-iscc-m:bluedevil.204','bluedevil','blue devil',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:bluefox.23','bluefox','blue fox',[92,80,79],'5c504f',6049871],
['nbs-iscc-m:bluegrass.165','bluegrass','blue grass',[0,75,73],'004b49',19273],
['nbs-iscc-m:bluehaze.266','bluehaze','blue haze',[85,85,85],'555555',5592405],
['nbs-iscc-m:bluejay.179','bluejay','bluejay',[0,65,106],'00416a',16746],
['nbs-iscc-m:bluejay.183','bluejay','bluejay',[0,48,78],'00304e',12366],
['nbs-iscc-m:bluejewel.169','bluejewel','blue jewel',[0,119,145],'007791',30609],
['nbs-iscc-m:bluelavender.203','bluelavender','blue lavender',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:bluelotus.181','bluelotus','blue lotus',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:blueochre.150','blueochre','blue ochre',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:blueochre.186','blueochre','blue ochre',[83,104,120],'536878',5466232],
['nbs-iscc-m:blueorchid.186','blueorchid','blue orchid',[83,104,120],'536878',5466232],
['nbs-iscc-m:bluesapphire.173','bluesapphire','blue sapphire',[54,117,136],'367588',3569032],
['nbs-iscc-m:bluespruce.145','bluespruce','blue spruce',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:bluespruce.150','bluespruce','blue spruce',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:bluet.182','bluet','bluet',[67,107,149],'436b95',4418453],
['nbs-iscc-m:blueturquoise.163','blueturquoise','blue turquoise',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:blueturquoise.172','blueturquoise','blue turquoise',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:blueuntramarineash.182','blueuntramarineash','blue untramarine ash ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:blueverditer.182','blueverditer','blue verditer',[67,107,149],'436b95',4418453],
['nbs-iscc-m:blunket.190','blunket','blunket',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:blush.29','blush','blush',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:blush.57','blush','blush',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:blushrose.19','blushrose','blush rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:boa.120','boa','boa',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:boa.121','boa','boa',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:boa.135','boa','boa',[147,197,146],'93c592',9684370],
['nbs-iscc-m:bobolink.80','bobolink','bobolink',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:boisderose.19','boisderose','bois de rose ',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:bokhara.259','bokhara','bokhara',[103,49,71],'673147',6762823],
['nbs-iscc-m:bole.43','bole','bole',[121,68,59],'79443b',7947323],
['nbs-iscc-m:bolearmoniack.43','bolearmoniack','bole armoniack',[121,68,59],'79443b',7947323],
['nbs-iscc-m:bolus.43','bolus','bolus',[121,68,59],'79443b',7947323],
['nbs-iscc-m:bombay.55','bombay','bombay',[128,70,27],'80461b',8406555],
['nbs-iscc-m:bombay.58','bombay','bombay',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:bonebrown.95','bonebrown','bone brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:bonebrown.96','bonebrown','bone brown',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:bonfire.12','bonfire','bonfire',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:bonito.64','bonito','bonito',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:bonnieblue.176','bonnieblue','bonnie blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:boreal.43','boreal','boreal',[121,68,59],'79443b',7947323],
['nbs-iscc-m:bosphorus.151','bosphorus','bosphorus',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:botticelli.238','botticelli','botticelli',[112,41,99],'702963',7350627],
['nbs-iscc-m:bottlegreen.151','bottlegreen','bottle green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:bottlegreen.165','bottlegreen','bottle green',[0,75,73],'004b49',19273],
['nbs-iscc-m:bougainville.223','bougainville','bougainville',[134,96,142],'86608e',8806542],
['nbs-iscc-m:bougainville.241','bougainville','bougainville',[145,92,131],'915c83',9526403],
['nbs-iscc-m:boulevard.64','boulevard','boulevard',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:bouquetgreen.144','bouquetgreen','bouquet green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:bourgeon.120','bourgeon','bourgeon',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:boxgreen.120','boxgreen','box green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:bracken.95','bracken','bracken',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:bracken.96','bracken','bracken',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:bramble.212','bramble','bramble',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:bran.57','bran','bran',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:bran.76','bran','bran',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:brass.87','brass','brass',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:brazenyellow.87','brazenyellow','brazen yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:brazilbrown.47','brazilbrown','brazil brown',[67,48,46],'43302e',4403246],
['nbs-iscc-m:brazilred.38','brazilred','brazil [red] ',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:brazilwood.15','brazilwood','brazilwood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:brazilwood.19','brazilwood','brazilwood',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:bremenblue.164','bremenblue','bremen blue',[49,120,115],'317873',3242099],
['nbs-iscc-m:bremengreen.136','bremengreen','bremen green',[103,146,103],'679267',6787687],
['nbs-iscc-m:brewstergreen.125','brewstergreen','brewster green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:briar.55','briar','briar',[128,70,27],'80461b',8406555],
['nbs-iscc-m:briar.58','briar','briar',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:briarwood.62','briarwood','briarwood',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:brickdust.13','brickdust','brickdust',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:brickred.55','brickred','brick red',[128,70,27],'80461b',8406555],
['nbs-iscc-m:brickred.58','brickred','brick red',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:bridalrose.6','bridalrose','bridal rose',[192,128,129],'c08081',12615809],
['nbs-iscc-m:brigand.12','brigand','brigand',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:brigand.15','brigand','brigand',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:brigand.35','brigand','brigand',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:brigand.37','brigand','brigand',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:brimstoneyellow.101','brimstoneyellow','brimstone [yellow] ',[234,230,121],'eae679',15394425],
['nbs-iscc-m:brittany.173','brittany','brittany',[54,117,136],'367588',3569032],
['nbs-iscc-m:brittany.182','brittany','brittany',[67,107,149],'436b95',4418453],
['nbs-iscc-m:brittany.186','brittany','brittany',[83,104,120],'536878',5466232],
['nbs-iscc-m:broccolibrown.64','broccolibrown','broccoli brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:broncho.81','broncho','broncho',[72,60,50],'483c32',4734002],
['nbs-iscc-m:broncho.95','broncho','broncho',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:broncho.96','broncho','broncho',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:bronze.77','bronze','bronze',[130,102,68],'826644',8545860],
['nbs-iscc-m:bronzebrown.64','bronzebrown','bronze brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:bronzeclair.79','bronzeclair','bronze clair',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:bronzegreen.127','bronzegreen','bronze green',[81,87,68],'515744',5330756],
['nbs-iscc-m:bronzelustre.110','bronzelustre','bronze lustre',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:bronzenude.95','bronzenude','bronze nude',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:bronzered.15','bronzered','bronze red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:bronzesheen.110','bronzesheen','bronzesheen',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:bronzeyellow.53','bronzeyellow','bronze yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:bronzeyellow.72','bronzeyellow','bronze yellow',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:brownbay.61','brownbay','brown bay',[99,81,71],'635147',6508871],
['nbs-iscc-m:brownbread.55','brownbread','brown bread',[128,70,27],'80461b',8406555],
['nbs-iscc-m:brownbread.58','brownbread','brown bread',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:brownmadder.43','brownmadder','brown madder',[121,68,59],'79443b',7947323],
['nbs-iscc-m:brownochre.53','brownochre','brown ochre',[217,144,88],'d99058',14258264],
['nbs-iscc-m:brownpink.72','brownpink','brown pink',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:brownpink.74','brownpink','brown pink',[153,101,21],'996515',10052885],
['nbs-iscc-m:brownred.43','brownred','brown red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:brownstone.61','brownstone','brown stone',[99,81,71],'635147',6508871],
['nbs-iscc-m:brownstone.61','brownstone','brownstone',[99,81,71],'635147',6508871],
['nbs-iscc-m:brownsugar.58','brownsugar','brown sugar',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:brownsugar.61','brownsugar','brown sugar',[99,81,71],'635147',6508871],
['nbs-iscc-m:brownsugar.77','brownsugar','brown sugar',[130,102,68],'826644',8545860],
['nbs-iscc-m:brownsugar.80','brownsugar','brown sugar',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:bruges.174','bruges','bruges',[0,73,88],'004958',18776],
['nbs-iscc-m:bruges.187','bruges','bruges',[54,69,79],'36454f',3556687],
['nbs-iscc-m:brushwood.61','brushwood','brushwood',[99,81,71],'635147',6508871],
['nbs-iscc-m:brusselsbrown.58','brusselsbrown','brussels brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:brusselsbrown.61','brusselsbrown','brussels brown',[99,81,71],'635147',6508871],
['nbs-iscc-m:brusselsbrown.77','brusselsbrown','brussels brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:brusselsbrown.80','brusselsbrown','brussels brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:buccaneer.12','buccaneer','buccaneer',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:buccaneer.15','buccaneer','buccaneer',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:buccaneer.36','buccaneer','buccaneer',[170,56,30],'aa381e',11155486],
['nbs-iscc-m:buccaneer.38','buccaneer','buccaneer',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:buckskin.45','buckskin','buckskin',[151,127,115],'977f73',9928563],
['nbs-iscc-m:buckskin.60','buckskin','buckskin',[149,128,112],'958070',9797744],
['nbs-iscc-m:buckthornberries.68','buckthornberries','buckthorn berries',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:buckthornberries.71','buckthornberries','buckthorn berries',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:buckthornbrown.72','buckthornbrown','buckthorn brown',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:buckthornbrown.74','buckthornbrown','buckthorn brown',[153,101,21],'996515',10052885],
['nbs-iscc-m:buckthornbrown.76','buckthornbrown','buckthorn brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:buckthornbrown.77','buckthornbrown','buckthorn brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:buckthornbrown.88','buckthornbrown','buckthorn brown',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:buckthornbrown.91','buckthornbrown','buckthorn brown',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:buckthornbrown.94','buckthornbrown','buckthorn brown',[150,113,23],'967117',9859351],
['nbs-iscc-m:buddha.12','buddha','buddha',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:buddha.15','buddha','buddha',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:budgreen.131','budgreen','bud green',[68,148,74],'44944a',4494410],
['nbs-iscc-m:buff.71','buff','buff',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:buffalo.77','buffalo','buffalo',[130,102,68],'826644',8545860],
['nbs-iscc-m:bulgare.19','bulgare','bulgare',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:bunny.77','bunny','bunny',[130,102,68],'826644',8545860],
['nbs-iscc-m:bure.74','bure','bure',[153,101,21],'996515',10052885],
['nbs-iscc-m:bure.76','bure','bure',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:bure.77','bure','bure',[130,102,68],'826644',8545860],
['nbs-iscc-m:burel.58','burel','burel',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:burgundy.229','burgundy','burgundy',[80,64,77],'50404d',5259341],
['nbs-iscc-m:burgundy.230','burgundy','burgundy',[41,30,41],'291e29',2694697],
['nbs-iscc-m:burgundyviolet.218','burgundyviolet','burgundy violet',[135,86,146],'875692',8869522],
['nbs-iscc-m:burlwood.60','burlwood','burlwood',[149,128,112],'958070',9797744],
['nbs-iscc-m:burlwood.79','burlwood','burlwood',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:burma.54','burma','burma',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:burmesegold.37','burmesegold','burmese gold',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:burmeseruby.16','burmeseruby','burmese ruby',[114,47,55],'722f37',7483191],
['nbs-iscc-m:burnblue.184','burnblue','burn blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-m:burnblue.185','burnblue','burn blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:burnblue.202','burnblue','burn blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-m:burnblue.203','burnblue','burn blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:burnishedgold.72','burnishedgold','burnished gold',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:burnishedgold.74','burnishedgold','burnished gold',[153,101,21],'996515',10052885],
['nbs-iscc-m:burnishedgold.76','burnishedgold','burnished gold',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:burnishedgold.88','burnishedgold','burnished gold',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:burnishedgold.94','burnishedgold','burnished gold',[150,113,23],'967117',9859351],
['nbs-iscc-m:burnous.73','burnous','burnous',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:burnt.91','burnt','burnt',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:burntalmond.58','burntalmond','burnt almond',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:burntcarmine.13','burntcarmine','burnt carmine',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:burntcarmine.15','burntcarmine','burnt carmine',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:burntcoral.37','burntcoral','burnt coral',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:burntcrimsonlake.13','burntcrimsonlake','burnt crimson lake',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:burntcrimsonlake.15','burntcrimsonlake','burnt crimson lake',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:burntitalianearth.38','burntitalianearth','burnt italian earth',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:burntitalianochre.38','burntitalianochre','burnt italian ochre',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:burntlake.13','burntlake','burnt lake',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:burntlake.15','burntlake','burnt lake',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:burntochre.37','burntochre','burnt ochre',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:burntorange.37','burntorange','burnt orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:burntromanochre.50','burntromanochre','burnt roman ochre',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:burntrose.41','burntrose','burnt rose',[86,7,12],'56070c',5637900],
['nbs-iscc-m:burntrose.43','burntrose','burnt rose',[121,68,59],'79443b',7947323],
['nbs-iscc-m:burntrusset.16','burntrusset','burnt russet',[114,47,55],'722f37',7483191],
['nbs-iscc-m:burntrusset.43','burntrusset','burnt russet',[121,68,59],'79443b',7947323],
['nbs-iscc-m:burntsienna.38','burntsienna','burnt sienna',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:burntterreverte.58','burntterreverte','burnt terre verte',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:burntumber.58','burntumber','burnt umber',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:buttercupyellow.90','buttercupyellow','buttercup [yellow] ',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:butterfly.102','butterfly','butterfly',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:butternut.95','butternut','butternut',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:butterscotch.58','butterscotch','butterscotch',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:butterscotch.77','butterscotch','butterscotch',[130,102,68],'826644',8545860],
['nbs-iscc-m:byron.81','byron','byron',[72,60,50],'483c32',4734002],
['nbs-iscc-m:byzantine.254','byzantine','byzantine',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:byzantium.238','byzantium','byzantium',[112,41,99],'702963',7350627],
['nbs-iscc-m:byzantium.242','byzantium','byzantium',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:cabaret.144','cabaret','cabaret',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:cabbagegreen.155','cabbagegreen','cabbage green',[125,137,132],'7d8984',8227204],
['nbs-iscc-m:cacao.77','cacao','cacao',[130,102,68],'826644',8545860],
['nbs-iscc-m:cacaobrown.55','cacaobrown','cacao brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:cacha.58','cacha','cacha',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cachou.58','cachou','cachou',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cactus.137','cactus','cactus',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:cadet.186','cadet','cadet',[83,104,120],'536878',5466232],
['nbs-iscc-m:cadetblue.182','cadetblue','cadet blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:cadetgrey.191','cadetgrey','cadet grey ',[129,135,139],'81878b',8488843],
['nbs-iscc-m:cadmiumcarmine.12','cadmiumcarmine','cadmium carmine',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:cadmiumgreen.141','cadmiumgreen','cadmium green',[0,121,89],'007959',31065],
['nbs-iscc-m:cadmiumlemon.97','cadmiumlemon','cadmium lemon',[220,211,0],'dcd300',14471936],
['nbs-iscc-m:cadmiumlemon.98','cadmiumlemon','cadmium lemon',[233,228,80],'e9e450',15328336],
['nbs-iscc-m:cadmiumorange.50','cadmiumorange','cadmium orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:cadmiumpurple.13','cadmiumpurple','cadmium purple',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:cadmiumpurple.15','cadmiumpurple','cadmium purple',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:cadmiumvermilion.12','cadmiumvermilion','cadmium vermilion',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:cadmiumvermilion.15','cadmiumvermilion','cadmium vermilion',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:cadmiumyellow.50','cadmiumyellow','cadmium yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:cadmiumyellow.53','cadmiumyellow','cadmium yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:cadmiumyellow.68','cadmiumyellow','cadmium yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:cadmiumyellow.71','cadmiumyellow','cadmium yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:caenstone.73','caenstone','caen stone',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:caeruleum.167','caeruleum','caeruleum',[0,133,161],'0085a1',34209],
['nbs-iscc-m:caeruleum.176','caeruleum','caeruleum',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:cafaulait.45','cafaulait','caf-au-lait',[151,127,115],'977f73',9928563],
['nbs-iscc-m:cafaulait.57','cafaulait','caf-au-lait',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:cafaulait.60','cafaulait','caf-au-lait',[149,128,112],'958070',9797744],
['nbs-iscc-m:cafcrme.57','cafcrme','caf crme',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:cafcrme.58','cafcrme','caf crme',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cafcrme.77','cafcrme','caf crme',[130,102,68],'826644',8545860],
['nbs-iscc-m:cafnoir.81','cafnoir','caf noir',[72,60,50],'483c32',4734002],
['nbs-iscc-m:cairo.179','cairo','cairo',[0,65,106],'00416a',16746],
['nbs-iscc-m:calabash.77','calabash','calabash',[130,102,68],'826644',8545860],
['nbs-iscc-m:calabash.94','calabash','calabash',[150,113,23],'967117',9859351],
['nbs-iscc-m:calamineblue.172','calamineblue','calamine blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:caldera.43','caldera','caldera',[121,68,59],'79443b',7947323],
['nbs-iscc-m:caledonianbrown.55','caledonianbrown','caledonian brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:caliaturwood.15','caliaturwood','caliaturwood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:californiacolor.58','californiacolor','california color',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:californiagreen.91','californiagreen','california green',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:callagreen.120','callagreen','calla green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:callistegreen.117','callistegreen','calliste green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-m:callistegreen.120','callistegreen','calliste green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:cambridgeblue.163','cambridgeblue','cambridge blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:cambridgered.15','cambridgered','cambridge red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:cambridgered.19','cambridgered','cambridge red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:camel.64','camel','camel',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:camellia.12','camellia','camellia ',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:camellia.15','camellia','camellia ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:camelshairorcamelshair.80','camelshairorcamelshair','camels hair or camel\'s hair',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:cameoblue.163','cameoblue','cameo blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:cameobrown.19','cameobrown','cameo brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:cameobrown.42','cameobrown','cameo brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:cameobrown.43','cameobrown','cameo brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:cameobrown.46','cameobrown','cameo brown',[103,76,71],'674c47',6769735],
['nbs-iscc-m:cameogreen.135','cameogreen','cameo green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:cameogreen.144','cameogreen','cameo green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:cameogreen.149','cameogreen','cameo green',[141,163,153],'8da399',9282457],
['nbs-iscc-m:cameopink.253','cameopink','cameo pink',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-m:cameoyellow.89','cameoyellow','cameo yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:campanula.207','campanula','campanula',[96,78,151],'604e97',6311575],
['nbs-iscc-m:campanula.211','campanula','campanula',[96,78,129],'604e81',6311553],
['nbs-iscc-m:campanulablue.199','campanulablue','campanula blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:campanulablue.195','campanulablue','campanula blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-m:campanulablue.206','campanulablue','campanula blue',[126,115,184],'7e73b8',8287160],
['nbs-iscc-m:campanulapurple.245','campanulapurple','campanula purple',[131,100,121],'836479',8610937],
['nbs-iscc-m:campanulaviolet.245','campanulaviolet','campanula violet',[131,100,121],'836479',8610937],
['nbs-iscc-m:camrier.224','camrier','camrier',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:camwood.15','camwood','camwood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:canard.165','canard','canard',[0,75,73],'004b49',19273],
['nbs-iscc-m:canard.174','canard','canard',[0,73,88],'004958',18776],
['nbs-iscc-m:canarybirdgreen.88','canarybirdgreen','canary-bird green',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:canarygreen.88','canarygreen','canary green',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:canaryyellow.87','canaryyellow','canary [yellow] ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:candida.261','candida','candida',[175,134,142],'af868e',11503246],
['nbs-iscc-m:candypink.3','candypink','candy pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:candypink.26','candypink','candy pink',[248,131,121],'f88379',16286585],
['nbs-iscc-m:candypink.27','candypink','candy pink',[230,103,97],'e66761',15099745],
['nbs-iscc-m:canna.37','canna','canna',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:canna.38','canna','canna',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:canna.39','canna','canna',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:canna.43','canna','canna',[121,68,59],'79443b',7947323],
['nbs-iscc-m:cannon.152','cannon','cannon',[26,36,33],'1a2421',1713185],
['nbs-iscc-m:canterbury.207','canterbury','canterbury',[96,78,151],'604e97',6311575],
['nbs-iscc-m:cantonblue.183','cantonblue','canton [blue] ',[0,48,78],'00304e',12366],
['nbs-iscc-m:cantonjade.164','cantonjade','canton jade',[49,120,115],'317873',3242099],
['nbs-iscc-m:canyon.16','canyon','canyon',[114,47,55],'722f37',7483191],
['nbs-iscc-m:canyon.259','canyon','canyon',[103,49,71],'673147',6762823],
['nbs-iscc-m:cappagh.58','cappagh','cappagh',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cappahbrown.58','cappahbrown','cappah brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:capri.169','capri','capri ',[0,119,145],'007791',30609],
['nbs-iscc-m:caprice.236','caprice','caprice',[135,0,116],'870074',8847476],
['nbs-iscc-m:caprice.226','caprice','caprice',[214,202,221],'d6cadd',14076637],
['nbs-iscc-m:capucine.87','capucine','capucine ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:capucinebuff.73','capucinebuff','capucine buff ',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:capucinelake.26','capucinelake','capucine lake ',[248,131,121],'f88379',16286585],
['nbs-iscc-m:capucinelake.37','capucinelake','capucine lake ',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:capucinelake.50','capucinelake','capucine lake ',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:capucinelake.53','capucinelake','capucine lake ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:capucinemadder.53','capucinemadder','capucine madder ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:capucineorange.53','capucineorange','capucine orange ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:capucinered.25','capucinered','capucine red ',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-m:capucinered.35','capucinered','capucine red ',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:capucineyellow.53','capucineyellow','capucine yellow ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:caputmortuum.43','caputmortuum','caput mortuum',[121,68,59],'79443b',7947323],
['nbs-iscc-m:caraibe.58','caraibe','caraibe',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:caraibe.61','caraibe','caraibe',[99,81,71],'635147',6508871],
['nbs-iscc-m:caraibe.77','caraibe','caraibe',[130,102,68],'826644',8545860],
['nbs-iscc-m:caraibe.80','caraibe','caraibe',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:caramel.54','caramel','caramel',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:caramel.57','caramel','caramel',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:carbuncle.47','carbuncle','carbuncle',[67,48,46],'43302e',4403246],
['nbs-iscc-m:cardinalred.11','cardinalred','cardinal [red] ',[190,0,50],'be0032',12451890],
['nbs-iscc-m:carmine.11','carmine','carmine',[190,0,50],'be0032',12451890],
['nbs-iscc-m:carmine.12','carmine','carmine',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:carminelake.11','carminelake','carmine lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:carminelake.12','carminelake','carmine lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:carnation.89','carnation','carnation',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:carnation.90','carnation','carnation',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:carnationred.15','carnationred','carnation [red] ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:carnationrose.2','carnationrose','carnation rose',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:carnelian.39','carnelian','carnelian',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:carnelianred.37','carnelianred','carnelian red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:carnivalred.12','carnivalred','carnival red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:carobbrown.58','carobbrown','carob brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:caroubier.58','caroubier','caroubier',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:carraragreen.146','carraragreen','carrara green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:carrotred.50','carrotred','carrot red',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:carrotred.53','carrotred','carrot red',[217,144,88],'d99058',14258264],
['nbs-iscc-m:carthamusred.11','carthamusred','carthamus red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:carthamusrose.11','carthamusrose','carthamus rose',[190,0,50],'be0032',12451890],
['nbs-iscc-m:cartouche.58','cartouche','cartouche',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cartridgebuff.89','cartridgebuff','cartridge buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:cartridgebuff.90','cartridgebuff','cartridge buff',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:cascade.163','cascade','cascade',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:cashew.58','cashew','cashew',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cashewlake.58','cashewlake','cashew lake',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cashewnut.61','cashewnut','cashew nut',[99,81,71],'635147',6508871],
['nbs-iscc-m:cashoo.58','cashoo','cashoo',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:casinopink.255','casinopink','casino pink',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:casselbrown.58','casselbrown','cassel brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:casselearth.58','casselearth','cassel earth',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:casselyellow.83','casselyellow','cassel yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:casselyellow.84','casselyellow','cassel yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:casselyellow.86','casselyellow','cassel yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:casselyellow.87','casselyellow','cassel yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:casserole.43','casserole','casserole',[121,68,59],'79443b',7947323],
['nbs-iscc-m:castaneous.61','castaneous','castaneous',[99,81,71],'635147',6508871],
['nbs-iscc-m:castellon.43','castellon','castellon',[121,68,59],'79443b',7947323],
['nbs-iscc-m:castileearth.58','castileearth','castile earth',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:castilianbrown.43','castilianbrown','castilian brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:castilianred.11','castilianred','castilian red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:castor.64','castor','castor',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:castorgrey.156','castorgrey','castor grey ',[78,87,85],'4e5755',5134165],
['nbs-iscc-m:catalpa.228','catalpa','catalpa',[121,104,120],'796878',7956600],
['nbs-iscc-m:catawba.17','catawba','catawba',[63,23,40],'3f1728',4134696],
['nbs-iscc-m:catawba.21','catawba','catawba',[46,29,33],'2e1d21',3022113],
['nbs-iscc-m:cate.58','cate','cate',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:catechu.58','catechu','catechu',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cathay.54','cathay','cathay',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:cathay.74','cathay','cathay',[153,101,21],'996515',10052885],
['nbs-iscc-m:cathedral.212','cathedral','cathedral',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:cathedralblue.182','cathedralblue','cathedral blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:cathedralblue.200','cathedralblue','cathedral blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:cattail.81','cattail','cattail',[72,60,50],'483c32',4734002],
['nbs-iscc-m:cattleya.223','cattleya','cattleya',[134,96,142],'86608e',8806542],
['nbs-iscc-m:caucasia.80','caucasia','caucasia',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:cauldron.16','cauldron','cauldron',[114,47,55],'722f37',7483191],
['nbs-iscc-m:cauldron.40','cauldron','cauldron',[136,45,23],'882d17',8924439],
['nbs-iscc-m:cauldron.43','cauldron','cauldron',[121,68,59],'79443b',7947323],
['nbs-iscc-m:cavalry.71','cavalry','cavalry',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:cedar.46','cedar','cedar',[103,76,71],'674c47',6769735],
['nbs-iscc-m:cedarbark.19','cedarbark','cedarbark',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:cedarbark.43','cedarbark','cedarbark',[121,68,59],'79443b',7947323],
['nbs-iscc-m:cedargreen.125','cedargreen','cedar green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:cedarwood.43','cedarwood','cedar wood',[121,68,59],'79443b',7947323],
['nbs-iscc-m:cedre.125','cedre','cedre',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:celadongreen.122','celadongreen','celadon green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:celandinegreen.150','celandinegreen','celandine green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:celest.186','celest','celest',[83,104,120],'536878',5466232],
['nbs-iscc-m:celest.203','celest','celest',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:celestial.182','celestial','celestial',[67,107,149],'436b95',4418453],
['nbs-iscc-m:celestialblue.185','celestialblue','celestial blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:cellini.236','cellini','cellini',[135,0,116],'870074',8847476],
['nbs-iscc-m:cellini.254','cellini','cellini',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:cement.265','cement','cement',[132,132,130],'848482',8684674],
['nbs-iscc-m:cendrillon.151','cendrillon','cendrillon',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:cendrillon.192','cendrillon','cendrillon',[81,88,94],'51585e',5331038],
['nbs-iscc-m:centennialbrown.74','centennialbrown','centennial brown',[153,101,21],'996515',10052885],
['nbs-iscc-m:centennialbrown.76','centennialbrown','centennial brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:centennialbrown.77','centennialbrown','centennial brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:centreblue.182','centreblue','centre blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:ceramic.182','ceramic','ceramic',[67,107,149],'436b95',4418453],
['nbs-iscc-m:ceres.53','ceres','ceres',[217,144,88],'d99058',14258264],
['nbs-iscc-m:cerise.15','cerise','cerise',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:cerrogreen.120','cerrogreen','cerro green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:cerrogreen.125','cerrogreen','cerro green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:certosa.103','certosa','certosa',[152,148,62],'98943e',9999422],
['nbs-iscc-m:certosa.106','certosa','certosa',[134,126,54],'867e36',8814134],
['nbs-iscc-m:certosa.120','certosa','certosa',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:cerulean.181','cerulean','cerulean',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:cerulean.199','cerulean','cerulean',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:ceruleanblue.167','ceruleanblue','cerulean blue',[0,133,161],'0085a1',34209],
['nbs-iscc-m:ceruleanblue.176','ceruleanblue','cerulean blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:ceylonblue.174','ceylonblue','ceylon blue',[0,73,88],'004958',18776],
['nbs-iscc-m:chaeturablack.267','chaeturablack','chaetura black',[34,34,34],'222222',2236962],
['nbs-iscc-m:chaeturadrab.266','chaeturadrab','chaetura drab',[85,85,85],'555555',5592405],
['nbs-iscc-m:chalcedonyyellow.101','chalcedonyyellow','chalcedony yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-m:chaletred.19','chaletred','chalet red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:chamois.90','chamois','chamois',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:chamoisskin.90','chamoisskin','chamois skin',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:chamoline.72','chamoline','chamoline',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:chamoline.74','chamoline','chamoline',[153,101,21],'996515',10052885],
['nbs-iscc-m:chamoline.76','chamoline','chamoline',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:chamoline.77','chamoline','chamoline',[130,102,68],'826644',8545860],
['nbs-iscc-m:chamoline.88','chamoline','chamoline',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:chamoline.91','chamoline','chamoline',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:chamoline.94','chamoline','chamoline',[150,113,23],'967117',9859351],
['nbs-iscc-m:champagne.73','champagne','champagne',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:champagne.79','champagne','champagne',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:champagne.90','champagne','champagne',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:champagne.93','champagne','champagne',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:chantilly.144','chantilly','chantilly',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:charcoalgrey.266','charcoalgrey','charcoal grey',[85,85,85],'555555',5592405],
['nbs-iscc-m:chardon.259','chardon','chardon',[103,49,71],'673147',6762823],
['nbs-iscc-m:charlesx.259','charlesx','charles x',[103,49,71],'673147',6762823],
['nbs-iscc-m:chartreuse.98','chartreuse','chartreuse',[233,228,80],'e9e450',15328336],
['nbs-iscc-m:chartreuse.99','chartreuse','chartreuse',[190,183,46],'beb72e',12498734],
['nbs-iscc-m:chartreuse.101','chartreuse','chartreuse',[234,230,121],'eae679',15394425],
['nbs-iscc-m:chartreuse.102','chartreuse','chartreuse',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:chartreusegreen.103','chartreusegreen','chartreuse green',[152,148,62],'98943e',9999422],
['nbs-iscc-m:chartreuseyellow.101','chartreuseyellow','chartreuse yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-m:chartreuseyellow.102','chartreuseyellow','chartreuse yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:chasseur.138','chasseur','chasseur',[23,54,32],'173620',1521184],
['nbs-iscc-m:chatemuc.15','chatemuc','chatemuc',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:chatenaypink.28','chatenaypink','chatenay pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-m:chatenaypink.29','chatenaypink','chatenay pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:chaudron.37','chaudron','chaudron',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:chaudron.38','chaudron','chaudron',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:chaudron.39','chaudron','chaudron',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:chaudron.43','chaudron','chaudron',[121,68,59],'79443b',7947323],
['nbs-iscc-m:checkerberry.11','checkerberry','checkerberry',[190,0,50],'be0032',12451890],
['nbs-iscc-m:chemicblue.174','chemicblue','chemic blue ',[0,73,88],'004958',18776],
['nbs-iscc-m:chemicgreen.164','chemicgreen','chemic green ',[49,120,115],'317873',3242099],
['nbs-iscc-m:cherokee.37','cherokee','cherokee',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:cherry.34','cherry','cherry',[226,88,34],'e25822',14833698],
['nbs-iscc-m:cherrybloom.26','cherrybloom','cherry bloom',[248,131,121],'f88379',16286585],
['nbs-iscc-m:cherryblossom.15','cherryblossom','cherry blossom',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:cherryred.34','cherryred','cherry red',[226,88,34],'e25822',14833698],
['nbs-iscc-m:cherub.29','cherub','cherub',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:chessyliteblue.182','chessyliteblue','chessylite blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:chestnut.61','chestnut','chestnut',[99,81,71],'635147',6508871],
['nbs-iscc-m:chevreuse.19','chevreuse','chevreuse',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:chevreuse.43','chevreuse','chevreuse',[121,68,59],'79443b',7947323],
['nbs-iscc-m:chianti.13','chianti','chianti',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:chickadeegray.113','chickadeegray','chickadee gray',[87,85,76],'57554c',5723468],
['nbs-iscc-m:chicle.61','chicle','chicle',[99,81,71],'635147',6508871],
['nbs-iscc-m:chicory.203','chicory','chicory',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:chicoryblue.121','chicoryblue','chicory blue',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:chicoryblue.203','chicoryblue','chicory blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:chimneyred.13','chimneyred','chimney red',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:chimneyred.15','chimneyred','chimney red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:chinablue.182','chinablue','china blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:chinablue.186','chinablue','china blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:chinarose.258','chinarose','china rose',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:chinchilla.265','chinchilla','chinchilla',[132,132,130],'848482',8684674],
['nbs-iscc-m:chinchinblue.186','chinchinblue','chin-chin blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:chinesegold.54','chinesegold','chinese gold',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:chinesegreen.135','chinesegreen','chinese green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:chinesegreen.144','chinesegreen','chinese green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:chinesegreen.146','chinesegreen','chinese green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:chinesegreen.165','chinesegreen','chinese green',[0,75,73],'004b49',19273],
['nbs-iscc-m:chineselake.11','chineselake','chinese lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:chineselake.12','chineselake','chinese lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:chineseorange.25','chineseorange','chinese orange',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-m:chineseorange.35','chineseorange','chinese orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:chinesered.36','chinesered','chinese red',[170,56,30],'aa381e',11155486],
['nbs-iscc-m:chinesered.38','chinesered','chinese red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:chinesered.40','chinesered','chinese red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:chineserouge.11','chineserouge','chinese rouge',[190,0,50],'be0032',12451890],
['nbs-iscc-m:chinesevermilion.11','chinesevermilion','chinese vermilion ',[190,0,50],'be0032',12451890],
['nbs-iscc-m:chineseviolet.223','chineseviolet','chinese violet',[134,96,142],'86608e',8806542],
['nbs-iscc-m:chineseyellow.83','chineseyellow','chinese yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:chineseyellow.84','chineseyellow','chinese yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:chineseyellow.86','chineseyellow','chinese yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:chineseyellow.87','chineseyellow','chinese yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:chineseyellow.71','chineseyellow','chinese yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:ching.176','ching','ch\'ing',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:chinook.38','chinook','chinook',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:chip.109','chip','chip',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:chip.112','chip','chip',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:chipmunk.74','chipmunk','chipmunk',[153,101,21],'996515',10052885],
['nbs-iscc-m:chippendale.62','chippendale','chippendale',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:chiswick.183','chiswick','chiswick',[0,48,78],'00304e',12366],
['nbs-iscc-m:chocolate.62','chocolate','chocolate',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:chocolatebrown.62','chocolatebrown','chocolate brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:chocolatemaroon.16','chocolatemaroon','chocolate maroon',[114,47,55],'722f37',7483191],
['nbs-iscc-m:chromecitron.86','chromecitron','chrome citron',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:chromegreen.141','chromegreen','chrome green',[0,121,89],'007959',31065],
['nbs-iscc-m:chromegreen.145','chromegreen','chrome green',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:chromelemon.86','chromelemon','chrome lemon',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:chromeorange.34','chromeorange','chrome orange',[226,88,34],'e25822',14833698],
['nbs-iscc-m:chromeorange.48','chromeorange','chrome orange',[243,132,0],'f38400',15959040],
['nbs-iscc-m:chromeprimrose.98','chromeprimrose','chrome primrose',[233,228,80],'e9e450',15328336],
['nbs-iscc-m:chromeprimrose.101','chromeprimrose','chrome primrose',[234,230,121],'eae679',15394425],
['nbs-iscc-m:chromescarlet.35','chromescarlet','chrome scarlet',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:chromiumgreen.120','chromiumgreen','chromium green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:chromiumoxide.136','chromiumoxide','chromium oxide ',[103,146,103],'679267',6787687],
['nbs-iscc-m:chrysanthemum.13','chrysanthemum','chrysanthemum',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:chrysanthemum.16','chrysanthemum','chrysanthemum',[114,47,55],'722f37',7483191],
['nbs-iscc-m:chrysocollo.136','chrysocollo','chrysocollo',[103,146,103],'679267',6787687],
['nbs-iscc-m:chrysolitegreen.102','chrysolitegreen','chrysolite green',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:chrysolitegreen.105','chrysolitegreen','chrysolite green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:chrysolitegreen.120','chrysolitegreen','chrysolite green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:chrysopraisegreen.140','chrysopraisegreen','chrysopraise [green] ',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:chrysopraisegreen.144','chrysopraisegreen','chrysopraise [green] ',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:chukkerbrown.61','chukkerbrown','chukker brown',[99,81,71],'635147',6508871],
['nbs-iscc-m:chukkerbrown.80','chukkerbrown','chukker brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:chutney.43','chutney','chutney',[121,68,59],'79443b',7947323],
['nbs-iscc-m:cigarette.58','cigarette','cigarette',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cindergrey.233','cindergrey','cinder [grey] ',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:cineraria.254','cineraria','cineraria',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:cinereous.264','cinereous','cinereous',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:cinnamon.57','cinnamon','cinnamon',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:cinnamon.76','cinnamon','cinnamon',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:cinnamonbrown.58','cinnamonbrown','cinnamon brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cinnamonbrown.77','cinnamonbrown','cinnamon brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:cinnamonpink.42','cinnamonpink','cinnamon pink',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:circassian.58','circassian','circassian',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:citrine.106','citrine','citrine',[134,126,54],'867e36',8814134],
['nbs-iscc-m:citronelle.98','citronelle','citronelle',[233,228,80],'e9e450',15328336],
['nbs-iscc-m:citronelle.99','citronelle','citronelle',[190,183,46],'beb72e',12498734],
['nbs-iscc-m:citronelle.101','citronelle','citronelle',[234,230,121],'eae679',15394425],
['nbs-iscc-m:citronelle.102','citronelle','citronelle',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:citrongreen.102','citrongreen','citron green',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:citrongreen.105','citrongreen','citron green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:citronyellow.86','citronyellow','citron [yellow] ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:citrus.101','citrus','citrus',[234,230,121],'eae679',15394425],
['nbs-iscc-m:civettegreen.137','civettegreen','civette green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:clairdelune.149','clairdelune','clair de lune',[141,163,153],'8da399',9282457],
['nbs-iscc-m:claretcup.262','claretcup','claret cup',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:claretlees.259','claretlees','claret lees',[103,49,71],'673147',6762823],
['nbs-iscc-m:claretred.15','claretred','claret [red] ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:claver.241','claver','claver',[145,92,131],'915c83',9526403],
['nbs-iscc-m:clay.74','clay','clay',[153,101,21],'996515',10052885],
['nbs-iscc-m:clay.76','clay','clay',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:clay.77','clay','clay',[130,102,68],'826644',8545860],
['nbs-iscc-m:claybank.54','claybank','clay bank',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:claydrab.77','claydrab','clay drab',[130,102,68],'826644',8545860],
['nbs-iscc-m:claydrab.94','claydrab','clay drab',[150,113,23],'967117',9859351],
['nbs-iscc-m:clematis.207','clematis','clematis',[96,78,151],'604e97',6311575],
['nbs-iscc-m:cleopatra.176','cleopatra','cleopatra',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:clochette.200','clochette','clochette',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:clochette.211','clochette','clochette',[96,78,129],'604e81',6311553],
['nbs-iscc-m:cloisonn.176','cloisonn','cloisonn',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:cloisonn.194','cloisonn','cloisonn',[48,38,122],'30267a',3155578],
['nbs-iscc-m:cloud.186','cloud','cloud',[83,104,120],'536878',5466232],
['nbs-iscc-m:cloudgrey.233','cloudgrey','cloud grey ',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:cloudgrey.265','cloudgrey','cloud grey ',[132,132,130],'848482',8684674],
['nbs-iscc-m:cloudyamber.90','cloudyamber','cloudy amber',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:cloudyamber.91','cloudyamber','cloudy amber',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:clove.58','clove','clove',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:clovebrown.64','clovebrown','clove brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:clovepink.16','clovepink','clove pink',[114,47,55],'722f37',7483191],
['nbs-iscc-m:clover.241','clover','clover',[145,92,131],'915c83',9526403],
['nbs-iscc-m:cobaltblue.169','cobaltblue','cobalt blue',[0,119,145],'007791',30609],
['nbs-iscc-m:cobaltglass.179','cobaltglass','cobalt glass',[0,65,106],'00416a',16746],
['nbs-iscc-m:cobaltglass.182','cobaltglass','cobalt glass',[67,107,149],'436b95',4418453],
['nbs-iscc-m:cobaltgreen.136','cobaltgreen','cobalt green',[103,146,103],'679267',6787687],
['nbs-iscc-m:cobaltred.254','cobaltred','cobalt red',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:cobaltred.255','cobaltred','cobalt red',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:cobaltultramarine.169','cobaltultramarine','cobalt ultramarine ',[0,119,145],'007791',30609],
['nbs-iscc-m:cobaltviolet.223','cobaltviolet','cobalt violet',[134,96,142],'86608e',8806542],
['nbs-iscc-m:cobaltyellow.83','cobaltyellow','cobalt yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:cobaltyellow.84','cobaltyellow','cobalt yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:cobblestone.266','cobblestone','cobblestone',[85,85,85],'555555',5592405],
['nbs-iscc-m:cobweb.79','cobweb','cobweb',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:coccineous.11','coccineous','coccineous',[190,0,50],'be0032',12451890],
['nbs-iscc-m:cocher.95','cocher','cocher',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:cochin.58','cochin','cochin',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cochineal.11','cochineal','cochineal',[190,0,50],'be0032',12451890],
['nbs-iscc-m:cockatoo.86','cockatoo','cockatoo',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:cocoa.58','cocoa','cocoa',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cocoabrown.58','cocoabrown','cocoa brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cocobala.19','cocobala','cocobala',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:cocobala.46','cocobala','cocobala',[103,76,71],'674c47',6769735],
['nbs-iscc-m:coconut.61','coconut','coconut',[99,81,71],'635147',6508871],
['nbs-iscc-m:coconutbrown.58','coconutbrown','coconut brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:codgrey.110','codgrey','cod grey',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:codgrey.113','codgrey','cod grey',[87,85,76],'57554c',5723468],
['nbs-iscc-m:coeruleum.167','coeruleum','coeruleum',[0,133,161],'0085a1',34209],
['nbs-iscc-m:coeruleum.176','coeruleum','coeruleum',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:coffee.58','coffee','coffee',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cognac.58','cognac','cognac',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:colcothar.43','colcothar','colcothar',[121,68,59],'79443b',7947323],
['nbs-iscc-m:colewortgreen.155','colewortgreen','colewort green',[125,137,132],'7d8984',8227204],
['nbs-iscc-m:colibri.164','colibri','colibri',[49,120,115],'317873',3242099],
['nbs-iscc-m:collie.80','collie','collie',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:colognebrown.58','colognebrown','cologne brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cologneearth.58','cologneearth','cologne earth',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cologneyellow.84','cologneyellow','cologne yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:colonial.179','colonial','colonial',[0,65,106],'00416a',16746],
['nbs-iscc-m:colonial.183','colonial','colonial',[0,48,78],'00304e',12366],
['nbs-iscc-m:colonial.197','colonial','colonial',[39,36,88],'272458',2565208],
['nbs-iscc-m:colonial.200','colonial','colonial',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:colonialbuff.86','colonialbuff','colonial buff',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:colonialbuff.89','colonialbuff','colonial buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:colonialyellow.87','colonialyellow','colonial yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:columbia.178','columbia','columbia',[0,103,165],'0067a5',26533],
['nbs-iscc-m:columbiablue.185','columbiablue','columbia blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:columbianred.43','columbianred','columbian red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:columbineblue.200','columbineblue','columbine blue ',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:columbineblue.211','columbineblue','columbine blue ',[96,78,129],'604e81',6311553],
['nbs-iscc-m:columbinered.259','columbinered','columbine red ',[103,49,71],'673147',6762823],
['nbs-iscc-m:comet.183','comet','comet',[0,48,78],'00304e',12366],
['nbs-iscc-m:commelinablue.182','commelinablue','commelina blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:commodore.194','commodore','commodore',[48,38,122],'30267a',3155578],
['nbs-iscc-m:como.173','como','como',[54,117,136],'367588',3569032],
['nbs-iscc-m:conchshell.26','conchshell','conch shell',[248,131,121],'f88379',16286585],
['nbs-iscc-m:concord.212','concord','concord',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:condor.77','condor','condor',[130,102,68],'826644',8545860],
['nbs-iscc-m:confetti.3','confetti','confetti',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:confetti.15','confetti','confetti',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:congobrown.81','congobrown','congo [brown] ',[72,60,50],'483c32',4734002],
['nbs-iscc-m:congopink.39','congopink','congo pink',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:continentalblue.229','continentalblue','continental blue',[80,64,77],'50404d',5259341],
['nbs-iscc-m:continentalblue.235','continentalblue','continental blue',[36,33,36],'242124',2367780],
['nbs-iscc-m:cookie.58','cookie','cookie',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:coolie.200','coolie','coolie',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:coolie.201','coolie','coolie',[37,36,64],'252440',2434112],
['nbs-iscc-m:copenhagenblue.186','copenhagenblue','copenhagen [blue] ',[83,104,120],'536878',5466232],
['nbs-iscc-m:copenhagenblue.204','copenhagenblue','copenhagen [blue] ',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:copper.39','copper','copper',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:copperblue.182','copperblue','copper blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:copperbrown.55','copperbrown','copper brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:coppergreen.136','coppergreen','copper green',[103,146,103],'679267',6787687],
['nbs-iscc-m:copperleaf.43','copperleaf','copperleaf',[121,68,59],'79443b',7947323],
['nbs-iscc-m:copperlustre.55','copperlustre','copper lustre',[128,70,27],'80461b',8406555],
['nbs-iscc-m:copperred.39','copperred','copper red',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:copperrose.15','copperrose','copper rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:copperyellow.87','copperyellow','copper yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:copra.23','copra','copra',[92,80,79],'5c504f',6049871],
['nbs-iscc-m:coptic.43','coptic','coptic',[121,68,59],'79443b',7947323],
['nbs-iscc-m:coquelicot.11','coquelicot','coquelicot',[190,0,50],'be0032',12451890],
['nbs-iscc-m:coquelicot.34','coquelicot','coquelicot',[226,88,34],'e25822',14833698],
['nbs-iscc-m:coquette.26','coquette','coquette',[248,131,121],'f88379',16286585],
['nbs-iscc-m:coquette.29','coquette','coquette',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:coralbell.15','coralbell','coralbell',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:coralbell.37','coralbell','coralbell',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:coralblush.26','coralblush','coral blush',[248,131,121],'f88379',16286585],
['nbs-iscc-m:coralblush.27','coralblush','coral blush',[230,103,97],'e66761',15099745],
['nbs-iscc-m:coralblush.37','coralblush','coral blush',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:coralpink.29','coralpink','coral pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:coralred.3','coralred','coral [red] ',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:coralsands.29','coralsands','coral sands',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:coralsands.32','coralsands','coral sands',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:corcir.258','corcir','corcir',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:cordova.43','cordova','cordova',[121,68,59],'79443b',7947323],
['nbs-iscc-m:cordovan.81','cordovan','cordovan',[72,60,50],'483c32',4734002],
['nbs-iscc-m:cordovan.267','cordovan','cordovan',[34,34,34],'222222',2236962],
['nbs-iscc-m:corial.29','corial','corial',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:corial.42','corial','corial',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:corinth.262','corinth','corinth',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:corinthianpink.5','corinthianpink','corinthian pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:corinthianpink.18','corinthianpink','corinthian pink',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:corinthianpurple.259','corinthianpurple','corinthian purple',[103,49,71],'673147',6762823],
['nbs-iscc-m:corinthianpurple.262','corinthianpurple','corinthian purple',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:corinthianred.19','corinthianred','corinthian red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:cork.57','cork','cork',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:cork.258','cork','cork',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:corker.258','corker','corker',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:corkur.258','corkur','corkur',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:corn.87','corn','corn',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:cornelianred.39','cornelianred','cornelian red',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:cornflowerblue.200','cornflowerblue','cornflower [blue] ',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:cornhusk.73','cornhusk','cornhusk',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:cornhusk.76','cornhusk','cornhusk',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:cornsilk.86','cornsilk','cornsilk',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:coromandel.43','coromandel','coromandel',[121,68,59],'79443b',7947323],
['nbs-iscc-m:coronation.242','coronation','coronation',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:coronation.259','coronation','coronation',[103,49,71],'673147',6762823],
['nbs-iscc-m:corsagegreen.144','corsagegreen','corsage green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:corsagegreen.163','corsagegreen','corsage green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:corsair.183','corsair','corsair',[0,48,78],'00304e',12366],
['nbs-iscc-m:corsicanblue.200','corsicanblue','corsican blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:corsicanblue.201','corsicanblue','corsican blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:corsicanblue.212','corsicanblue','corsican blue',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:corydalisgreen.122','corydalisgreen','corydalis green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:cosmos.251','cosmos','cosmos',[193,126,145],'c17e91',12680849],
['nbs-iscc-m:cossack.150','cossack','cossack',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:cossackgreen.137','cossackgreen','cossack green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:cossegreen.120','cossegreen','cosse green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:cotch.58','cotch','cotch',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cotingapurple.219','cotingapurple','cotinga purple',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:cotingapurple.224','cotingapurple','cotinga purple',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:cotingapurple.238','cotingapurple','cotinga purple',[112,41,99],'702963',7350627],
['nbs-iscc-m:cotingapurple.242','cotingapurple','cotinga purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:cotrine.72','cotrine','cotrine',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:cotrine.76','cotrine','cotrine',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:courgegreen.103','courgegreen','courge green',[152,148,62],'98943e',9999422],
['nbs-iscc-m:courgegreen.106','courgegreen','courge green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:courgegreen.120','courgegreen','courge green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:cowboy.58','cowboy','cowboy',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cowboy.61','cowboy','cowboy',[99,81,71],'635147',6508871],
['nbs-iscc-m:cowboy.77','cowboy','cowboy',[130,102,68],'826644',8545860],
['nbs-iscc-m:cowboy.80','cowboy','cowboy',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:cowslip.50','cowslip','cowslip',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:cowslip.53','cowslip','cowslip',[217,144,88],'d99058',14258264],
['nbs-iscc-m:crabapple.37','crabapple','crabapple',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:cracker.76','cracker','cracker',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:crag.113','crag','crag',[87,85,76],'57554c',5723468],
['nbs-iscc-m:crane.233','crane','crane',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:crash.90','crash','crash',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:crash.91','crash','crash',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:crash.94','crash','crash',[150,113,23],'967117',9859351],
['nbs-iscc-m:crash.109','crash','crash',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:crawshayred.38','crawshayred','crawshay red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:crawshayred.55','crawshayred','crawshay red',[128,70,27],'80461b',8406555],
['nbs-iscc-m:crayonblue.186','crayonblue','crayon blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:cream.89','cream','cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:creambeige.42','creambeige','cream beige',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:creambeige.57','creambeige','cream beige',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:creambeige.60','creambeige','cream beige',[149,128,112],'958070',9797744],
['nbs-iscc-m:creambuff.89','creambuff','cream buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:creambuff.90','creambuff','cream buff',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:creole.54','creole','creole',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:creole.57','creole','creole',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:cressgreen.120','cressgreen','cress green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:cresson.120','cresson','cresson',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:crevette.26','crevette','crevette',[248,131,121],'f88379',16286585],
['nbs-iscc-m:crimsonlake.15','crimsonlake','crimson lake',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:crimsonmadder.11','crimsonmadder','crimson madder',[190,0,50],'be0032',12451890],
['nbs-iscc-m:crimsonmaple.41','crimsonmaple','crimson maple',[86,7,12],'56070c',5637900],
['nbs-iscc-m:croceus.53','croceus','croceus',[217,144,88],'d99058',14258264],
['nbs-iscc-m:croceus.71','croceus','croceus',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:crocreal.53','crocreal','crocreal',[217,144,88],'d99058',14258264],
['nbs-iscc-m:crocreal.71','crocreal','crocreal',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:crocus.53','crocus','crocus',[217,144,88],'d99058',14258264],
['nbs-iscc-m:crocus.71','crocus','crocus',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:crocus.244','crocus','crocus',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-m:crocus.245','crocus','crocus',[131,100,121],'836479',8610937],
['nbs-iscc-m:crocusmartis.43','crocusmartis','crocus martis',[121,68,59],'79443b',7947323],
['nbs-iscc-m:crostil.258','crostil','crostil',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:crotal.258','crotal','crotal',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:crottle.258','crottle','crottle',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:crowshayred.38','crowshayred','crowshay red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:crowshayred.55','crowshayred','crowshay red',[128,70,27],'80461b',8406555],
['nbs-iscc-m:cruiser.266','cruiser','cruiser',[85,85,85],'555555',5592405],
['nbs-iscc-m:crushedberry.19','crushedberry','crushed berry',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:crushedstrawberry.3','crushedstrawberry','crushed strawberry',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:crushedviolets.228','crushedviolets','crushed violets',[121,104,120],'796878',7956600],
['nbs-iscc-m:crystalgrey.233','crystalgrey','crystal grey',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:crystalpalaceblue.183','crystalpalaceblue','crystal palace blue',[0,48,78],'00304e',12366],
['nbs-iscc-m:crystalpalacegreen.113','crystalpalacegreen','crystal palace green',[87,85,76],'57554c',5723468],
['nbs-iscc-m:crystalsofvenus.136','crystalsofvenus','crystals of venus',[103,146,103],'679267',6787687],
['nbs-iscc-m:cub.113','cub','cub',[87,85,76],'57554c',5723468],
['nbs-iscc-m:cuba.16','cuba','cuba',[114,47,55],'722f37',7483191],
['nbs-iscc-m:cuba.43','cuba','cuba',[121,68,59],'79443b',7947323],
['nbs-iscc-m:cubansand.79','cubansand','cuban sand',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:cudbear.258','cudbear','cudbear',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:cuir.76','cuir','cuir',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:cuissedenymphe.89','cuissedenymphe','cuisse de nymphe',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:cullenearth.58','cullenearth','cullen earth',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cupidpink.29','cupidpink','cupid pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:cupreous.86','cupreous','cupreous',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:curcuma.86','curcuma','curcuma',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:currantred.12','currantred','currant [red] ',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:cutch.58','cutch','cutch',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:cuyahogared.16','cuyahogared','cuyahoga red',[114,47,55],'722f37',7483191],
['nbs-iscc-m:cyanblue.164','cyanblue','cyan blue',[49,120,115],'317873',3242099],
['nbs-iscc-m:cyanblue.173','cyanblue','cyan blue',[54,117,136],'367588',3569032],
['nbs-iscc-m:cyanineblue.176','cyanineblue','cyanine blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:cyanineblue.200','cyanineblue','cyanine blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:cyanineblue.201','cyanineblue','cyanine blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:cyclamen.243','cyclamen','cyclamen',[52,23,49],'341731',3413809],
['nbs-iscc-m:cygnet.259','cygnet','cygnet',[103,49,71],'673147',6762823],
['nbs-iscc-m:cypressgreen.125','cypressgreen','cypress [green] ',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:cypressgreen.131','cypressgreen','cypress green',[68,148,74],'44944a',4494410],
['nbs-iscc-m:cyprusearth.77','cyprusearth','cyprus earth',[130,102,68],'826644',8545860],
['nbs-iscc-m:cyprusearth.78','cyprusearth','cyprus earth',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:cyprusumber.77','cyprusumber','cyprus umber',[130,102,68],'826644',8545860],
['nbs-iscc-m:cyprusumber.78','cyprusumber','cyprus umber',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:daffodileyellow.71','daffodileyellow','daffodile [yellow] ',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:daffodilyellow.50','daffodilyellow','daffodil yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:daffodilyellow.53','daffodilyellow','daffodil yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:daffodilyellow.68','daffodilyellow','daffodil yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:daffodilyellow.71','daffodilyellow','daffodil yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:dagestan.183','dagestan','dagestan',[0,48,78],'00304e',12366],
['nbs-iscc-m:dahlia.223','dahlia','dahlia',[134,96,142],'86608e',8806542],
['nbs-iscc-m:dahliacarmine.259','dahliacarmine','dahlia carmine',[103,49,71],'673147',6762823],
['nbs-iscc-m:dahliamauve.241','dahliamauve','dahlia mauve',[145,92,131],'915c83',9526403],
['nbs-iscc-m:dahliapurple.259','dahliapurple','dahlia purple',[103,49,71],'673147',6762823],
['nbs-iscc-m:dahliapurple.260','dahliapurple','dahlia purple',[56,21,44],'38152c',3675436],
['nbs-iscc-m:damascen.211','damascen','damascen',[96,78,129],'604e81',6311553],
['nbs-iscc-m:damascen.212','damascen','damascen',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:damask.19','damask','damask',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:damonico.26','damonico','damonico',[248,131,121],'f88379',16286585],
['nbs-iscc-m:damonico.37','damonico','damonico',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:damonico.50','damonico','damonico',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:damonico.53','damonico','damonico',[217,144,88],'d99058',14258264],
['nbs-iscc-m:damson.211','damson','damson',[96,78,129],'604e81',6311553],
['nbs-iscc-m:damson.212','damson','damson',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:dana.50','dana','dana',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:dana.53','dana','dana',[217,144,88],'d99058',14258264],
['nbs-iscc-m:dana.186','dana','dana',[83,104,120],'536878',5466232],
['nbs-iscc-m:dandelion.83','dandelion','dandelion',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:dante.229','dante','dante',[80,64,77],'50404d',5259341],
['nbs-iscc-m:dante.242','dante','dante',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:dante.259','dante','dante',[103,49,71],'673147',6762823],
['nbs-iscc-m:danubegreen.137','danubegreen','danube green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:danubegreen.151','danubegreen','danube green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:daphne.182','daphne','daphne',[67,107,149],'436b95',4418453],
['nbs-iscc-m:daphnepink.262','daphnepink','daphne pink',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:daphnered.258','daphnered','daphne red',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:daphnered.262','daphnered','daphne red',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:darkbeaver.58','darkbeaver','dark beaver',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:darkbeaver.61','darkbeaver','dark beaver',[99,81,71],'635147',6508871],
['nbs-iscc-m:darkcardinal.16','darkcardinal','dark cardinal',[114,47,55],'722f37',7483191],
['nbs-iscc-m:darkgobelinblue.173','darkgobelinblue','dark gobelin blue ',[54,117,136],'367588',3569032],
['nbs-iscc-m:darkgobelinblue.186','darkgobelinblue','dark gobelin blue ',[83,104,120],'536878',5466232],
['nbs-iscc-m:darkwedgwoodblue.200','darkwedgwoodblue','dark wedgwood [blue] ',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:darkwedgwoodblue.204','darkwedgwoodblue','dark wedgwood [blue] ',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:date.81','date','date',[72,60,50],'483c32',4734002],
['nbs-iscc-m:datura.223','datura','datura',[134,96,142],'86608e',8806542],
['nbs-iscc-m:dauphine.18','dauphine','dauphine',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:davysgrey.266','davysgrey','davy\'s grey',[85,85,85],'555555',5592405],
['nbs-iscc-m:dawn.5','dawn','dawn',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:dawngrey.265','dawngrey','dawn grey ',[132,132,130],'848482',8684674],
['nbs-iscc-m:daybreak.210','daybreak','daybreak',[140,130,182],'8c82b6',9208502],
['nbs-iscc-m:daybreak.222','daybreak','daybreak',[182,149,192],'b695c0',11965888],
['nbs-iscc-m:daytona.63','daytona','daytona',[142,130,121],'8e8279',9339513],
['nbs-iscc-m:dbutantepink.5','dbutantepink','dbutante pink ',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:deadcarnations.258','deadcarnations','dead carnations',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:deadleaf.51','deadleaf','dead leaf',[190,101,22],'be6516',12477718],
['nbs-iscc-m:deadleaf.54','deadleaf','dead leaf',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:deadleaf.55','deadleaf','dead leaf',[128,70,27],'80461b',8406555],
['nbs-iscc-m:deauvillesand.45','deauvillesand','deauville sand',[151,127,115],'977f73',9928563],
['nbs-iscc-m:deauvillesand.60','deauvillesand','deauville sand',[149,128,112],'958070',9797744],
['nbs-iscc-m:deepbrunswickgreen.146','deepbrunswickgreen','deep brunswick green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:deepchromegreen.137','deepchromegreen','deep chrome green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:deepchromeyellow.71','deepchromeyellow','deep chrome yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:deepstone.88','deepstone','deep stone',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:deepstone.91','deepstone','deep stone',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:deepstone.94','deepstone','deep stone',[150,113,23],'967117',9859351],
['nbs-iscc-m:deer.80','deer','deer',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:delftblue.204','delftblue','delft blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:dellarobbia.196','dellarobbia','della robbia',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:delmonte.228','delmonte','del monte',[121,104,120],'796878',7956600],
['nbs-iscc-m:delphinium.177','delphinium','delphinium',[73,151,208],'4997d0',4822992],
['nbs-iscc-m:delphinium.178','delphinium','delphinium',[0,103,165],'0067a5',26533],
['nbs-iscc-m:delphinium.181','delphinium','delphinium',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:demedici.259','demedici','de\'medici ',[103,49,71],'673147',6762823],
['nbs-iscc-m:denmark.186','denmark','denmark',[83,104,120],'536878',5466232],
['nbs-iscc-m:denver.265','denver','denver',[132,132,130],'848482',8684674],
['nbs-iscc-m:derbyblue.212','derbyblue','derby blue',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:desert.76','desert','desert',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:devilsred.12','devilsred','devil\'s red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:devilsred.15','devilsred','devil\'s red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:devonbrown.19','devonbrown','devon [brown] ',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:deweyred.12','deweyred','dewey red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:deweyred.15','deweyred','dewey red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:dewkiss.150','dewkiss','dewkiss',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:diadem.227','diadem','diadem',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:diana.181','diana','diana',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:dianthus.15','dianthus','dianthus',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:dianthus.19','dianthus','dianthus',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:diavolo.19','diavolo','diavolo',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:digitalis.228','digitalis','digitalis',[121,104,120],'796878',7956600],
['nbs-iscc-m:dipalito.71','dipalito','di palito',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:directoireblue.176','directoireblue','directoire blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:directoireblue.178','directoireblue','directoire blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:distilledgreen.136','distilledgreen','distilled green',[103,146,103],'679267',6787687],
['nbs-iscc-m:divablue.178','divablue','diva blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:divablue.182','divablue','diva blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:doe.57','doe','doe',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:doe.60','doe','doe',[149,128,112],'958070',9797744],
['nbs-iscc-m:doe.76','doe','doe',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:doe.79','doe','doe',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:doeskinbrown.42','doeskinbrown','doe-skin brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:doge.15','doge','doge',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:dogwood.57','dogwood','dogwood',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:dogwood.58','dogwood','dogwood',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:dogwood.77','dogwood','dogwood',[130,102,68],'826644',8545860],
['nbs-iscc-m:dollypink.15','dollypink','dolly pink',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:domingo.43','domingo','domingo',[121,68,59],'79443b',7947323],
['nbs-iscc-m:domingobrown.59','domingobrown','domingo brown',[66,37,24],'422518',4334872],
['nbs-iscc-m:dorado.76','dorado','dorado',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:doubloon.53','doubloon','doubloon',[217,144,88],'d99058',14258264],
['nbs-iscc-m:dove.266','dove','dove',[85,85,85],'555555',5592405],
['nbs-iscc-m:dove.259','dove','dove',[103,49,71],'673147',6762823],
['nbs-iscc-m:dovegrey.233','dovegrey','dove grey',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:dovergrey.266','dovergrey','dover grey',[85,85,85],'555555',5592405],
['nbs-iscc-m:dozer.183','dozer','dozer',[0,48,78],'00304e',12366],
['nbs-iscc-m:drab.94','drab','drab',[150,113,23],'967117',9859351],
['nbs-iscc-m:drabolive.110','drabolive','drabolive ',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:dragonfly.174','dragonfly','dragonfly',[0,73,88],'004958',18776],
['nbs-iscc-m:dragonsblood.19','dragonsblood','dragon\'s blood',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:dragonsblood.39','dragonsblood','dragon\'s blood',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:dragonsblood.42','dragonsblood','dragon\'s blood',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:drake.174','drake','drake',[0,73,88],'004958',18776],
['nbs-iscc-m:drakesneckgreen.174','drakesneckgreen','drake\'s-neck green',[0,73,88],'004958',18776],
['nbs-iscc-m:dregsofwine.16','dregsofwine','dregs of wine',[114,47,55],'722f37',7483191],
['nbs-iscc-m:dregsofwine.41','dregsofwine','dregs of wine',[86,7,12],'56070c',5637900],
['nbs-iscc-m:dregsofwine.44','dregsofwine','dregs of wine',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-m:dresdenblue.182','dresdenblue','dresden blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:dresdenbrown.77','dresdenbrown','dresden brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:dresdenbrown.94','dresdenbrown','dresden brown',[150,113,23],'967117',9859351],
['nbs-iscc-m:dresdenbrown.95','dresdenbrown','dresden brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:dryad.150','dryad','dryad',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:dryrose.19','dryrose','dry rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:dryrose.43','dryrose','dry rose',[121,68,59],'79443b',7947323],
['nbs-iscc-m:dubarry.26','dubarry','du barry',[248,131,121],'f88379',16286585],
['nbs-iscc-m:duckblue.169','duckblue','duck blue',[0,119,145],'007791',30609],
['nbs-iscc-m:duckgreen.165','duckgreen','duck green',[0,75,73],'004b49',19273],
['nbs-iscc-m:duckling.174','duckling','duckling',[0,73,88],'004958',18776],
['nbs-iscc-m:duckling.187','duckling','duckling',[54,69,79],'36454f',3556687],
['nbs-iscc-m:duckwing.204','duckwing','duck-wing',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:dugueslin.183','dugueslin','du gueslin',[0,48,78],'00304e',12366],
['nbs-iscc-m:dugueslin.201','dugueslin','du gueslin',[37,36,64],'252440',2434112],
['nbs-iscc-m:dugueslin.204','dugueslin','du gueslin',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:dumontsblue.179','dumontsblue','dumont\'s blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:dumontsblue.182','dumontsblue','dumont\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:dune.109','dune','dune',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:durango.58','durango','durango',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:dusk.234','dusk','dusk',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:dust.94','dust','dust',[150,113,23],'967117',9859351],
['nbs-iscc-m:dustygreen.109','dustygreen','dusty green',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:dutchazure.179','dutchazure','dutch azure',[0,65,106],'00416a',16746],
['nbs-iscc-m:dutchazure.182','dutchazure','dutch azure',[67,107,149],'436b95',4418453],
['nbs-iscc-m:dutchblue.186','dutchblue','dutch blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:dutchorange.68','dutchorange','dutch orange',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:dutchorange.71','dutchorange','dutch orange',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:dutchpink.83','dutchpink','dutch pink',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:dutchpink.84','dutchpink','dutch pink',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:dutchpink.86','dutchpink','dutch pink',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:dutchpink.87','dutchpink','dutch pink',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:dutchscarlet.11','dutchscarlet','dutch scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-m:dutchvermilion.34','dutchvermilion','dutch vermilion',[226,88,34],'e25822',14833698],
['nbs-iscc-m:dutchwareblue.204','dutchwareblue','dutch ware blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:dyersbroom.101','dyersbroom','dyer\'s broom',[234,230,121],'eae679',15394425],
['nbs-iscc-m:dyersbroom.102','dyersbroom','dyer\'s broom',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:dyersgreenwood.101','dyersgreenwood','dyer\'s greenwood',[234,230,121],'eae679',15394425],
['nbs-iscc-m:dyersgreenwood.102','dyersgreenwood','dyer\'s greenwood',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:dyerssaffron.11','dyerssaffron','dyer\'s saffron',[190,0,50],'be0032',12451890],
['nbs-iscc-m:eagle.64','eagle','eagle',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:eaudejavelgreen.102','eaudejavelgreen','eau-de-javel green',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:eaudenile.120','eaudenile','eau-de-nile',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:eaudenile.121','eaudenile','eau-de-nile',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:eaudenile.135','eaudenile','eau-de-nile',[147,197,146],'93c592',9684370],
['nbs-iscc-m:eburnean.89','eburnean','eburnean',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:ecclesiastic.236','ecclesiastic','ecclesiastic',[135,0,116],'870074',8847476],
['nbs-iscc-m:ecclesiastic.237','ecclesiastic','ecclesiastic',[158,79,136],'9e4f88',10375048],
['nbs-iscc-m:ecru.89','ecru','ecru',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:ecru.90','ecru','ecru',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:edengreen.131','edengreen','eden green',[68,148,74],'44944a',4494410],
['nbs-iscc-m:edengreen.136','edengreen','eden green',[103,146,103],'679267',6787687],
['nbs-iscc-m:eggplant.230','eggplant','eggplant',[41,30,41],'291e29',2694697],
['nbs-iscc-m:eggplant.235','eggplant','eggplant',[36,33,36],'242124',2367780],
['nbs-iscc-m:eggshellblue.149','eggshellblue','eggshell blue',[141,163,153],'8da399',9282457],
['nbs-iscc-m:eggshellblue.163','eggshellblue','eggshell blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:eggshellgreen.149','eggshellgreen','eggshell green',[141,163,153],'8da399',9282457],
['nbs-iscc-m:eggshellgreen.163','eggshellgreen','eggshell green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:eglantine.254','eglantine','eglantine',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:egypt.178','egypt','egypt',[0,103,165],'0067a5',26533],
['nbs-iscc-m:egyptian.19','egyptian','egyptian',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:egyptianblue.176','egyptianblue','egyptian blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:egyptianblue.178','egyptianblue','egyptian blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:egyptianbrown.81','egyptianbrown','egyptian brown',[72,60,50],'483c32',4734002],
['nbs-iscc-m:egyptiangreen.145','egyptiangreen','egyptian green',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:egyptianred.16','egyptianred','egyptian red',[114,47,55],'722f37',7483191],
['nbs-iscc-m:egyptianred.40','egyptianred','egyptian red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:eifel.19','eifel','eifel',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:eifel.43','eifel','eifel',[121,68,59],'79443b',7947323],
['nbs-iscc-m:elderberry.212','elderberry','elderberry',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:eldorado.54','eldorado','eldorado',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:electricblue.186','electricblue','electric [blue] ',[83,104,120],'536878',5466232],
['nbs-iscc-m:electricgreen.186','electricgreen','electric green',[83,104,120],'536878',5466232],
['nbs-iscc-m:elephantgreen.138','elephantgreen','elephant green',[23,54,32],'173620',1521184],
['nbs-iscc-m:elephantskin.64','elephantskin','elephant skin',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:elf.144','elf','elf',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:elf.149','elf','elf',[141,163,153],'8da399',9282457],
['nbs-iscc-m:elfingreen.144','elfingreen','elfin green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:elk.81','elk','elk',[72,60,50],'483c32',4734002],
['nbs-iscc-m:elmgreen.125','elmgreen','elm green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:elmwood.79','elmwood','elmwood',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:elmwood.94','elmwood','elmwood',[150,113,23],'967117',9859351],
['nbs-iscc-m:email.164','email','email',[49,120,115],'317873',3242099],
['nbs-iscc-m:email.173','email','email',[54,117,136],'367588',3569032],
['nbs-iscc-m:ember.15','ember','ember',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:emberglow.15','emberglow','emberglow',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:emberglow.27','emberglow','emberglow',[230,103,97],'e66761',15099745],
['nbs-iscc-m:emberglow.37','emberglow','emberglow',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:emeraldgreen.136','emeraldgreen','emerald green',[103,146,103],'679267',6787687],
['nbs-iscc-m:emeraldgreen.140','emeraldgreen','emerald green',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:emeraude.136','emeraude','emeraude',[103,146,103],'679267',6787687],
['nbs-iscc-m:emeraude.141','emeraude','emeraude',[0,121,89],'007959',31065],
['nbs-iscc-m:emeraude.145','emeraude','emeraude',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:eminence.224','eminence','eminence',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:emperorgreen.140','emperorgreen','emperor green',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:empire.141','empire','empire',[0,121,89],'007959',31065],
['nbs-iscc-m:empireblue.182','empireblue','empire blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:empiregreen.137','empiregreen','empire green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:empiregreen.151','empiregreen','empire green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:empireyellow.83','empireyellow','empire yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:empireyellow.86','empireyellow','empire yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:enamelblue.179','enamelblue','enamel blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:enamelblue.182','enamelblue','enamel blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:endive.98','endive','endive',[233,228,80],'e9e450',15328336],
['nbs-iscc-m:endive.101','endive','endive',[234,230,121],'eae679',15394425],
['nbs-iscc-m:endiveblue.185','endiveblue','endive blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:endiveblue.227','endiveblue','endive blue',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:englishblue.182','englishblue','english blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:englishgreen.117','englishgreen','english green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-m:englishgreen.131','englishgreen','english green',[68,148,74],'44944a',4494410],
['nbs-iscc-m:englishgreen.146','englishgreen','english green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:englishgrey.113','englishgrey','english grey ',[87,85,76],'57554c',5723468],
['nbs-iscc-m:englishinde.229','englishinde','english inde',[80,64,77],'50404d',5259341],
['nbs-iscc-m:englishivy.137','englishivy','english ivy',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:englishoak.58','englishoak','english oak',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:englishochre.71','englishochre','english ochre',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:englishpink.83','englishpink','english pink',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:englishpink.84','englishpink','english pink',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:englishpink.86','englishpink','english pink',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:englishpink.87','englishpink','english pink',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:englishred.12','englishred','english red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:englishred.15','englishred','english red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:englishred.35','englishred','english red',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:englishred.37','englishred','english red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:englishred.38','englishred','english red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:englishred.55','englishred','english red',[128,70,27],'80461b',8406555],
['nbs-iscc-m:englishred.43','englishred','english red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:englishvermilion.12','englishvermilion','english vermilion',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:englishviolet.224','englishviolet','english violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:ensign.183','ensign','ensign',[0,48,78],'00304e',12366],
['nbs-iscc-m:epinauche.151','epinauche','epinauche',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:epsom.120','epsom','epsom',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:erin.145','erin','erin',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:erlaugreen.136','erlaugreen','erlau green',[103,146,103],'679267',6787687],
['nbs-iscc-m:escadre.186','escadre','escadre',[83,104,120],'536878',5466232],
['nbs-iscc-m:eschel.179','eschel','eschel',[0,65,106],'00416a',16746],
['nbs-iscc-m:eschel.182','eschel','eschel',[67,107,149],'436b95',4418453],
['nbs-iscc-m:eskimo.43','eskimo','eskimo',[121,68,59],'79443b',7947323],
['nbs-iscc-m:estheticgrey.155','estheticgrey','esthetic grey',[125,137,132],'7d8984',8227204],
['nbs-iscc-m:etainblue.148','etainblue','etain blue',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-m:etainblue.184','etainblue','etain blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-m:etainblue.148','etainblue','etain blue',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-m:etainblue.162','etainblue','etain blue',[150,222,209],'96ded1',9887441],
['nbs-iscc-m:etainblue.171','etainblue','etain blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-m:etainblue.184','etainblue','etain blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-m:etang.149','etang','etang',[141,163,153],'8da399',9282457],
['nbs-iscc-m:etang.154','etang','etang',[178,190,181],'b2beb5',11714229],
['nbs-iscc-m:ether.172','ether','ether',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:etherealblue.181','etherealblue','ethereal blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:etherealblue.199','etherealblue','ethereal blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:etonblue.163','etonblue','eton blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:etruscan.43','etruscan','etruscan',[121,68,59],'79443b',7947323],
['nbs-iscc-m:etruscan.58','etruscan','etruscan',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:etruscanred.39','etruscanred','etruscan red',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:eucalyptusgreen.90','eucalyptusgreen','eucalyptus [green] ',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:eucalyptusgreen.122','eucalyptusgreen','eucalyptus [green] ',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:eugeniared.15','eugeniared','eugenia red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:eugenie.228','eugenie','eugenie',[121,104,120],'796878',7956600],
['nbs-iscc-m:eupatoriumpurple.241','eupatoriumpurple','eupatorium purple',[145,92,131],'915c83',9526403],
['nbs-iscc-m:eurekared.16','eurekared','eureka red',[114,47,55],'722f37',7483191],
['nbs-iscc-m:evegreen.98','evegreen','eve green',[233,228,80],'e9e450',15328336],
['nbs-iscc-m:evegreen.130','evegreen','eve green',[131,211,125],'83d37d',8639357],
['nbs-iscc-m:evegreen.131','evegreen','eve green',[68,148,74],'44944a',4494410],
['nbs-iscc-m:evenglow.22','evenglow','evenglow',[143,129,127],'8f817f',9404799],
['nbs-iscc-m:eventide.214','eventide','eventide',[150,144,171],'9690ab',9867435],
['nbs-iscc-m:everglade.267','everglade','everglade',[34,34,34],'222222',2236962],
['nbs-iscc-m:evergreen.137','evergreen','evergreen',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:evque.224','evque','evque',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:fadedrose.19','fadedrose','faded rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:faience.169','faience','faience',[0,119,145],'007791',30609],
['nbs-iscc-m:faience.173','faience','faience',[54,117,136],'367588',3569032],
['nbs-iscc-m:fairway.152','fairway','fairway',[26,36,33],'1a2421',1713185],
['nbs-iscc-m:fairygreen.136','fairygreen','fairy green ',[103,146,103],'679267',6787687],
['nbs-iscc-m:fakir.73','fakir','fakir',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:falcon.62','falcon','falcon',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:fallow.76','fallow','fallow',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:fandango.254','fandango','fandango',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:faon.45','faon','faon',[151,127,115],'977f73',9928563],
['nbs-iscc-m:faon.58','faon','faon',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:faon.60','faon','faon',[149,128,112],'958070',9797744],
['nbs-iscc-m:faon.61','faon','faon',[99,81,71],'635147',6508871],
['nbs-iscc-m:fashiongray.266','fashiongray','fashion gray',[85,85,85],'555555',5592405],
['nbs-iscc-m:fawnbrown.45','fawnbrown','fawn [brown] ',[151,127,115],'977f73',9928563],
['nbs-iscc-m:fawnbrown.58','fawnbrown','fawn [brown] ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:fawnbrown.60','fawnbrown','fawn [brown] ',[149,128,112],'958070',9797744],
['nbs-iscc-m:fawnbrown.61','fawnbrown','fawn [brown] ',[99,81,71],'635147',6508871],
['nbs-iscc-m:feldspar.144','feldspar','feldspar',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:fern.120','fern','fern',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:fernambucowood.15','fernambucowood','fernambucowood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:fernambucowood.19','fernambucowood','fernambucowood',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:ferngreen.120','ferngreen','fern green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:ferngreen.122','ferngreen','fern green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:ferruginous.38','ferruginous','ferruginous',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:ferruginous.55','ferruginous','ferruginous',[128,70,27],'80461b',8406555],
['nbs-iscc-m:feuille.58','feuille','feuille',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:feuillemorte.51','feuillemorte','feuille morte',[190,101,22],'be6516',12477718],
['nbs-iscc-m:feuillemorte.54','feuillemorte','feuille morte',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:feuillemorte.55','feuillemorte','feuille morte',[128,70,27],'80461b',8406555],
['nbs-iscc-m:feulamort.51','feulamort','feulamort',[190,101,22],'be6516',12477718],
['nbs-iscc-m:feulamort.54','feulamort','feulamort',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:feulamort.55','feulamort','feulamort',[128,70,27],'80461b',8406555],
['nbs-iscc-m:fez.11','fez','fez',[190,0,50],'be0032',12451890],
['nbs-iscc-m:fieldsorangevermilion.35','fieldsorangevermilion','field\'s orange vermilion',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:fieryred.34','fieryred','fiery red',[226,88,34],'e25822',14833698],
['nbs-iscc-m:fiesta.3','fiesta','fiesta',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:fieulamort.51','fieulamort','fieulamort',[190,101,22],'be6516',12477718],
['nbs-iscc-m:fieulamort.54','fieulamort','fieulamort',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:fieulamort.55','fieulamort','fieulamort',[128,70,27],'80461b',8406555],
['nbs-iscc-m:filbertbrown.57','filbertbrown','filbert [brown] ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:filbertbrown.74','filbertbrown','filbert [brown] ',[153,101,21],'996515',10052885],
['nbs-iscc-m:filemot.51','filemot','filemot',[190,101,22],'be6516',12477718],
['nbs-iscc-m:filemot.54','filemot','filemot',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:filemot.55','filemot','filemot',[128,70,27],'80461b',8406555],
['nbs-iscc-m:fillemot.51','fillemot','fillemot',[190,101,22],'be6516',12477718],
['nbs-iscc-m:fillemot.54','fillemot','fillemot',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:fillemot.55','fillemot','fillemot',[128,70,27],'80461b',8406555],
['nbs-iscc-m:firecracker.34','firecracker','firecracker',[226,88,34],'e25822',14833698],
['nbs-iscc-m:firefly.12','firefly','firefly',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:firefly.15','firefly','firefly',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:firered.34','firered','fire red',[226,88,34],'e25822',14833698],
['nbs-iscc-m:firescarlet.11','firescarlet','fire scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-m:fireweed.219','fireweed','fireweed',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:firgreen.137','firgreen','fir [green] ',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:firgreen.138','firgreen','fir [green] ',[23,54,32],'173620',1521184],
['nbs-iscc-m:firgreen.151','firgreen','fir [green] ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:firmament.186','firmament','firmament',[83,104,120],'536878',5466232],
['nbs-iscc-m:firmamentblue.172','firmamentblue','firmament blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:fishgrey.110','fishgrey','fish grey ',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:fishgrey.113','fishgrey','fish grey ',[87,85,76],'57554c',5723468],
['nbs-iscc-m:flag.212','flag','flag',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:flameblue.200','flameblue','flame blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:flameblue.204','flameblue','flame blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:flameorange.34','flameorange','flame orange',[226,88,34],'e25822',14833698],
['nbs-iscc-m:flamescarlet.34','flamescarlet','flame [scarlet] ',[226,88,34],'e25822',14833698],
['nbs-iscc-m:flamingmaple.11','flamingmaple','flaming maple',[190,0,50],'be0032',12451890],
['nbs-iscc-m:flamingmaple.12','flamingmaple','flaming maple',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:flamingmaple.13','flamingmaple','flaming maple',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:flamingmaple.15','flamingmaple','flaming maple',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:flamingo.37','flamingo','flamingo',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:flammeous.35','flammeous','flammeous',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:flash.12','flash','flash',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:flash.15','flash','flash',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:flash.36','flash','flash',[170,56,30],'aa381e',11155486],
['nbs-iscc-m:flash.38','flash','flash',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:flax.90','flax','flax',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:flaxen.90','flaxen','flaxen',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:flaxflowerblossom.186','flaxflowerblossom','flaxflower blossom',[83,104,120],'536878',5466232],
['nbs-iscc-m:flaxflowerblue.182','flaxflowerblue','flaxflower blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:flaxflowerblue.199','flaxflowerblue','flaxflower blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:flea.16','flea','flea',[114,47,55],'722f37',7483191],
['nbs-iscc-m:flemishblue.187','flemishblue','flemish blue',[54,69,79],'36454f',3556687],
['nbs-iscc-m:flesh.73','flesh','flesh',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:flesh.93','flesh','flesh',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:fleshblond.29','fleshblond','flesh blond',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:fleshblond.32','fleshblond','flesh blond',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:fleshblond.33','fleshblond','flesh blond',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:fleshochre.38','fleshochre','flesh ochre',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:fleurdelys.223','fleurdelys','fleur-de-lys',[134,96,142],'86608e',8806542],
['nbs-iscc-m:flint.267','flint','flint',[34,34,34],'222222',2236962],
['nbs-iscc-m:flintgrey.265','flintgrey','flint grey',[132,132,130],'848482',8684674],
['nbs-iscc-m:flirt.15','flirt','flirt',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:florencebrown.19','florencebrown','florence brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:florenceearth.43','florenceearth','florence earth',[121,68,59],'79443b',7947323],
['nbs-iscc-m:florentine.34','florentine','florentine',[226,88,34],'e25822',14833698],
['nbs-iscc-m:florentinelake.11','florentinelake','florentine lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:florentinelake.12','florentinelake','florentine lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:floridagold.68','floridagold','florida gold',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:floridagold.71','floridagold','florida gold',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:flossflowerblue.227','flossflowerblue','floss flower blue',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:flowerdelucegreen.137','flowerdelucegreen','flower de luce green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:fluoritegreen.136','fluoritegreen','fluorite green',[103,146,103],'679267',6787687],
['nbs-iscc-m:fluoriteviolet.224','fluoriteviolet','fluorite violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:fluoriteviolet.225','fluoriteviolet','fluorite violet',[48,25,52],'301934',3152180],
['nbs-iscc-m:fog.264','fog','fog',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:foliagebrown.51','foliagebrown','foliage brown',[190,101,22],'be6516',12477718],
['nbs-iscc-m:foliagebrown.54','foliagebrown','foliage brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:foliagebrown.55','foliagebrown','foliage brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:foliagegreen.120','foliagegreen','foliage green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:folimort.51','folimort','folimort',[190,101,22],'be6516',12477718],
['nbs-iscc-m:folimort.54','folimort','folimort',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:folimort.55','folimort','folimort',[128,70,27],'80461b',8406555],
['nbs-iscc-m:folkstone.79','folkstone','folkstone',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:folly.11','folly','folly',[190,0,50],'be0032',12451890],
['nbs-iscc-m:folly.12','folly','folly',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:fontainebleau.19','fontainebleau','fontainebleau',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:forest.151','forest','forest',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:forestgreen.125','forestgreen','forest green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:forestofdeanred.38','forestofdeanred','forest of dean red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:forestofdeanred.55','forestofdeanred','forest of dean red',[128,70,27],'80461b',8406555],
['nbs-iscc-m:forgetmenotblue.185','forgetmenotblue','forget-me-not [blue] ',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:forgetmenotblue.186','forgetmenotblue','forget-me-not [blue] ',[83,104,120],'536878',5466232],
['nbs-iscc-m:formosa.53','formosa','formosa',[217,144,88],'d99058',14258264],
['nbs-iscc-m:formosa.57','formosa','formosa',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:forsythia.71','forsythia','forsythia',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:fox.77','fox','fox',[130,102,68],'826644',8545860],
['nbs-iscc-m:fox.94','fox','fox',[150,113,23],'967117',9859351],
['nbs-iscc-m:fox.95','fox','fox',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:foxglove.207','foxglove','foxglove',[96,78,151],'604e97',6311575],
['nbs-iscc-m:foxglove.211','foxglove','foxglove',[96,78,129],'604e81',6311553],
['nbs-iscc-m:foxtrot.163','foxtrot','fox trot',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:fragonard.15','fragonard','fragonard',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:france.183','france','france',[0,48,78],'00304e',12366],
['nbs-iscc-m:francerose.3','francerose','france rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:francerose.24','francerose','france rose',[40,32,34],'282022',2629666],
['nbs-iscc-m:freedom.183','freedom','freedom',[0,48,78],'00304e',12366],
['nbs-iscc-m:freestone.73','freestone','freestone',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:frenchbeige.57','frenchbeige','french beige',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:frenchberries.68','frenchberries','french berries',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:frenchberries.71','frenchberries','french berries',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:frenchblue.178','frenchblue','french blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:frenchblue.196','frenchblue','french blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:frenchgreen.136','frenchgreen','french green',[103,146,103],'679267',6787687],
['nbs-iscc-m:frenchgreen.145','frenchgreen','french green',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:frenchgrey.154','frenchgrey','french grey',[178,190,181],'b2beb5',11714229],
['nbs-iscc-m:frenchgrey.264','frenchgrey','french grey',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:frenchlilac.223','frenchlilac','french lilac',[134,96,142],'86608e',8806542],
['nbs-iscc-m:frenchlilac.228','frenchlilac','french lilac',[121,104,120],'796878',7956600],
['nbs-iscc-m:frenchmaroon.19','frenchmaroon','french maroon',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:frenchnude.45','frenchnude','french nude',[151,127,115],'977f73',9928563],
['nbs-iscc-m:frenchnude.57','frenchnude','french nude',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:frenchnude.60','frenchnude','french nude',[149,128,112],'958070',9797744],
['nbs-iscc-m:frenchochre.71','frenchochre','french ochre',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:frenchpink.73','frenchpink','french pink',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:frenchpink.87','frenchpink','french pink',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:frenchpurple.258','frenchpurple','french purple',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:frenchscarlet.11','frenchscarlet','french scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-m:frenchultramarine.178','frenchultramarine','french ultramarine',[0,103,165],'0067a5',26533],
['nbs-iscc-m:frenchultramarine.196','frenchultramarine','french ultramarine',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:frenchvermilion.34','frenchvermilion','french vermilion',[226,88,34],'e25822',14833698],
['nbs-iscc-m:frenchveronesegreen.141','frenchveronesegreen','[french] veronese green ',[0,121,89],'007959',31065],
['nbs-iscc-m:frenchveronesegreen.145','frenchveronesegreen','[french] veronese green ',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:frenchwhite.232','frenchwhite','french white',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-m:frenchwhite.252','frenchwhite','french white',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-m:frenchyellow.54','frenchyellow','french yellow',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:frenchyellow.74','frenchyellow','french yellow',[153,101,21],'996515',10052885],
['nbs-iscc-m:frenchyellow.57','frenchyellow','french yellow',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:friar.61','friar','friar',[99,81,71],'635147',6508871],
['nbs-iscc-m:friar.62','friar','friar',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:frostgrey.265','frostgrey','frost grey',[132,132,130],'848482',8684674],
['nbs-iscc-m:frostygreen.151','frostygreen','frosty green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:fuchsia.236','fuchsia','fuchsia',[135,0,116],'870074',8847476],
['nbs-iscc-m:fudge.58','fudge','fudge',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:fujiyama.43','fujiyama','fujiyama',[121,68,59],'79443b',7947323],
['nbs-iscc-m:fuscous.64','fuscous','fuscous',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:fustet.83','fustet','fustet',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:fustet.84','fustet','fustet',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:fustic.87','fustic','fustic',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:fustic.90','fustic','fustic',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:gagegreen.122','gagegreen','gage green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:gaiety.3','gaiety','gaiety',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:galleon.62','galleon','galleon',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:gallstone.84','gallstone','gallstone',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:gambia.58','gambia','gambia',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:gamboge.84','gamboge','gamboge',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:gardeniagreen.151','gardeniagreen','gardenia green ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:gargoyle.266','gargoyle','gargoyle',[85,85,85],'555555',5592405],
['nbs-iscc-m:garlandgreen.125','garlandgreen','garland green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:garlandgreen.137','garlandgreen','garland green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:garnet.16','garnet','garnet',[114,47,55],'722f37',7483191],
['nbs-iscc-m:garnetbrown.16','garnetbrown','garnet brown',[114,47,55],'722f37',7483191],
['nbs-iscc-m:garnetbrown.43','garnetbrown','garnet brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:garnetred.13','garnetred','garnet red',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:garnetred.16','garnetred','garnet red',[114,47,55],'722f37',7483191],
['nbs-iscc-m:garterblue.204','garterblue','garter blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:gaude.101','gaude','gaude',[234,230,121],'eae679',15394425],
['nbs-iscc-m:gaude.102','gaude','gaude',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:gaudelake.86','gaudelake','gaude lake',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:gaudygreen.120','gaudygreen','gaudy green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:gaudygreen.125','gaudygreen','gaudy green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:gaygreen.120','gaygreen','gay green ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:gazellebrown.61','gazellebrown','gazelle [brown] ',[99,81,71],'635147',6508871],
['nbs-iscc-m:gazellebrown.80','gazellebrown','gazelle [brown] ',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:geisha.241','geisha','geisha',[145,92,131],'915c83',9526403],
['nbs-iscc-m:geisha.258','geisha','geisha',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:geisha.262','geisha','geisha',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:gendarmeblue.164','gendarmeblue','gendarme [blue] ',[49,120,115],'317873',3242099],
['nbs-iscc-m:gendarmeblue.173','gendarmeblue','gendarme [blue] ',[54,117,136],'367588',3569032],
['nbs-iscc-m:generall.83','generall','generall',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:generall.84','generall','generall',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:generall.86','generall','generall',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:generall.87','generall','generall',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:genestrole.101','genestrole','genestrole',[234,230,121],'eae679',15394425],
['nbs-iscc-m:genestrole.102','genestrole','genestrole',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:genet.101','genet','genet',[234,230,121],'eae679',15394425],
['nbs-iscc-m:genet.102','genet','genet',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:genevablue.204','genevablue','geneva blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:genista.53','genista','genista',[217,144,88],'d99058',14258264],
['nbs-iscc-m:genoablue.186','genoablue','genoa blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:gentian.182','gentian','gentian',[67,107,149],'436b95',4418453],
['nbs-iscc-m:gentian.199','gentian','gentian',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:gentianblue.200','gentianblue','gentian blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:genuineultramarineblue.176','genuineultramarineblue','genuine ultramarine [blue] ',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:genuineultramarineblue.178','genuineultramarineblue','genuine ultramarine [blue] ',[0,103,165],'0067a5',26533],
['nbs-iscc-m:geranium.12','geranium','geranium',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:geraniumlake.11','geraniumlake','geranium lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:geraniumpetal.11','geraniumpetal','geranium petal',[190,0,50],'be0032',12451890],
['nbs-iscc-m:geraniumpink.3','geraniumpink','geranium pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:ghent.183','ghent','ghent',[0,48,78],'00304e',12366],
['nbs-iscc-m:giallolini.86','giallolini','giallolini',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:giallolini.87','giallolini','giallolini',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:giallolini.89','giallolini','giallolini',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:giallolini.90','giallolini','giallolini',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:giallolino.86','giallolino','giallolino',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:giallolino.87','giallolino','giallolino',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:giallolino.89','giallolino','giallolino',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:giallolino.90','giallolino','giallolino',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:gigas.223','gigas','gigas',[134,96,142],'86608e',8806542],
['nbs-iscc-m:gild.68','gild','gild',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:gild.71','gild','gild',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:gilded.68','gilded','gilded',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:gilded.71','gilded','gilded',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:gilt.68','gilt','gilt',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:gilt.71','gilt','gilt',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:gingeline.55','gingeline','gingeline',[128,70,27],'80461b',8406555],
['nbs-iscc-m:gingeoline.55','gingeoline','gingeoline',[128,70,27],'80461b',8406555],
['nbs-iscc-m:ginger.55','ginger','ginger',[128,70,27],'80461b',8406555],
['nbs-iscc-m:gingerline.55','gingerline','gingerline',[128,70,27],'80461b',8406555],
['nbs-iscc-m:gingerspice.43','gingerspice','gingerspice',[121,68,59],'79443b',7947323],
['nbs-iscc-m:gingioline.55','gingioline','gingioline',[128,70,27],'80461b',8406555],
['nbs-iscc-m:giraffe.54','giraffe','giraffe',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:giraffe.57','giraffe','giraffe',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:glacier.187','glacier','glacier',[54,69,79],'36454f',3556687],
['nbs-iscc-m:glacierblue.186','glacierblue','glacier blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:gladiolus.12','gladiolus','gladiolus',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:glaeul.18','glaeul','glaeul',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:glaeul.30','glaeul','glaeul',[196,131,121],'c48379',12878713],
['nbs-iscc-m:glassgreen.119','glassgreen','glass green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:glassgrey.190','glassgrey','glass grey',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:glaucous.121','glaucous','glaucous',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:glaucousblue.186','glaucousblue','glaucous-blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:glaucousgreen.148','glaucousgreen','glaucous-green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-m:glaucousgrey.190','glaucousgrey','glaucous-grey',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:glaucousgrey.264','glaucousgrey','glaucous-grey',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:glintogold.87','glintogold','glint o\'gold',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:gloaming.18','gloaming','gloaming',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:glory.197','glory','glory',[39,36,88],'272458',2565208],
['nbs-iscc-m:glory.208','glory','glory',[50,23,77],'32174d',3282765],
['nbs-iscc-m:gloxinia.219','gloxinia','gloxinia',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:gmelinsblue.178','gmelinsblue','gmelin\'s blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:gmelinsblue.196','gmelinsblue','gmelin\'s blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:gnaphaliumgreen.149','gnaphaliumgreen','gnaphalium green',[141,163,153],'8da399',9282457],
['nbs-iscc-m:goat.64','goat','goat',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:gobelinblue.186','gobelinblue','gobelin blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:gobelinblue.173','gobelinblue','gobelin blue',[54,117,136],'367588',3569032],
['nbs-iscc-m:gobelinblue.186','gobelinblue','gobelin blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:gobelingreen.145','gobelingreen','gobelin green',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:gobelinscarlet.11','gobelinscarlet','gobelin scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-m:gold.94','gold','gold',[150,113,23],'967117',9859351],
['nbs-iscc-m:goldbronze.61','goldbronze','gold bronze',[99,81,71],'635147',6508871],
['nbs-iscc-m:goldbronze.80','goldbronze','gold bronze',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:goldbrown.55','goldbrown','gold brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:goldearth.71','goldearth','gold earth',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:golden.76','golden','golden',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:golden.91','golden','golden',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:golden.94','golden','golden',[150,113,23],'967117',9859351],
['nbs-iscc-m:goldenbrown.55','goldenbrown','golden brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:goldenchestnut.58','goldenchestnut','golden chestnut',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:goldencoral.26','goldencoral','golden coral',[248,131,121],'f88379',16286585],
['nbs-iscc-m:goldencorn.71','goldencorn','golden corn',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:goldenfeather.83','goldenfeather','golden feather',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:goldenfeather.84','goldenfeather','golden feather',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:goldenfeather.86','goldenfeather','golden feather',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:goldenfeather.87','goldenfeather','golden feather',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:goldenglow.71','goldenglow','golden glow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:goldenglow.84','goldenglow','golden glow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:goldengreen.90','goldengreen','golden green',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:goldengreen.91','goldengreen','golden green',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:goldenochre.53','goldenochre','golden ochre',[217,144,88],'d99058',14258264],
['nbs-iscc-m:goldenpoppy.34','goldenpoppy','golden poppy',[226,88,34],'e25822',14833698],
['nbs-iscc-m:goldenrod.84','goldenrod','golden rod',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:goldenwheat.71','goldenwheat','golden wheat',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:goldenyellow.68','goldenyellow','golden yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:goldenyellow.71','goldenyellow','golden yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:goldenyellow.72','goldenyellow','golden yellow',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:goldenyellow.74','goldenyellow','golden yellow',[153,101,21],'996515',10052885],
['nbs-iscc-m:goldleaf.53','goldleaf','gold leaf',[217,144,88],'d99058',14258264],
['nbs-iscc-m:goldleaf.72','goldleaf','gold leaf',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:goldochre.53','goldochre','gold ochre',[217,144,88],'d99058',14258264],
['nbs-iscc-m:goldyellow.68','goldyellow','gold yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:goldyellow.71','goldyellow','gold yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:golfgreen.137','golfgreen','golf green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:golfred.12','golfred','golf [red] ',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:golfred.15','golfred','golf [red] ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:gooseberry.259','gooseberry','gooseberry',[103,49,71],'673147',6762823],
['nbs-iscc-m:gooseberrygreen.136','gooseberrygreen','gooseberry green',[103,146,103],'679267',6787687],
['nbs-iscc-m:goosegrey.81','goosegrey','goose grey',[72,60,50],'483c32',4734002],
['nbs-iscc-m:gorevan.58','gorevan','gorevan',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:goura.229','goura','goura',[80,64,77],'50404d',5259341],
['nbs-iscc-m:goya.12','goya','goya',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:grain.73','grain','grain',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:grain.76','grain','grain',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:grain.79','grain','grain',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:grain.11','grain','grain',[190,0,50],'be0032',12451890],
['nbs-iscc-m:grainingrain.11','grainingrain','grain in grain',[190,0,50],'be0032',12451890],
['nbs-iscc-m:granada.47','granada','granada',[67,48,46],'43302e',4403246],
['nbs-iscc-m:granada.62','granada','granada',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:granat.11','granat','granat',[190,0,50],'be0032',12451890],
['nbs-iscc-m:granat.34','granat','granat',[226,88,34],'e25822',14833698],
['nbs-iscc-m:granatflower.11','granatflower','granatflower',[190,0,50],'be0032',12451890],
['nbs-iscc-m:granatflower.34','granatflower','granatflower',[226,88,34],'e25822',14833698],
['nbs-iscc-m:granite.233','granite','granite',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:graniteblue.264','graniteblue','granite blue',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:grape.212','grape','grape',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:grapeblue.212','grapeblue','grape blue',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:grapefruit.102','grapefruit','grapefruit',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:grapegreen.106','grapegreen','grape green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:grapejuice.219','grapejuice','grapejuice',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:grapenuts.58','grapenuts','grapenuts',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:graphite.229','graphite','graphite',[80,64,77],'50404d',5259341],
['nbs-iscc-m:graphite.267','graphite','graphite',[34,34,34],'222222',2236962],
['nbs-iscc-m:grassgreen.120','grassgreen','grass green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:grasshopper.120','grasshopper','grasshopper',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:gravel.79','gravel','gravel',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:grayn.11','grayn','grayn',[190,0,50],'be0032',12451890],
['nbs-iscc-m:grebe.234','grebe','grebe',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:grebe.266','grebe','grebe',[85,85,85],'555555',5592405],
['nbs-iscc-m:grecianrose.18','grecianrose','grecian rose',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:grecianrose.30','grecianrose','grecian rose',[196,131,121],'c48379',12878713],
['nbs-iscc-m:greenash.135','greenash','green ash',[147,197,146],'93c592',9684370],
['nbs-iscc-m:greenfinch.106','greenfinch','green finch',[134,126,54],'867e36',8814134],
['nbs-iscc-m:greenslate.150','greenslate','green slate',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:greenslate.156','greenslate','green slate',[78,87,85],'4e5755',5134165],
['nbs-iscc-m:greenstone.122','greenstone','green stone',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:grenadinered.37','grenadinered','grenadine red ',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:grenat.16','grenat','grenat',[114,47,55],'722f37',7483191],
['nbs-iscc-m:gretnagreen.136','gretnagreen','gretna green',[103,146,103],'679267',6787687],
['nbs-iscc-m:gretnagreen.145','gretnagreen','gretna green',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:grey31.64','grey31','grey 31 ',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:greydawn.233','greydawn','grey dawn',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:greydawn.265','greydawn','grey dawn',[132,132,130],'848482',8684674],
['nbs-iscc-m:greydrab.109','greydrab','grey drab',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:greyn.11','greyn','greyn',[190,0,50],'be0032',12451890],
['nbs-iscc-m:greystone.112','greystone','grey stone',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:greyultramarineash.154','greyultramarineash','grey ultramarine ash',[178,190,181],'b2beb5',11714229],
['nbs-iscc-m:gridelin.258','gridelin','gridelin',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:griffin.266','griffin','griffin',[85,85,85],'555555',5592405],
['nbs-iscc-m:grisdelin.258','grisdelin','gris-de-lin',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:grottoblue.169','grottoblue','grotto [blue] ',[0,119,145],'007791',30609],
['nbs-iscc-m:grouse.61','grouse','grouse',[99,81,71],'635147',6508871],
['nbs-iscc-m:grouse.80','grouse','grouse',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:guignetsgreen.165','guignetsgreen','guignet\'s green',[0,75,73],'004b49',19273],
['nbs-iscc-m:guimetsblue.178','guimetsblue','guimet\'s blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:guimetsblue.196','guimetsblue','guimet\'s blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:guineagreen.160','guineagreen','guinea green',[0,122,116],'007a74',31348],
['nbs-iscc-m:guineahen.266','guineahen','guinea hen',[85,85,85],'555555',5592405],
['nbs-iscc-m:gull.265','gull','gull',[132,132,130],'848482',8684674],
['nbs-iscc-m:gullgrey.233','gullgrey','gull grey',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:gunmetal.266','gunmetal','gunmetal',[85,85,85],'555555',5592405],
['nbs-iscc-m:gypsy.55','gypsy','gypsy',[128,70,27],'80461b',8406555],
['nbs-iscc-m:gypsyred.15','gypsyred','gypsy red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:haematitered.16','haematitered','haematite red',[114,47,55],'722f37',7483191],
['nbs-iscc-m:haematitered.19','haematitered','haematite red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:haematitered.20','haematitered','haematite red',[84,61,63],'543d3f',5520703],
['nbs-iscc-m:hairbrown.64','hairbrown','hair brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:hairbrown.266','hairbrown','hair brown',[85,85,85],'555555',5592405],
['nbs-iscc-m:hamadan.94','hamadan','hamadan',[150,113,23],'967117',9859351],
['nbs-iscc-m:hamburglake.11','hamburglake','hamburg lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:hamburglake.12','hamburglake','hamburg lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:hampsteadbrown.46','hampsteadbrown','hampstead brown',[103,76,71],'674c47',6769735],
['nbs-iscc-m:hankow.183','hankow','hankow',[0,48,78],'00304e',12366],
['nbs-iscc-m:hankow.201','hankow','hankow',[37,36,64],'252440',2434112],
['nbs-iscc-m:hankow.204','hankow','hankow',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:harborblue.192','harborblue','harbor blue',[81,88,94],'51585e',5331038],
['nbs-iscc-m:harlemblue.170','harlemblue','harlem blue',[46,132,149],'2e8495',3048597],
['nbs-iscc-m:harlemblue.182','harlemblue','harlem blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:harlequin.131','harlequin','harlequin',[68,148,74],'44944a',4494410],
['nbs-iscc-m:harrisonred.11','harrisonred','harrison red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:harvardcrimson.15','harvardcrimson','harvard crimson',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:harvest.54','harvest','harvest',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:harvest.57','harvest','harvest',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:hathigray.155','hathigray','hathi gray',[125,137,132],'7d8984',8227204],
['nbs-iscc-m:hathor.176','hathor','hathor',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:hathor.178','hathor','hathor',[0,103,165],'0067a5',26533],
['nbs-iscc-m:havanarose.19','havanarose','havana rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:hay.105','hay','hay',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:hazel.57','hazel','hazel',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:hazel.74','hazel','hazel',[153,101,21],'996515',10052885],
['nbs-iscc-m:hazelnut.57','hazelnut','hazelnut',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:hazelnut.74','hazelnut','hazelnut',[153,101,21],'996515',10052885],
['nbs-iscc-m:hazyblue.135','hazyblue','hazy blue',[147,197,146],'93c592',9684370],
['nbs-iscc-m:hazyblue.144','hazyblue','hazy blue',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:hazyblue.149','hazyblue','hazy blue',[141,163,153],'8da399',9282457],
['nbs-iscc-m:heather.262','heather','heather',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:hebe.15','hebe','hebe',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:heliotrope.242','heliotrope','heliotrope',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:heliotropegrey.227','heliotropegrey','heliotrope grey ',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:heliotropegrey.228','heliotropegrey','heliotrope grey ',[121,104,120],'796878',7956600],
['nbs-iscc-m:heliotropegrey.233','heliotropegrey','heliotrope grey ',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:helleboregreen.125','helleboregreen','hellebore green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:helleboregreen.120','helleboregreen','hellebore green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:helleboregreen.122','helleboregreen','hellebore green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:helleboregreen.125','helleboregreen','hellebore green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:helleboregreen.127','helleboregreen','hellebore green',[81,87,68],'515744',5330756],
['nbs-iscc-m:helleborered.258','helleborered','hellebore red',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:helvetiablue.179','helvetiablue','helvetia blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:hemlock.152','hemlock','hemlock',[26,36,33],'1a2421',1713185],
['nbs-iscc-m:hemp.109','hemp','hemp',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:henna.40','henna','henna',[136,45,23],'882d17',8924439],
['nbs-iscc-m:hepatica.223','hepatica','hepatica',[134,96,142],'86608e',8806542],
['nbs-iscc-m:hermosapink.2','hermosapink','hermosa pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:hermosapink.5','hermosapink','hermosa pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:heron.186','heron','heron',[83,104,120],'536878',5466232],
['nbs-iscc-m:hiberniangreen.137','hiberniangreen','hibernian green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:highlandgreen.157','highlandgreen','highland green',[30,35,33],'1e2321',1975073],
['nbs-iscc-m:hindu.62','hindu','hindu',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:hispano.55','hispano','hispano',[128,70,27],'80461b',8406555],
['nbs-iscc-m:hockey.11','hockey','hockey',[190,0,50],'be0032',12451890],
['nbs-iscc-m:hollandblue.183','hollandblue','holland blue',[0,48,78],'00304e',12366],
['nbs-iscc-m:hollyberry.12','hollyberry','holly berry',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:hollyberry.15','hollyberry','holly berry',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:hollygreen.125','hollygreen','holly green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:hollygreen.132','hollygreen','holly green',[0,98,45],'00622d',25133],
['nbs-iscc-m:hollygreen.137','hollygreen','holly green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:hollyhock.256','hollyhock','hollyhock',[120,24,74],'78184a',7870538],
['nbs-iscc-m:hollywood.13','hollywood','hollywood',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:hollywood.15','hollywood','hollywood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:homageblue.201','homageblue','homage blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:honeybeige.76','honeybeige','honey beige',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:honeybird.168','honeybird','honey bird',[35,158,186],'239eba',2334394],
['nbs-iscc-m:honeydew.26','honeydew','honeydew',[248,131,121],'f88379',16286585],
['nbs-iscc-m:honeydew.53','honeydew','honeydew',[217,144,88],'d99058',14258264],
['nbs-iscc-m:honeysuckle.76','honeysuckle','honeysuckle',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:honeysweet.87','honeysweet','honeysweet',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:honeysweet.90','honeysweet','honeysweet',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:honeyyellow.91','honeyyellow','honey [yellow] ',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:hopi.57','hopi','hopi',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:horacevernetsblue.194','horacevernetsblue','horace vernet\'s blue',[48,38,122],'30267a',3155578],
['nbs-iscc-m:horizonblue.153','horizonblue','horizon [blue] ',[223,237,232],'dfede8',14675432],
['nbs-iscc-m:horsechestnut.62','horsechestnut','horsechestnut',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:hortenseviolet.223','hortenseviolet','hortense violet',[134,96,142],'86608e',8806542],
['nbs-iscc-m:hortensia.224','hortensia','hortensia',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:hortensia.225','hortensia','hortensia',[48,25,52],'301934',3152180],
['nbs-iscc-m:hortensia.229','hortensia','hortensia',[80,64,77],'50404d',5259341],
['nbs-iscc-m:hortensia.230','hortensia','hortensia',[41,30,41],'291e29',2694697],
['nbs-iscc-m:huckleberry.212','huckleberry','huckleberry',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:hudsonseal.266','hudsonseal','hudson seal',[85,85,85],'555555',5592405],
['nbs-iscc-m:hudsonseal.267','hudsonseal','hudson seal',[34,34,34],'222222',2236962],
['nbs-iscc-m:hummingbird.164','hummingbird','hummingbird',[49,120,115],'317873',3242099],
['nbs-iscc-m:hungarianblue.182','hungarianblue','hungarian blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:hungariangreen.136','hungariangreen','hungarian green',[103,146,103],'679267',6787687],
['nbs-iscc-m:huntergreen.138','huntergreen','hunter [green] ',[23,54,32],'173620',1521184],
['nbs-iscc-m:huntersgreen.138','huntersgreen','hunter\'s green',[23,54,32],'173620',1521184],
['nbs-iscc-m:huron.164','huron','huron',[49,120,115],'317873',3242099],
['nbs-iscc-m:hussar.186','hussar','hussar',[83,104,120],'536878',5466232],
['nbs-iscc-m:hyacinth.210','hyacinth','hyacinth',[140,130,182],'8c82b6',9208502],
['nbs-iscc-m:hyacinth.223','hyacinth','hyacinth',[134,96,142],'86608e',8806542],
['nbs-iscc-m:hyacinthblue.197','hyacinthblue','hyacinth blue',[39,36,88],'272458',2565208],
['nbs-iscc-m:hyacinthred.39','hyacinthred','hyacinth red',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:hyacinthviolet.219','hyacinthviolet','hyacinth violet',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:hydrangeablue.186','hydrangeablue','hydrangea blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:hydrangeablue.203','hydrangeablue','hydrangea blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:hydrangeapink.5','hydrangeapink','hydrangea pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:hydrangeared.19','hydrangeared','hydrangea red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:hydro.186','hydro','hydro',[83,104,120],'536878',5466232],
['nbs-iscc-m:hypermicred.11','hypermicred','hypermic red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:hyssopviolet.228','hyssopviolet','hyssop violet',[121,104,120],'796878',7956600],
['nbs-iscc-m:ibispink.26','ibispink','ibis pink',[248,131,121],'f88379',16286585],
['nbs-iscc-m:ibispink.29','ibispink','ibis pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:ibisred.47','ibisred','ibis red',[67,48,46],'43302e',4403246],
['nbs-iscc-m:iceberg.186','iceberg','iceberg',[83,104,120],'536878',5466232],
['nbs-iscc-m:immenssee.150','immenssee','immenssee',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:imperial.219','imperial','imperial',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:imperial.224','imperial','imperial',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:imperial.238','imperial','imperial',[112,41,99],'702963',7350627],
['nbs-iscc-m:imperial.242','imperial','imperial',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:imperialblue.179','imperialblue','imperial blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:imperialgreen.136','imperialgreen','imperial green',[103,146,103],'679267',6787687],
['nbs-iscc-m:imperialgreen.140','imperialgreen','imperial green',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:imperialjade.137','imperialjade','imperial jade',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:imperialpurple.215','imperialpurple','imperial purple',[85,76,105],'554c69',5590121],
['nbs-iscc-m:imperialstone.94','imperialstone','imperial stone ',[150,113,23],'967117',9859351],
['nbs-iscc-m:imperialyellow.71','imperialyellow','imperial yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:incagold.71','incagold','inca gold',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:indebaudias.229','indebaudias','indebaudias',[80,64,77],'50404d',5259341],
['nbs-iscc-m:indeblue.229','indeblue','inde blue',[80,64,77],'50404d',5259341],
['nbs-iscc-m:independence.212','independence','independence',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:indiaink.266','indiaink','india ink',[85,85,85],'555555',5592405],
['nbs-iscc-m:indian.54','indian','indian',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:indiana.254','indiana','indiana',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:indianblue.229','indianblue','indian blue',[80,64,77],'50404d',5259341],
['nbs-iscc-m:indianbrown.81','indianbrown','indian brown',[72,60,50],'483c32',4734002],
['nbs-iscc-m:indianbrown.95','indianbrown','indian brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:indianbrown.96','indianbrown','indian brown',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:indianbuff.76','indianbuff','indian buff',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:indianlake.258','indianlake','indian lake',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:indianorange.34','indianorange','indian orange',[226,88,34],'e25822',14833698],
['nbs-iscc-m:indianpink.42','indianpink','indian pink',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:indianpurple.259','indianpurple','indian purple',[103,49,71],'673147',6762823],
['nbs-iscc-m:indianred.43','indianred','indian red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:indianred.40','indianred','indian red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:indiansaffron.86','indiansaffron','indian saffron',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:indiantan.74','indiantan','indian tan',[153,101,21],'996515',10052885],
['nbs-iscc-m:indiantan.76','indiantan','indian tan',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:indiantan.77','indiantan','indian tan',[130,102,68],'826644',8545860],
['nbs-iscc-m:indianturquoise.164','indianturquoise','indian turquoise',[49,120,115],'317873',3242099],
['nbs-iscc-m:indianyellow.68','indianyellow','indian yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:indianyellow.71','indianyellow','indian yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:indiared.41','indiared','india red',[86,7,12],'56070c',5637900],
['nbs-iscc-m:indiaspice.57','indiaspice','india spice ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:indiatan.58','indiatan','india tan',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:indico.229','indico','indico',[80,64,77],'50404d',5259341],
['nbs-iscc-m:indicocarmine.169','indicocarmine','indico carmine',[0,119,145],'007791',30609],
['nbs-iscc-m:indigo.229','indigo','indigo',[80,64,77],'50404d',5259341],
['nbs-iscc-m:indigocarmine.169','indigocarmine','indigo carmine',[0,119,145],'007791',30609],
['nbs-iscc-m:indigoextract.169','indigoextract','indigo extract',[0,119,145],'007791',30609],
['nbs-iscc-m:indo.186','indo','indo',[83,104,120],'536878',5466232],
['nbs-iscc-m:infanta.182','infanta','infanta',[67,107,149],'436b95',4418453],
['nbs-iscc-m:infantry.186','infantry','infantry ',[83,104,120],'536878',5466232],
['nbs-iscc-m:infernalblue.201','infernalblue','infernal blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:ingenue.121','ingenue','ingenue',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:ingenue.122','ingenue','ingenue',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:inkblack.192','inkblack','ink black',[81,88,94],'51585e',5331038],
['nbs-iscc-m:inkblue.187','inkblue','ink blue',[54,69,79],'36454f',3556687],
['nbs-iscc-m:intenseblue.200','intenseblue','intense blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:intenseblue.201','intenseblue','intense blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:international.186','international','international',[83,104,120],'536878',5466232],
['nbs-iscc-m:invisiblegreen.165','invisiblegreen','invisible green',[0,75,73],'004b49',19273],
['nbs-iscc-m:invisiblegreen.152','invisiblegreen','invisible green',[26,36,33],'1a2421',1713185],
['nbs-iscc-m:ionianblue.187','ionianblue','ionian blue',[54,69,79],'36454f',3556687],
['nbs-iscc-m:ionianblue.188','ionianblue','ionian blue',[32,40,48],'202830',2107440],
['nbs-iscc-m:iris.185','iris','iris',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:iris.227','iris','iris',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:irisglow.233','irisglow','irisglow',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:irisgreen.137','irisgreen','iris green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:irisgreen.136','irisgreen','iris green',[103,146,103],'679267',6787687],
['nbs-iscc-m:irismauve.31','irismauve','iris mauve',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-m:irismauve.32','irismauve','iris mauve',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:irismauve.33','irismauve','iris mauve',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:iron.81','iron','iron',[72,60,50],'483c32',4734002],
['nbs-iscc-m:iron.267','iron','iron',[34,34,34],'222222',2236962],
['nbs-iscc-m:ironblue.266','ironblue','iron blue',[85,85,85],'555555',5592405],
['nbs-iscc-m:ironbrown.81','ironbrown','iron brown',[72,60,50],'483c32',4734002],
['nbs-iscc-m:ironbrown.267','ironbrown','iron brown',[34,34,34],'222222',2236962],
['nbs-iscc-m:ironbuff.76','ironbuff','iron buff',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:ironbuff.90','ironbuff','iron buff',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:ironcrocus.43','ironcrocus','iron crocus',[121,68,59],'79443b',7947323],
['nbs-iscc-m:irongrey.266','irongrey','iron grey ',[85,85,85],'555555',5592405],
['nbs-iscc-m:ironminium.19','ironminium','iron minium',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:ironminium.46','ironminium','iron minium',[103,76,71],'674c47',6769735],
['nbs-iscc-m:ironoxidered.40','ironoxidered','iron oxide red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:ironoxidered.55','ironoxidered','iron oxide red',[128,70,27],'80461b',8406555],
['nbs-iscc-m:ironred.40','ironred','iron red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:ironsaffron.43','ironsaffron','iron saffron',[121,68,59],'79443b',7947323],
['nbs-iscc-m:ironyellow.50','ironyellow','iron yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:ironyellow.53','ironyellow','iron yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:isabella.76','isabella','isabella',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:isabella.77','isabella','isabella',[130,102,68],'826644',8545860],
['nbs-iscc-m:isabella.91','isabella','isabella',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:isabella.94','isabella','isabella',[150,113,23],'967117',9859351],
['nbs-iscc-m:ispahan.187','ispahan','ispahan',[54,69,79],'36454f',3556687],
['nbs-iscc-m:italianblue.167','italianblue','italian blue',[0,133,161],'0085a1',34209],
['nbs-iscc-m:italianblue.169','italianblue','italian blue',[0,119,145],'007791',30609],
['nbs-iscc-m:italianlake.71','italianlake','italian lake',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:italianochre.54','italianochre','italian ochre',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:italianochre.57','italianochre','italian ochre',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:italianpink.83','italianpink','italian pink',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:italianpink.84','italianpink','italian pink',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:italianpink.86','italianpink','italian pink',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:italianpink.87','italianpink','italian pink',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:italianstraw.89','italianstraw','italian straw',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:italianstraw.90','italianstraw','italian straw',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:ivorybrown.95','ivorybrown','ivory brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:ivorybrown.96','ivorybrown','ivory brown',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:ivorywhite.89','ivorywhite','ivory white',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:ivoryyellow.89','ivoryyellow','ivory [yellow] ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:ivygreen.107','ivygreen','ivy [green] ',[102,93,30],'665d1e',6708510],
['nbs-iscc-m:ivygreen.110','ivygreen','ivy [green] ',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:jacarandabrown.81','jacarandabrown','jacaranda brown',[72,60,50],'483c32',4734002],
['nbs-iscc-m:jacinthe.53','jacinthe','jacinthe',[217,144,88],'d99058',14258264],
['nbs-iscc-m:jackrabbit.266','jackrabbit','jack rabbit',[85,85,85],'555555',5592405],
['nbs-iscc-m:jackrose.11','jackrose','jack rose',[190,0,50],'be0032',12451890],
['nbs-iscc-m:jacqueminot.15','jacqueminot','jacqueminot',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:jadesheen.136','jadesheen','jadesheen',[103,146,103],'679267',6787687],
['nbs-iscc-m:jadesheen.137','jadesheen','jadesheen',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:jadesheen.150','jadesheen','jadesheen',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:jaffaorange.37','jaffaorange','jaffa orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:jaffaorange.53','jaffaorange','jaffa orange',[217,144,88],'d99058',14258264],
['nbs-iscc-m:jaffi.113','jaffi','jaffi',[87,85,76],'57554c',5723468],
['nbs-iscc-m:jalapa.55','jalapa','jalapa',[128,70,27],'80461b',8406555],
['nbs-iscc-m:japanblue.183','japanblue','japan blue',[0,48,78],'00304e',12366],
['nbs-iscc-m:japanearth.58','japanearth','japan earth',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:japaneseblue.150','japaneseblue','japanese blue',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:japanesegreen.150','japanesegreen','japanese green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:japanesered.40','japanesered','japanese red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:japaneseyellow.25','japaneseyellow','japanese yellow',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-m:japaneseyellow.35','japaneseyellow','japanese yellow',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:japanrose.29','japanrose','japan rose',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:japanrose.53','japanrose','japan rose',[217,144,88],'d99058',14258264],
['nbs-iscc-m:japonica.19','japonica','japonica',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:jasmine.83','jasmine','jasmine',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:jasmine.86','jasmine','jasmine',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:jasper.152','jasper','jasper',[26,36,33],'1a2421',1713185],
['nbs-iscc-m:jaspergreen.145','jaspergreen','jasper green',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:jasperpink.26','jasperpink','jasper pink',[248,131,121],'f88379',16286585],
['nbs-iscc-m:jasperred.15','jasperred','jasper red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:java.59','java','java',[66,37,24],'422518',4334872],
['nbs-iscc-m:javabrown.62','javabrown','java brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:javelgreen.102','javelgreen','javel green',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:jayblue.182','jayblue','jay [blue] ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:jeanbart.212','jeanbart','jean bart',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:jewspitch.81','jewspitch','jew\'s pitch ',[72,60,50],'483c32',4734002],
['nbs-iscc-m:jockey.15','jockey','jockey',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:jonquilyellow.70','jonquilyellow','jonquil [yellow] ',[251,201,127],'fbc97f',16501119],
['nbs-iscc-m:jonquilyellow.71','jonquilyellow','jonquil [yellow] ',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:jonquilyellow.73','jonquilyellow','jonquil [yellow] ',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:jonquilyellow.86','jonquilyellow','jonquil [yellow] ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:jonquilyellow.87','jonquilyellow','jonquil [yellow] ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:josephine.57','josephine','josephine',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:jouvenceblue.164','jouvenceblue','jouvence blue',[49,120,115],'317873',3242099],
['nbs-iscc-m:jouvenceblue.173','jouvenceblue','jouvence blue',[54,117,136],'367588',3569032],
['nbs-iscc-m:judee.228','judee','judee',[121,104,120],'796878',7956600],
['nbs-iscc-m:junglegreen.147','junglegreen','jungle green',[28,53,45],'1c352d',1848621],
['nbs-iscc-m:junglegreen.152','junglegreen','jungle green',[26,36,33],'1a2421',1713185],
['nbs-iscc-m:juniper.151','juniper','juniper',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:kabistan.151','kabistan','kabistan',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:kaffa.46','kaffa','kaffa',[103,76,71],'674c47',6769735],
['nbs-iscc-m:kaiserbrown.55','kaiserbrown','kaiser brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:kangaroo.113','kangaroo','kangaroo',[87,85,76],'57554c',5723468],
['nbs-iscc-m:kara.164','kara','kara',[49,120,115],'317873',3242099],
['nbs-iscc-m:karadagh.267','karadagh','kara dagh',[34,34,34],'222222',2236962],
['nbs-iscc-m:kashabeige.112','kashabeige','kasha-beige',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:kashabeige.265','kashabeige','kasha-beige',[132,132,130],'848482',8684674],
['nbs-iscc-m:kashan.169','kashan','kashan',[0,119,145],'007791',30609],
['nbs-iscc-m:kashmir.137','kashmir','kashmir',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:kashmir.145','kashmir','kashmir',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:kashmir.150','kashmir','kashmir',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:kazak.43','kazak','kazak',[121,68,59],'79443b',7947323],
['nbs-iscc-m:kentuckygreen.107','kentuckygreen','kentucky green',[102,93,30],'665d1e',6708510],
['nbs-iscc-m:kermanshah.61','kermanshah','kermanshah',[99,81,71],'635147',6508871],
['nbs-iscc-m:kermes.11','kermes','kermes',[190,0,50],'be0032',12451890],
['nbs-iscc-m:kermesberries.11','kermesberries','kermes berries',[190,0,50],'be0032',12451890],
['nbs-iscc-m:kesseleryellow.83','kesseleryellow','kesseler yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:kesseleryellow.84','kesseleryellow','kesseler yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:kesseleryellow.86','kesseleryellow','kesseler yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:kesseleryellow.87','kesseleryellow','kesseler yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:kettledrum.43','kettledrum','kettledrum',[121,68,59],'79443b',7947323],
['nbs-iscc-m:khaki.76','khaki','khaki',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:khaki.77','khaki','khaki',[130,102,68],'826644',8545860],
['nbs-iscc-m:khiva.38','khiva','khiva',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:kildaregreen.120','kildaregreen','kildare green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:killarneygreen.136','killarneygreen','killarney [green] ',[103,146,103],'679267',6787687],
['nbs-iscc-m:killarneygreen.145','killarneygreen','killarney [green] ',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:kinemared.12','kinemared','kinema red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:kingfisher.183','kingfisher','kingfisher ',[0,48,78],'00304e',12366],
['nbs-iscc-m:kingsblue.181','kingsblue','king\'s blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:kingsblue.179','kingsblue','king\'s blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:kingsblue.182','kingsblue','king\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:kingsblue.182','kingsblue','king\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:kingsyellow.83','kingsyellow','king\'s yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:kingsyellow.84','kingsyellow','king\'s yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:kingsyellow.86','kingsyellow','king\'s yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:kingsyellow.97','kingsyellow','king\'s yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:kirchbergergreen.140','kirchbergergreen','kirchberger green',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:kiskilim.58','kiskilim','kis kilim',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:kobe.40','kobe','kobe',[136,45,23],'882d17',8924439],
['nbs-iscc-m:kolinsky.59','kolinsky','kolinsky',[66,37,24],'422518',4334872],
['nbs-iscc-m:korea.38','korea','korea',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:korea.43','korea','korea',[121,68,59],'79443b',7947323],
['nbs-iscc-m:kork.258','kork','kork',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:korkir.258','korkir','korkir',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:kremlin.165','kremlin','kremlin',[0,75,73],'004b49',19273],
['nbs-iscc-m:kronbergsgreen.125','kronbergsgreen','kronberg\'s green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:kurdistan.187','kurdistan','kurdistan',[54,69,79],'36454f',3556687],
['nbs-iscc-m:kurdistan.193','kurdistan','kurdistan',[32,36,40],'202428',2106408],
['nbs-iscc-m:kurdistan.229','kurdistan','kurdistan',[80,64,77],'50404d',5259341],
['nbs-iscc-m:kurdistan.235','kurdistan','kurdistan',[36,33,36],'242124',2367780],
['nbs-iscc-m:kyoto.26','kyoto','kyoto',[248,131,121],'f88379',16286585],
['nbs-iscc-m:kyoto.50','kyoto','kyoto',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:kyoto.53','kyoto','kyoto',[217,144,88],'d99058',14258264],
['nbs-iscc-m:labrador.183','labrador','labrador',[0,48,78],'00304e',12366],
['nbs-iscc-m:labrador.187','labrador','labrador',[54,69,79],'36454f',3556687],
['nbs-iscc-m:laclake.258','laclake','lac lake',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:lacquerred.38','lacquerred','lacquer red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:laeliapink.251','laeliapink','laelia pink',[193,126,145],'c17e91',12680849],
['nbs-iscc-m:laeliapink.261','laeliapink','laelia pink',[175,134,142],'af868e',11503246],
['nbs-iscc-m:lafrancepink.5','lafrancepink','la france pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:lagoon.163','lagoon','lagoon',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:lake.11','lake','lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:lake.12','lake','lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:lakeblue.164','lakeblue','lake blue',[49,120,115],'317873',3242099],
['nbs-iscc-m:lama.81','lama','lama',[72,60,50],'483c32',4734002],
['nbs-iscc-m:lambertsblue.182','lambertsblue','lambert\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:lapis.164','lapis','lapis',[49,120,115],'317873',3242099],
['nbs-iscc-m:lariat.57','lariat','lariat',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:lariat.76','lariat','lariat',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:lark.90','lark','lark',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:lark.91','lark','lark',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:lark.94','lark','lark',[150,113,23],'967117',9859351],
['nbs-iscc-m:larkspur.173','larkspur','larkspur',[54,117,136],'367588',3569032],
['nbs-iscc-m:latericeous.55','latericeous','latericeous',[128,70,27],'80461b',8406555],
['nbs-iscc-m:latericeous.58','latericeous','latericeous',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:lateritious.55','lateritious','lateritious',[128,70,27],'80461b',8406555],
['nbs-iscc-m:lateritious.58','lateritious','lateritious',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:latoun.87','latoun','latoun',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:latten.87','latten','latten',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:laundryblue.179','laundryblue','laundry blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:laundryblue.182','laundryblue','laundry blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:laurelgreen.106','laurelgreen','laurel green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:laureloak.43','laureloak','laurel oak',[121,68,59],'79443b',7947323],
['nbs-iscc-m:laurelpink.3','laurelpink','laurel pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:laurelpink.15','laurelpink','laurel pink',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:lava.267','lava','lava',[34,34,34],'222222',2236962],
['nbs-iscc-m:lavallire.228','lavallire','la vallire ',[121,104,120],'796878',7956600],
['nbs-iscc-m:lavender.227','lavender','lavender',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:lawngreen.120','lawngreen','lawn green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:lead.234','lead','lead',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:lead.266','lead','lead',[85,85,85],'555555',5592405],
['nbs-iscc-m:leadgrey.109','leadgrey','lead grey ',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:leadochre.89','leadochre','lead ochre ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:leadville.234','leadville','leadville',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:leafmold.59','leafmold','leaf mold',[66,37,24],'422518',4334872],
['nbs-iscc-m:leafred.11','leafred','leaf red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:leather.54','leather','leather',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:leatherbrown.58','leatherbrown','leather brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:leatherlake.51','leatherlake','leather lake',[190,101,22],'be6516',12477718],
['nbs-iscc-m:leatherlake.54','leatherlake','leather lake',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:leatherlake.55','leatherlake','leather lake',[128,70,27],'80461b',8406555],
['nbs-iscc-m:leekgreen.106','leekgreen','leek green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:leekgreen.120','leekgreen','leek green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:leghorn.89','leghorn','leghorn',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:leghorn.90','leghorn','leghorn',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:legionblue.183','legionblue','legion blue',[0,48,78],'00304e',12366],
['nbs-iscc-m:leitchsblue.176','leitchsblue','leitch\'s blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-m:leithnersblue.169','leithnersblue','leithner\'s blue',[0,119,145],'007791',30609],
['nbs-iscc-m:lemmianearth.43','lemmianearth','lemmian earth',[121,68,59],'79443b',7947323],
['nbs-iscc-m:lemnianruddle.43','lemnianruddle','lemnian ruddle',[121,68,59],'79443b',7947323],
['nbs-iscc-m:lemnos.43','lemnos','lemnos',[121,68,59],'79443b',7947323],
['nbs-iscc-m:lemonchrome.83','lemonchrome','lemon chrome',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:lemonyellow.83','lemonyellow','lemon yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:lemonyellow.84','lemonyellow','lemon yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:lemonyellow.86','lemonyellow','lemon yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:lemonyellow.87','lemonyellow','lemon yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:lettucegreen.120','lettucegreen','lettuce green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:levantred.15','levantred','levant red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:leydenblue.169','leydenblue','leyden blue',[0,119,145],'007791',30609],
['nbs-iscc-m:liberia.62','liberia','liberia',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:liberty.178','liberty','liberty',[0,103,165],'0067a5',26533],
['nbs-iscc-m:liberty.196','liberty','liberty',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:libertyblue.200','libertyblue','liberty blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:libertygreen.120','libertygreen','liberty green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:lichen.127','lichen','lichen',[81,87,68],'515744',5330756],
['nbs-iscc-m:lichengreen.154','lichengreen','lichen green',[178,190,181],'b2beb5',11714229],
['nbs-iscc-m:lido.94','lido','lido',[150,113,23],'967117',9859351],
['nbs-iscc-m:lierre.107','lierre','lierre',[102,93,30],'665d1e',6708510],
['nbs-iscc-m:lierre.110','lierre','lierre',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:lightblue1.121','lightblue1','light blue 1',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:lightblue2lightblue3.148','lightblue2lightblue3','light blue 2, light blue 3',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-m:lightblue2lightblue3.184','lightblue2lightblue3','light blue 2, light blue 3',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-m:lightblue4.184','lightblue4','light blue 4',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-m:lightblue6.185','lightblue6','light blue 6',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:lightbluelightblue5.148','lightbluelightblue5','light blue,, light blue 5',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-m:lightbrunswickgreen.137','lightbrunswickgreen','light brunswick green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:lightchromegreen.137','lightchromegreen','light chrome green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:lightchromeyellow.84','lightchromeyellow','light chrome yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:lightgrge.112','lightgrge','light grge',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:lightgunmetal.266','lightgunmetal','light gunmetal',[85,85,85],'555555',5592405],
['nbs-iscc-m:lightred.37','lightred','light red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:lightstone.90','lightstone','light stone',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:lightstone.91','lightstone','light stone',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:lightwedgwoodblue.186','lightwedgwoodblue','light wedgwood [blue] ',[83,104,120],'536878',5466232],
['nbs-iscc-m:lilac.5','lilac','lilac',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:lilac.18','lilac','lilac',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:lilac.227','lilac','lilac',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:lilaceous.5','lilaceous','lilaceous',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:lilaceous.18','lilaceous','lilaceous',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:lilacgray.33','lilacgray','lilac gray',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:lilacgray.93','lilacgray','lilac gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:lilas.5','lilas','lilas',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:lilas.18','lilas','lilas',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:lilium.223','lilium','lilium',[134,96,142],'86608e',8806542],
['nbs-iscc-m:lilium.241','lilium','lilium',[145,92,131],'915c83',9526403],
['nbs-iscc-m:lilygreen.120','lilygreen','lily green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:lilygreen.156','lilygreen','lily green',[78,87,85],'4e5755',5134165],
['nbs-iscc-m:limawood.15','limawood','limawood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:limawood.19','limawood','limawood',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:limeblue.182','limeblue','lime blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:limegreen.105','limegreen','lime green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:limegreen.106','limegreen','lime green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:limestone.64','limestone','limestone',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:limestone.266','limestone','limestone',[85,85,85],'555555',5592405],
['nbs-iscc-m:limeyellow.87','limeyellow','lime [yellow] ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:limeyellow.90','limeyellow','lime [yellow] ',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:limoges.178','limoges','limoges',[0,103,165],'0067a5',26533],
['nbs-iscc-m:limoges.182','limoges','limoges',[67,107,149],'436b95',4418453],
['nbs-iscc-m:lincolngreen.125','lincolngreen','lincoln green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:lincolnred.11','lincolnred','lincoln red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:lindengreen.102','lindengreen','linden green',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:lindenyellow.102','lindenyellow','linden yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:linoleumbrown.77','linoleumbrown','linoleum brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:lint.109','lint','lint',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:lintwhite.89','lintwhite','lint-white',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:lintwhite.90','lintwhite','lint-white',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:lion.76','lion','lion',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:lion.77','lion','lion',[130,102,68],'826644',8545860],
['nbs-iscc-m:liontawny.76','liontawny','lion tawny',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:liontawny.77','liontawny','lion tawny',[130,102,68],'826644',8545860],
['nbs-iscc-m:liqueurgreen.101','liqueurgreen','liqueur green',[234,230,121],'eae679',15394425],
['nbs-iscc-m:liqueurgreen.102','liqueurgreen','liqueur green',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:liseranpurple.237','liseranpurple','liseran purple',[158,79,136],'9e4f88',10375048],
['nbs-iscc-m:lithopurple.223','lithopurple','litho purple',[134,96,142],'86608e',8806542],
['nbs-iscc-m:lithopurple.224','lithopurple','litho purple',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:lithopurple.228','lithopurple','litho purple',[121,104,120],'796878',7956600],
['nbs-iscc-m:liver.46','liver','liver',[103,76,71],'674c47',6769735],
['nbs-iscc-m:liverbrown.46','liverbrown','liver brown',[103,76,71],'674c47',6769735],
['nbs-iscc-m:livermaroon.46','livermaroon','liver maroon',[103,76,71],'674c47',6769735],
['nbs-iscc-m:livid.234','livid','livid',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:livid.266','livid','livid',[85,85,85],'555555',5592405],
['nbs-iscc-m:lividbrown.19','lividbrown','livid brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:lividpink.8','lividpink','livid pink',[196,174,173],'c4aead',12889773],
['nbs-iscc-m:lividpurple.245','lividpurple','livid purple',[131,100,121],'836479',8610937],
['nbs-iscc-m:lividviolet.18','lividviolet','livid violet',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:lizardbronze.106','lizardbronze','lizard bronze',[134,126,54],'867e36',8814134],
['nbs-iscc-m:lizardgreen.145','lizardgreen','lizard [green] ',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:loam.64','loam','loam',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:lobeliablue.207','lobeliablue','lobelia [blue] ',[96,78,151],'604e97',6311575],
['nbs-iscc-m:lobeliaviolet.228','lobeliaviolet','lobelia violet',[121,104,120],'796878',7956600],
['nbs-iscc-m:lobster.36','lobster','lobster',[170,56,30],'aa381e',11155486],
['nbs-iscc-m:lobster.38','lobster','lobster',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:locarnogreen.145','locarnogreen','locarno green',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:loganberry.224','loganberry','loganberry',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:logcabin.64','logcabin','log cabin',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:logwood.230','logwood','logwood',[41,30,41],'291e29',2694697],
['nbs-iscc-m:logwood.235','logwood','logwood',[36,33,36],'242124',2367780],
['nbs-iscc-m:logwoodblue.192','logwoodblue','logwood blue',[81,88,94],'51585e',5331038],
['nbs-iscc-m:lokao.135','lokao','lo-kao',[147,197,146],'93c592',9684370],
['nbs-iscc-m:lokao.144','lokao','lo-kao',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:londonbrown.47','londonbrown','london brown',[67,48,46],'43302e',4403246],
['nbs-iscc-m:londonsmoke.267','londonsmoke','london smoke',[34,34,34],'222222',2236962],
['nbs-iscc-m:longbeach.76','longbeach','long beach ',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:longchamps.57','longchamps','longchamps',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:longchamps.60','longchamps','longchamps',[149,128,112],'958070',9797744],
['nbs-iscc-m:lotus.6','lotus','lotus',[192,128,129],'c08081',12615809],
['nbs-iscc-m:lotus.18','lotus','lotus',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:lotus.30','lotus','lotus',[196,131,121],'c48379',12878713],
['nbs-iscc-m:louisphilippe.199','louisphilippe','louis philippe',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:loutre.95','loutre','loutre',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:loutre.96','loutre','loutre',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:louvain.186','louvain','louvain',[83,104,120],'536878',5466232],
['nbs-iscc-m:louvain.192','louvain','louvain',[81,88,94],'51585e',5331038],
['nbs-iscc-m:lovebird.117','lovebird','love bird',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-m:loveinamist.172','loveinamist','love-in-a-mist',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:lucerneblue.199','lucerneblue','lucerne blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:luciole.191','luciole','luciole',[129,135,139],'81878b',8488843],
['nbs-iscc-m:luckystone.185','luckystone','lucky stone',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:lumiereblue.163','lumiereblue','lumiere blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:lumieregreen.119','lumieregreen','lumiere green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:lupine.181','lupine','lupine',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:lupine.199','lupine','lupine',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:luteous.101','luteous','luteous',[234,230,121],'eae679',15394425],
['nbs-iscc-m:luteous.102','luteous','luteous',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:luxor.196','luxor','luxor',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:lyonsblue.178','lyonsblue','lyons blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:macaroon.76','macaroon','macaroon',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:madder.12','madder','madder',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:madder.15','madder','madder',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:madder.35','madder','madder',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:madder.37','madder','madder',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:madderblue.214','madderblue','madder blue',[150,144,171],'9690ab',9867435],
['nbs-iscc-m:madderblue.215','madderblue','madder blue',[85,76,105],'554c69',5590121],
['nbs-iscc-m:madderbrown.43','madderbrown','madder brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:maddercarmine.15','maddercarmine','madder carmine',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:maddercarmine.258','maddercarmine','madder carmine',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:madderindianred.43','madderindianred','madder indian red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:madderlake.12','madderlake','madder lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:madderlake.255','madderlake','madder lake',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:madderpink.255','madderpink','madder pink',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:madderred.12','madderred','madder red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:madderred.15','madderred','madder red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:madderred.35','madderred','madder red',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:madderred.37','madderred','madder red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:madderviolet.224','madderviolet','madder violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:madelineblue.204','madelineblue','madeline blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:madonna.182','madonna','madonna',[67,107,149],'436b95',4418453],
['nbs-iscc-m:madonna.186','madonna','madonna',[83,104,120],'536878',5466232],
['nbs-iscc-m:madrid.61','madrid','madrid ',[99,81,71],'635147',6508871],
['nbs-iscc-m:madrid.80','madrid','madrid ',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:madura.77','madura','madura',[130,102,68],'826644',8545860],
['nbs-iscc-m:magenta.256','magenta','magenta',[120,24,74],'78184a',7870538],
['nbs-iscc-m:magentarose.256','magentarose','magenta rose',[120,24,74],'78184a',7870538],
['nbs-iscc-m:magnolia.6','magnolia','magnolia',[192,128,129],'c08081',12615809],
['nbs-iscc-m:magnolia.19','magnolia','magnolia',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:magnolia.30','magnolia','magnolia',[196,131,121],'c48379',12878713],
['nbs-iscc-m:mahogany.43','mahogany','mahogany',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mahoganybrown.43','mahoganybrown','mahogany brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mahoganyred.43','mahoganyred','mahogany red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:maidensblush.42','maidensblush','maiden\'s blush ',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:maintenon.37','maintenon','maintenon',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:maise.71','maise','maise',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:maise.73','maise','maise',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:maise.87','maise','maise',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:majolica.183','majolica','majolica',[0,48,78],'00304e',12366],
['nbs-iscc-m:majolicablue.183','majolicablue','majolica blue',[0,48,78],'00304e',12366],
['nbs-iscc-m:majolicablue.201','majolicablue','majolica blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:majolicablue.204','majolicablue','majolica blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:majolicaearth.40','majolicaearth','majolica earth',[136,45,23],'882d17',8924439],
['nbs-iscc-m:malabar.58','malabar','malabar',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:malacca.76','malacca','malacca',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:malacca.90','malacca','malacca',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:malachitegreen.136','malachitegreen','malachite green',[103,146,103],'679267',6787687],
['nbs-iscc-m:malaga.16','malaga','malaga',[114,47,55],'722f37',7483191],
['nbs-iscc-m:malaga.41','malaga','malaga',[86,7,12],'56070c',5637900],
['nbs-iscc-m:malay.58','malay','malay',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mallard.174','mallard','mallard',[0,73,88],'004958',18776],
['nbs-iscc-m:mallowpink.250','mallowpink','mallow pink',[213,151,174],'d597ae',13997998],
['nbs-iscc-m:mallowpurple.258','mallowpurple','mallow purple',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:mallowred.258','mallowred','mallow red',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:malmaison.86','malmaison','malmaison',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:malmaison.87','malmaison','malmaison',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:malmaisonrose.254','malmaisonrose','malmaison rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:malmaisonrose.255','malmaisonrose','malmaison rose',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:manchu.58','manchu','manchu',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mandalay.61','mandalay','mandalay',[99,81,71],'635147',6508871],
['nbs-iscc-m:mandalay.62','mandalay','mandalay',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:mandarinorange.50','mandarinorange','mandarin orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:mandarinred.35','mandarinred','mandarin red',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:manganesebrown.58','manganesebrown','manganese brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:manganesevelvetbrown.77','manganesevelvetbrown','manganese velvet brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:manganesevelvetbrown.78','manganesevelvetbrown','manganese velvet brown',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:manganeseviolet.218','manganeseviolet','manganese violet',[135,86,146],'875692',8869522],
['nbs-iscc-m:mango.54','mango','mango',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:mango.57','mango','mango',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:manila.76','manila','manila ',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:manon.60','manon','manon',[149,128,112],'958070',9797744],
['nbs-iscc-m:manzanita.43','manzanita','manzanita ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:maple.90','maple','maple',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:maplesugar.77','maplesugar','maple sugar',[130,102,68],'826644',8545860],
['nbs-iscc-m:maracaibo.59','maracaibo','maracaibo',[66,37,24],'422518',4334872],
['nbs-iscc-m:marathon.50','marathon','marathon',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:marblegreen.157','marblegreen','marble green ',[30,35,33],'1e2321',1975073],
['nbs-iscc-m:margueriteyellow.121','margueriteyellow','marguerite yellow',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:marieantoinette.18','marieantoinette','marie antoinette',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:marieantoinette.19','marieantoinette','marie antoinette',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:marineblue.183','marineblue','marine [blue] ',[0,48,78],'00304e',12366],
['nbs-iscc-m:marineblue.200','marineblue','marine [blue] ',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:marineblue.201','marineblue','marine [blue] ',[37,36,64],'252440',2434112],
['nbs-iscc-m:marinecorps.204','marinecorps','marine corps',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:marinegreen.146','marinegreen','marine green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:marinegreen.151','marinegreen','marine green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:maris.151','maris','maris',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:maris.165','maris','maris',[0,75,73],'004b49',19273],
['nbs-iscc-m:marmora.164','marmora','marmora',[49,120,115],'317873',3242099],
['nbs-iscc-m:marocain.61','marocain','marocain',[99,81,71],'635147',6508871],
['nbs-iscc-m:marone.61','marone','marone',[99,81,71],'635147',6508871],
['nbs-iscc-m:maroon.16','maroon','maroon',[114,47,55],'722f37',7483191],
['nbs-iscc-m:maroon.41','maroon','maroon',[86,7,12],'56070c',5637900],
['nbs-iscc-m:maroon.44','maroon','maroon',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-m:marron.61','marron','marron',[99,81,71],'635147',6508871],
['nbs-iscc-m:marrone.61','marrone','marrone ',[99,81,71],'635147',6508871],
['nbs-iscc-m:marronglac.58','marronglac','marron glac',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:marsala.43','marsala','marsala',[121,68,59],'79443b',7947323],
['nbs-iscc-m:marsbrown.58','marsbrown','mars brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:marshrose.19','marshrose','marsh rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:marsorange.37','marsorange','mars orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:marsred.38','marsred','mars red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:marsviolet.41','marsviolet','mars violet',[86,7,12],'56070c',5637900],
['nbs-iscc-m:marsyellow.50','marsyellow','mars yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:marsyellow.53','marsyellow','mars yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:martinique.54','martinique','martinique',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:martinique.57','martinique','martinique',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:martiusyellow.101','martiusyellow','martius yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-m:marygold.50','marygold','marygold',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:mascara.43','mascara','mascara',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mascot.187','mascot','mascot',[54,69,79],'36454f',3556687],
['nbs-iscc-m:mascot.188','mascot','mascot',[32,40,48],'202830',2107440],
['nbs-iscc-m:mascot.201','mascot','mascot',[37,36,64],'252440',2434112],
['nbs-iscc-m:mascot.204','mascot','mascot',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:massicotyellow.89','massicotyellow','massicot [yellow] ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:mastcolour.54','mastcolour','mast colour',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:mastic.94','mastic','mastic',[150,113,23],'967117',9859351],
['nbs-iscc-m:matelot.179','matelot','matelot',[0,65,106],'00416a',16746],
['nbs-iscc-m:matrix.164','matrix','matrix',[49,120,115],'317873',3242099],
['nbs-iscc-m:mauveblush.33','mauveblush','mauve blush ',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:mauveblush.79','mauveblush','mauve blush ',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:mauveblush.93','mauveblush','mauve blush ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:mauvecastor.23','mauvecastor','mauve castor',[92,80,79],'5c504f',6049871],
['nbs-iscc-m:mauvedust.23','mauvedust','mauve dust',[92,80,79],'5c504f',6049871],
['nbs-iscc-m:mauveglow.18','mauveglow','mauveglow',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:mauverose.16','mauverose','mauverose',[114,47,55],'722f37',7483191],
['nbs-iscc-m:mauvetaupe.23','mauvetaupe','mauve taupe',[92,80,79],'5c504f',6049871],
['nbs-iscc-m:mauvette.227','mauvette','mauvette',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:mauvewood.43','mauvewood','mauvewood',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mauvewood.46','mauvewood','mauvewood',[103,76,71],'674c47',6769735],
['nbs-iscc-m:mavis.79','mavis','mavis',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:maya.54','maya','maya',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:maya.57','maya','maya',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:mayfairtan.57','mayfairtan','mayfair tan',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:mayfairtan.76','mayfairtan','mayfair tan',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:mayfairtan.77','mayfairtan','mayfair tan',[130,102,68],'826644',8545860],
['nbs-iscc-m:mayflower.15','mayflower','mayflower',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:mazarineblue.197','mazarineblue','mazarine blue',[39,36,88],'272458',2565208],
['nbs-iscc-m:meadowbrook.151','meadowbrook','meadowbrook',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:meadowbrook.165','meadowbrook','meadowbrook',[0,75,73],'004b49',19273],
['nbs-iscc-m:meadowgrass.137','meadowgrass','meadowgrass',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:meadowgrass.151','meadowgrass','meadowgrass',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:meadowgreen.137','meadowgreen','meadow [green] ',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:meadowlark.80','meadowlark','meadowlark',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:meadowpink.258','meadowpink','meadowpink',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:meadowpink.262','meadowpink','meadowpink',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:meadowsweet.19','meadowsweet','meadowsweet',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:meadowviolet.218','meadowviolet','meadow violet',[135,86,146],'875692',8869522],
['nbs-iscc-m:meadowviolet.237','meadowviolet','meadow violet',[158,79,136],'9e4f88',10375048],
['nbs-iscc-m:mecca.43','mecca','mecca',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mecca.58','mecca','mecca',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:medalbronze.77','medalbronze','medal bronze',[130,102,68],'826644',8545860],
['nbs-iscc-m:medalbronze.94','medalbronze','medal bronze',[150,113,23],'967117',9859351],
['nbs-iscc-m:mediciblue.191','mediciblue','medici blue',[129,135,139],'81878b',8488843],
['nbs-iscc-m:mediterranian.164','mediterranian','mediterranian',[49,120,115],'317873',3242099],
['nbs-iscc-m:mediumchromegreen.137','mediumchromegreen','medium chrome green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:mediumchromegreen.146','mediumchromegreen','medium chrome green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:meerschaum.79','meerschaum','meerschaum',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:mehal.58','mehal','mehal',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:melilot.241','melilot','melilot',[145,92,131],'915c83',9526403],
['nbs-iscc-m:meline.87','meline','meline',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:mellomauve.18','mellomauve','mello-mauve',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:mellowglow.71','mellowglow','mellowglow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:melon.26','melon','melon',[248,131,121],'f88379',16286585],
['nbs-iscc-m:mephisto.15','mephisto','mephisto ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:merida.57','merida','merida ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:merida.76','merida','merida ',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:merida.77','merida','merida ',[130,102,68],'826644',8545860],
['nbs-iscc-m:merle.174','merle','merle ',[0,73,88],'004958',18776],
['nbs-iscc-m:mermaid.122','mermaid','mermaid ',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:mesa.58','mesa','mesa ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:metal.264','metal','metal ',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:metalbrown.43','metalbrown','metal brown ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:metalbrown.46','metalbrown','metal brown ',[103,76,71],'674c47',6769735],
['nbs-iscc-m:metallicgreen.107','metallicgreen','metallic green ',[102,93,30],'665d1e',6708510],
['nbs-iscc-m:metallicgrey.233','metallicgrey','metallic grey ',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:mexican.54','mexican','mexican ',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:mexican.74','mexican','mexican ',[153,101,21],'996515',10052885],
['nbs-iscc-m:mexicanred.54','mexicanred','mexican red ',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:mexicanred.57','mexicanred','mexican red ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:mexico.43','mexico','mexico ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mexico.55','mexico','mexico ',[128,70,27],'80461b',8406555],
['nbs-iscc-m:miamisand.79','miamisand','miami sand ',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:miamisand.94','miamisand','miami sand ',[150,113,23],'967117',9859351],
['nbs-iscc-m:michigan.165','michigan','michigan ',[0,75,73],'004b49',19273],
['nbs-iscc-m:microclinegreen.148','microclinegreen','microcline green ',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-m:middlebrunswickgreen.137','middlebrunswickgreen','middle brunswick green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:middlestone.91','middlestone','middle stone ',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:middy.183','middy','middy ',[0,48,78],'00304e',12366],
['nbs-iscc-m:midnight.229','midnight','midnight ',[80,64,77],'50404d',5259341],
['nbs-iscc-m:midnightsun.35','midnightsun','midnight sun ',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:mignon.223','mignon','mignon ',[134,96,142],'86608e',8806542],
['nbs-iscc-m:mignonettegreen.106','mignonettegreen','mignonette [green] ',[134,126,54],'867e36',8814134],
['nbs-iscc-m:mignongreen.120','mignongreen','mignon green ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:mikado.35','mikado','mikado ',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:mikado.50','mikado','mikado ',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:mikadobrown.58','mikadobrown','mikado brown ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mikadoorange.53','mikadoorange','mikado orange ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:milanoblue.186','milanoblue','milano blue ',[83,104,120],'536878',5466232],
['nbs-iscc-m:milkwhite.92','milkwhite','milk white ',[240,234,214],'f0ead6',15788758],
['nbs-iscc-m:milwaukeebrick.73','milwaukeebrick','milwaukee brick ',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:milwaukeebrick.89','milwaukeebrick','milwaukee brick ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:mimosa.86','mimosa','mimosa ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:mindoro.57','mindoro','mindoro ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:mineralbister.58','mineralbister','mineral bister ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mineralblue.182','mineralblue','mineral blue ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:mineralblue.170','mineralblue','mineral blue ',[46,132,149],'2e8495',3048597],
['nbs-iscc-m:mineralblue.182','mineralblue','mineral blue ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:mineralgreen.136','mineralgreen','mineral green ',[103,146,103],'679267',6787687],
['nbs-iscc-m:mineralgrey.154','mineralgrey','mineral grey ',[178,190,181],'b2beb5',11714229],
['nbs-iscc-m:mineralorange.34','mineralorange','mineral orange ',[226,88,34],'e25822',14833698],
['nbs-iscc-m:mineralpitch.81','mineralpitch','mineral pitch ',[72,60,50],'483c32',4734002],
['nbs-iscc-m:mineralpurple.41','mineralpurple','mineral purple ',[86,7,12],'56070c',5637900],
['nbs-iscc-m:mineralred.19','mineralred','mineral red ',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:mineralrouge.40','mineralrouge','mineral rouge ',[136,45,23],'882d17',8924439],
['nbs-iscc-m:mineralrouge.55','mineralrouge','mineral rouge ',[128,70,27],'80461b',8406555],
['nbs-iscc-m:mineralviolet.218','mineralviolet','mineral violet ',[135,86,146],'875692',8869522],
['nbs-iscc-m:mineralyellow.83','mineralyellow','mineral yellow ',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:mineralyellow.84','mineralyellow','mineral yellow ',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:mineralyellow.86','mineralyellow','mineral yellow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:mineralyellow.87','mineralyellow','mineral yellow ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:mineralyellow.71','mineralyellow','mineral yellow ',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:minggreen.141','minggreen','ming green ',[0,121,89],'007959',31065],
['nbs-iscc-m:miniaturepink.31','miniaturepink','miniature pink ',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-m:miniaturepink.32','miniaturepink','miniature pink ',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:minium.34','minium','minium ',[226,88,34],'e25822',14833698],
['nbs-iscc-m:mint.146','mint','mint ',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:mint.165','mint','mint ',[0,75,73],'004b49',19273],
['nbs-iscc-m:minuet.210','minuet','minuet ',[140,130,182],'8c82b6',9208502],
['nbs-iscc-m:mirabelle.53','mirabelle','mirabelle ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:mirabelle.71','mirabelle','mirabelle ',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:mirador.59','mirador','mirador ',[66,37,24],'422518',4334872],
['nbs-iscc-m:mirage.76','mirage','mirage ',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:mistblue.135','mistblue','mist blue ',[147,197,146],'93c592',9684370],
['nbs-iscc-m:mistblue.144','mistblue','mist blue ',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:mistblue.149','mistblue','mist blue ',[141,163,153],'8da399',9282457],
['nbs-iscc-m:mistgrey.22','mistgrey','mist [grey] ',[143,129,127],'8f817f',9404799],
['nbs-iscc-m:mistletoe.122','mistletoe','mistletoe ',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:mistyblue.135','mistyblue','misty blue ',[147,197,146],'93c592',9684370],
['nbs-iscc-m:mistyblue.144','mistyblue','misty blue ',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:mistyblue.149','mistyblue','misty blue ',[141,163,153],'8da399',9282457],
['nbs-iscc-m:mistymorn.45','mistymorn','misty morn ',[151,127,115],'977f73',9928563],
['nbs-iscc-m:mistymorn.60','mistymorn','misty morn ',[149,128,112],'958070',9797744],
['nbs-iscc-m:mitisgreen.140','mitisgreen','mitis green ',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:mittlersgreen.165','mittlersgreen','mittler\'s green ',[0,75,73],'004b49',19273],
['nbs-iscc-m:moccasin.58','moccasin','moccasin ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mocha.96','mocha','mocha ',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:mochabisque.58','mochabisque','mocha bisque ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:modebeige.94','modebeige','mode beige ',[150,113,23],'967117',9859351],
['nbs-iscc-m:mohawk.43','mohawk','mohawk ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mohawk.58','mohawk','mohawk ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:monaco.164','monaco','monaco ',[49,120,115],'317873',3242099],
['nbs-iscc-m:monetblue.197','monetblue','monet blue ',[39,36,88],'272458',2565208],
['nbs-iscc-m:monetblue.200','monetblue','monet blue ',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:monicon.26','monicon','monicon ',[248,131,121],'f88379',16286585],
['nbs-iscc-m:monicon.37','monicon','monicon ',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:monicon.50','monicon','monicon ',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:monicon.53','monicon','monicon ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:monkeyskin.42','monkeyskin','monkey skin ',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:monkshood.215','monkshood','monkshood ',[85,76,105],'554c69',5590121],
['nbs-iscc-m:monsignor.218','monsignor','monsignor ',[135,86,146],'875692',8869522],
['nbs-iscc-m:monsignor.219','monsignor','monsignor ',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:monsoreau.15','monsoreau','monsoreau ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:montecarlo.160','montecarlo','monte carlo ',[0,122,116],'007a74',31348],
['nbs-iscc-m:montecarlo.164','montecarlo','monte carlo ',[49,120,115],'317873',3242099],
['nbs-iscc-m:montella.62','montella','montella ',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:montella.81','montella','montella ',[72,60,50],'483c32',4734002],
['nbs-iscc-m:monterey.38','monterey','monterey ',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:monticellogreen.137','monticellogreen','monticello green ',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:montpelliergreen.136','montpelliergreen','montpellier green ',[103,146,103],'679267',6787687],
['nbs-iscc-m:montpellieryellow.83','montpellieryellow','montpellier yellow ',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:montpellieryellow.84','montpellieryellow','montpellier yellow ',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:montpellieryellow.86','montpellieryellow','montpellier yellow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:montpellieryellow.87','montpellieryellow','montpellier yellow ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:moonbeam.264','moonbeam','moonbeam ',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:moonlight.73','moonlight','moonlight ',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:moonlight.93','moonlight','moonlight ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:moonlightblue.186','moonlightblue','moonlight blue ',[83,104,120],'536878',5466232],
['nbs-iscc-m:moonmist.93','moonmist','moonmist ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:moorishred.50','moorishred','moorish red ',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:moose.111','moose','moose ',[54,53,39],'363527',3552551],
['nbs-iscc-m:mordor.43','mordor','mordor ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mordor.58','mordor','mordor ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:moreaberries.68','moreaberries','morea berries ',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:moreaberries.71','moreaberries','morea berries ',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:morello.235','morello','morello ',[36,33,36],'242124',2367780],
['nbs-iscc-m:moresco.50','moresco','moresco ',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:moresco.53','moresco','moresco ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:morillon.120','morillon','morillon ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:morningblue.149','morningblue','morning blue ',[141,163,153],'8da399',9282457],
['nbs-iscc-m:morningblue.154','morningblue','morning blue ',[178,190,181],'b2beb5',11714229],
['nbs-iscc-m:morningdawningyellow.26','morningdawningyellow','morning dawning yellow ',[248,131,121],'f88379',16286585],
['nbs-iscc-m:morningdawningyellow.27','morningdawningyellow','morning dawning yellow ',[230,103,97],'e66761',15099745],
['nbs-iscc-m:morningdawningyellow.37','morningdawningyellow','morning dawning yellow ',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:morningglory.244','morningglory','morning glory ',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-m:moroccan.16','moroccan','moroccan ',[114,47,55],'722f37',7483191],
['nbs-iscc-m:moroccan.38','moroccan','moroccan ',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:morocco.62','morocco','morocco ',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:moroccored.16','moroccored','morocco red ',[114,47,55],'722f37',7483191],
['nbs-iscc-m:moroccored.40','moroccored','morocco red ',[136,45,23],'882d17',8924439],
['nbs-iscc-m:moroccored.43','moroccored','morocco red ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:moroccosand.76','moroccosand','morocco sand ',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:morored.43','morored','moro red ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:morro.47','morro','morro ',[67,48,46],'43302e',4403246],
['nbs-iscc-m:morro.62','morro','morro ',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:mortdore.43','mortdore','mort d\'ore ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:mortdore.58','mortdore','mort d\'ore ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mosaicblue.182','mosaicblue','mosaic blue ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:mosque.55','mosque','mosque ',[128,70,27],'80461b',8406555],
['nbs-iscc-m:mossgreen.106','mossgreen','moss [green] ',[134,126,54],'867e36',8814134],
['nbs-iscc-m:mossgreen.120','mossgreen','moss [green] ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:mossgrey.109','mossgrey','moss grey ',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:mosspink.262','mosspink','moss pink ',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:mossrose.3','mossrose','moss rose ',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:mossrose.6','mossrose','moss rose ',[192,128,129],'c08081',12615809],
['nbs-iscc-m:mosul.57','mosul','mosul ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:mosul.58','mosul','mosul ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mosul.77','mosul','mosul ',[130,102,68],'826644',8545860],
['nbs-iscc-m:mothgrey.90','mothgrey','moth [grey] ',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:motmotblue.169','motmotblue','motmot blue ',[0,119,145],'007791',30609],
['nbs-iscc-m:motmotgreen.136','motmotgreen','motmot green ',[103,146,103],'679267',6787687],
['nbs-iscc-m:motmotgreen.144','motmotgreen','motmot green ',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:mountainblue.182','mountainblue','mountain blue ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:mountaingreen.151','mountaingreen','mountain green ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:mountaingreen.136','mountaingreen','mountain green ',[103,146,103],'679267',6787687],
['nbs-iscc-m:mountainyellow.71','mountainyellow','mountain yellow ',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:mountvernongreenormtvernongreen.125','mountvernongreenormtvernongreen','mount vernon green or mt. vernon green ',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:mousedun.64','mousedun','mouse-dun ',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:mousegrey.64','mousegrey','mouse [grey] ',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:mousse.106','mousse','mousse ',[134,126,54],'867e36',8814134],
['nbs-iscc-m:mousse.120','mousse','mousse ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:msange.149','msange','msange ',[141,163,153],'8da399',9282457],
['nbs-iscc-m:mtallique.113','mtallique','mtallique ',[87,85,76],'57554c',5723468],
['nbs-iscc-m:muffin.57','muffin','muffin ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:muffin.74','muffin','muffin ',[153,101,21],'996515',10052885],
['nbs-iscc-m:mulberry.235','mulberry','mulberry ',[36,33,36],'242124',2367780],
['nbs-iscc-m:mulberryfruit.17','mulberryfruit','mulberry fruit ',[63,23,40],'3f1728',4134696],
['nbs-iscc-m:mulberryfruit.21','mulberryfruit','mulberry fruit ',[46,29,33],'2e1d21',3022113],
['nbs-iscc-m:mulberrypurple.224','mulberrypurple','mulberry purple ',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:mummy.81','mummy','mummy ',[72,60,50],'483c32',4734002],
['nbs-iscc-m:mummy.77','mummy','mummy ',[130,102,68],'826644',8545860],
['nbs-iscc-m:mummybrown.58','mummybrown','mummy brown ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mummybrown.61','mummybrown','mummy brown ',[99,81,71],'635147',6508871],
['nbs-iscc-m:mummybrown.80','mummybrown','mummy brown ',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:muraille.58','muraille','muraille ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:murillo.182','murillo','murillo ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:murinus.64','murinus','murinus ',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:murrey.235','murrey','murrey ',[36,33,36],'242124',2367780],
['nbs-iscc-m:muscade.57','muscade','muscade ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:muscovite.156','muscovite','muscovite ',[78,87,85],'4e5755',5134165],
['nbs-iscc-m:mushroom.64','mushroom','mushroom ',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:musk.81','musk','musk ',[72,60,50],'483c32',4734002],
['nbs-iscc-m:musketeer.183','musketeer','musketeer ',[0,48,78],'00304e',12366],
['nbs-iscc-m:musketeer.201','musketeer','musketeer ',[37,36,64],'252440',2434112],
['nbs-iscc-m:musketeer.204','musketeer','musketeer ',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:muskmelon.39','muskmelon','muskmelon ',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:muskmelon.53','muskmelon','muskmelon ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:muskrat.62','muskrat','muskrat ',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:mustang.80','mustang','mustang ',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:mustardbrown.58','mustardbrown','mustard brown ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:mustardyellow.87','mustardyellow','mustard [yellow] ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:mutrieyellow.97','mutrieyellow','mutrie yellow ',[220,211,0],'dcd300',14471936],
['nbs-iscc-m:mutrieyellow.98','mutrieyellow','mutrie yellow ',[233,228,80],'e9e450',15328336],
['nbs-iscc-m:myosotisblue.185','myosotisblue','myosotis blue ',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:myosotisblue.186','myosotisblue','myosotis blue ',[83,104,120],'536878',5466232],
['nbs-iscc-m:myrtlegreen.151','myrtlegreen','myrtle [green] ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:myrtlegreen.165','myrtlegreen','myrtle [green] ',[0,75,73],'004b49',19273],
['nbs-iscc-m:mythogreen.120','mythogreen','mytho green ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:mythogreen.122','mythogreen','mytho green ',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:nacarat.11','nacarat','nacarat ',[190,0,50],'be0032',12451890],
['nbs-iscc-m:nacarine.11','nacarine','nacarine ',[190,0,50],'be0032',12451890],
['nbs-iscc-m:naiad.144','naiad','naiad ',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:nankeenyellow.86','nankeenyellow','nankeen [yellow] ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:nankeenyellow.87','nankeenyellow','nankeen [yellow] ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:nankeenyellow.89','nankeenyellow','nankeen [yellow] ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:nankeenyellow.90','nankeenyellow','nankeen [yellow] ',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:naplesred.43','naplesred','naples red ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:naplesred.40','naplesred','naples red ',[136,45,23],'882d17',8924439],
['nbs-iscc-m:naplesyellow.86','naplesyellow','naples yellow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:naplesyellow.87','naplesyellow','naples yellow ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:naplesyellow.89','naplesyellow','naples yellow ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:naplesyellow.90','naplesyellow','naples yellow ',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:napoleonblue.179','napoleonblue','napoleon blue ',[0,65,106],'00416a',16746],
['nbs-iscc-m:napoli.174','napoli','napoli ',[0,73,88],'004958',18776],
['nbs-iscc-m:narcissus.84','narcissus','narcissus ',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:narcissus.87','narcissus','narcissus ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:narrawood.15','narrawood','narrawood ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:narva.151','narva','narva ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:nasturtiumred.38','nasturtiumred','nasturtium [red] ',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:nasturtiumyellow.50','nasturtiumyellow','nasturtium [yellow] ',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:nasturtiumyellow.53','nasturtiumyellow','nasturtium [yellow] ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:nasturtiumyellow.68','nasturtiumyellow','nasturtium [yellow] ',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:nasturtiumyellow.71','nasturtiumyellow','nasturtium [yellow] ',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:natalbrown.61','natalbrown','natal brown',[99,81,71],'635147',6508871],
['nbs-iscc-m:nationalblue.179','nationalblue','national [blue] ',[0,65,106],'00416a',16746],
['nbs-iscc-m:nationalblue.182','nationalblue','national [blue] ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:nationalgrey.265','nationalgrey','national grey ',[132,132,130],'848482',8684674],
['nbs-iscc-m:nattier.199','nattier','nattier',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:natural.73','natural','natural',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:natural.93','natural','natural',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:navaho.48','navaho','navaho',[243,132,0],'f38400',15959040],
['nbs-iscc-m:navaho.50','navaho','navaho',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:navy1.187','navy1','navy 1 ',[54,69,79],'36454f',3556687],
['nbs-iscc-m:navy2.230','navy2','navy 2 ',[41,30,41],'291e29',2694697],
['nbs-iscc-m:navy3.187','navy3','navy 3 ',[54,69,79],'36454f',3556687],
['nbs-iscc-m:navy3.188','navy3','navy 3 ',[32,40,48],'202830',2107440],
['nbs-iscc-m:navyblue.201','navyblue','navy blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:navyblue.204','navyblue','navy blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:neapolitanblue.204','neapolitanblue','neapolitan blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:neapolitanyellow.86','neapolitanyellow','neapolitan yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:neapolitanyellow.87','neapolitanyellow','neapolitan yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:neapolitanyellow.89','neapolitanyellow','neapolitan yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:neapolitanyellow.90','neapolitanyellow','neapolitan yellow',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:nectar.19','nectar','nectar',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:nectarine.28','nectarine','nectarine',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-m:nectarine.29','nectarine','nectarine',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:negro.81','negro','negro',[72,60,50],'483c32',4734002],
['nbs-iscc-m:negro.267','negro','negro',[34,34,34],'222222',2236962],
['nbs-iscc-m:neptunegreen.144','neptunegreen','neptune [green] ',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:neptunegreen.145','neptunegreen','neptune [green] ',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:neutralorange.51','neutralorange','neutral orange',[190,101,22],'be6516',12477718],
['nbs-iscc-m:neutralred.16','neutralred','neutral red',[114,47,55],'722f37',7483191],
['nbs-iscc-m:neutralred.259','neutralred','neutral red',[103,49,71],'673147',6762823],
['nbs-iscc-m:neutraltint.267','neutraltint','neutral tint',[34,34,34],'222222',2236962],
['nbs-iscc-m:neuvidergreen.135','neuvidergreen','neuvider green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:neuvidergreen.144','neuvidergreen','neuvider green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:neuwiedblue.164','neuwiedblue','neuwied blue',[49,120,115],'317873',3242099],
['nbs-iscc-m:neuwiederblue.164','neuwiederblue','neuwieder blue',[49,120,115],'317873',3242099],
['nbs-iscc-m:neuwiedergreen.135','neuwiedergreen','neuwieder green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:neuwiedergreen.144','neuwiedergreen','neuwieder green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:nevagreen.117','nevagreen','neva green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-m:nevagreen.130','nevagreen','neva green',[131,211,125],'83d37d',8639357],
['nbs-iscc-m:newblue.178','newblue','new blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:newblue.196','newblue','new blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:newbronze.58','newbronze','new bronze',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:newbronze.61','newbronze','new bronze',[99,81,71],'635147',6508871],
['nbs-iscc-m:newbronze.77','newbronze','new bronze',[130,102,68],'826644',8545860],
['nbs-iscc-m:newbronze.80','newbronze','new bronze',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:newcocoa.61','newcocoa','new cocoa',[99,81,71],'635147',6508871],
['nbs-iscc-m:newhay.127','newhay','new hay',[81,87,68],'515744',5330756],
['nbs-iscc-m:newport.174','newport','newport',[0,73,88],'004958',18776],
['nbs-iscc-m:newsilver.89','newsilver','new silver',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:newsilver.90','newsilver','new silver',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:newsilver.93','newsilver','new silver',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:newsilver.121','newsilver','new silver',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:newsilver.265','newsilver','new silver',[132,132,130],'848482',8684674],
['nbs-iscc-m:niagara.172','niagara','niagara',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:niagaragreen.163','niagaragreen','niagara green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:nicaraguawood.15','nicaraguawood','nicaraguawood ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:nicaraguawood.19','nicaraguawood','nicaraguawood ',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:nice.186','nice','nice',[83,104,120],'536878',5466232],
['nbs-iscc-m:nightshade.212','nightshade','nightshade',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:nightshade.229','nightshade','nightshade',[80,64,77],'50404d',5259341],
['nbs-iscc-m:nikko.182','nikko','nikko',[67,107,149],'436b95',4418453],
['nbs-iscc-m:nikko.186','nikko','nikko',[83,104,120],'536878',5466232],
['nbs-iscc-m:nileblue.163','nileblue','nile blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:nilegreen.120','nilegreen','nile [green] ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:nilegreen.122','nilegreen','nile [green] ',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:nilegreen.135','nilegreen','nile [green] ',[147,197,146],'93c592',9684370],
['nbs-iscc-m:nimbus.265','nimbus','nimbus',[132,132,130],'848482',8684674],
['nbs-iscc-m:nippon.183','nippon','nippon',[0,48,78],'00304e',12366],
['nbs-iscc-m:noisette.57','noisette','noisette',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:noisette.74','noisette','noisette',[153,101,21],'996515',10052885],
['nbs-iscc-m:nomadbrown.59','nomadbrown','nomad brown',[66,37,24],'422518',4334872],
['nbs-iscc-m:norfolk.62','norfolk','norfolk',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:normandy.183','normandy','normandy',[0,48,78],'00304e',12366],
['nbs-iscc-m:normandy.201','normandy','normandy',[37,36,64],'252440',2434112],
['nbs-iscc-m:normandy.204','normandy','normandy',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:normandyblue.149','normandyblue','normandy blue',[141,163,153],'8da399',9282457],
['nbs-iscc-m:nougat.60','nougat','nougat',[149,128,112],'958070',9797744],
['nbs-iscc-m:nougat.79','nougat','nougat',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:nubian.267','nubian','nubian',[34,34,34],'222222',2236962],
['nbs-iscc-m:nude.33','nude','nude',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:nude.73','nude','nude',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:nude.76','nude','nude',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:nude.79','nude','nude',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:nugget.53','nugget','nugget',[217,144,88],'d99058',14258264],
['nbs-iscc-m:nugget.72','nugget','nugget',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:nuncio.223','nuncio','nuncio',[134,96,142],'86608e',8806542],
['nbs-iscc-m:nurembergred.43','nurembergred','nuremberg red ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:nurembergviolet.218','nurembergviolet','nuremberg violet',[135,86,146],'875692',8869522],
['nbs-iscc-m:nutmeg.58','nutmeg','nutmeg',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:nutmeg.61','nutmeg','nutmeg',[99,81,71],'635147',6508871],
['nbs-iscc-m:nutria.113','nutria','nutria',[87,85,76],'57554c',5723468],
['nbs-iscc-m:nymphea.223','nymphea','nymphea',[134,96,142],'86608e',8806542],
['nbs-iscc-m:nymphgreen.104','nymphgreen','nymph green',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-m:nymphgreen.119','nymphgreen','nymph green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:nymphpink.2','nymphpink','nymph [pink] ',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:nymphpink.5','nymphpink','nymph [pink] ',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:oad.186','oad','oad ',[83,104,120],'536878',5466232],
['nbs-iscc-m:oakbrown.55','oakbrown','oak [brown] ',[128,70,27],'80461b',8406555],
['nbs-iscc-m:oakbrown.58','oakbrown','oak [brown] ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:oakbuff.57','oakbuff','oakbuff',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:oakbuff.76','oakbuff','oakbuff',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:oakbuff.77','oakbuff','oakbuff',[130,102,68],'826644',8545860],
['nbs-iscc-m:oakgreen.106','oakgreen','oak [green] ',[134,126,54],'867e36',8814134],
['nbs-iscc-m:oakheart.19','oakheart','oakheart',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:oakheart.43','oakheart','oakheart',[121,68,59],'79443b',7947323],
['nbs-iscc-m:oakleafbrown.51','oakleafbrown','oakleaf brown',[190,101,22],'be6516',12477718],
['nbs-iscc-m:oakleafbrown.54','oakleafbrown','oakleaf brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:oakleafbrown.55','oakleafbrown','oakleaf brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:oakwood.58','oakwood','oakwood',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:oasis.106','oasis','oasis',[134,126,54],'867e36',8814134],
['nbs-iscc-m:oasis.120','oasis','oasis',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:oceangreen.135','oceangreen','ocean green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:ocherred.19','ocherred','ocher red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:ochraceous.71','ochraceous','ochraceous',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:ochre.71','ochre','ochre',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:ochrederu.54','ochrederu','ochre de ru',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:ochrederu.74','ochrederu','ochre de ru',[153,101,21],'996515',10052885],
['nbs-iscc-m:ochrered.38','ochrered','ochre red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:oilblue.194','oilblue','oil blue',[48,38,122],'30267a',3155578],
['nbs-iscc-m:oilgreen.136','oilgreen','oil green',[103,146,103],'679267',6787687],
['nbs-iscc-m:oilyellow.102','oilyellow','oil yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:oilyellow.103','oilyellow','oil yellow',[152,148,62],'98943e',9999422],
['nbs-iscc-m:okerdeluce.54','okerdeluce','oker de luce',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:okerdeluce.74','okerdeluce','oker de luce',[153,101,21],'996515',10052885],
['nbs-iscc-m:okerdeluke.54','okerdeluke','oker de luke',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:okerdeluke.74','okerdeluke','oker de luke',[153,101,21],'996515',10052885],
['nbs-iscc-m:okerderouse.54','okerderouse','oker de rouse',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:okerderouse.74','okerderouse','oker de rouse',[153,101,21],'996515',10052885],
['nbs-iscc-m:oldamethyst.16','oldamethyst','old amethyst',[114,47,55],'722f37',7483191],
['nbs-iscc-m:oldamethyst.259','oldamethyst','old amethyst',[103,49,71],'673147',6762823],
['nbs-iscc-m:oldblue.185','oldblue','old blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:oldblue.186','oldblue','old blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:oldblue.191','oldblue','old blue',[129,135,139],'81878b',8488843],
['nbs-iscc-m:oldbronze.94','oldbronze','old bronze',[150,113,23],'967117',9859351],
['nbs-iscc-m:oldbronze.106','oldbronze','old bronze',[134,126,54],'867e36',8814134],
['nbs-iscc-m:oldburgundy.44','oldburgundy','old burgundy',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-m:oldburgundy.47','oldburgundy','old burgundy',[67,48,46],'43302e',4403246],
['nbs-iscc-m:oldcedar.43','oldcedar','old cedar',[121,68,59],'79443b',7947323],
['nbs-iscc-m:oldchina.186','oldchina','old china',[83,104,120],'536878',5466232],
['nbs-iscc-m:oldchina.204','oldchina','old china',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:oldcoral.15','oldcoral','old coral',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:olde.101','olde','olde',[234,230,121],'eae679',15394425],
['nbs-iscc-m:olde.102','olde','olde',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:oldenglishbrown.81','oldenglishbrown','old english brown',[72,60,50],'483c32',4734002],
['nbs-iscc-m:oldenglishbrown.95','oldenglishbrown','old english brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:oldenglishbrown.96','oldenglishbrown','old english brown',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:oldgold.106','oldgold','old gold',[134,126,54],'867e36',8814134],
['nbs-iscc-m:oldhelio.224','oldhelio','old helio',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:oldivory.90','oldivory','old ivory',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:oldivory.91','oldivory','old ivory',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:oldivory.94','oldivory','old ivory',[150,113,23],'967117',9859351],
['nbs-iscc-m:oldlavender.235','oldlavender','old lavender',[36,33,36],'242124',2367780],
['nbs-iscc-m:oldlilac.228','oldlilac','old lilac',[121,104,120],'796878',7956600],
['nbs-iscc-m:oldlilac.245','oldlilac','old lilac',[131,100,121],'836479',8610937],
['nbs-iscc-m:oldmauve.229','oldmauve','old mauve',[80,64,77],'50404d',5259341],
['nbs-iscc-m:oldmauve.259','oldmauve','old mauve',[103,49,71],'673147',6762823],
['nbs-iscc-m:oldmossgreen.106','oldmossgreen','old moss [green] ',[134,126,54],'867e36',8814134],
['nbs-iscc-m:oldolive.95','oldolive','old olive ',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:oldpink.57','oldpink','old pink',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:oldred.13','oldred','old red',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:oldred.15','oldred','old red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:oldrose.19','oldrose','old rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:oldroseleaf.16','oldroseleaf','old roseleaf',[114,47,55],'722f37',7483191],
['nbs-iscc-m:oldsilver.265','oldsilver','old silver',[132,132,130],'848482',8684674],
['nbs-iscc-m:oldwood.19','oldwood','old wood',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:olivaceous.107','olivaceous','olivaceous',[102,93,30],'665d1e',6708510],
['nbs-iscc-m:olivebrown.95','olivebrown','olive brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:olivedrab.110','olivedrab','olive drab',[91,88,66],'5b5842',5986370],
['nbs-iscc-m:olivegreen.107','olivegreen','olive [green] ',[102,93,30],'665d1e',6708510],
['nbs-iscc-m:olivegrey.122','olivegrey','olive grey ',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:olivegrey.155','olivegrey','olive grey ',[125,137,132],'7d8984',8227204],
['nbs-iscc-m:olivesheen.91','olivesheen','olivesheen',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:oliveterraverte.106','oliveterraverte','olive terra verte',[134,126,54],'867e36',8814134],
['nbs-iscc-m:olivewood.80','olivewood','olive wood',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:oliveyellow.103','oliveyellow','olive yellow',[152,148,62],'98943e',9999422],
['nbs-iscc-m:oliveyellow.106','oliveyellow','olive yellow',[134,126,54],'867e36',8814134],
['nbs-iscc-m:olivine.135','olivine','olivine',[147,197,146],'93c592',9684370],
['nbs-iscc-m:olympia.160','olympia','olympia',[0,122,116],'007a74',31348],
['nbs-iscc-m:olympia.164','olympia','olympia',[49,120,115],'317873',3242099],
['nbs-iscc-m:olympianblue.179','olympianblue','olympian blue ',[0,65,106],'00416a',16746],
['nbs-iscc-m:olympiangreen.136','olympiangreen','olympian green',[103,146,103],'679267',6787687],
['nbs-iscc-m:olympic.187','olympic','olympic',[54,69,79],'36454f',3556687],
['nbs-iscc-m:olympicblue.169','olympicblue','olympic blue',[0,119,145],'007791',30609],
['nbs-iscc-m:ondine.149','ondine','ondine',[141,163,153],'8da399',9282457],
['nbs-iscc-m:onionpeel.19','onionpeel','onion-peel ',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:onionred.19','onionred','onion red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:onionskinpink.29','onionskinpink','onion-skin pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:onionskinpink.53','onionskinpink','onion-skin pink',[217,144,88],'d99058',14258264],
['nbs-iscc-m:onionskinpink.57','onionskinpink','onion-skin pink',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:ontarioviolet.203','ontarioviolet','ontario violet',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:oold.101','oold','oold',[234,230,121],'eae679',15394425],
['nbs-iscc-m:oold.102','oold','oold',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:opal.164','opal','opal',[49,120,115],'317873',3242099],
['nbs-iscc-m:opalblue.186','opalblue','opal blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:opalgrey.22','opalgrey','opal grey ',[143,129,127],'8f817f',9404799],
['nbs-iscc-m:opalgrey.265','opalgrey','opal grey ',[132,132,130],'848482',8684674],
['nbs-iscc-m:opalinegreen.143','opalinegreen','opaline green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-m:opalmauve.10','opalmauve','opal mauve',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-m:opaq.136','opaq','opaq',[103,146,103],'679267',6787687],
['nbs-iscc-m:operamauve.240','operamauve','opera mauve',[183,132,167],'b784a7',12027047],
['nbs-iscc-m:operapink.28','operapink','opera pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-m:operapink.29','operapink','opera pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:operapink.31','operapink','opera pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-m:operapink.32','operapink','opera pink',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:ophelia.241','ophelia','ophelia',[145,92,131],'915c83',9526403],
['nbs-iscc-m:ophelia.262','ophelia','ophelia',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:ophelia.245','ophelia','ophelia',[131,100,121],'836479',8610937],
['nbs-iscc-m:oporto.16','oporto','oporto',[114,47,55],'722f37',7483191],
['nbs-iscc-m:oporto.17','oporto','oporto',[63,23,40],'3f1728',4134696],
['nbs-iscc-m:orangeaurora.26','orangeaurora','orange aurora',[248,131,121],'f88379',16286585],
['nbs-iscc-m:orangeaurora.27','orangeaurora','orange aurora',[230,103,97],'e66761',15099745],
['nbs-iscc-m:orangeaurora.37','orangeaurora','orange aurora',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:orangelead.34','orangelead','orange lead',[226,88,34],'e25822',14833698],
['nbs-iscc-m:orangemadder.50','orangemadder','orange madder',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:orangeochre.50','orangeochre','orange ochre',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:orangepeel.50','orangepeel','orange-peel',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:orangerufous.50','orangerufous','orange rufous',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:orangetawny.37','orangetawny','orange tawny',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:orangevermilion.35','orangevermilion','orange vermilion',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:orchadee.240','orchadee','orchadee',[183,132,167],'b784a7',12027047],
['nbs-iscc-m:orchall.258','orchall','orchall',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:orchid.222','orchid','orchid',[182,149,192],'b695c0',11965888],
['nbs-iscc-m:orchid.227','orchid','orchid',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:orchidpink.2','orchidpink','orchid pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:orchil.15','orchil','orchil ',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:orchil.258','orchil','orchil ',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:orchis.19','orchis','orchis',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:orient.5','orient','orient',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:oriental.186','oriental','oriental',[83,104,120],'536878',5466232],
['nbs-iscc-m:orientalblue.204','orientalblue','oriental blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:orientalblue.178','orientalblue','oriental blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:orientalblue.196','orientalblue','oriental blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:orientalbole.43','orientalbole','oriental bole ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:orientalfuchsia.238','orientalfuchsia','oriental fuchsia',[112,41,99],'702963',7350627],
['nbs-iscc-m:orientalgreen.131','orientalgreen','oriental green',[68,148,74],'44944a',4494410],
['nbs-iscc-m:orientalgreen.136','orientalgreen','oriental green',[103,146,103],'679267',6787687],
['nbs-iscc-m:orientalpearl.112','orientalpearl','oriental pearl',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:orientalpearl.265','orientalpearl','oriental pearl',[132,132,130],'848482',8684674],
['nbs-iscc-m:orientalred.12','orientalred','oriental red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:orientblue.178','orientblue','orient [blue] ',[0,103,165],'0067a5',26533],
['nbs-iscc-m:orientblue.182','orientblue','orient blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:orientblue.186','orientblue','orient blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:orientpink.29','orientpink','orient pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:orientred.12','orientred','orient red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:orientyellow.50','orientyellow','orient yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:orientyellow.53','orientyellow','orient yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:orientyellow.68','orientyellow','orient yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:orientyellow.71','orientyellow','orient yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:orientyellow.88','orientyellow','orient yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:orientyellow.91','orientyellow','orient yellow',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:oriole.54','oriole','oriole',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:orion.183','orion','orion',[0,48,78],'00304e',12366],
['nbs-iscc-m:orlean.29','orlean','orlean',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:ormond.45','ormond','ormond',[151,127,115],'977f73',9928563],
['nbs-iscc-m:ormond.60','ormond','ormond',[149,128,112],'958070',9797744],
['nbs-iscc-m:ormond.63','ormond','ormond',[142,130,121],'8e8279',9339513],
['nbs-iscc-m:orpiment.83','orpiment','orpiment',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:orpiment.84','orpiment','orpiment',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:orpiment.86','orpiment','orpiment',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:orpiment.87','orpiment','orpiment',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:orpimentorange.48','orpimentorange','orpiment orange',[243,132,0],'f38400',15959040],
['nbs-iscc-m:orpimentorange.50','orpimentorange','orpiment orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:orpimentred.68','orpimentred','orpiment red',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:orpimentred.71','orpimentred','orpiment red',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:orpin.83','orpin','orpin',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:orpin.84','orpin','orpin',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:orpin.86','orpin','orpin',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:orpin.87','orpin','orpin',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:orseille.258','orseille','orseille',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:otterbrown.81','otterbrown','otter [brown] ',[72,60,50],'483c32',4734002],
['nbs-iscc-m:ouralgreen.135','ouralgreen','oural green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:ouralgreen.148','ouralgreen','oural green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-m:owl.64','owl','owl',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:oxbloodred.43','oxbloodred','oxblood [red] ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:oxfordblue.230','oxfordblue','oxford blue',[41,30,41],'291e29',2694697],
['nbs-iscc-m:oxfordchrome.71','oxfordchrome','oxford chrome',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:oxfordochre.71','oxfordochre','oxford ochre',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:oxfordyellow.71','oxfordyellow','oxford yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:oxgall.84','oxgall','oxgall',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:oxheart.13','oxheart','oxheart',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:oxideblue.167','oxideblue','oxide blue',[0,133,161],'0085a1',34209],
['nbs-iscc-m:oxidebrown.43','oxidebrown','oxide brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:oxidepurple.43','oxidepurple','oxide purple',[121,68,59],'79443b',7947323],
['nbs-iscc-m:oxideyellow.71','oxideyellow','oxide yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:oystergrey.121','oystergrey','oyster grey ',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:oysterwhite.121','oysterwhite','oyster [white] ',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:pablo.57','pablo','pablo',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:pablo.76','pablo','pablo',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:pacific.149','pacific','pacific',[141,163,153],'8da399',9282457],
['nbs-iscc-m:pacific.163','pacific','pacific',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:paddock.165','paddock','paddock',[0,75,73],'004b49',19273],
['nbs-iscc-m:pagodablue.174','pagodablue','pagoda [blue] ',[0,73,88],'004958',18776],
['nbs-iscc-m:pagodablue.187','pagodablue','pagoda [blue] ',[54,69,79],'36454f',3556687],
['nbs-iscc-m:palestine.228','palestine','palestine',[121,104,120],'796878',7956600],
['nbs-iscc-m:palestine.262','palestine','palestine',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:palm.120','palm','palm',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:palmetto.122','palmetto','palmetto',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:palmgreen.137','palmgreen','palm green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:palmleaf.106','palmleaf','palmleaf',[134,126,54],'867e36',8814134],
['nbs-iscc-m:paloma.54','paloma','paloma',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:paloma.57','paloma','paloma',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:pampas.64','pampas','pampas',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:pan.151','pan','pan',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:pancygreen.137','pancygreen','pancy green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:panse.207','panse','panse',[96,78,151],'604e97',6311575],
['nbs-iscc-m:pansy.207','pansy','pansy',[96,78,151],'604e97',6311575],
['nbs-iscc-m:pansymaroon.259','pansymaroon','pansy-maroon',[103,49,71],'673147',6762823],
['nbs-iscc-m:pansypurple.259','pansypurple','pansy purple',[103,49,71],'673147',6762823],
['nbs-iscc-m:pansyviolet.242','pansyviolet','pansy violet',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:paon.174','paon','paon',[0,73,88],'004958',18776],
['nbs-iscc-m:paperwhite.93','paperwhite','paper white',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:paprica.34','paprica','paprica',[226,88,34],'e25822',14833698],
['nbs-iscc-m:papyrus.57','papyrus','papyrus',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:paradisegreen.137','paradisegreen','paradise green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:parared.12','parared','para red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:parared.15','parared','para red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:parchment.90','parchment','parchment',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:parchment.91','parchment','parchment',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:parchment.94','parchment','parchment',[150,113,23],'967117',9859351],
['nbs-iscc-m:parisgreen.136','parisgreen','paris green ',[103,146,103],'679267',6787687],
['nbs-iscc-m:parisgreen.140','parisgreen','paris green ',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:parismud.20','parismud','paris mud',[84,61,63],'543d3f',5520703],
['nbs-iscc-m:parisred.34','parisred','paris red',[226,88,34],'e25822',14833698],
['nbs-iscc-m:parisyellow.84','parisyellow','paris yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:parkgreen.120','parkgreen','park green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:parmared.12','parmared','parma red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:parmared.15','parmared','parma red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:parme.211','parme','parme',[96,78,129],'604e81',6311553],
['nbs-iscc-m:parrakeet.120','parrakeet','parrakeet',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:parrakeet.140','parrakeet','parrakeet',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:parroquitgreen.120','parroquitgreen','parroquit green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:parrotgreen.120','parrotgreen','parrot green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:partridge.77','partridge','partridge',[130,102,68],'826644',8545860],
['nbs-iscc-m:partridge.78','partridge','partridge',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:parulablue.186','parulablue','parula blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:pastel.186','pastel','pastel',[83,104,120],'536878',5466232],
['nbs-iscc-m:pastelblue.186','pastelblue','pastel blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:pastelgrey.90','pastelgrey','pastel grey ',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:pastelparchment.29','pastelparchment','pastel parchment',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:pastelparchment.32','pastelparchment','pastel parchment',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:pastelparchment.33','pastelparchment','pastel parchment',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:patentyellow.83','patentyellow','patent yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:patentyellow.84','patentyellow','patent yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:patentyellow.86','patentyellow','patent yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:patentyellow.87','patentyellow','patent yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:patinagreen.135','patinagreen','patina green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:patinagreen.136','patinagreen','patina green',[103,146,103],'679267',6787687],
['nbs-iscc-m:patriarch.219','patriarch','patriarch',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:patricia.237','patricia','patricia',[158,79,136],'9e4f88',10375048],
['nbs-iscc-m:paulveronesegreen.140','paulveronesegreen','paul veronese green ',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:pauncygreen.137','pauncygreen','pauncy green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:pavonine.174','pavonine','pavonine',[0,73,88],'004958',18776],
['nbs-iscc-m:pawnee.57','pawnee','pawnee',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:pawnee.60','pawnee','pawnee',[149,128,112],'958070',9797744],
['nbs-iscc-m:pawnee.76','pawnee','pawnee',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:pawnee.79','pawnee','pawnee',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:paynesgrey.186','paynesgrey','payne\'s grey ',[83,104,120],'536878',5466232],
['nbs-iscc-m:paynesgrey.187','paynesgrey','payne\'s grey ',[54,69,79],'36454f',3556687],
['nbs-iscc-m:peach.28','peach','peach',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-m:peach.29','peach','peach',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:peachbeige.29','peachbeige','peachbeige',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:peachbisque.42','peachbisque','peach bisque',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:peachbloom.29','peachbloom','peach bloom',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:peachblossompink.2','peachblossompink','peach blossom [pink] ',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:peachblossompink.5','peachblossompink','peach blossom [pink] ',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:peachblossomred.2','peachblossomred','peach blossom [red] ',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:peachblossomred.5','peachblossomred','peach blossom [red] ',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:peachblow.73','peachblow','peach blow',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:peachblush.55','peachblush','peach blush',[128,70,27],'80461b',8406555],
['nbs-iscc-m:peachred.26','peachred','peach red',[248,131,121],'f88379',16286585],
['nbs-iscc-m:peachwood.15','peachwood','peachwood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:peachwood.19','peachwood','peachwood',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:peacockblue.174','peacockblue','peacock [blue] ',[0,73,88],'004958',18776],
['nbs-iscc-m:peacockgreen.136','peacockgreen','peacock green',[103,146,103],'679267',6787687],
['nbs-iscc-m:peagreen.120','peagreen','pea green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:peanut.90','peanut','peanut',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:pearl.264','pearl','pearl',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:pearlblue.264','pearlblue','pearl blue',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:pearlblush.33','pearlblush','pearlblush',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:pearlblush.60','pearlblush','pearlblush',[149,128,112],'958070',9797744],
['nbs-iscc-m:pearlgray.93','pearlgray','pearl gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:pearlwhite.264','pearlwhite','pearl white',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:peasant.201','peasant','peasant',[37,36,64],'252440',2434112],
['nbs-iscc-m:peasant.204','peasant','peasant',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:peasantblue.186','peasantblue','peasant blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:peasantblue.183','peasantblue','peasant blue',[0,48,78],'00304e',12366],
['nbs-iscc-m:peasantblue.201','peasantblue','peasant blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:peasantblue.204','peasantblue','peasant blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:pebble.90','pebble','pebble',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:pecan.79','pecan','pecan',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:pecanbrown.58','pecanbrown','pecan brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:pekinese.54','pekinese','pekinese',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:pekinese.57','pekinese','pekinese',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:pekingblue.183','pekingblue','peking blue',[0,48,78],'00304e',12366],
['nbs-iscc-m:pelican.266','pelican','pelican',[85,85,85],'555555',5592405],
['nbs-iscc-m:peligotsblue.164','peligotsblue','peligot\'s blue',[49,120,115],'317873',3242099],
['nbs-iscc-m:pelt.64','pelt','pelt',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:pencilwood.43','pencilwood','pencilwood',[121,68,59],'79443b',7947323],
['nbs-iscc-m:pencilwood.58','pencilwood','pencilwood',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:penguin.265','penguin','penguin',[132,132,130],'848482',8684674],
['nbs-iscc-m:peony.16','peony','peony',[114,47,55],'722f37',7483191],
['nbs-iscc-m:peonyred.13','peonyred','peony red',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:peonyred.16','peonyred','peony red',[114,47,55],'722f37',7483191],
['nbs-iscc-m:pepita.94','pepita','pepita',[150,113,23],'967117',9859351],
['nbs-iscc-m:peppermint.131','peppermint','peppermint',[68,148,74],'44944a',4494410],
['nbs-iscc-m:pepperred.15','pepperred','pepper red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:peridot.120','peridot','peridot',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:peridot.122','peridot','peridot',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:peridot.125','peridot','peridot',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:peridot.127','peridot','peridot',[81,87,68],'515744',5330756],
['nbs-iscc-m:perilla.205','perilla','perilla',[144,101,202],'9065ca',9463242],
['nbs-iscc-m:perilla.207','perilla','perilla',[96,78,151],'604e97',6311575],
['nbs-iscc-m:perillapurple.259','perillapurple','perilla purple',[103,49,71],'673147',6762823],
['nbs-iscc-m:perique.81','perique','perique',[72,60,50],'483c32',4734002],
['nbs-iscc-m:periwinkle.203','periwinkle','periwinkle',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:periwinkle.204','periwinkle','periwinkle',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:permanentblue.178','permanentblue','permanent blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:permanentblue.196','permanentblue','permanent blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:permanentred.12','permanentred','permanent red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:permanentred.15','permanentred','permanent red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:permanentviolet.218','permanentviolet','permanent violet',[135,86,146],'875692',8869522],
['nbs-iscc-m:permanentyellow.71','permanentyellow','permanent yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:permared.12','permared','perma red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:permared.15','permared','perma red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:pernambucowood.15','pernambucowood','pernambucowood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:pernambucowood.19','pernambucowood','pernambucowood',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:perruche.120','perruche','perruche',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:persenche.214','persenche','persenche',[150,144,171],'9690ab',9867435],
['nbs-iscc-m:persianblue.185','persianblue','persian blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:persianblue.204','persianblue','persian blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:persianearth.40','persianearth','persian earth',[136,45,23],'882d17',8924439],
['nbs-iscc-m:persiangreen.151','persiangreen','persian green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:persianlilac.251','persianlilac','persian lilac',[193,126,145],'c17e91',12680849],
['nbs-iscc-m:persianmelon.39','persianmelon','persian melon',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:persianorange.53','persianorange','persian orange',[217,144,88],'d99058',14258264],
['nbs-iscc-m:persianpink.258','persianpink','persian pink',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:persianred.40','persianred','persian red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:persianrose.254','persianrose','persian rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:persianyellow.34','persianyellow','persian yellow',[226,88,34],'e25822',14833698],
['nbs-iscc-m:persianyellow.48','persianyellow','persian yellow',[243,132,0],'f38400',15959040],
['nbs-iscc-m:persimmon.55','persimmon','persimmon',[128,70,27],'80461b',8406555],
['nbs-iscc-m:persio.258','persio','persio',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:persis.258','persis','persis',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:peruvianbrown.54','peruvianbrown','peruvian brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:peruvianbrown.57','peruvianbrown','peruvian brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:peruvianyellow.37','peruvianyellow','peruvian yellow',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:pervenche.204','pervenche','pervenche',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:petunia.224','petunia','petunia',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:petuniaviolet.219','petuniaviolet','petunia [violet] ',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:pewke.16','pewke','pewke',[114,47,55],'722f37',7483191],
['nbs-iscc-m:pewter.266','pewter','pewter',[85,85,85],'555555',5592405],
['nbs-iscc-m:phantom.266','phantom','phantom',[85,85,85],'555555',5592405],
['nbs-iscc-m:phantomred.34','phantomred','phantom red',[226,88,34],'e25822',14833698],
['nbs-iscc-m:pharaoh.200','pharaoh','pharaoh',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:pharaoh.201','pharaoh','pharaoh',[37,36,64],'252440',2434112],
['nbs-iscc-m:pheasant.53','pheasant','pheasant',[217,144,88],'d99058',14258264],
['nbs-iscc-m:pheasant.57','pheasant','pheasant',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:philamot.51','philamot','philamot',[190,101,22],'be6516',12477718],
['nbs-iscc-m:philamot.54','philamot','philamot',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:philamot.55','philamot','philamot',[128,70,27],'80461b',8406555],
['nbs-iscc-m:philimot.51','philimot','philimot',[190,101,22],'be6516',12477718],
['nbs-iscc-m:philimot.54','philimot','philimot',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:philimot.55','philimot','philimot',[128,70,27],'80461b',8406555],
['nbs-iscc-m:philomot.51','philomot','philomot',[190,101,22],'be6516',12477718],
['nbs-iscc-m:philomot.54','philomot','philomot',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:philomot.55','philomot','philomot',[128,70,27],'80461b',8406555],
['nbs-iscc-m:phlox.238','phlox','phlox',[112,41,99],'702963',7350627],
['nbs-iscc-m:phlox.259','phlox','phlox',[103,49,71],'673147',6762823],
['nbs-iscc-m:phloxpink.227','phloxpink','phlox pink',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:phloxpurple.237','phloxpurple','phlox purple',[158,79,136],'9e4f88',10375048],
['nbs-iscc-m:phyliamort.51','phyliamort','phyliamort ',[190,101,22],'be6516',12477718],
['nbs-iscc-m:phyliamort.54','phyliamort','phyliamort ',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:phyliamort.55','phyliamort','phyliamort ',[128,70,27],'80461b',8406555],
['nbs-iscc-m:phyllamort.51','phyllamort','phyllamort',[190,101,22],'be6516',12477718],
['nbs-iscc-m:phyllamort.54','phyllamort','phyllamort',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:phyllamort.55','phyllamort','phyllamort',[128,70,27],'80461b',8406555],
['nbs-iscc-m:piccadilly.43','piccadilly','piccadilly',[121,68,59],'79443b',7947323],
['nbs-iscc-m:piccadilly.46','piccadilly','piccadilly',[103,76,71],'674c47',6769735],
['nbs-iscc-m:piccaninny.81','piccaninny','piccaninny',[72,60,50],'483c32',4734002],
['nbs-iscc-m:piccolpassored.43','piccolpassored','piccolpasso red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:pigeon.234','pigeon','pigeon',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:pigeonblood.16','pigeonblood','pigeon blood',[114,47,55],'722f37',7483191],
['nbs-iscc-m:pigeonneck.266','pigeonneck','pigeon neck',[85,85,85],'555555',5592405],
['nbs-iscc-m:pigeonsbreast.19','pigeonsbreast','pigeon\'s-breast',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:pigeonsthroat.145','pigeonsthroat','pigeon\'s throat',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:pigskin.57','pigskin','pigskin',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:pigskin.58','pigskin','pigskin',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:pigskin.77','pigskin','pigskin',[130,102,68],'826644',8545860],
['nbs-iscc-m:pilgrim.266','pilgrim','pilgrim',[85,85,85],'555555',5592405],
['nbs-iscc-m:pilgrimbrown.61','pilgrimbrown','pilgrim brown',[99,81,71],'635147',6508871],
['nbs-iscc-m:pilgrimbrown.62','pilgrimbrown','pilgrim brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:pilotblue.182','pilotblue','pilot blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:pimento.11','pimento','pimento',[190,0,50],'be0032',12451890],
['nbs-iscc-m:pimlico.215','pimlico','pimlico',[85,76,105],'554c69',5590121],
['nbs-iscc-m:pinardyellow.86','pinardyellow','pinard yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:pinchbeckbrown.72','pinchbeckbrown','pinchbeck brown',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:pinchbeckbrown.74','pinchbeckbrown','pinchbeck brown',[153,101,21],'996515',10052885],
['nbs-iscc-m:pinchbeckbrown.76','pinchbeckbrown','pinchbeck brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:pinchbeckbrown.88','pinchbeckbrown','pinchbeck brown',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:pinchbeckbrown.94','pinchbeckbrown','pinchbeck brown',[150,113,23],'967117',9859351],
['nbs-iscc-m:pineapple.86','pineapple','pineapple',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:pineapple.87','pineapple','pineapple',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:pinecone.61','pinecone','pinecone',[99,81,71],'635147',6508871],
['nbs-iscc-m:pinecone.80','pinecone','pinecone',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:pinefrost.149','pinefrost','pine frost',[141,163,153],'8da399',9282457],
['nbs-iscc-m:pinegrove.151','pinegrove','pinegrove',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:pineneedle.146','pineneedle','pineneedle',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:pineneedle.151','pineneedle','pineneedle',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:pinetree.165','pinetree','pine tree',[0,75,73],'004b49',19273],
['nbs-iscc-m:pink1.10','pink1','pink 1 ',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-m:pink2.7','pink2','pink 2 ',[234,216,215],'ead8d7',15390935],
['nbs-iscc-m:pink3.4','pink3','pink 3 ',[249,204,202],'f9ccca',16370890],
['nbs-iscc-m:pink3.7','pink3','pink 3 ',[234,216,215],'ead8d7',15390935],
['nbs-iscc-m:pink4.4','pink4','pink 4 ',[249,204,202],'f9ccca',16370890],
['nbs-iscc-m:pink4.5','pink4','pink 4 ',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:pink5.5','pink5','pink 5 ',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:pinkcoral.3','pinkcoral','pink coral',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:pinkcoral.26','pinkcoral','pink coral',[248,131,121],'f88379',16286585],
['nbs-iscc-m:pinkpearl.5','pinkpearl','pink pearl',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:pipingrock.112','pipingrock','piping rock',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:piquantgreen.120','piquantgreen','piquant green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:pirate.12','pirate','pirate',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:pirate.35','pirate','pirate',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:pistache.120','pistache','pistache',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:pistache.135','pistache','pistache',[147,197,146],'93c592',9684370],
['nbs-iscc-m:pistachiogreen.120','pistachiogreen','pistachio green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:pistachiogreen.135','pistachiogreen','pistachio green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:pitchpine.151','pitchpine','pitchpine',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:piuree.68','piuree','piuree',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:piuree.71','piuree','piuree',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:piuri.68','piuri','piuri',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:piuri.71','piuri','piuri',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:piyu.145','piyu','pi yu',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:plantation.43','plantation','plantation',[121,68,59],'79443b',7947323],
['nbs-iscc-m:platinayellow.54','platinayellow','platina yellow',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:platinum.265','platinum','platinum',[132,132,130],'848482',8684674],
['nbs-iscc-m:plazagrey.93','plazagrey','plaza grey',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:pleromaviolet.223','pleromaviolet','pleroma violet',[134,96,142],'86608e',8806542],
['nbs-iscc-m:plover.64','plover','plover',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:plumbaceous.234','plumbaceous','plumbaceous',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:plumbaceous.266','plumbaceous','plumbaceous',[85,85,85],'555555',5592405],
['nbs-iscc-m:plumbagoblue.227','plumbagoblue','plumbago blue',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:plumbagoblue.233','plumbagoblue','plumbago blue',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:plumbagogrey.227','plumbagogrey','plumbago grey ',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:plumbagogrey.233','plumbagogrey','plumbago grey ',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:plumbagoslate.234','plumbagoslate','plumbago slate',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:plumbet.190','plumbet','plumbet',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:plumpurple.224','plumpurple','plum [purple] ',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:plumpurple.212','plumpurple','plum purple',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:plumviolet.16','plumviolet','plum violet',[114,47,55],'722f37',7483191],
['nbs-iscc-m:plumviolet.259','plumviolet','plum violet',[103,49,71],'673147',6762823],
['nbs-iscc-m:plunket.190','plunket','plunket',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:plymouth.266','plymouth','plymouth',[85,85,85],'555555',5592405],
['nbs-iscc-m:poildours.266','poildours','poil d\'ours',[85,85,85],'555555',5592405],
['nbs-iscc-m:poilu.191','poilu','poilu',[129,135,139],'81878b',8488843],
['nbs-iscc-m:poinsettia.11','poinsettia','poinsettia',[190,0,50],'be0032',12451890],
['nbs-iscc-m:poinsettia.12','poinsettia','poinsettia',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:poisgreen.122','poisgreen','pois green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:polarbear.73','polarbear','polar bear',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:polarbear.92','polarbear','polar bear',[240,234,214],'f0ead6',15788758],
['nbs-iscc-m:polignac.18','polignac','polignac',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:polignac.42','polignac','polignac',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:polignac.45','polignac','polignac',[151,127,115],'977f73',9928563],
['nbs-iscc-m:pologreen.125','pologreen','polo green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:pologreen.137','pologreen','polo green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:polotan.76','polotan','polo tan',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:pomegranate.16','pomegranate','pomegranate',[114,47,55],'722f37',7483191],
['nbs-iscc-m:pomegranateblossom.11','pomegranateblossom','pomegranate blossom',[190,0,50],'be0032',12451890],
['nbs-iscc-m:pomegranateblossom.34','pomegranateblossom','pomegranate blossom',[226,88,34],'e25822',14833698],
['nbs-iscc-m:pomegranatepurple.15','pomegranatepurple','pomegranate purple',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:pomegranatepurple.258','pomegranatepurple','pomegranate purple',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:pomegranatepurple.258','pomegranatepurple','pomegranate purple',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:pomegranatepurple.262','pomegranatepurple','pomegranate purple',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:pomonagreen.120','pomonagreen','pomona green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:pompadourgreen.182','pompadourgreen','pompadour [green] ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:pompandpower.223','pompandpower','pomp and power',[134,96,142],'86608e',8806542],
['nbs-iscc-m:pompeianblue.185','pompeianblue','pompeian blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:pompeianred.19','pompeianred','pompeian red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:pompeianred.39','pompeianred','pompeian red',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:pompeianred.42','pompeianred','pompeian red',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:pompeianyellow.71','pompeianyellow','pompeian yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:pompeii.41','pompeii','pompeii',[86,7,12],'56070c',5637900],
['nbs-iscc-m:pompeii.43','pompeii','pompeii',[121,68,59],'79443b',7947323],
['nbs-iscc-m:ponceau.11','ponceau','ponceau',[190,0,50],'be0032',12451890],
['nbs-iscc-m:ponceau.34','ponceau','ponceau',[226,88,34],'e25822',14833698],
['nbs-iscc-m:poncedeleon.50','poncedeleon','ponce de leon',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:pondlily.86','pondlily','pond lily',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:pondlily.87','pondlily','pond lily',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:pongee.76','pongee','pongee',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:pontiffpurple.219','pontiffpurple','pontiff [purple] ',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:ponybrown.61','ponybrown','pony brown',[99,81,71],'635147',6508871],
['nbs-iscc-m:popcorn.86','popcorn','popcorn',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:popinjaygreen.120','popinjaygreen','popinjay green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:poplar.151','poplar','poplar',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:poppyred.11','poppyred','poppy [red] ',[190,0,50],'be0032',12451890],
['nbs-iscc-m:poppyred.34','poppyred','poppy [red] ',[226,88,34],'e25822',14833698],
['nbs-iscc-m:porcelain.182','porcelain','porcelain',[67,107,149],'436b95',4418453],
['nbs-iscc-m:porcelainblue.186','porcelainblue','porcelain blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:porcelaingreen.164','porcelaingreen','porcelain green',[49,120,115],'317873',3242099],
['nbs-iscc-m:porraaceous.120','porraaceous','porraaceous',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:porret.120','porret','porret',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:port.17','port','port',[63,23,40],'3f1728',4134696],
['nbs-iscc-m:portablered.12','portablered','portable red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:portablered.15','portablered','portable red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:portablered.36','portablered','portable red',[170,56,30],'aa381e',11155486],
['nbs-iscc-m:portablered.38','portablered','portable red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:portugeseredorportuguesered.11','portugeseredorportuguesered','portugese red or portuguese red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:portwine.47','portwine','port wine',[67,48,46],'43302e',4403246],
['nbs-iscc-m:postofficered.36','postofficered','post office red',[170,56,30],'aa381e',11155486],
['nbs-iscc-m:postofficered.38','postofficered','post office red',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:posygreen.150','posygreen','posy green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:poudre.185','poudre','poudre',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:poudre.191','poudre','poudre',[129,135,139],'81878b',8488843],
['nbs-iscc-m:poudre.190','poudre','poudre',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:poudreblue.185','poudreblue','poudre blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:poudreblue.191','poudreblue','poudre blue',[129,135,139],'81878b',8488843],
['nbs-iscc-m:powderblue.185','powderblue','powder blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:powderblue.191','powderblue','powder blue',[129,135,139],'81878b',8488843],
['nbs-iscc-m:powderblue.179','powderblue','powder blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:powderblue.182','powderblue','powder blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:powderedgold.91','powderedgold','powdered gold',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:powderpink.29','powderpink','powder pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:prairie.76','prairie','prairie',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:prairiebrown.54','prairiebrown','prairie brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:praline.58','praline','praline',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:praline.61','praline','praline',[99,81,71],'635147',6508871],
['nbs-iscc-m:prawnpink.26','prawnpink','prawn [pink] ',[248,131,121],'f88379',16286585],
['nbs-iscc-m:prelate.211','prelate','prelate',[96,78,129],'604e81',6311553],
['nbs-iscc-m:primrosegreen.104','primrosegreen','primrose green',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-m:primroseyellow.86','primroseyellow','primrose yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:primroseyellow.87','primroseyellow','primrose yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:primulineyellow.84','primulineyellow','primuline yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:princegrey.233','princegrey','prince grey ',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:princetonorange.50','princetonorange','princeton orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:priscilla.264','priscilla','priscilla',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-m:privet.127','privet','privet',[81,87,68],'515744',5330756],
['nbs-iscc-m:proutsbrown.58','proutsbrown','prout\'s brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:proutsbrown.61','proutsbrown','prout\'s brown',[99,81,71],'635147',6508871],
['nbs-iscc-m:proutsbrown.77','proutsbrown','prout\'s brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:proutsbrown.80','proutsbrown','prout\'s brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:prune.242','prune','prune',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:prunella.208','prunella','prunella',[50,23,77],'32174d',3282765],
['nbs-iscc-m:prunella.212','prunella','prunella',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:prunepurple.224','prunepurple','prune purple',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:prussianbrown.54','prussianbrown','prussian brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:prussianred.40','prussianred','prussian red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:prussianred.43','prussianred','prussian red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:psyche.135','psyche','psyche',[147,197,146],'93c592',9684370],
['nbs-iscc-m:ptshell.73','ptshell','pt shell',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:ptshell.76','ptshell','pt shell',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:puce.16','puce','puce',[114,47,55],'722f37',7483191],
['nbs-iscc-m:pueblo.58','pueblo','pueblo',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:puke.16','puke','puke',[114,47,55],'722f37',7483191],
['nbs-iscc-m:pumpkin.50','pumpkin','pumpkin',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:punjab.51','punjab','punjab',[190,101,22],'be6516',12477718],
['nbs-iscc-m:punjab.54','punjab','punjab',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:puritangrey.191','puritangrey','puritan grey ',[129,135,139],'81878b',8488843],
['nbs-iscc-m:puritangrey.265','puritangrey','puritan grey ',[132,132,130],'848482',8684674],
['nbs-iscc-m:purpleaster.223','purpleaster','purple aster',[134,96,142],'86608e',8806542],
['nbs-iscc-m:purplebrown.43','purplebrown','purple brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:purpleheather.223','purpleheather','purple heather',[134,96,142],'86608e',8806542],
['nbs-iscc-m:purplelake.13','purplelake','purple lake',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:purplelake.15','purplelake','purple lake',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:purplemadder.15','purplemadder','purple madder',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:purplemadder.16','purplemadder','purple madder',[114,47,55],'722f37',7483191],
['nbs-iscc-m:purplenavy.183','purplenavy','purple navy',[0,48,78],'00304e',12366],
['nbs-iscc-m:purplenavy.200','purplenavy','purple navy',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:purplenavy.201','purplenavy','purple navy',[37,36,64],'252440',2434112],
['nbs-iscc-m:purpleochre.40','purpleochre','purple ochre',[136,45,23],'882d17',8924439],
['nbs-iscc-m:purpleoxide.43','purpleoxide','purple oxide',[121,68,59],'79443b',7947323],
['nbs-iscc-m:purplerubiate.15','purplerubiate','purple rubiate',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:purplerubiate.16','purplerubiate','purple rubiate',[114,47,55],'722f37',7483191],
['nbs-iscc-m:purreaarabica.68','purreaarabica','purrea arabica',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:purreaarabica.71','purreaarabica','purrea arabica',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:purree.68','purree','purree',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:purree.71','purree','purree',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:putty.89','putty','putty',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:putty.90','putty','putty',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:pygmalion.74','pygmalion','pygmalion',[153,101,21],'996515',10052885],
['nbs-iscc-m:pygmalion.76','pygmalion','pygmalion',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:pygmalion.77','pygmalion','pygmalion',[130,102,68],'826644',8545860],
['nbs-iscc-m:pyrethrumyellow.83','pyrethrumyellow','pyrethrum yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:pyrethrumyellow.84','pyrethrumyellow','pyrethrum yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:pyrethrumyellow.86','pyrethrumyellow','pyrethrum yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:pyrethrumyellow.87','pyrethrumyellow','pyrethrum yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:pyriteyellow.88','pyriteyellow','pyrite yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:quail.64','quail','quail',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:quail.266','quail','quail',[85,85,85],'555555',5592405],
['nbs-iscc-m:quaker.233','quaker','quaker',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:quaker.265','quaker','quaker',[132,132,130],'848482',8684674],
['nbs-iscc-m:quakerblue.267','quakerblue','quaker blue',[34,34,34],'222222',2236962],
['nbs-iscc-m:quakerdrab.265','quakerdrab','quaker drab',[132,132,130],'848482',8684674],
['nbs-iscc-m:quakergreen.125','quakergreen','quaker green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:quakergrey.109','quakergrey','quaker grey ',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:queenannegreen.122','queenannegreen','queen anne green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:queenblue.182','queenblue','queen blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:queensblue.182','queensblue','queen\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:queensyellow.86','queensyellow','queen\'s yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:quercitron.86','quercitron','quercitron',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:quercitronlake.71','quercitronlake','quercitron lake',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:quimper.186','quimper','quimper',[83,104,120],'536878',5466232],
['nbs-iscc-m:quinceyellow.87','quinceyellow','quince yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:rabbit.64','rabbit','rabbit',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:racquet.61','racquet','racquet',[99,81,71],'635147',6508871],
['nbs-iscc-m:racquet.80','racquet','racquet',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:raddle.43','raddle','raddle',[121,68,59],'79443b',7947323],
['nbs-iscc-m:radiance.3','radiance','radiance',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:radiantyellow.50','radiantyellow','radiant yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:radiantyellow.53','radiantyellow','radiant yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:radiantyellow.68','radiantyellow','radiant yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:radiantyellow.71','radiantyellow','radiant yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:radio.183','radio','radio',[0,48,78],'00304e',12366],
['nbs-iscc-m:radio.186','radio','radio',[83,104,120],'536878',5466232],
['nbs-iscc-m:radioblue.187','radioblue','radio blue',[54,69,79],'36454f',3556687],
['nbs-iscc-m:raffia.76','raffia','raffia',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:raffia.90','raffia','raffia',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:raggedsailor.200','raggedsailor','ragged sailor',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:rail.266','rail','rail',[85,85,85],'555555',5592405],
['nbs-iscc-m:rainettegreen.120','rainettegreen','rainette green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:raisin.259','raisin','raisin',[103,49,71],'673147',6762823],
['nbs-iscc-m:raisinblack.235','raisinblack','raisin black',[36,33,36],'242124',2367780],
['nbs-iscc-m:raisinpurple.238','raisinpurple','raisin purple',[112,41,99],'702963',7350627],
['nbs-iscc-m:ramblerrose.3','ramblerrose','rambler rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:ramblerrose.258','ramblerrose','rambler rose',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:rameau.267','rameau','rameau',[34,34,34],'222222',2236962],
['nbs-iscc-m:rameses.179','rameses','rameses',[0,65,106],'00416a',16746],
['nbs-iscc-m:ramierblue.228','ramierblue','ramier blue',[121,104,120],'796878',7956600],
['nbs-iscc-m:rangoon.58','rangoon','rangoon',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:raphael.182','raphael','raphael',[67,107,149],'436b95',4418453],
['nbs-iscc-m:raphael.183','raphael','raphael',[0,48,78],'00304e',12366],
['nbs-iscc-m:rapids.182','rapids','rapids',[67,107,149],'436b95',4418453],
['nbs-iscc-m:raspberry.16','raspberry','raspberry',[114,47,55],'722f37',7483191],
['nbs-iscc-m:raspberryglac.15','raspberryglac','raspberry glac',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:raspberryglac.19','raspberryglac','raspberry glac',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:raspberryglac.258','raspberryglac','raspberry glac',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:raspberryglac.262','raspberryglac','raspberry glac',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:raspberryred.15','raspberryred','raspberry red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:rat.113','rat','rat',[87,85,76],'57554c',5723468],
['nbs-iscc-m:rattan.87','rattan','rattan',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:rawitalianearth.54','rawitalianearth','raw italian earth',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:rawitalianearth.57','rawitalianearth','raw italian earth',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:rawsienna.54','rawsienna','raw sienna',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:rawsienna.57','rawsienna','raw sienna',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:rawumber.77','rawumber','raw umber',[130,102,68],'826644',8545860],
['nbs-iscc-m:rawumber.78','rawumber','raw umber',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:rawumber.58','rawumber','raw umber',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:rcamier.5','rcamier','rcamier',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:rcamier.26','rcamier','rcamier',[248,131,121],'f88379',16286585],
['nbs-iscc-m:realgar.68','realgar','realgar',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:realgar.71','realgar','realgar',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:redbanana.13','redbanana','red banana',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:redbanana.15','redbanana','red banana',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:redbole.43','redbole','red bole',[121,68,59],'79443b',7947323],
['nbs-iscc-m:redchalk.43','redchalk','red chalk',[121,68,59],'79443b',7947323],
['nbs-iscc-m:redcross.11','redcross','red cross',[190,0,50],'be0032',12451890],
['nbs-iscc-m:redcross.12','redcross','red cross',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:redding.43','redding','redding',[121,68,59],'79443b',7947323],
['nbs-iscc-m:reddle.43','reddle','reddle',[121,68,59],'79443b',7947323],
['nbs-iscc-m:redearth.43','redearth','red earth',[121,68,59],'79443b',7947323],
['nbs-iscc-m:redfeather.12','redfeather','redfeather',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:redfeather.15','redfeather','redfeather',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:redinplates.11','redinplates','red in plates',[190,0,50],'be0032',12451890],
['nbs-iscc-m:redlead.34','redlead','red lead',[226,88,34],'e25822',14833698],
['nbs-iscc-m:redochre.43','redochre','red ochre',[121,68,59],'79443b',7947323],
['nbs-iscc-m:redoxide.40','redoxide','red oxide',[136,45,23],'882d17',8924439],
['nbs-iscc-m:redoxide.55','redoxide','red oxide',[128,70,27],'80461b',8406555],
['nbs-iscc-m:redrobin.41','redrobin','red robin',[86,7,12],'56070c',5637900],
['nbs-iscc-m:redwood.16','redwood','redwood',[114,47,55],'722f37',7483191],
['nbs-iscc-m:redwood.40','redwood','redwood',[136,45,23],'882d17',8924439],
['nbs-iscc-m:redwood.43','redwood','redwood',[121,68,59],'79443b',7947323],
['nbs-iscc-m:redwoodredwood.15','redwoodredwood','redwood redwood -)',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:redwoodredwood.15','redwoodredwood','redwood redwood -)',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:redwoodredwood.19','redwoodredwood','redwood redwood -)',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:reedgreen.119','reedgreen','reed green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:reedyellow.101','reedyellow','reed yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-m:reedyellow.104','reedyellow','reed yellow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-m:regal.197','regal','regal',[39,36,88],'272458',2565208],
['nbs-iscc-m:regalpurple.207','regalpurple','regal purple',[96,78,151],'604e97',6311575],
['nbs-iscc-m:regatta.178','regatta','regatta',[0,103,165],'0067a5',26533],
['nbs-iscc-m:regatta.196','regatta','regatta',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:regimental.204','regimental','regimental',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:rejanegreen.136','rejanegreen','rejane green',[103,146,103],'679267',6787687],
['nbs-iscc-m:rembrandt.62','rembrandt','rembrandt',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:rembrandtsmadder.37','rembrandtsmadder','rembrandt\'s madder',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:rembrandtsmadder.38','rembrandtsmadder','rembrandt\'s madder',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:rembrandtsmadder.39','rembrandtsmadder','rembrandt\'s madder',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:rembrandtsmadder.43','rembrandtsmadder','rembrandt\'s madder',[121,68,59],'79443b',7947323],
['nbs-iscc-m:renaissance.254','renaissance','renaissance',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:resedagreen.106','resedagreen','reseda [green] ',[134,126,54],'867e36',8814134],
['nbs-iscc-m:resolute.182','resolute','resolute',[67,107,149],'436b95',4418453],
['nbs-iscc-m:reveree.31','reveree','reveree',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-m:reveree.32','reveree','reveree',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:rhododendron.259','rhododendron','rhododendron',[103,49,71],'673147',6762823],
['nbs-iscc-m:rhodonitepink.251','rhodonitepink','rhodonite pink',[193,126,145],'c17e91',12680849],
['nbs-iscc-m:rhone.19','rhone','rhone',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:rhone.121','rhone','rhone',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:rhubarb.106','rhubarb','rhubarb',[134,126,54],'867e36',8814134],
['nbs-iscc-m:riflegreen.128','riflegreen','rifle [green] ',[49,54,43],'31362b',3225131],
['nbs-iscc-m:riflegreen.267','riflegreen','rifle [green] ',[34,34,34],'222222',2236962],
['nbs-iscc-m:riga.164','riga','riga',[49,120,115],'317873',3242099],
['nbs-iscc-m:rigablue.151','rigablue','riga blue',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:rigablue.186','rigablue','riga blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:rinnemannsgreen.136','rinnemannsgreen','rinnemann\'s green',[103,146,103],'679267',6787687],
['nbs-iscc-m:ripplegreen.150','ripplegreen','ripple green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:ripplegreen.164','ripplegreen','ripple green',[49,120,115],'317873',3242099],
['nbs-iscc-m:risigal.68','risigal','risigal',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:risigal.71','risigal','risigal',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:rivagegreen.120','rivagegreen','rivage green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:rivagegreen.135','rivagegreen','rivage green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:riviera.178','riviera','riviera',[0,103,165],'0067a5',26533],
['nbs-iscc-m:roan.43','roan','roan',[121,68,59],'79443b',7947323],
['nbs-iscc-m:robinhoodgreen.146','robinhoodgreen','robinhood green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:robinseggblue.149','robinseggblue','robin\'s egg blue',[141,163,153],'8da399',9282457],
['nbs-iscc-m:robinseggblue.163','robinseggblue','robin\'s egg blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:rocou.29','rocou','rocou',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:rodent.266','rodent','rodent',[85,85,85],'555555',5592405],
['nbs-iscc-m:roe.76','roe','roe',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:roe.91','roe','roe',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:romablue.204','romablue','roma blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:romablue.215','romablue','roma blue',[85,76,105],'554c69',5590121],
['nbs-iscc-m:romanearth.53','romanearth','roman earth',[217,144,88],'d99058',14258264],
['nbs-iscc-m:romanesque.242','romanesque','romanesque',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:romangreen.107','romangreen','roman green',[102,93,30],'665d1e',6708510],
['nbs-iscc-m:romanlake.11','romanlake','roman lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:romanlake.12','romanlake','roman lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:romanochre.53','romanochre','roman ochre',[217,144,88],'d99058',14258264],
['nbs-iscc-m:romanpurple.211','romanpurple','roman purple',[96,78,129],'604e81',6311553],
['nbs-iscc-m:romansepia.58','romansepia','roman sepia',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:romanticgreen.106','romanticgreen','romantic green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:romanumber.77','romanumber','roman umber',[130,102,68],'826644',8545860],
['nbs-iscc-m:romanumber.78','romanumber','roman umber',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:romanviolet.242','romanviolet','roman violet',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:romany.187','romany','romany',[54,69,79],'36454f',3556687],
['nbs-iscc-m:romany.188','romany','romany',[32,40,48],'202830',2107440],
['nbs-iscc-m:romany.201','romany','romany',[37,36,64],'252440',2434112],
['nbs-iscc-m:romany.204','romany','romany',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:romarin.151','romarin','romarin',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:rosalgar.68','rosalgar','rosalgar',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:rosalgar.71','rosalgar','rosalgar',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:rosario.57','rosario','rosario',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:roseamber.54','roseamber','rose amber',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:roseamber.57','roseamber','rose amber',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:roseash.19','roseash','rose ash',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:rosebeige.80','rosebeige','rose beige',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:rosebeige2.57','rosebeige2','rose beige 2 ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:rosebisque.42','rosebisque','rosebisque',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:rosebloom.18','rosebloom','rosebloom',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:rosebloom.30','rosebloom','rosebloom',[196,131,121],'c48379',12878713],
['nbs-iscc-m:rosebloom.39','rosebloom','rosebloom',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:rosebloom.42','rosebloom','rosebloom',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:roseblush.42','roseblush','rose blush',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:roseblush2.57','roseblush2','rose blush 2 ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:rosebreath.4','rosebreath','rose breath',[249,204,202],'f9ccca',16370890],
['nbs-iscc-m:rosebreath.7','rosebreath','rose breath',[234,216,215],'ead8d7',15390935],
['nbs-iscc-m:rosebud.248','rosebud','rosebud',[222,111,161],'de6fa1',14577569],
['nbs-iscc-m:rosebud.251','rosebud','rosebud',[193,126,145],'c17e91',12680849],
['nbs-iscc-m:rosecaroline.29','rosecaroline','rose caroline',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:rosecarthame.11','rosecarthame','rose carthame',[190,0,50],'be0032',12451890],
['nbs-iscc-m:rosecastor.22','rosecastor','rose castor',[143,129,127],'8f817f',9404799],
['nbs-iscc-m:rosecendre.29','rosecendre','rose cendre',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:rosedalma.262','rosedalma','rose d\'alma',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:rosedalthoea.2','rosedalthoea','rose d\'althoea',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:rosedawn.29','rosedawn','rose dawn',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:rosedawn.42','rosedawn','rose dawn',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:rosedenymphe.89','rosedenymphe','rose de nymphe',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:rosedeprovence.255','rosedeprovence','rose de provence',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:rosedore.3','rosedore','rose dore',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:rosedore.15','rosedore','rose dore',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:rosedust.19','rosedust','rosedust',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:rosedust.46','rosedust','rosedust',[103,76,71],'674c47',6769735],
['nbs-iscc-m:roseebony.47','roseebony','rose ebony ',[67,48,46],'43302e',4403246],
['nbs-iscc-m:rosefrance.29','rosefrance','rose france',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:roseglow.42','roseglow','roseglow',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:rosegrey.64','rosegrey','rose grey ',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:rosehermosa.5','rosehermosa','rose hermosa',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:rosehortensia.42','rosehortensia','rose hortensia',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:roselake.38','roselake','rose lake',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:roseleaf.5','roseleaf','roseleaf',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:roselustre.16','roselustre','roselustre',[114,47,55],'722f37',7483191],
['nbs-iscc-m:rosemadder.255','rosemadder','rose madder',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:rosemarie.3','rosemarie','rose marie',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:rosemary.245','rosemary','rosemary',[131,100,121],'836479',8610937],
['nbs-iscc-m:rosemorn.29','rosemorn','rose morn',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:roseneyron.12','roseneyron','rose neyron',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:roseneyron.255','roseneyron','rose neyron',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:rosenilsson.3','rosenilsson','rose nilsson',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:rosenude.29','rosenude','rose nude',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:rosenude.32','rosenude','rose nude',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:rosenude.33','rosenude','rose nude',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:roseoak.43','roseoak','rose oak',[121,68,59],'79443b',7947323],
['nbs-iscc-m:roseofpicardy.15','roseofpicardy','rose of picardy',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:roseofsharon.15','roseofsharon','rose of sharon',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:rosepetal.19','rosepetal','rose petal',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:rosepink.38','rosepink','rose pink',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:rosepurple.222','rosepurple','rose-purple ',[182,149,192],'b695c0',11965888],
['nbs-iscc-m:rosepurple.240','rosepurple','rose-purple ',[183,132,167],'b784a7',12027047],
['nbs-iscc-m:rosequartz.227','rosequartz','rose quartz',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:rosesoire.3','rosesoire','rose soire',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:rosestone.45','rosestone','rosestone',[151,127,115],'977f73',9928563],
['nbs-iscc-m:roset.38','roset','roset',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:rosetan.33','rosetan','rosetan',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:rosetan.60','rosetan','rosetan',[149,128,112],'958070',9797744],
['nbs-iscc-m:rosetaupe.266','rosetaupe','rose taupe',[85,85,85],'555555',5592405],
['nbs-iscc-m:rosetta.23','rosetta','rosetta',[92,80,79],'5c504f',6049871],
['nbs-iscc-m:rosevale.15','rosevale','rosevale',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:rosevale.19','rosevale','rosevale',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:rosewood.43','rosewood','rosewood',[121,68,59],'79443b',7947323],
['nbs-iscc-m:roslynblue.197','roslynblue','roslyn blue',[39,36,88],'272458',2565208],
['nbs-iscc-m:roucou.29','roucou','roucou',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:rougedefer.43','rougedefer','rouge de fer',[121,68,59],'79443b',7947323],
['nbs-iscc-m:rougevegetal.11','rougevegetal','rouge vegetal',[190,0,50],'be0032',12451890],
['nbs-iscc-m:royalblue.179','royalblue','royal blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:royalblue.182','royalblue','royal blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:royalblue.179','royalblue','royal blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:royalpink.3','royalpink','royal pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:royalpurple.207','royalpurple','royal purple',[96,78,151],'604e97',6311575],
['nbs-iscc-m:royalyellow.83','royalyellow','royal yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:royalyellow.84','royalyellow','royal yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:royalyellow.86','royalyellow','royal yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:royalyellow.87','royalyellow','royal yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:rubaiyat.16','rubaiyat','rubaiyat',[114,47,55],'722f37',7483191],
['nbs-iscc-m:rubber.95','rubber','rubber',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:rubelite.254','rubelite','rubelite',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:rubensmadder.38','rubensmadder','ruben\'s madder',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:rubient.16','rubient','rubient',[114,47,55],'722f37',7483191],
['nbs-iscc-m:rubrica.43','rubrica','rubrica',[121,68,59],'79443b',7947323],
['nbs-iscc-m:ruby.16','ruby','ruby',[114,47,55],'722f37',7483191],
['nbs-iscc-m:rubyofarsenic.68','rubyofarsenic','ruby of arsenic',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:rubyofarsenic.71','rubyofarsenic','ruby of arsenic',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:ruddle.43','ruddle','ruddle',[121,68,59],'79443b',7947323],
['nbs-iscc-m:rufous.26','rufous','rufous',[248,131,121],'f88379',16286585],
['nbs-iscc-m:rufous.53','rufous','rufous',[217,144,88],'d99058',14258264],
['nbs-iscc-m:rugbytan.55','rugbytan','rugby tan',[128,70,27],'80461b',8406555],
['nbs-iscc-m:runnymede.145','runnymede','runnymede',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:ruochre.54','ruochre','ru ochre',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:ruochre.74','ruochre','ru ochre',[153,101,21],'996515',10052885],
['nbs-iscc-m:russetbrown.55','russetbrown','russet brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:russetbrown.58','russetbrown','russet brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:russetgreen.102','russetgreen','russet green',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:russetgreen.103','russetgreen','russet green',[152,148,62],'98943e',9999422],
['nbs-iscc-m:russetgreen.105','russetgreen','russet green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:russetgreen.106','russetgreen','russet green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:russetorange.35','russetorange','russet orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:russianblue.185','russianblue','russian blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:russianblue.191','russianblue','russian blue',[129,135,139],'81878b',8488843],
['nbs-iscc-m:russiancalf.58','russiancalf','russian calf',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:russiangreen.136','russiangreen','russian green',[103,146,103],'679267',6787687],
['nbs-iscc-m:russiangreen.137','russiangreen','russian green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:russiangreen.150','russiangreen','russian green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:russiangrey.112','russiangrey','russian grey ',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:russiangrey.265','russiangrey','russian grey ',[132,132,130],'848482',8684674],
['nbs-iscc-m:russianviolet.208','russianviolet','russian violet',[50,23,77],'32174d',3282765],
['nbs-iscc-m:rust.55','rust','rust',[128,70,27],'80461b',8406555],
['nbs-iscc-m:rusticbrown.43','rusticbrown','rustic brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:rusticdrab.94','rusticdrab','rustic drab',[150,113,23],'967117',9859351],
['nbs-iscc-m:rutochre.54','rutochre','rut ochre',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:rutochre.74','rutochre','rut ochre',[153,101,21],'996515',10052885],
['nbs-iscc-m:sable.80','sable','sable',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:saddle.61','saddle','saddle',[99,81,71],'635147',6508871],
['nbs-iscc-m:saddle.80','saddle','saddle',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:safaran.53','safaran','safaran',[217,144,88],'d99058',14258264],
['nbs-iscc-m:safaran.71','safaran','safaran',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:safflor.11','safflor','safflor',[190,0,50],'be0032',12451890],
['nbs-iscc-m:safflowerred.11','safflowerred','safflower red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:saffor.11','saffor','saffor',[190,0,50],'be0032',12451890],
['nbs-iscc-m:saffronyellow.53','saffronyellow','saffron yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:saffronyellow.71','saffronyellow','saffron yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:safranopink.29','safranopink','safrano pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:sagebrushgreen.156','sagebrushgreen','sagebrush green',[78,87,85],'4e5755',5134165],
['nbs-iscc-m:sagedrab.127','sagedrab','sage drab',[81,87,68],'515744',5330756],
['nbs-iscc-m:sagegreen.120','sagegreen','sage [green] ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:sagegrey.109','sagegrey','sage grey ',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:sahara.58','sahara','sahara',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:sailor.230','sailor','sailor',[41,30,41],'291e29',2694697],
['nbs-iscc-m:sailor.235','sailor','sailor',[36,33,36],'242124',2367780],
['nbs-iscc-m:sailorblue.200','sailorblue','sailor blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-m:sakkara.64','sakkara','sakkara',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:sallow.105','sallow','sallow',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:salmonpink.29','salmonpink','salmon [pink] ',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:salvia.11','salvia','salvia',[190,0,50],'be0032',12451890],
['nbs-iscc-m:salviablue.178','salviablue','salvia blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:samara.164','samara','samara',[49,120,115],'317873',3242099],
['nbs-iscc-m:samovar.76','samovar','samovar',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:samurai.39','samurai','samurai',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:sand.109','sand','sand',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:sand.112','sand','sand',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:sandalwood.15','sandalwood','sandalwood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:sandalwood.45','sandalwood','sandalwood',[151,127,115],'977f73',9928563],
['nbs-iscc-m:sandalwood.58','sandalwood','sandalwood',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:sandalwood.60','sandalwood','sandalwood',[149,128,112],'958070',9797744],
['nbs-iscc-m:sandalwood.61','sandalwood','sandalwood',[99,81,71],'635147',6508871],
['nbs-iscc-m:sandarach.34','sandarach','sandarach',[226,88,34],'e25822',14833698],
['nbs-iscc-m:sandarach.68','sandarach','sandarach',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:sandarach.71','sandarach','sandarach',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:sandaracha.34','sandaracha','sandaracha',[226,88,34],'e25822',14833698],
['nbs-iscc-m:sandaracha.68','sandaracha','sandaracha',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:sandaracha.71','sandaracha','sandaracha',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:sanddune.94','sanddune','sand dune',[150,113,23],'967117',9859351],
['nbs-iscc-m:sandersblue.182','sandersblue','sander\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:sanderswood.15','sanderswood','sanderswood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:sandix.34','sandix','sandix',[226,88,34],'e25822',14833698],
['nbs-iscc-m:sandrift.63','sandrift','sandrift',[142,130,121],'8e8279',9339513],
['nbs-iscc-m:sandstone.42','sandstone','sandstone',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:sandstone.57','sandstone','sandstone',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:sandstone.60','sandstone','sandstone',[149,128,112],'958070',9797744],
['nbs-iscc-m:sandust.29','sandust','sandust',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:sandybeige.63','sandybeige','sandy-beige',[142,130,121],'8e8279',9339513],
['nbs-iscc-m:sandyx.34','sandyx','sandyx',[226,88,34],'e25822',14833698],
['nbs-iscc-m:sangdeboeuf.43','sangdeboeuf','sang de boeuf',[121,68,59],'79443b',7947323],
['nbs-iscc-m:sanguine.12','sanguine','sanguine',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:sanguine.15','sanguine','sanguine',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:sanguineus.13','sanguineus','sanguineus',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:sanguineus.16','sanguineus','sanguineus',[114,47,55],'722f37',7483191],
['nbs-iscc-m:sanguineus.17','sanguineus','sanguineus',[63,23,40],'3f1728',4134696],
['nbs-iscc-m:sanguineus.44','sanguineus','sanguineus',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-m:sanguineus.242','sanguineus','sanguineus',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:sanguineus.259','sanguineus','sanguineus',[103,49,71],'673147',6762823],
['nbs-iscc-m:santalwood.15','santalwood','santalwood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:santos.58','santos','santos',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:santos.61','santos','santos',[99,81,71],'635147',6508871],
['nbs-iscc-m:saona.43','saona','saona',[121,68,59],'79443b',7947323],
['nbs-iscc-m:sappanwood.15','sappanwood','sappanwood',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:sappanwood.19','sappanwood','sappanwood',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:sapphireblue.183','sapphireblue','sapphire [blue] ',[0,48,78],'00304e',12366],
['nbs-iscc-m:sappho.18','sappho','sappho',[173,136,132],'ad8884',11372676],
['nbs-iscc-m:saraband.19','saraband','saraband',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:saratoga.53','saratoga','saratoga',[217,144,88],'d99058',14258264],
['nbs-iscc-m:saravan.55','saravan','saravan',[128,70,27],'80461b',8406555],
['nbs-iscc-m:saravan.58','saravan','saravan',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:sarouk.61','sarouk','sarouk',[99,81,71],'635147',6508871],
['nbs-iscc-m:satinwood.57','satinwood','satinwood',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:satsuma.37','satsuma','satsuma',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:saturninered.34','saturninered','saturnine red',[226,88,34],'e25822',14833698],
['nbs-iscc-m:saturnred.34','saturnred','saturn red',[226,88,34],'e25822',14833698],
['nbs-iscc-m:saul.156','saul','saul',[78,87,85],'4e5755',5134165],
['nbs-iscc-m:saundersblue.182','saundersblue','saunder\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:sauterne.87','sauterne','sauterne',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:sauterne.57','sauterne','sauterne',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:saxeblue.186','saxeblue','saxe blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:saxonblue.169','saxonblue','saxon blue',[0,119,145],'007791',30609],
['nbs-iscc-m:saxonblue.174','saxonblue','saxon blue',[0,73,88],'004958',18776],
['nbs-iscc-m:saxongreen.164','saxongreen','saxon green',[49,120,115],'317873',3242099],
['nbs-iscc-m:saxonyblue.169','saxonyblue','saxony blue',[0,119,145],'007791',30609],
['nbs-iscc-m:saxonyblue.174','saxonyblue','saxony blue',[0,73,88],'004958',18776],
['nbs-iscc-m:saxonyblue.179','saxonyblue','saxony blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:saxonyblue.182','saxonyblue','saxony blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:saxonygreen.139','saxonygreen','saxony green',[0,136,86],'008856',34902],
['nbs-iscc-m:sayalbrown.54','sayalbrown','sayal brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:sayalbrown.57','sayalbrown','sayal brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:sayalbrown.74','sayalbrown','sayal brown',[153,101,21],'996515',10052885],
['nbs-iscc-m:scabiosa.228','scabiosa','scabiosa ',[121,104,120],'796878',7956600],
['nbs-iscc-m:scarab.145','scarab','scarab',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:scarlet.11','scarlet','scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-m:scarletingrain.11','scarletingrain','scarlet in grain',[190,0,50],'be0032',12451890],
['nbs-iscc-m:scarletlake.12','scarletlake','scarlet lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:scarletlake.15','scarletlake','scarlet lake',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:scarletmadder.26','scarletmadder','scarlet madder',[248,131,121],'f88379',16286585],
['nbs-iscc-m:scarletochre.40','scarletochre','scarlet ochre',[136,45,23],'882d17',8924439],
['nbs-iscc-m:scarletred.11','scarletred','scarlet red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:scarletvermilion.34','scarletvermilion','scarlet vermilion',[226,88,34],'e25822',14833698],
['nbs-iscc-m:scheelesgreen.117','scheelesgreen','scheele\'s green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-m:scheelesgreen.131','scheelesgreen','scheele\'s green',[68,148,74],'44944a',4494410],
['nbs-iscc-m:schoenfeldspurple.256','schoenfeldspurple','schoenfeld\'s purple',[120,24,74],'78184a',7870538],
['nbs-iscc-m:schoenfeldspurple.258','schoenfeldspurple','schoenfeld\'s purple',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:schweinfurtgreen.140','schweinfurtgreen','schweinfurt green',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:scotchblue.201','scotchblue','scotch blue',[37,36,64],'252440',2434112],
['nbs-iscc-m:scotchgrey.122','scotchgrey','scotch grey ',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:scotchgrey.155','scotchgrey','scotch grey ',[125,137,132],'7d8984',8227204],
['nbs-iscc-m:seabird.266','seabird','seabird',[85,85,85],'555555',5592405],
['nbs-iscc-m:seablue.165','seablue','sea blue',[0,75,73],'004b49',19273],
['nbs-iscc-m:seacrest.135','seacrest','seacrest',[147,197,146],'93c592',9684370],
['nbs-iscc-m:seafoam.140','seafoam','seafoam',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:seafoam.144','seafoam','seafoam',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:seafoamgreen.121','seafoamgreen','seafoam green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:seafoamyellow.121','seafoamyellow','seafoam yellow',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:seagreen.120','seagreen','sea green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:seahawk.113','seahawk','sea hawk',[87,85,76],'57554c',5723468],
['nbs-iscc-m:sealbrown.81','sealbrown','seal [brown] ',[72,60,50],'483c32',4734002],
['nbs-iscc-m:seamanblue.204','seamanblue','seaman blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:seamist.233','seamist','sea mist',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:seamist.265','seamist','sea mist',[132,132,130],'848482',8684674],
['nbs-iscc-m:seamoss.106','seamoss','sea moss ',[134,126,54],'867e36',8814134],
['nbs-iscc-m:seamoss.151','seamoss','sea moss ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:seapink.2','seapink','sea pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-m:seapink.5','seapink','sea pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:seasannotseasand.33','seasannotseasand','seasan not seasand',[194,172,153],'c2ac99',12758169],
['nbs-iscc-m:seasannotseasand.73','seasannotseasand','seasan not seasand',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:seasannotseasand.76','seasannotseasand','seasan not seasand',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:seasannotseasand.79','seasannotseasand','seasan not seasand',[174,155,130],'ae9b82',11443074],
['nbs-iscc-m:seashell.29','seashell','sea shell',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:seashell.53','seashell','sea shell',[217,144,88],'d99058',14258264],
['nbs-iscc-m:seashell.57','seashell','sea shell',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:seashellpink.28','seashellpink','seashell pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-m:seashellpink.29','seashellpink','seashell pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:seaside.94','seaside','seaside',[150,113,23],'967117',9859351],
['nbs-iscc-m:seaside.45','seaside','seaside',[151,127,115],'977f73',9928563],
['nbs-iscc-m:seaside.60','seaside','seaside',[149,128,112],'958070',9797744],
['nbs-iscc-m:seaside.63','seaside','seaside',[142,130,121],'8e8279',9339513],
['nbs-iscc-m:seaspray.122','seaspray','seaspray',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:seaspray.136','seaspray','seaspray',[103,146,103],'679267',6787687],
['nbs-iscc-m:seaspray.149','seaspray','seaspray',[141,163,153],'8da399',9282457],
['nbs-iscc-m:seawatergreen.120','seawatergreen','sea-water green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:seaweedgreen.122','seaweedgreen','seaweed green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:sedge.61','sedge','sedge',[99,81,71],'635147',6508871],
['nbs-iscc-m:seedpearl.89','seedpearl','seed pearl',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:seedpearl.90','seedpearl','seed pearl',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:seeredgreen.120','seeredgreen','seered green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:seladongreen.122','seladongreen','seladon green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:seminole.58','seminole','seminole',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:sepia.96','sepia','sepia',[59,49,33],'3b3121',3879201],
['nbs-iscc-m:serapi.186','serapi','serapi',[83,104,120],'536878',5466232],
['nbs-iscc-m:serpent.149','serpent','serpent',[141,163,153],'8da399',9282457],
['nbs-iscc-m:serpentine.144','serpentine','serpentine',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:serpentinegreen.106','serpentinegreen','serpentine green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:servicecorps.142','servicecorps','service corps',[0,84,61],'00543d',21565],
['nbs-iscc-m:seville.208','seville','seville',[50,23,77],'32174d',3282765],
['nbs-iscc-m:sevilleorange.53','sevilleorange','seville orange',[217,144,88],'d99058',14258264],
['nbs-iscc-m:sevresblue.178','sevresblue','sevres [blue] ',[0,103,165],'0067a5',26533],
['nbs-iscc-m:shadow.22','shadow','shadow',[143,129,127],'8f817f',9404799],
['nbs-iscc-m:shadowgreen.120','shadowgreen','shadow green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:shagbark.77','shagbark','shagbark',[130,102,68],'826644',8545860],
['nbs-iscc-m:shagbark.80','shagbark','shagbark',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:shalegreen.136','shalegreen','shale green',[103,146,103],'679267',6787687],
['nbs-iscc-m:shamrock.131','shamrock','shamrock',[68,148,74],'44944a',4494410],
['nbs-iscc-m:shamrockgreen.131','shamrockgreen','shamrock [green] ',[68,148,74],'44944a',4494410],
['nbs-iscc-m:shark.228','shark','shark',[121,104,120],'796878',7956600],
['nbs-iscc-m:shark.234','shark','shark',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:sheepskin.90','sheepskin','sheepskin',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:sheik.15','sheik','sheik',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:sheik.38','sheik','sheik',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:shellgrey.93','shellgrey','shell grey ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:shirvan.151','shirvan','shirvan',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:shrimppink.26','shrimppink','shrimp [pink] ',[248,131,121],'f88379',16286585],
['nbs-iscc-m:shrimpred.26','shrimpred','shrimp [red] ',[248,131,121],'f88379',16286585],
['nbs-iscc-m:siam.58','siam','siam',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:siam.61','siam','siam',[99,81,71],'635147',6508871],
['nbs-iscc-m:siam.77','siam','siam',[130,102,68],'826644',8545860],
['nbs-iscc-m:siam.80','siam','siam',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:siberianbrown.95','siberianbrown','siberian brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:siberien.151','siberien','siberien',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:sicilianumber.77','sicilianumber','sicilian umber',[130,102,68],'826644',8545860],
['nbs-iscc-m:sicilianumber.78','sicilianumber','sicilian umber',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:siderinyellow.50','siderinyellow','siderin yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:siderinyellow.53','siderinyellow','siderin yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:siena.40','siena','siena',[136,45,23],'882d17',8924439],
['nbs-iscc-m:siennabrown.58','siennabrown','sienna brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:siennayellow.73','siennayellow','sienna yellow',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:siennayellow.87','siennayellow','sienna yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:siennesedrab.45','siennesedrab','siennese drab',[151,127,115],'977f73',9928563],
['nbs-iscc-m:siennesedrab.60','siennesedrab','siennese drab',[149,128,112],'958070',9797744],
['nbs-iscc-m:sierra.40','sierra','sierra',[136,45,23],'882d17',8924439],
['nbs-iscc-m:signalred.11','signalred','signal red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:sil.71','sil','sil',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:siluriangray.121','siluriangray','silurian gray',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:silverfern.106','silverfern','silver fern',[134,126,54],'867e36',8814134],
['nbs-iscc-m:silverfern.109','silverfern','silver fern',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:silvergreen.122','silvergreen','silver green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:silverpine.150','silverpine','silverpine',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:silverwing.233','silverwing','silver-wing',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:sinbad.187','sinbad','sinbad',[54,69,79],'36454f',3556687],
['nbs-iscc-m:sinbad.193','sinbad','sinbad',[32,36,40],'202428',2106408],
['nbs-iscc-m:sinbad.229','sinbad','sinbad',[80,64,77],'50404d',5259341],
['nbs-iscc-m:sinbad.235','sinbad','sinbad',[36,33,36],'242124',2367780],
['nbs-iscc-m:sirocco.109','sirocco','sirocco',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:siskingreen.105','siskingreen','siskin green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:sistine.172','sistine','sistine',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:sistine.173','sistine','sistine',[54,117,136],'367588',3569032],
['nbs-iscc-m:sistine.185','sistine','sistine',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:sistine.186','sistine','sistine',[83,104,120],'536878',5466232],
['nbs-iscc-m:skating.174','skating','skating',[0,73,88],'004958',18776],
['nbs-iscc-m:ski.137','ski','ski',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:ski.145','ski','ski',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:skimmedmilkwhite.121','skimmedmilkwhite','skimmed-milk white',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:skobeloffgreen.160','skobeloffgreen','skobeloff green',[0,122,116],'007a74',31348],
['nbs-iscc-m:sky.181','sky','sky',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:sky.199','sky','sky',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:skyblue.181','skyblue','sky blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:skyblue.199','skyblue','sky blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:skycolour.181','skycolour','sky colour',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:skycolour.199','skycolour','sky colour',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:skygreen.119','skygreen','sky green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:slag.266','slag','slag',[85,85,85],'555555',5592405],
['nbs-iscc-m:slate.192','slate','slate',[81,88,94],'51585e',5331038],
['nbs-iscc-m:slateblack.267','slateblack','slate-black',[34,34,34],'222222',2236962],
['nbs-iscc-m:slateblue.186','slateblue','slate blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:slateblue.186','slateblue','slate-blue ',[83,104,120],'536878',5466232],
['nbs-iscc-m:slatecolor.234','slatecolor','slate [color] ',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:slategreen.150','slategreen','slate-green',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:slategreen.156','slategreen','slate-green',[78,87,85],'4e5755',5134165],
['nbs-iscc-m:slategrey.112','slategrey','slate-grey ',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:slategrey.265','slategrey','slate-grey ',[132,132,130],'848482',8684674],
['nbs-iscc-m:slateolive.156','slateolive','slate-olive',[78,87,85],'4e5755',5134165],
['nbs-iscc-m:slatepurple.229','slatepurple','slate-purple',[80,64,77],'50404d',5259341],
['nbs-iscc-m:slatepurple.242','slatepurple','slate-purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:slateviolet.19','slateviolet','slate-violet',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:smalt.179','smalt','smalt',[0,65,106],'00416a',16746],
['nbs-iscc-m:smalt.182','smalt','smalt',[67,107,149],'436b95',4418453],
['nbs-iscc-m:smaltgreen.136','smaltgreen','smalt green',[103,146,103],'679267',6787687],
['nbs-iscc-m:smaltino.179','smaltino','smaltino',[0,65,106],'00416a',16746],
['nbs-iscc-m:smaltino.182','smaltino','smaltino',[67,107,149],'436b95',4418453],
['nbs-iscc-m:smokeblue.192','smokeblue','smoke blue',[81,88,94],'51585e',5331038],
['nbs-iscc-m:smokebrown.266','smokebrown','smoke brown',[85,85,85],'555555',5592405],
['nbs-iscc-m:smokedpearl.266','smokedpearl','smoked pearl',[85,85,85],'555555',5592405],
['nbs-iscc-m:smokegrey.121','smokegrey','smoke grey ',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:smokeyellow.109','smokeyellow','smoke yellow',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:smokeyellow.112','smokeyellow','smoke yellow',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:snapdragon.86','snapdragon','snapdragon',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:snapdragon.87','snapdragon','snapdragon',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:snowshoe.68','snowshoe','snowshoe',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:snowshoe.71','snowshoe','snowshoe',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:soapstone.61','soapstone','soapstone',[99,81,71],'635147',6508871],
['nbs-iscc-m:solferino.258','solferino','solferino',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:solitaire.47','solitaire','solitaire',[67,48,46],'43302e',4403246],
['nbs-iscc-m:solitaire.62','solitaire','solitaire',[62,50,44],'3e322c',4076076],
['nbs-iscc-m:somalis.38','somalis','somalis',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:somalis.43','somalis','somalis',[121,68,59],'79443b',7947323],
['nbs-iscc-m:sombrero.90','sombrero','sombrero',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:sonora.54','sonora','sonora',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:sonora.57','sonora','sonora',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:sootbrown.61','sootbrown','soot brown',[99,81,71],'635147',6508871],
['nbs-iscc-m:sootbrown.80','sootbrown','soot brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:sootyblack.267','sootyblack','sooty black',[34,34,34],'222222',2236962],
['nbs-iscc-m:sorbier.262','sorbier','sorbier',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:sorghumbrown.45','sorghumbrown','sorghum brown',[151,127,115],'977f73',9928563],
['nbs-iscc-m:sorghumbrown.60','sorghumbrown','sorghum brown',[149,128,112],'958070',9797744],
['nbs-iscc-m:sorollabrown.55','sorollabrown','sorolla brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:sorrel.54','sorrel','sorrel',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:sorrel.57','sorrel','sorrel',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:sorrentogreen.164','sorrentogreen','sorrento green',[49,120,115],'317873',3242099],
['nbs-iscc-m:souci.50','souci','souci',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:source.136','source','source',[103,146,103],'679267',6787687],
['nbs-iscc-m:source.144','source','source',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:source.149','source','source',[141,163,153],'8da399',9282457],
['nbs-iscc-m:spalte.81','spalte','spalte',[72,60,50],'483c32',4734002],
['nbs-iscc-m:spaltum.81','spaltum','spaltum',[72,60,50],'483c32',4734002],
['nbs-iscc-m:spanishbrown.40','spanishbrown','spanish brown',[136,45,23],'882d17',8924439],
['nbs-iscc-m:spanishcedar.19','spanishcedar','spanish cedar',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:spanishcedar.43','spanishcedar','spanish cedar',[121,68,59],'79443b',7947323],
['nbs-iscc-m:spanishflesh.89','spanishflesh','spanish flesh',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:spanishflesh.90','spanishflesh','spanish flesh',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:spanishgreen.136','spanishgreen','spanish green',[103,146,103],'679267',6787687],
['nbs-iscc-m:spanishochre.50','spanishochre','spanish ochre',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:spanishraisin.47','spanishraisin','spanish raisin',[67,48,46],'43302e',4403246],
['nbs-iscc-m:spanishred.11','spanishred','spanish red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:spanishred.40','spanishred','spanish red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:spanishred.55','spanishred','spanish red',[128,70,27],'80461b',8406555],
['nbs-iscc-m:spanishwine.16','spanishwine','spanish wine',[114,47,55],'722f37',7483191],
['nbs-iscc-m:spanishyellow.68','spanishyellow','spanish yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:spanishyellow.71','spanishyellow','spanish yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:spark.11','spark','spark',[190,0,50],'be0032',12451890],
['nbs-iscc-m:sparrow.64','sparrow','sparrow',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:spatan.54','spatan','spa-tan',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:spearmint.139','spearmint','spearmint',[0,136,86],'008856',34902],
['nbs-iscc-m:sphinx.80','sphinx','sphinx',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:spice.54','spice','spice',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:spinachgreen.120','spinachgreen','spinach green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:spinachgreen.125','spinachgreen','spinach green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:spinelpink.258','spinelpink','spinel pink',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:spinelred.12','spinelred','spinel red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:spinelred.255','spinelred','spinel red',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:sponge.94','sponge','sponge',[150,113,23],'967117',9859351],
['nbs-iscc-m:spray.162','spray','spray',[150,222,209],'96ded1',9887441],
['nbs-iscc-m:springbeauty.254','springbeauty','spring beauty',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:springbeauty.255','springbeauty','spring beauty',[179,68,108],'b3446c',11748460],
['nbs-iscc-m:springgreen.120','springgreen','spring green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:springgreen.135','springgreen','spring green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:springtime.3','springtime','springtime',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:sprite.159','sprite','sprite',[0,166,147],'00a693',42643],
['nbs-iscc-m:sprite.163','sprite','sprite',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:spruce.151','spruce','spruce',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:spruce.157','spruce','spruce',[30,35,33],'1e2321',1975073],
['nbs-iscc-m:spruceochre.54','spruceochre','spruce ochre',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:spruceochre.74','spruceochre','spruce ochre',[153,101,21],'996515',10052885],
['nbs-iscc-m:spruceyellow.72','spruceyellow','spruce yellow',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:spruceyellow.76','spruceyellow','spruce yellow',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:squillblue.181','squillblue','squill blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:squirrel.234','squirrel','squirrel',[93,85,91],'5d555b',6116699],
['nbs-iscc-m:squirrel.266','squirrel','squirrel',[85,85,85],'555555',5592405],
['nbs-iscc-m:stag.77','stag','stag',[130,102,68],'826644',8545860],
['nbs-iscc-m:starchblue.179','starchblue','starch blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:starchblue.182','starchblue','starch blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:stardew.186','stardew','stardew',[83,104,120],'536878',5466232],
['nbs-iscc-m:starflower.251','starflower','starflower',[193,126,145],'c17e91',12680849],
['nbs-iscc-m:starlight.185','starlight','starlight',[145,163,176],'91a3b0',9544624],
['nbs-iscc-m:starling.64','starling','starling',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:stbenoitorsaintbenoit.81','stbenoitorsaintbenoit','st. benoit or saint benoit',[72,60,50],'483c32',4734002],
['nbs-iscc-m:stbenoitorsaintbenoit.267','stbenoitorsaintbenoit','st. benoit or saint benoit',[34,34,34],'222222',2236962],
['nbs-iscc-m:steel.266','steel','steel',[85,85,85],'555555',5592405],
['nbs-iscc-m:steelgrey.266','steelgrey','steel grey ',[85,85,85],'555555',5592405],
['nbs-iscc-m:steeplechase.196','steeplechase','steeplechase',[84,90,167],'545aa7',5528231],
['nbs-iscc-m:stildegrainbrown.72','stildegrainbrown','stil de grain brown',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:stildegrainbrown.74','stildegrainbrown','stil de grain brown',[153,101,21],'996515',10052885],
['nbs-iscc-m:stildegrainyellow.83','stildegrainyellow','stil de grain yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:stildegrainyellow.84','stildegrainyellow','stil de grain yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:stildegrainyellow.86','stildegrainyellow','stil de grain yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:stildegrainyellow.87','stildegrainyellow','stil de grain yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:stoneblue.182','stoneblue','stone blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:stonegrey.113','stonegrey','stone grey ',[87,85,76],'57554c',5723468],
['nbs-iscc-m:stormgrey.155','stormgrey','storm grey ',[125,137,132],'7d8984',8227204],
['nbs-iscc-m:strawberry.19','strawberry','strawberry',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:strawberrypink.3','strawberrypink','strawberry pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:strawberrypink.26','strawberrypink','strawberry pink',[248,131,121],'f88379',16286585],
['nbs-iscc-m:strawberrypink.27','strawberrypink','strawberry pink',[230,103,97],'e66761',15099745],
['nbs-iscc-m:strawyellow.89','strawyellow','straw [yellow] ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:striegauearth.43','striegauearth','striegau earth',[121,68,59],'79443b',7947323],
['nbs-iscc-m:strollertan.58','strollertan','stroller tan',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:strontianyellow.98','strontianyellow','strontian yellow ',[233,228,80],'e9e450',15328336],
['nbs-iscc-m:stucco.45','stucco','stucco',[151,127,115],'977f73',9928563],
['nbs-iscc-m:stucco.60','stucco','stucco',[149,128,112],'958070',9797744],
['nbs-iscc-m:succoryblue.121','succoryblue','succory blue',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:sudan.91','sudan','sudan',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:sudan.94','sudan','sudan',[150,113,23],'967117',9859351],
['nbs-iscc-m:sudan.109','sudan','sudan',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:sudanbrown.55','sudanbrown','sudan brown',[128,70,27],'80461b',8406555],
['nbs-iscc-m:sudanbrown.58','sudanbrown','sudan brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:suede.57','suede','suede',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:suede.58','suede','suede',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:suede.77','suede','suede',[130,102,68],'826644',8545860],
['nbs-iscc-m:sugarcane.73','sugarcane','sugar cane',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:sugarcane.76','sugarcane','sugar cane',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:sulphategreen.163','sulphategreen','sulphate green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:sulphategreen.164','sulphategreen','sulphate green',[49,120,115],'317873',3242099],
['nbs-iscc-m:sulphineyellow.88','sulphineyellow','sulphine yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:sulphur.101','sulphur','sulphur',[234,230,121],'eae679',15394425],
['nbs-iscc-m:sulphuryellow.101','sulphuryellow','sulphur [yellow] ',[234,230,121],'eae679',15394425],
['nbs-iscc-m:sultan.15','sultan','sultan',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:sultana.16','sultana','sultana',[114,47,55],'722f37',7483191],
['nbs-iscc-m:sultana.259','sultana','sultana',[103,49,71],'673147',6762823],
['nbs-iscc-m:sumac.72','sumac','sumac',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:sumac.74','sumac','sumac',[153,101,21],'996515',10052885],
['nbs-iscc-m:sumac.76','sumac','sumac',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:sumac.77','sumac','sumac',[130,102,68],'826644',8545860],
['nbs-iscc-m:sumac.88','sumac','sumac',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:sumac.91','sumac','sumac',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:sumac.94','sumac','sumac',[150,113,23],'967117',9859351],
['nbs-iscc-m:sunbeam.90','sunbeam','sunbeam',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:sunburn.57','sunburn','sunburn',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:sunburst.50','sunburst','sunburst',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:sunburst.53','sunburst','sunburst',[217,144,88],'d99058',14258264],
['nbs-iscc-m:sundown.76','sundown','sundown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:sunfloweryellow.83','sunfloweryellow','sunflower [yellow] ',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:sunglow.3','sunglow','sunglow',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:sunglow.15','sunglow','sunglow',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:sungod.34','sungod','sungod',[226,88,34],'e25822',14833698],
['nbs-iscc-m:sunkiss.53','sunkiss','sunkiss ',[217,144,88],'d99058',14258264],
['nbs-iscc-m:sunlight.87','sunlight','sunlight',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:sunni.86','sunni','sunni',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:sunni.87','sunni','sunni',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:sunray.71','sunray','sunray',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:sunriseyellow.29','sunriseyellow','sunrise yellow',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:sunriseyellow.53','sunriseyellow','sunrise yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-m:sunset.73','sunset','sunset',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:sunstone.54','sunstone','sunstone',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:suntan.57','suntan','suntan',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:suntan.76','suntan','suntan',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:suntan.77','suntan','suntan',[130,102,68],'826644',8545860],
['nbs-iscc-m:superior.165','superior','superior',[0,75,73],'004b49',19273],
['nbs-iscc-m:surfgreen.136','surfgreen','surf green',[103,146,103],'679267',6787687],
['nbs-iscc-m:surreygreen.122','surreygreen','surrey green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:surreygreen.149','surreygreen','surrey green',[141,163,153],'8da399',9282457],
['nbs-iscc-m:swamp.151','swamp','swamp',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:swedishgreen.117','swedishgreen','swedish green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-m:swedishgreen.131','swedishgreen','swedish green',[68,148,74],'44944a',4494410],
['nbs-iscc-m:sweetbriar.248','sweetbriar','sweet briar',[222,111,161],'de6fa1',14577569],
['nbs-iscc-m:sweetmeat.76','sweetmeat','sweetmeat',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:sweetpea.32','sweetpea','sweet pea',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:sweetwilliam.3','sweetwilliam','sweet william',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:swissblue.186','swissblue','swiss blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:swissrose.15','swissrose','swiss rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:syrup.94','syrup','syrup',[150,113,23],'967117',9859351],
['nbs-iscc-m:syrup.95','syrup','syrup',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:taffy.76','taffy','taffy',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:talavera.54','talavera','talavera',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:tamarach.61','tamarach','tamarach',[99,81,71],'635147',6508871],
['nbs-iscc-m:tamarach.80','tamarach','tamarach',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:taming.68','taming','ta-ming',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:taming.71','taming','ta-ming',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:tan.54','tan','tan',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:tanagra.43','tanagra','tanagra',[121,68,59],'79443b',7947323],
['nbs-iscc-m:tanaura.90','tanaura','tanaura ',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:tanbark.58','tanbark','tanbark',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:tangerine.37','tangerine','tangerine',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:tangier.50','tangier','tangier',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:tangopink.19','tangopink','tango pink',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:tansan.57','tansan','tansan',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:tansan.76','tansan','tansan',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:tapestry.183','tapestry','tapestry',[0,48,78],'00304e',12366],
['nbs-iscc-m:tapestry.201','tapestry','tapestry',[37,36,64],'252440',2434112],
['nbs-iscc-m:tapestry.204','tapestry','tapestry',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:tapestry.233','tapestry','tapestry',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:tapestryred.16','tapestryred','tapestry red',[114,47,55],'722f37',7483191],
['nbs-iscc-m:tapisvert.120','tapisvert','tapis vert',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:tarragon.120','tarragon','tarragon',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:tarragon.122','tarragon','tarragon',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:tarragon.136','tarragon','tarragon',[103,146,103],'679267',6787687],
['nbs-iscc-m:tarragona.40','tarragona','tarragona',[136,45,23],'882d17',8924439],
['nbs-iscc-m:tarragona.55','tarragona','tarragona',[128,70,27],'80461b',8406555],
['nbs-iscc-m:tartangreen.151','tartangreen','tartan green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:taupe.81','taupe','taupe',[72,60,50],'483c32',4734002],
['nbs-iscc-m:tawny.54','tawny','tawny',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:tawny.57','tawny','tawny',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:tawnybirch.42','tawnybirch','tawny birch',[168,124,109],'a87c6d',11041901],
['nbs-iscc-m:tawnybirch.57','tawnybirch','tawny birch',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:tawnybirch.60','tawnybirch','tawny birch',[149,128,112],'958070',9797744],
['nbs-iscc-m:tea.122','tea','tea',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:tea.149','tea','tea',[141,163,153],'8da399',9282457],
['nbs-iscc-m:teagreen.122','teagreen','tea green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:teakbrown.58','teakbrown','teak [brown] ',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:teakwood.61','teakwood','teakwood',[99,81,71],'635147',6508871],
['nbs-iscc-m:teakwood.80','teakwood','teakwood',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:tealblue.174','tealblue','teal blue',[0,73,88],'004958',18776],
['nbs-iscc-m:tealblue.187','tealblue','teal blue',[54,69,79],'36454f',3556687],
['nbs-iscc-m:tealduck.174','tealduck','teal duck ',[0,73,88],'004958',18776],
['nbs-iscc-m:teatime.94','teatime','tea time',[150,113,23],'967117',9859351],
['nbs-iscc-m:telegraphblue.228','telegraphblue','telegraph blue',[121,104,120],'796878',7956600],
['nbs-iscc-m:tennis.88','tennis','tennis',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:tennis.91','tennis','tennis',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:terracotta.51','terracotta','terra cotta',[190,101,22],'be6516',12477718],
['nbs-iscc-m:terracotta.54','terracotta','terra cotta',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:terrajaponica.58','terrajaponica','terra japonica',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:terralemnia.43','terralemnia','terra lemnia',[121,68,59],'79443b',7947323],
['nbs-iscc-m:terramerita.86','terramerita','terra merita',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:terraorellana.29','terraorellana','terra orellana',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:terraorellano.29','terraorellano','terra orellano ',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:terrapin.58','terrapin','terrapin',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:terrapozzuoli.43','terrapozzuoli','terra pozzuoli',[121,68,59],'79443b',7947323],
['nbs-iscc-m:terrarosa.43','terrarosa','terra rosa',[121,68,59],'79443b',7947323],
['nbs-iscc-m:terrasiena.54','terrasiena','terra siena ',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:terrasiena.57','terrasiena','terra siena ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:terrasigillata.43','terrasigillata','terra sigillata',[121,68,59],'79443b',7947323],
['nbs-iscc-m:terrasse.120','terrasse','terrasse',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:terraumber.77','terraumber','terra umber',[130,102,68],'826644',8545860],
['nbs-iscc-m:terraumber.78','terraumber','terra umber',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:testaceous.53','testaceous','testaceous',[217,144,88],'d99058',14258264],
['nbs-iscc-m:testaceous.57','testaceous','testaceous',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:thenardsblue.169','thenardsblue','thenard\'s blue',[0,119,145],'007791',30609],
['nbs-iscc-m:thistle.223','thistle','thistle',[134,96,142],'86608e',8806542],
['nbs-iscc-m:thistlebloom.237','thistlebloom','thistle bloom',[158,79,136],'9e4f88',10375048],
['nbs-iscc-m:thistletuft.238','thistletuft','thistletuft',[112,41,99],'702963',7350627],
['nbs-iscc-m:thrush.77','thrush','thrush',[130,102,68],'826644',8545860],
['nbs-iscc-m:thrush.80','thrush','thrush',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:thulitepink.248','thulitepink','thulite pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-m:thyme.151','thyme','thyme',[58,75,71],'3a4b47',3820359],
['nbs-iscc-m:tiber.146','tiber','tiber',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:tibergreen.135','tibergreen','tiber green',[147,197,146],'93c592',9684370],
['nbs-iscc-m:tiffin.77','tiffin','tiffin',[130,102,68],'826644',8545860],
['nbs-iscc-m:tigerlily.35','tigerlily','tigerlily',[217,96,59],'d9603b',14245947],
['nbs-iscc-m:tigerlily.37','tigerlily','tigerlily',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:tileblue.173','tileblue','tile blue',[54,117,136],'367588',3569032],
['nbs-iscc-m:tilered.37','tilered','tile red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-m:tilleulbuff.31','tilleulbuff','tilleul buff',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-m:tilleulbuff.93','tilleulbuff','tilleul buff',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:tilleulgreen.104','tilleulgreen','tilleul [green] ',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-m:tinsel.88','tinsel','tinsel',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:tinsel.91','tinsel','tinsel',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:tinsel.94','tinsel','tinsel',[150,113,23],'967117',9859351],
['nbs-iscc-m:titania.242','titania','titania',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:titania.259','titania','titania',[103,49,71],'673147',6762823],
['nbs-iscc-m:titian.54','titian','titian',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:titiangold.54','titiangold','titian gold',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:titmouseblue.149','titmouseblue','titmouse blue ',[141,163,153],'8da399',9282457],
['nbs-iscc-m:toast.57','toast','toast',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:toastedalmond.57','toastedalmond','toasted almond',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:toboggan.34','toboggan','toboggan',[226,88,34],'e25822',14833698],
['nbs-iscc-m:toboggan.48','toboggan','toboggan',[243,132,0],'f38400',15959040],
['nbs-iscc-m:toga.212','toga','toga',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:tokay.43','tokay','tokay',[121,68,59],'79443b',7947323],
['nbs-iscc-m:tokyo.25','tokyo','tokyo',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-m:tokyo.26','tokyo','tokyo',[248,131,121],'f88379',16286585],
['nbs-iscc-m:tokyo.50','tokyo','tokyo',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:toltec.71','toltec','toltec',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:tomatored.38','tomatored','tomato [red] ',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:tommyred.12','tommyred','tommy red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:topaz.57','topaz','topaz',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:topaz.72','topaz','topaz',[190,138,61],'be8a3d',12487229],
['nbs-iscc-m:topaz.76','topaz','topaz',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:toquet.32','toquet','toquet',[199,173,163],'c7ada3',13086115],
['nbs-iscc-m:toreador.34','toreador','toreador',[226,88,34],'e25822',14833698],
['nbs-iscc-m:torinoblue.186','torinoblue','torino blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:tortoise.55','tortoise','tortoise',[128,70,27],'80461b',8406555],
['nbs-iscc-m:tortoiseshell.58','tortoiseshell','tortoise shell',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:totem.38','totem','totem',[158,71,50],'9e4732',10372914],
['nbs-iscc-m:tourmaline.163','tourmaline','tourmaline',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:tourmalinepink.262','tourmalinepink','tourmaline pink',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:tourterelle.94','tourterelle','tourterelle',[150,113,23],'967117',9859351],
['nbs-iscc-m:transparentchromiumoxide.141','transparentchromiumoxide','transparent chromium oxide',[0,121,89],'007959',31065],
['nbs-iscc-m:transparentchromiumoxide.145','transparentchromiumoxide','transparent chromium oxide',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:transparentgoldochre.54','transparentgoldochre','transparent gold ochre',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:transparentgoldochre.74','transparentgoldochre','transparent gold ochre',[153,101,21],'996515',10052885],
['nbs-iscc-m:traprock.266','traprock','traprock',[85,85,85],'555555',5592405],
['nbs-iscc-m:travertine.94','travertine','travertine ',[150,113,23],'967117',9859351],
['nbs-iscc-m:trentanel.101','trentanel','trentanel',[234,230,121],'eae679',15394425],
['nbs-iscc-m:trentanel.102','trentanel','trentanel',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:trianon.29','trianon','trianon',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:trianon.53','trianon','trianon',[217,144,88],'d99058',14258264],
['nbs-iscc-m:triton.146','triton','triton',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:triumphblue.182','triumphblue','triumph blue',[67,107,149],'436b95',4418453],
['nbs-iscc-m:triumphblue.183','triumphblue','triumph blue',[0,48,78],'00304e',12366],
['nbs-iscc-m:trooper.183','trooper','trooper',[0,48,78],'00304e',12366],
['nbs-iscc-m:trooper.187','trooper','trooper',[54,69,79],'36454f',3556687],
['nbs-iscc-m:trooper.188','trooper','trooper',[32,40,48],'202830',2107440],
['nbs-iscc-m:trotteurtan.58','trotteurtan','trotteur tan',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:troubadorred.12','troubadorred','troubador red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:trublu.186','trublu','trublu',[83,104,120],'536878',5466232],
['nbs-iscc-m:tuileries.182','tuileries','tuileries',[67,107,149],'436b95',4418453],
['nbs-iscc-m:tulipwood.58','tulipwood','tulipwood',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:tunis.187','tunis','tunis',[54,69,79],'36454f',3556687],
['nbs-iscc-m:tunis.188','tunis','tunis',[32,40,48],'202830',2107440],
['nbs-iscc-m:turbithmineral.86','turbithmineral','turbith mineral',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:turkeyblue.204','turkeyblue','turkey blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:turkeyred.15','turkeyred','turkey red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:turkeyumber.77','turkeyumber','turkey umber',[130,102,68],'826644',8545860],
['nbs-iscc-m:turkeyumber.78','turkeyumber','turkey umber',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:turkishblue.204','turkishblue','turkish blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:turkishcrescentred.13','turkishcrescentred','turkish crescent red ',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:turkishcrescentred.16','turkishcrescentred','turkish crescent red ',[114,47,55],'722f37',7483191],
['nbs-iscc-m:turkishred.15','turkishred','turkish red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:turmeric.86','turmeric','turmeric',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:turnersyellow.83','turnersyellow','turner\'s yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:turnersyellow.84','turnersyellow','turner\'s yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:turnersyellow.86','turnersyellow','turner\'s yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:turnersyellow.87','turnersyellow','turner\'s yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:turquoiseblue.163','turquoiseblue','turquoise [blue] ',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:turquoisegreen.163','turquoisegreen','turquoise green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:turtle.58','turtle','turtle',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:turtledove.23','turtledove','turtledove',[92,80,79],'5c504f',6049871],
['nbs-iscc-m:turtledove.266','turtledove','turtledove',[85,85,85],'555555',5592405],
['nbs-iscc-m:turtlegreen.120','turtlegreen','turtle green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:tuscan.73','tuscan','tuscan',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:tuscanbrown.43','tuscanbrown','tuscan brown',[121,68,59],'79443b',7947323],
['nbs-iscc-m:tuscanbrown.58','tuscanbrown','tuscan brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:tuscanred.43','tuscanred','tuscan red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:tuscantan.57','tuscantan','tuscan tan',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:tuscany.43','tuscany','tuscany',[121,68,59],'79443b',7947323],
['nbs-iscc-m:tussore.28','tussore','tussore',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-m:tussore.29','tussore','tussore',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:twilightblue.186','twilightblue','twilight [blue] ',[83,104,120],'536878',5466232],
['nbs-iscc-m:twine.109','twine','twine',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:twinkleblue.172','twinkleblue','twinkle blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:tyrianblue.186','tyrianblue','tyrian blue',[83,104,120],'536878',5466232],
['nbs-iscc-m:tyrianblue.204','tyrianblue','tyrian blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:tyrianpink.254','tyrianpink','tyrian pink',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:tyrianviolet.258','tyrianviolet','tyrian violet',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:tyrol.77','tyrol','tyrol',[130,102,68],'826644',8545860],
['nbs-iscc-m:tyrolesegreen.136','tyrolesegreen','tyrolese green',[103,146,103],'679267',6787687],
['nbs-iscc-m:tyrolian.152','tyrolian','tyrolian',[26,36,33],'1a2421',1713185],
['nbs-iscc-m:tyrolitegreen.163','tyrolitegreen','tyrolite green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:tzarine.157','tzarine','tzarine',[30,35,33],'1e2321',1975073],
['nbs-iscc-m:ultramarinegreen.157','ultramarinegreen','ultramarine green',[30,35,33],'1e2321',1975073],
['nbs-iscc-m:ultramarineyellow.84','ultramarineyellow','ultramarine yellow ',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:uraniablue.212','uraniablue','urania blue',[47,33,64],'2f2140',3088704],
['nbs-iscc-m:vagabondgreen.165','vagabondgreen','vagabond green',[0,75,73],'004b49',19273],
['nbs-iscc-m:valencia.248','valencia','valencia',[222,111,161],'de6fa1',14577569],
['nbs-iscc-m:vanda.228','vanda','vanda',[121,104,120],'796878',7956600],
['nbs-iscc-m:vanda.245','vanda','vanda',[131,100,121],'836479',8610937],
['nbs-iscc-m:vandykebrown.58','vandykebrown','vandyke brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:vandykemadder.258','vandykemadder','vandyke madder',[168,81,110],'a8516e',11030894],
['nbs-iscc-m:vandykered.19','vandykered','vandyke red',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:vanilla.89','vanilla','vanilla',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:vanilla.90','vanilla','vanilla',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:vanity.29','vanity','vanity',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-m:variscitegreen.144','variscitegreen','variscite green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:varleysgrey.228','varleysgrey','varley\'s grey ',[121,104,120],'796878',7956600],
['nbs-iscc-m:vassarrose.6','vassarrose','vassar rose',[192,128,129],'c08081',12615809],
['nbs-iscc-m:vassarrose.19','vassarrose','vassar rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:vassartan.55','vassartan','vassar tan',[128,70,27],'80461b',8406555],
['nbs-iscc-m:vassartan.58','vassartan','vassar tan',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:vatican.224','vatican','vatican',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:vatican.225','vatican','vatican',[48,25,52],'301934',3152180],
['nbs-iscc-m:veaudor.73','veaudor','veau d\'or',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:veaudor.76','veaudor','veau d\'or',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:vegetablered.11','vegetablered','vegetable red',[190,0,50],'be0032',12451890],
['nbs-iscc-m:vegetablerouge.11','vegetablerouge','vegetable rouge',[190,0,50],'be0032',12451890],
['nbs-iscc-m:velasquez.259','velasquez','velasquez ',[103,49,71],'673147',6762823],
['nbs-iscc-m:velvetbrown.77','velvetbrown','velvet brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:velvetbrown.78','velvetbrown','velvet brown',[75,54,33],'4b3621',4929057],
['nbs-iscc-m:velvetgreen.125','velvetgreen','velvet green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:venet.163','venet','venet',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:venetianblue.169','venetianblue','venetian blue',[0,119,145],'007791',30609],
['nbs-iscc-m:venetianfuchsia.254','venetianfuchsia','venetian fuchsia',[206,70,118],'ce4676',13518454],
['nbs-iscc-m:venetianlake.11','venetianlake','venetian lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:venetianlake.12','venetianlake','venetian lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:venetianpink.5','venetianpink','venetian pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-m:venetianred.40','venetianred','venetian red',[136,45,23],'882d17',8924439],
['nbs-iscc-m:venetianrose.13','venetianrose','venetian rose',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:venetianrose.15','venetianrose','venetian rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:venetianscarlet.11','venetianscarlet','venetian scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-m:venetianyellow.86','venetianyellow','venetian yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:venetianyellow.87','venetianyellow','venetian yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:venezia.164','venezia','venezia',[49,120,115],'317873',3242099],
['nbs-iscc-m:veniceberries.68','veniceberries','venice berries',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:veniceberries.71','veniceberries','venice berries',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:veniceblue.163','veniceblue','venice [blue] ',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:venicegreen.163','venicegreen','venice green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:venicered.43','venicered','venice red',[121,68,59],'79443b',7947323],
['nbs-iscc-m:venus.88','venus','venus',[171,145,68],'ab9144',11243844],
['nbs-iscc-m:venus.91','venus','venus',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:verbena.241','verbena','verbena',[145,92,131],'915c83',9526403],
['nbs-iscc-m:verbenaviolet.214','verbenaviolet','verbena [violet] ',[150,144,171],'9690ab',9867435],
['nbs-iscc-m:verbenaviolet.227','verbenaviolet','verbena [violet] ',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:verdantgreen.120','verdantgreen','verdant green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:verdet.136','verdet','verdet',[103,146,103],'679267',6787687],
['nbs-iscc-m:verdevessie.106','verdevessie','verde vessie',[134,126,54],'867e36',8814134],
['nbs-iscc-m:verdgay.120','verdgay','verd gay',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:verdigrisgreen.136','verdigrisgreen','verdigris [green] ',[103,146,103],'679267',6787687],
['nbs-iscc-m:verditergreen.136','verditergreen','verditer green',[103,146,103],'679267',6787687],
['nbs-iscc-m:verdure.137','verdure','verdure',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:veridinegreen.144','veridinegreen','veridine green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:vernoniapurple.262','vernoniapurple','vernonia purple',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:veronabrown.58','veronabrown','verona brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:veronayellow.83','veronayellow','verona yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:veronayellow.84','veronayellow','verona yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:veronayellow.86','veronayellow','verona yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:veronayellow.87','veronayellow','verona yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:veroneseyellow.83','veroneseyellow','veronese yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:veroneseyellow.84','veroneseyellow','veronese yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:veroneseyellow.86','veroneseyellow','veronese yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:veroneseyellow.87','veroneseyellow','veronese yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:veronica.211','veronica','veronica',[96,78,129],'604e81',6311553],
['nbs-iscc-m:versailles.172','versailles','versailles',[102,170,188],'66aabc',6728380],
['nbs-iscc-m:vertrusse.136','vertrusse','vert russe',[103,146,103],'679267',6787687],
['nbs-iscc-m:vertrusse.137','vertrusse','vert russe',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:vertrusse.150','vertrusse','vert russe',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:vervain.214','vervain','vervain',[150,144,171],'9690ab',9867435],
['nbs-iscc-m:vervain.227','vervain','vervain',[170,152,169],'aa98a9',11180201],
['nbs-iscc-m:vestal.228','vestal','vestal',[121,104,120],'796878',7956600],
['nbs-iscc-m:vestal.245','vestal','vestal',[131,100,121],'836479',8610937],
['nbs-iscc-m:veteran.187','veteran','veteran',[54,69,79],'36454f',3556687],
['nbs-iscc-m:vetivergreen.109','vetivergreen','vetiver green',[140,135,103],'8c8767',9209703],
['nbs-iscc-m:victoria.224','victoria','victoria',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:victoriablue.178','victoriablue','victoria blue',[0,103,165],'0067a5',26533],
['nbs-iscc-m:victoriagreen.144','victoriagreen','victoria green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-m:victoriagreen.149','victoriagreen','victoria green',[141,163,153],'8da399',9282457],
['nbs-iscc-m:victoriagreen.163','victoriagreen','victoria green',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:victorialake.16','victorialake','victoria lake',[114,47,55],'722f37',7483191],
['nbs-iscc-m:viennablue.169','viennablue','vienna blue',[0,119,145],'007791',30609],
['nbs-iscc-m:viennabrown.61','viennabrown','vienna brown',[99,81,71],'635147',6508871],
['nbs-iscc-m:viennabrown.80','viennabrown','vienna brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:viennagreen.140','viennagreen','vienna green',[62,180,137],'3eb489',4109449],
['nbs-iscc-m:viennalake.11','viennalake','vienna lake',[190,0,50],'be0032',12451890],
['nbs-iscc-m:viennalake.12','viennalake','vienna lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-m:viennasmoke.266','viennasmoke','vienna smoke',[85,85,85],'555555',5592405],
['nbs-iscc-m:vineyard.16','vineyard','vineyard',[114,47,55],'722f37',7483191],
['nbs-iscc-m:vineyard.17','vineyard','vineyard',[63,23,40],'3f1728',4134696],
['nbs-iscc-m:viola.223','viola','viola',[134,96,142],'86608e',8806542],
['nbs-iscc-m:violetcarmine.242','violetcarmine','violet-carmine',[93,57,84],'5d3954',6109524],
['nbs-iscc-m:violine.207','violine','violine',[96,78,151],'604e97',6311575],
['nbs-iscc-m:violine.211','violine','violine',[96,78,129],'604e81',6311553],
['nbs-iscc-m:virgin.182','virgin','virgin',[67,107,149],'436b95',4418453],
['nbs-iscc-m:viridian.141','viridian','viridian',[0,121,89],'007959',31065],
['nbs-iscc-m:viridian.145','viridian','viridian',[59,120,97],'3b7861',3897441],
['nbs-iscc-m:viridinegreen.119','viridinegreen','viridine green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:viridineyellow.117','viridineyellow','viridine yellow',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-m:vitellineyellow.84','vitellineyellow','vitelline yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:vitellinous.84','vitellinous','vitellinous',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:vitreous.119','vitreous','vitreous',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:wad.186','wad','wad',[83,104,120],'536878',5466232],
['nbs-iscc-m:wald.101','wald','wald',[234,230,121],'eae679',15394425],
['nbs-iscc-m:wald.102','wald','wald',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:wallflowerbrown.16','wallflowerbrown','wallflower [brown] ',[114,47,55],'722f37',7483191],
['nbs-iscc-m:wallflowerbrown.43','wallflowerbrown','wallflower [brown] ',[121,68,59],'79443b',7947323],
['nbs-iscc-m:wallgreen.160','wallgreen','wall green',[0,122,116],'007a74',31348],
['nbs-iscc-m:walnutbrown.76','walnutbrown','walnut [brown] ',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:warblergreen.106','warblergreen','warbler green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:warmsepia.61','warmsepia','warm sepia ',[99,81,71],'635147',6508871],
['nbs-iscc-m:waterblue.164','waterblue','water blue',[49,120,115],'317873',3242099],
['nbs-iscc-m:watercolor.163','watercolor','water-color',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:watercress.120','watercress','water cress',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:waterfall.164','waterfall','waterfall',[49,120,115],'317873',3242099],
['nbs-iscc-m:watergreen.105','watergreen','water green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:watergreen.119','watergreen','water green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-m:watergreen.121','watergreen','water green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-m:watergrey.112','watergrey','water grey ',[138,135,118],'8a8776',9078646],
['nbs-iscc-m:waterloo.204','waterloo','waterloo',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:watermelon.3','watermelon','watermelon',[228,113,122],'e4717a',14971258],
['nbs-iscc-m:watermelon.15','watermelon','watermelon',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:watersprite.135','watersprite','water sprite',[147,197,146],'93c592',9684370],
['nbs-iscc-m:watteau.181','watteau','watteau',[112,163,204],'70a3cc',7381964],
['nbs-iscc-m:wau.101','wau','wau',[234,230,121],'eae679',15394425],
['nbs-iscc-m:wau.102','wau','wau',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:waxbrown.77','waxbrown','wax brown',[130,102,68],'826644',8545860],
['nbs-iscc-m:waxcolor.104','waxcolor','wax color',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-m:waxcolor.105','waxcolor','wax color',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:waxen.104','waxen','waxen',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-m:waxen.105','waxen','waxen',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:waxred.39','waxred','wax red',[180,116,94],'b4745e',11826270],
['nbs-iscc-m:waxwhite.104','waxwhite','wax white',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-m:waxwhite.105','waxwhite','wax white',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:waxyellow.87','waxyellow','wax yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:weatheredoak.59','weatheredoak','weathered oak',[66,37,24],'422518',4334872],
['nbs-iscc-m:weigelia.15','weigelia','weigelia',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:weld.101','weld','weld',[234,230,121],'eae679',15394425],
['nbs-iscc-m:weld.102','weld','weld',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:westminster.194','westminster','westminster',[48,38,122],'30267a',3155578],
['nbs-iscc-m:westminster.205','westminster','westminster',[144,101,202],'9065ca',9463242],
['nbs-iscc-m:westpoint.192','westpoint','west point',[81,88,94],'51585e',5331038],
['nbs-iscc-m:wheat.71','wheat','wheat',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:wheat.73','wheat','wheat',[250,214,165],'fad6a5',16438949],
['nbs-iscc-m:whippet.95','whippet','whippet',[108,84,30],'6c541e',7099422],
['nbs-iscc-m:whirlpool.174','whirlpool','whirlpool',[0,73,88],'004958',18776],
['nbs-iscc-m:whiteblue.190','whiteblue','white blue',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-m:whitejade.31','whitejade','white jade',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-m:whitejade.93','whitejade','white jade',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:wield.101','wield','wield',[234,230,121],'eae679',15394425],
['nbs-iscc-m:wield.102','wield','wield',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:wigwam.58','wigwam','wigwam',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:wildaster.219','wildaster','wild aster',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:wildaster.238','wildaster','wild aster',[112,41,99],'702963',7350627],
['nbs-iscc-m:wildcherry.16','wildcherry','wild cherry',[114,47,55],'722f37',7483191],
['nbs-iscc-m:wildcherry.259','wildcherry','wild cherry',[103,49,71],'673147',6762823],
['nbs-iscc-m:wilddovegrey.64','wilddovegrey','wild dove grey ',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:wildhoney.54','wildhoney','wild honey',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:wildhoney.57','wildhoney','wild honey',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:wildiris.233','wildiris','wild iris',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:wildorchid.245','wildorchid','wild orchid',[131,100,121],'836479',8610937],
['nbs-iscc-m:wildpigeon.64','wildpigeon','wild pigeon',[91,80,79],'5b504f',5984335],
['nbs-iscc-m:wildraspberry.16','wildraspberry','wild raspberry',[114,47,55],'722f37',7483191],
['nbs-iscc-m:wildraspberry.259','wildraspberry','wild raspberry',[103,49,71],'673147',6762823],
['nbs-iscc-m:wildrose.6','wildrose','wild rose',[192,128,129],'c08081',12615809],
['nbs-iscc-m:wildstrawberry.13','wildstrawberry','wild strawberry',[132,27,45],'841b2d',8657709],
['nbs-iscc-m:wildstrawberry.16','wildstrawberry','wild strawberry',[114,47,55],'722f37',7483191],
['nbs-iscc-m:willow.107','willow','willow',[102,93,30],'665d1e',6708510],
['nbs-iscc-m:willowgreen.106','willowgreen','willow green',[134,126,54],'867e36',8814134],
['nbs-iscc-m:windflower.262','windflower','windflower',[145,95,109],'915f6d',9527149],
['nbs-iscc-m:windsor.224','windsor','windsor',[86,60,92],'563c5c',5651548],
['nbs-iscc-m:windsorblue.204','windsorblue','windsor blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-m:windsorgreen.137','windsorgreen','windsor green',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:windsortan.54','windsortan','windsor tan',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:wineberry.259','wineberry','wineberry',[103,49,71],'673147',6762823],
['nbs-iscc-m:winedregs.16','winedregs','wine dregs',[114,47,55],'722f37',7483191],
['nbs-iscc-m:winedregs.41','winedregs','wine dregs',[86,7,12],'56070c',5637900],
['nbs-iscc-m:winedregs.44','winedregs','wine dregs',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-m:winelees.16','winelees','wine lees',[114,47,55],'722f37',7483191],
['nbs-iscc-m:winelees.41','winelees','wine lees',[86,7,12],'56070c',5637900],
['nbs-iscc-m:winelees.44','winelees','wine lees',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-m:wineyellow.89','wineyellow','wine yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-m:wineyellow.90','wineyellow','wine yellow',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:wintergreen.136','wintergreen','winter green',[103,146,103],'679267',6787687],
['nbs-iscc-m:wintergreen.137','wintergreen','wintergreen ',[53,94,59],'355e3b',3497531],
['nbs-iscc-m:winterleaf.61','winterleaf','winter leaf',[99,81,71],'635147',6508871],
['nbs-iscc-m:wireless.182','wireless','wireless',[67,107,149],'436b95',4418453],
['nbs-iscc-m:wistariablue.210','wistariablue','wistaria [blue] ',[140,130,182],'8c82b6',9208502],
['nbs-iscc-m:wistariablue.199','wistariablue','wistaria blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:wistariaviolet.210','wistariaviolet','wistaria [violet] ',[140,130,182],'8c82b6',9208502],
['nbs-iscc-m:witchwood.58','witchwood','witchwood',[111,78,55],'6f4e37',7294519],
['nbs-iscc-m:witheredleaf.51','witheredleaf','withered leaf',[190,101,22],'be6516',12477718],
['nbs-iscc-m:witheredleaf.54','witheredleaf','withered leaf',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:witheredleaf.55','witheredleaf','withered leaf',[128,70,27],'80461b',8406555],
['nbs-iscc-m:witheredrose.19','witheredrose','withered rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-m:witheredrose.43','witheredrose','withered rose',[121,68,59],'79443b',7947323],
['nbs-iscc-m:woad.186','woad','woad',[83,104,120],'536878',5466232],
['nbs-iscc-m:woald.101','woald','woald',[234,230,121],'eae679',15394425],
['nbs-iscc-m:woald.102','woald','woald',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:wod.101','wod','wod',[234,230,121],'eae679',15394425],
['nbs-iscc-m:wod.102','wod','wod',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:wode.186','wode','wode',[83,104,120],'536878',5466232],
['nbs-iscc-m:wold.101','wold','wold',[234,230,121],'eae679',15394425],
['nbs-iscc-m:wold.102','wold','wold',[185,180,89],'b9b459',12170329],
['nbs-iscc-m:woodash.93','woodash','woodash',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-m:woodbark.80','woodbark','woodbark',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-m:woodbinegreen.120','woodbinegreen','woodbine green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-m:woodbinegreen.122','woodbinegreen','woodbine green',[143,151,121],'8f9779',9410425],
['nbs-iscc-m:woodbinegreen.125','woodbinegreen','woodbine green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:woodbinegreen.127','woodbinegreen','woodbine green',[81,87,68],'515744',5330756],
['nbs-iscc-m:woodlandbrown.81','woodlandbrown','woodland brown',[72,60,50],'483c32',4734002],
['nbs-iscc-m:woodlandbrown.267','woodlandbrown','woodland brown',[34,34,34],'222222',2236962],
['nbs-iscc-m:woodlandgreen.125','woodlandgreen','woodland green ',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:woodlandrose.57','woodlandrose','woodland rose',[166,123,91],'a67b5b',10910555],
['nbs-iscc-m:woodrose.45','woodrose','wood rose',[151,127,115],'977f73',9928563],
['nbs-iscc-m:woodrose.60','woodrose','wood rose',[149,128,112],'958070',9797744],
['nbs-iscc-m:woodviolet.219','woodviolet','wood violet',[96,47,107],'602f6b',6303595],
['nbs-iscc-m:wren.111','wren','wren',[54,53,39],'363527',3552551],
['nbs-iscc-m:wren.113','wren','wren',[87,85,76],'57554c',5723468],
['nbs-iscc-m:wroughtiron.266','wroughtiron','wrought iron',[85,85,85],'555555',5592405],
['nbs-iscc-m:yacht.178','yacht','yacht',[0,103,165],'0067a5',26533],
['nbs-iscc-m:yaleblue.179','yaleblue','yale blue',[0,65,106],'00416a',16746],
['nbs-iscc-m:yama.163','yama','yama',[102,173,164],'66ada4',6729124],
['nbs-iscc-m:yellowbeige.76','yellowbeige','yellow beige',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:yellowbeige.77','yellowbeige','yellow beige',[130,102,68],'826644',8545860],
['nbs-iscc-m:yellowberries.68','yellowberries','yellow berries',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:yellowberries.71','yellowberries','yellow berries',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:yellowbrazilwood.87','yellowbrazilwood','yellow brazil wood',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:yellowbrazilwood.90','yellowbrazilwood','yellow brazil wood',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:yellowcarmine.68','yellowcarmine','yellow carmine',[234,162,33],'eaa221',15376929],
['nbs-iscc-m:yellowcarmine.71','yellowcarmine','yellow carmine',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:yellowdaisy.83','yellowdaisy','yellow daisy',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:yellowdaisy.84','yellowdaisy','yellow daisy',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:yellowdaisy.86','yellowdaisy','yellow daisy',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:yellowdaisy.87','yellowdaisy','yellow daisy',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:yellowearth.71','yellowearth','yellow earth',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:yellowmadder.83','yellowmadder','yellow madder',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:yellowmadder.84','yellowmadder','yellow madder',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:yellowmadder.86','yellowmadder','yellow madder',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:yellowmadder.87','yellowmadder','yellow madder',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:yellowochre.71','yellowochre','yellow ochre',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:yellowrealgar.83','yellowrealgar','yellow realgar',[250,218,94],'fada5e',16439902],
['nbs-iscc-m:yellowrealgar.84','yellowrealgar','yellow realgar',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:yellowrealgar.86','yellowrealgar','yellow realgar',[248,222,126],'f8de7e',16309886],
['nbs-iscc-m:yellowrealgar.87','yellowrealgar','yellow realgar',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:yellowsienna.71','yellowsienna','yellow sienna',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:yellowstone.105','yellowstone','yellow stone',[185,181,125],'b9b57d',12170621],
['nbs-iscc-m:yellowstone.91','yellowstone','yellowstone',[161,143,96],'a18f60',10588000],
['nbs-iscc-m:yellowwash.71','yellowwash','yellow wash',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:yellowwood.87','yellowwood','yellow wood',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-m:yellowwood.90','yellowwood','yellow wood',[194,178,128],'c2b280',12759680],
['nbs-iscc-m:yewgreen.125','yewgreen','yew green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-m:yolkyellow.84','yolkyellow','yolk yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:yosemite.76','yosemite','yosemite',[193,154,107],'c19a6b',12687979],
['nbs-iscc-m:yucatan.54','yucatan','yucatan',[174,105,56],'ae6938',11430200],
['nbs-iscc-m:yucatan.74','yucatan','yucatan',[153,101,21],'996515',10052885],
['nbs-iscc-m:yucca.150','yucca','yucca',[94,113,106],'5e716a',6189418],
['nbs-iscc-m:yuchi.146','yuchi','yu chi',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-m:yvetteviolet.228','yvetteviolet','yvette violet',[121,104,120],'796878',7956600],
['nbs-iscc-m:zaffreblue.179','zaffreblue','zaffre blue ',[0,65,106],'00416a',16746],
['nbs-iscc-m:zaffreblue.182','zaffreblue','zaffre blue ',[67,107,149],'436b95',4418453],
['nbs-iscc-m:zanzibar.47','zanzibar','zanzibar',[67,48,46],'43302e',4403246],
['nbs-iscc-m:zedoarywash.71','zedoarywash','zedoary wash',[227,168,87],'e3a857',14919767],
['nbs-iscc-m:zenithblue.199','zenithblue','zenith [blue] ',[135,145,191],'8791bf',8884671],
['nbs-iscc-m:zenithblue.203','zenithblue','zenith [blue] ',[140,146,172],'8c92ac',9212588],
['nbs-iscc-m:zephyr.7','zephyr','zephyr',[234,216,215],'ead8d7',15390935],
['nbs-iscc-m:zephyr.8','zephyr','zephyr',[196,174,173],'c4aead',12889773],
['nbs-iscc-m:zinc.233','zinc','zinc',[139,133,137],'8b8589',9143689],
['nbs-iscc-m:zinc.265','zinc','zinc',[132,132,130],'848482',8684674],
['nbs-iscc-m:zincgreen.136','zincgreen','zinc green',[103,146,103],'679267',6787687],
['nbs-iscc-m:zincorange.50','zincorange','zinc orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-m:zincorange.53','zincorange','zinc orange',[217,144,88],'d99058',14258264],
['nbs-iscc-m:zincyellow.84','zincyellow','zinc yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-m:zinnia.15','zinnia','zinnia',[171,78,82],'ab4e52',11226706],
['nbs-iscc-m:zulu.47','zulu','zulu',[67,48,46],'43302e',4403246],
['nbs-iscc-m:zunibrown.58','zunibrown','zuni brown',[111,78,55],'6f4e37',7294519]
    ];
}

sub _description {
    return {
          'subtitle' => 'Dictionary of Color',
          'title' => 'NBS/ISCC M',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (M) Dictionary of Color

Maerz and Paul,
Dictionary of Color, 1st ed. 

This idiosyncratic dictionary\'s 3064 names map to 4401 colors, using 223 of the 267 centroids.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#M]
'
        }

}

1;
