package Color::Library::Dictionary::NBS_ISCC::P;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::P;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::P - (NBS/ISCC P) Plochere Color System

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (P) Plochere Color System

        Plochere Color System

    This idiosyncratic dictionary for interior decorating has 1246 names mapping to 1606 colors, using 206 of the 267 centroids.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#P>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>absinthe yellow</td><td>absintheyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>abstract blue</td><td>abstractblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>abyss</td><td>abyss</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>acacia</td><td>acacia</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>acacia gray</td><td>acaciagray</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>acacia green</td><td>acaciagreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>aden</td><td>aden</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>admiral</td><td>admiral</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>african green</td><td>africangreen</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>african night</td><td>africannight</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>after glow</td><td>afterglow</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>agean mist</td><td>ageanmist</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>ageratum</td><td>ageratum</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>air castle blue</td><td>aircastleblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>airy cream</td><td>airycream</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>aladdin's lamp</td><td>aladdinslamp</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>algiers blue</td><td>algiersblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>allure</td><td>allure</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>almond</td><td>almond</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>almond cream</td><td>almondcream</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>alpine blue</td><td>alpineblue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>alpine blue</td><td>alpineblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>amaranth</td><td>amaranth</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>amaranth</td><td>amaranth</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>amber coral</td><td>ambercoral</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>amber gold</td><td>ambergold</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>amber gold</td><td>ambergold</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>amber gold</td><td>ambergold</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#b6e5af;width:4em;" /><td>ambrosia</td><td>ambrosia</td><td>##b6e5af</td><td>182</td> <td>229</td> <td>175</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>amethyst</td><td>amethyst</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>amethyst orchid</td><td>amethystorchid</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>amulet</td><td>amulet</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>ancestral</td><td>ancestral</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>ancestral</td><td>ancestral</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>angel blue</td><td>angelblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>angel wing</td><td>angelwing</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>angora</td><td>angora</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>angora</td><td>angora</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>antique brass</td><td>antiquebrass</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>antique bronze</td><td>antiquebronze</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>antique fuchsia</td><td>antiquefuchsia</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>antique yellow</td><td>antiqueyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>apple green</td><td>applegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>apricot</td><td>apricot</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>apricot cream</td><td>apricotcream</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>apricot cream</td><td>apricotcream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>apricot ice</td><td>apricotice</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>apricot sherbet</td><td>apricotsherbet</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>apricot tan</td><td>apricottan</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>apricot tan</td><td>apricottan</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>april sky</td><td>aprilsky</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>aqua gray</td><td>aquagray</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>aquamarine green</td><td>aquamarinegreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>aqua queen</td><td>aquaqueen</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>aqua sky</td><td>aquasky</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>arbor green</td><td>arborgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>arcadia</td><td>arcadia</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>arcadia</td><td>arcadia</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>arctic</td><td>arctic</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>arctic</td><td>arctic</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>arno blue</td><td>arnoblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>ashes of roses </td><td>ashesofroses</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>ashes of roses </td><td>ashesofroses</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>asthetic blue</td><td>astheticblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>atlantis</td><td>atlantis</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>atonement</td><td>atonement</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>aurora pink</td><td>aurorapink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>aurora pink</td><td>aurorapink</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>aurora yellow</td><td>aurorayellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>autumn brown</td><td>autumnbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>autumn brown</td><td>autumnbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>autumn glory</td><td>autumnglory</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>autumn glory</td><td>autumnglory</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>autumn glory</td><td>autumnglory</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>autumn gold </td><td>autumngold</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>autumn tan</td><td>autumntan</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>avon</td><td>avon</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>azalea</td><td>azalea</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>azurite blue</td><td>azuriteblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>azurite blue</td><td>azuriteblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>baby blue</td><td>babyblue</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>baby blue eyes</td><td>babyblueeyes</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>baby blue eyes</td><td>babyblueeyes</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>bagdad</td><td>bagdad</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>ballad blue</td><td>balladblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>ballerina</td><td>ballerina</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>balmy air</td><td>balmyair</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>balsam green </td><td>balsamgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>baltic </td><td>baltic</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>baltic </td><td>baltic</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>banana</td><td>banana</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>banshee</td><td>banshee</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>banshee</td><td>banshee</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>banshee</td><td>banshee</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>banshee</td><td>banshee</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>baronet</td><td>baronet</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>basic</td><td>basic</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>bath stone</td><td>bathstone</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>bavarian blue</td><td>bavarianblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>bay leaf</td><td>bayleaf</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>bayou</td><td>bayou</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>bayou</td><td>bayou</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>beau blue</td><td>beaublue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>beautiful</td><td>beautiful</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>beauty pink</td><td>beautypink</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>beige gray</td><td>beigegray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>belladonna</td><td>belladonna</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>bellflower</td><td>bellflower</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>beryl green</td><td>berylgreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>best effort</td><td>besteffort</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>best effort</td><td>besteffort</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>bewitch</td><td>bewitch</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>bewitching blue</td><td>bewitchingblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#00443f;width:4em;" /><td>billiard</td><td>billiard</td><td>##00443f</td><td>0</td> <td>68</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>billiard</td><td>billiard</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>billow</td><td>billow</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>birch</td><td>birch</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>bird's-egg-green</td><td>birdsegggreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>bird's-egg-green</td><td>birdsegggreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>biscay bay</td><td>biscaybay</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>biscay bay</td><td>biscaybay</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>bishop</td><td>bishop</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>bison</td><td>bison</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>bisque</td><td>bisque</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>bisque</td><td>bisque</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>bittersweet</td><td>bittersweet</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>bittersweet orange</td><td>bittersweetorange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>bittersweet orange</td><td>bittersweetorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>blackberry cream</td><td>blackberrycream</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>black forest</td><td>blackforest</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>black knight</td><td>blackknight</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>black knight</td><td>blackknight</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>black water</td><td>blackwater</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black water</td><td>blackwater</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>blanch</td><td>blanch</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>blarney</td><td>blarney</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>blarney</td><td>blarney</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>blaze blue </td><td>blazeblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>blaze blue </td><td>blazeblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>blend</td><td>blend</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>blithe</td><td>blithe</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>blonde green</td><td>blondegreen</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>blossom</td><td>blossom</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>blue appeal</td><td>blueappeal</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>blue appeal</td><td>blueappeal</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>blue bell</td><td>bluebell</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>blue chill</td><td>bluechill</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>blue danube</td><td>bluedanube</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>blue dash</td><td>bluedash</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>blue day</td><td>blueday</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>blue fog</td><td>bluefog</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>blue fog</td><td>bluefog</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>blue glow</td><td>blueglow</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>blue grotto</td><td>bluegrotto</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>blue heaven</td><td>blueheaven</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>blue heaven</td><td>blueheaven</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>blue heaven</td><td>blueheaven</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>blue horizon</td><td>bluehorizon</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>blue hour</td><td>bluehour</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>blue idol</td><td>blueidol</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>blue light</td><td>bluelight</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>blue lightning</td><td>bluelightning</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>blue mist</td><td>bluemist</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>blue mist</td><td>bluemist</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>blue prose</td><td>blueprose</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>blue ridge</td><td>blueridge</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>blue ridge</td><td>blueridge</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>blue shadow</td><td>blueshadow</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>blue spruce</td><td>bluespruce</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>blue swirl</td><td>blueswirl</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>blue tease</td><td>bluetease</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>blue turquoise</td><td>blueturquoise</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>blue waltz </td><td>bluewaltz</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>blue waltz </td><td>bluewaltz</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>blue wash</td><td>bluewash</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>blush rose</td><td>blushrose</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>blush yellow</td><td>blushyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>blush yellow</td><td>blushyellow</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>bog</td><td>bog</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>bohemian blue</td><td>bohemianblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>bonnie blue</td><td>bonnieblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>bonnie blue</td><td>bonnieblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>bottle green</td><td>bottlegreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>bottle green</td><td>bottlegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>bougainvillea </td><td>bougainvillea</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>bounding main</td><td>boundingmain</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>bouquet green</td><td>bouquetgreen</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>bouquet green</td><td>bouquetgreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#d5badb;width:4em;" /><td>bouquet orchid</td><td>bouquetorchid</td><td>##d5badb</td><td>213</td> <td>186</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>bouquet orchid</td><td>bouquetorchid</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>bouquet yellow</td><td>bouquetyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>brass</td><td>brass</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>brazil red</td><td>brazilred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>breath of spring</td><td>breathofspring</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>breath of spring</td><td>breathofspring</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>bridesmaid pink</td><td>bridesmaidpink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>bright sun</td><td>brightsun</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>bright sun</td><td>brightsun</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>brilliant green</td><td>brilliantgreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>bronze gold </td><td>bronzegold</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>bronze gold </td><td>bronzegold</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>bronze mist</td><td>bronzemist</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>bronze pink</td><td>bronzepink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>bronze pink</td><td>bronzepink</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>bronze sheen</td><td>bronzesheen</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>bronzio</td><td>bronzio</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>brook green</td><td>brookgreen</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>bruges</td><td>bruges</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>buccaneer</td><td>buccaneer</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>buckskin tan</td><td>buckskintan</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>buff citron</td><td>buffcitron</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>burnt almond</td><td>burntalmond</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>burnt orange</td><td>burntorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>burnt yellow</td><td>burntyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>butterfly yellow</td><td>butterflyyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>butterfly yellow</td><td>butterflyyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>cabbage</td><td>cabbage</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>caen stone</td><td>caenstone</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>california gold</td><td>californiagold</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>california green</td><td>californiagreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>california poppy</td><td>californiapoppy</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>camelia pink</td><td>cameliapink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>camelia pink</td><td>cameliapink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>camelia rose</td><td>cameliarose</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>cameo</td><td>cameo</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>cameo pink</td><td>cameopink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>cameo pink</td><td>cameopink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>canary bronze</td><td>canarybronze</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>canary yellow</td><td>canaryyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>canary yellow</td><td>canaryyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>candida</td><td>candida</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>canton</td><td>canton</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>caprice lavender</td><td>capricelavender</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>caprice pink</td><td>capricepink</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>caprice pink</td><td>capricepink</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>caramel</td><td>caramel</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>caramel cream</td><td>caramelcream</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>caravan</td><td>caravan</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carnival red</td><td>carnivalred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>castilian blue</td><td>castilianblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#301934;width:4em;" /><td>cathedral</td><td>cathedral</td><td>##301934</td><td>48</td> <td>25</td> <td>52</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>cathedral</td><td>cathedral</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>cedar</td><td>cedar</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>cedar bough</td><td>cedarbough</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>celestial blue</td><td>celestialblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>celestial blue</td><td>celestialblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>celestial yellow</td><td>celestialyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>celestial yellow</td><td>celestialyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>ceramic</td><td>ceramic</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>ceramic</td><td>ceramic</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>ceres</td><td>ceres</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>cerise pink</td><td>cerisepink</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>cerise rose</td><td>ceriserose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>ceylon blue</td><td>ceylonblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>chalk violet</td><td>chalkviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>chalk violet</td><td>chalkviolet</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>chamois yellow</td><td>chamoisyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>chamois yellow</td><td>chamoisyellow</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>champagne</td><td>champagne</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>champagne buff</td><td>champagnebuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>chantilly</td><td>chantilly</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>charcoal</td><td>charcoal</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>charcoal</td><td>charcoal</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>charm</td><td>charm</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>charm</td><td>charm</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>charm</td><td>charm</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>charm</td><td>charm</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>charm pink</td><td>charmpink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>charm school</td><td>charmschool</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>charm school</td><td>charmschool</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8db600;width:4em;" /><td>chartreuse green</td><td>chartreusegreen</td><td>##8db600</td><td>141</td> <td>182</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>chartreuse green</td><td>chartreusegreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>chartreuse yellow</td><td>chartreuseyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>chaste</td><td>chaste</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>chateau</td><td>chateau</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>cheddar cheese</td><td>cheddarcheese</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>cheer</td><td>cheer</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cheerful yellow</td><td>cheerfulyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cheerful yellow</td><td>cheerfulyellow</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>chelsea yellow</td><td>chelseayellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>chelsea yellow</td><td>chelseayellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>cherry</td><td>cherry</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>chili </td><td>chili</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>china pink</td><td>chinapink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>china pink</td><td>chinapink</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>china rose</td><td>chinarose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>china sea</td><td>chinasea</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>chive</td><td>chive</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>chive</td><td>chive</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>christmas green</td><td>christmasgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>chrysanthemum yelllow</td><td>chrysanthemumyelllow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>chrysolite green</td><td>chrysolitegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>cinderella</td><td>cinderella</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>cineraria</td><td>cineraria</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>cinnamon</td><td>cinnamon</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>cinnamon cream</td><td>cinnamoncream</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>citron bronze</td><td>citronbronze</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>citron gray</td><td>citrongray</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>citron gray</td><td>citrongray</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>citron yellow</td><td>citronyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>citron yellow</td><td>citronyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>citron yellow</td><td>citronyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>citron yellow</td><td>citronyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>classic blue</td><td>classicblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>classic blue</td><td>classicblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>clementine</td><td>clementine</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>cleopatra</td><td>cleopatra</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>clivia</td><td>clivia</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>cloister</td><td>cloister</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>cloister</td><td>cloister</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cloud cream</td><td>cloudcream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cloud cream</td><td>cloudcream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>cloud gray</td><td>cloudgray</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>cloudy blue</td><td>cloudyblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>clover</td><td>clover</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>cocoa bronze</td><td>cocoabronze</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>cocoa brown</td><td>cocoabrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>cold morn</td><td>coldmorn</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>cold morn</td><td>coldmorn</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>colonial blue</td><td>colonialblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>colonial cream</td><td>colonialcream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>colonial exterior green</td><td>colonialexteriorgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>conclude</td><td>conclude</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>congo</td><td>congo</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>congo blue</td><td>congoblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>congo brown</td><td>congobrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>congo brown</td><td>congobrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>conifer</td><td>conifer</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>continental blue</td><td>continentalblue</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>cool eve</td><td>cooleve</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>copper</td><td>copper</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>copper bronze</td><td>copperbronze</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>copper cream</td><td>coppercream</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>coquette</td><td>coquette</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>coral</td><td>coral</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>coral blush</td><td>coralblush</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>coral blush</td><td>coralblush</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>coral cloud</td><td>coralcloud</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>coral gold</td><td>coralgold</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>coral pink</td><td>coralpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>coral rose</td><td>coralrose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>coronation</td><td>coronation</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>coronet blue</td><td>coronetblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>corsage pink</td><td>corsagepink</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>corsair</td><td>corsair</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>corydalis</td><td>corydalis</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>corydalis</td><td>corydalis</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>cosmic blue</td><td>cosmicblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#d5badb;width:4em;" /><td>cosmos pink</td><td>cosmospink</td><td>##d5badb</td><td>213</td> <td>186</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>cosmos pink</td><td>cosmospink</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>cowslip</td><td>cowslip</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>crab pink</td><td>crabpink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>crab pink</td><td>crabpink</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cream</td><td>cream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>cream blush</td><td>creamblush</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>cream chant</td><td>creamchant</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cream cheese</td><td>creamcheese</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>cream delight</td><td>creamdelight</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cream dream</td><td>creamdream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>cream gold</td><td>creamgold</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cream pearl</td><td>creampearl</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cream tone</td><td>creamtone</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cream tone</td><td>creamtone</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>cream white</td><td>creamwhite</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cream yellow</td><td>creamyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>creole pink</td><td>creolepink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>crest</td><td>crest</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>crimson glory</td><td>crimsonglory</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>crisp blue</td><td>crispblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>crocus rose</td><td>crocusrose</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>cruise blue</td><td>cruiseblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>cruise blue</td><td>cruiseblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>crystal blue</td><td>crystalblue</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>crystal blue</td><td>crystalblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>cuban orchid</td><td>cubanorchid</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>cuban orchid</td><td>cubanorchid</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>cuban sand</td><td>cubansand</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>cuban sand</td><td>cubansand</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>cuddle blue</td><td>cuddleblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>cuddle blue</td><td>cuddleblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>cupid blue</td><td>cupidblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>cyan blue</td><td>cyanblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>cypress</td><td>cypress</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>daphne pink</td><td>daphnepink</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark forest</td><td>darkforest</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>dark fuchsia</td><td>darkfuchsia</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>dawn glow</td><td>dawnglow</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>dawn glow</td><td>dawnglow</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>dawn pink</td><td>dawnpink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>daybreak</td><td>daybreak</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>day dream</td><td>daydream</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>dazzle blue</td><td>dazzleblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>debonair</td><td>debonair</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>debutante blue</td><td>debutanteblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>debutante blue</td><td>debutanteblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>debutante pink</td><td>debutantepink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>debutante yellow</td><td>debutanteyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>deep hellebore red </td><td>deephelleborered</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>deep purple</td><td>deeppurple</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>deep purple</td><td>deeppurple</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#242124;width:4em;" /><td>deep purple</td><td>deeppurple</td><td>##242124</td><td>36</td> <td>33</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>deep ravine</td><td>deepravine</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>deep reverie</td><td>deepreverie</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>deep sea</td><td>deepsea</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>deep twilight</td><td>deeptwilight</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>deep violet</td><td>deepviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>deep violet</td><td>deepviolet</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>deep water</td><td>deepwater</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>delectable</td><td>delectable</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>delectable</td><td>delectable</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>delectable</td><td>delectable</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>delight</td><td>delight</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>del monte</td><td>delmonte</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>delta</td><td>delta</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>delusion </td><td>delusion</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>demon blue</td><td>demonblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>demure blue</td><td>demureblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>depth green</td><td>depthgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>desert brown</td><td>desertbrown</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>desert dust</td><td>desertdust</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>desert dust</td><td>desertdust</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>desert glass</td><td>desertglass</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>desert mist</td><td>desertmist</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>desert palm</td><td>desertpalm</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>desert pride</td><td>desertpride</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>desert sand</td><td>desertsand</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>desirable</td><td>desirable</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#d5badb;width:4em;" /><td>desire</td><td>desire</td><td>##d5badb</td><td>213</td> <td>186</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>dewkist </td><td>dewkist</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>dewkist </td><td>dewkist</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>diadem</td><td>diadem</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>dignity</td><td>dignity</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>dignity</td><td>dignity</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>dignity</td><td>dignity</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>distinction</td><td>distinction</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>diva blue</td><td>divablue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>diva blue</td><td>divablue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>divine blue</td><td>divineblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>dolly varden</td><td>dollyvarden</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>dove gray</td><td>dovegray</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>dove gray</td><td>dovegray</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>drab olive</td><td>drabolive</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>dream blue</td><td>dreamblue</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>dream cream</td><td>dreamcream</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>dream fluff</td><td>dreamfluff</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>dream stuff</td><td>dreamstuff</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>dreamy blue</td><td>dreamyblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>dried leaf</td><td>driedleaf</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>drizzle</td><td>drizzle</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>dryad</td><td>dryad</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>dryad rose </td><td>dryadrose</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>du barry blue</td><td>dubarryblue</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>duckling blue</td><td>ducklingblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>duckling blue</td><td>ducklingblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>dusky blue</td><td>duskyblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>dusky citron</td><td>duskycitron</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>dusky green</td><td>duskygreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>dusty green</td><td>dustygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>dusty green</td><td>dustygreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>dutch cream</td><td>dutchcream</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>dutch cream</td><td>dutchcream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>dynasty green</td><td>dynastygreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>earth brown</td><td>earthbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>easter bonnet</td><td>easterbonnet</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>easter egg yellow</td><td>eastereggyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ecru</td><td>ecru</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ecru cream</td><td>ecrucream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>ecru cream</td><td>ecrucream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>eerie blue</td><td>eerieblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>egg plant </td><td>eggplant</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>egg plant </td><td>eggplant</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>egg shell</td><td>eggshell</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>egg shell</td><td>eggshell</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>egyptian red</td><td>egyptianred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>eighteenth century citron</td><td>eighteenthcenturycitron</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>eighteenth century green</td><td>eighteenthcenturygreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>eighteenth century tan</td><td>eighteenthcenturytan</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>eighteenth century turquoise</td><td>eighteenthcenturyturquoise</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>eighteenth century turquoise</td><td>eighteenthcenturyturquoise</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>eighteenth century violet</td><td>eighteenthcenturyviolet</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>eighteenth century yellow</td><td>eighteenthcenturyyellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>electra</td><td>electra</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>elf green</td><td>elfgreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>elf green</td><td>elfgreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>elm</td><td>elm</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b6e5af;width:4em;" /><td>emerald green</td><td>emeraldgreen</td><td>##b6e5af</td><td>182</td> <td>229</td> <td>175</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>emerald isle</td><td>emeraldisle</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>empire yellow</td><td>empireyellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>empire yellow</td><td>empireyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>empirical blue</td><td>empiricalblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>enchantress</td><td>enchantress</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>enduring</td><td>enduring</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>enduring</td><td>enduring</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>english mist</td><td>englishmist</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>erie</td><td>erie</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>etherial green</td><td>etherialgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>etherial green</td><td>etherialgreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>eucalyptus green </td><td>eucalyptusgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>eve green</td><td>evegreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>eve green</td><td>evegreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>evening glow</td><td>eveningglow</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>evening haze</td><td>eveninghaze</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>eventide</td><td>eventide</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>everglade</td><td>everglade</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>fable</td><td>fable</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>fairy gold</td><td>fairygold</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>fairy land </td><td>fairyland</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>fairy land </td><td>fairyland</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>fairy princess</td><td>fairyprincess</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>falcon</td><td>falcon</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>fall blue</td><td>fallblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>fall blue</td><td>fallblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>fall bronze</td><td>fallbronze</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>fall leaf</td><td>fallleaf</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>fall leaf</td><td>fallleaf</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>fall yellow</td><td>fallyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>fall yellow</td><td>fallyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>fancy free</td><td>fancyfree</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>fanfare</td><td>fanfare</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>fantasia</td><td>fantasia</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>fantasy rose</td><td>fantasyrose</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>fantasy yellow</td><td>fantasyyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>far horizon</td><td>farhorizon</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>favorite</td><td>favorite</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>ferndell</td><td>ferndell</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>fernery</td><td>fernery</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>fern green</td><td>ferngreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>fern lane </td><td>fernlane</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>festival</td><td>festival</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>festival</td><td>festival</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>festive green</td><td>festivegreen</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>festive green</td><td>festivegreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>festoon</td><td>festoon</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>fidelity</td><td>fidelity</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>finesse</td><td>finesse</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>firecracker</td><td>firecracker</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>fire fly </td><td>firefly</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>fir green</td><td>firgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>firmament blue</td><td>firmamentblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>firmament gray</td><td>firmamentgray</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>firmament gray</td><td>firmamentgray</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>first lady</td><td>firstlady</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>first lady</td><td>firstlady</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>flame</td><td>flame</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>flame</td><td>flame</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>flamingo pink</td><td>flamingopink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>flash</td><td>flash</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>flax flower blue </td><td>flaxflowerblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>flemish blue</td><td>flemishblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>flesh cream</td><td>fleshcream</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>flesh cream</td><td>fleshcream</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>flesh pink</td><td>fleshpink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>flesh tint</td><td>fleshtint</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>flesh tint</td><td>fleshtint</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>flint</td><td>flint</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>flirtation</td><td>flirtation</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>flowerlet</td><td>flowerlet</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>fog blue</td><td>fogblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>fog green</td><td>foggreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>fog yellow</td><td>fogyellow</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>foliage</td><td>foliage</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>forest shade</td><td>forestshade</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>fortune</td><td>fortune</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>fountain blue</td><td>fountainblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>fountain green</td><td>fountaingreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#b6e5af;width:4em;" /><td>fountain green</td><td>fountaingreen</td><td>##b6e5af</td><td>182</td> <td>229</td> <td>175</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>four-leaf clover</td><td>fourleafclover</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>french beige</td><td>frenchbeige</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>french blue</td><td>frenchblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>french lilac</td><td>frenchlilac</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>french nude</td><td>frenchnude</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>frosty night</td><td>frostynight</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>froth</td><td>froth</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>frozen dew</td><td>frozendew</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>fuchsia</td><td>fuchsia</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>fuchsia</td><td>fuchsia</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>fuchsia pink</td><td>fuchsiapink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>fuchsia pink</td><td>fuchsiapink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>fuchsia pink</td><td>fuchsiapink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>fuchsia pink</td><td>fuchsiapink</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>fuchsia rose</td><td>fuchsiarose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>fuchsia rose</td><td>fuchsiarose</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>gale cloud</td><td>galecloud</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>gale winds</td><td>galewinds</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>garden pool</td><td>gardenpool</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>garnet rose</td><td>garnetrose</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>gay yellow</td><td>gayyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>gay yellow</td><td>gayyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>geneva blue</td><td>genevablue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>geneva blue</td><td>genevablue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>ghostly blue</td><td>ghostlyblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>ghostly blue</td><td>ghostlyblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>gleam</td><td>gleam</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>glint o'gold</td><td>glintogold</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>glint o'gold</td><td>glintogold</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>glory green</td><td>glorygreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>glory green-blue</td><td>glorygreenblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>gold coast</td><td>goldcoast</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>golden apricot</td><td>goldenapricot</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>golden apricot</td><td>goldenapricot</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>golden brown</td><td>goldenbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>golden buff</td><td>goldenbuff</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>golden cream</td><td>goldencream</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>golden dawn</td><td>goldendawn</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>golden fleece</td><td>goldenfleece</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>golden fleece</td><td>goldenfleece</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>golden fleece</td><td>goldenfleece</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>golden gem</td><td>goldengem</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>golden glow</td><td>goldenglow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>golden mist</td><td>goldenmist</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>golden mist</td><td>goldenmist</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>golden mist</td><td>goldenmist</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>golden peach</td><td>goldenpeach</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>golden rapture</td><td>goldenrapture</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>golden ray</td><td>goldenray</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>golden ray</td><td>goldenray</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>golden rod</td><td>goldenrod</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>golden sheaf</td><td>goldensheaf</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>golden sulphur</td><td>goldensulphur</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>golden tan</td><td>goldentan</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>golden west</td><td>goldenwest</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>golden yellow</td><td>goldenyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>gold fantasy</td><td>goldfantasy</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>gold glow</td><td>goldglow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>gold glow</td><td>goldglow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>gold pheasant</td><td>goldpheasant</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>gold rush</td><td>goldrush</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>good omen</td><td>goodomen</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>good omen</td><td>goodomen</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>gorge</td><td>gorge</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>gorge</td><td>gorge</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>gracious green</td><td>graciousgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>grand canyon</td><td>grandcanyon</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>grand canyon</td><td>grandcanyon</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>granite blue</td><td>graniteblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>granite green</td><td>granitegreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>grape</td><td>grape</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>grape</td><td>grape</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>grapefruit green</td><td>grapefruitgreen</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>grapefruit green</td><td>grapefruitgreen</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>grapefruit green</td><td>grapefruitgreen</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>grapefruit green</td><td>grapefruitgreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>grape green</td><td>grapegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>gravel</td><td>gravel</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>gravel</td><td>gravel</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>gravel</td><td>gravel</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>gray blue</td><td>grayblue</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>gray dream</td><td>graydream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>gray dream</td><td>graydream</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>gray drift</td><td>graydrift</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>gray drift</td><td>graydrift</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>gray green</td><td>graygreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>gray lady</td><td>graylady</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>gray light</td><td>graylight</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>gray light</td><td>graylight</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>gray mist</td><td>graymist</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>gray mist</td><td>graymist</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>gray mood</td><td>graymood</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>gray morn</td><td>graymorn</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>gray night</td><td>graynight</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>gray sand</td><td>graysand</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>gray sand</td><td>graysand</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>grecian rose</td><td>grecianrose</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>grecian rose</td><td>grecianrose</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>green banana</td><td>greenbanana</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>green banana</td><td>greenbanana</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>green black</td><td>greenblack</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>green black</td><td>greenblack</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>green black</td><td>greenblack</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>green black</td><td>greenblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>green breath</td><td>greenbreath</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>green charm</td><td>greencharm</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>green charm</td><td>greencharm</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>green dream</td><td>greendream</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#8db600;width:4em;" /><td>greenery</td><td>greenery</td><td>##8db600</td><td>141</td> <td>182</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>greenery</td><td>greenery</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>green eyes</td><td>greeneyes</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>green fog</td><td>greenfog</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>green glory</td><td>greenglory</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>green glory</td><td>greenglory</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>green glow</td><td>greenglow</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>green grass</td><td>greengrass</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>green haze</td><td>greenhaze</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>green ice</td><td>greenice</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>green ice</td><td>greenice</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>green lily</td><td>greenlily</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>green matrix</td><td>greenmatrix</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>green mist</td><td>greenmist</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>green moss</td><td>greenmoss</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>green oasis</td><td>greenoasis</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>green oasis</td><td>greenoasis</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>green olive </td><td>greenolive</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>green pride</td><td>greenpride</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>green ravine</td><td>greenravine</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>green river mist</td><td>greenrivermist</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#1e2321;width:4em;" /><td>green slate</td><td>greenslate</td><td>##1e2321</td><td>30</td> <td>35</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>green spring</td><td>greenspring</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>green stone</td><td>greenstone</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>green sulphur</td><td>greensulphur</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>green tea</td><td>greentea</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>green tee </td><td>greentee</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>growth green</td><td>growthgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>guinea green</td><td>guineagreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>gull gray</td><td>gullgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>gumdrop green</td><td>gumdropgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>gun metal</td><td>gunmetal</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>gypsy</td><td>gypsy</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>hanging garden</td><td>hanginggarden</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>hansa yellow</td><td>hansayellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>happy day</td><td>happyday</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>happy day</td><td>happyday</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>harbor blue</td><td>harborblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>harem blue</td><td>haremblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>harmonious blue</td><td>harmoniousblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>harvest gold</td><td>harvestgold</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>hawk brown</td><td>hawkbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>heart's desire</td><td>heartsdesire</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>heavenly charm</td><td>heavenlycharm</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>heavenly day</td><td>heavenlyday</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>heavenly flower</td><td>heavenlyflower</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>heavenly green</td><td>heavenlygreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>heavenly orchid</td><td>heavenlyorchid</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>heavenly pink</td><td>heavenlypink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>heliotrope</td><td>heliotrope</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>heliotrope</td><td>heliotrope</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>heliotrope gray</td><td>heliotropegray</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>heliotrope gray</td><td>heliotropegray</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>heliotrope gray</td><td>heliotropegray</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>hemlock</td><td>hemlock</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>hemp</td><td>hemp</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>hiawatha green</td><td>hiawathagreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>highland</td><td>highland</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>holiday</td><td>holiday</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>holland blue</td><td>hollandblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>honey beige</td><td>honeybeige</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>horizon</td><td>horizon</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>hortensia</td><td>hortensia</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>hortensia</td><td>hortensia</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>huckleberry</td><td>huckleberry</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>huron</td><td>huron</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>hussar</td><td>hussar</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>iceberg green</td><td>iceberggreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>iceberg green</td><td>iceberggreen</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>ice boat</td><td>iceboat</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>ice cap</td><td>icecap</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>ice flow</td><td>iceflow</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>iceland blue</td><td>icelandblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>icy green</td><td>icygreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>icy morn</td><td>icymorn</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>icy morn</td><td>icymorn</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>ideal</td><td>ideal</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>illusion</td><td>illusion</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>illusion</td><td>illusion</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>illusive</td><td>illusive</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>independence</td><td>independence</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>independence</td><td>independence</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>independence</td><td>independence</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>indian red</td><td>indianred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>ink blue</td><td>inkblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>ink blue</td><td>inkblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>inspiration</td><td>inspiration</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>intimate mood</td><td>intimatemood</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>ionian blue</td><td>ionianblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>ionian blue</td><td>ionianblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>irish isle</td><td>irishisle</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>iris leaf</td><td>irisleaf</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>iris orchid</td><td>irisorchid</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>iris orchid</td><td>irisorchid</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>iron mask</td><td>ironmask</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>iron mask</td><td>ironmask</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>irresistible</td><td>irresistible</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>island green</td><td>islandgreen</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>italian blue</td><td>italianblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ivory</td><td>ivory</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ivory white</td><td>ivorywhite</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>jade cream</td><td>jadecream</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>jade lime</td><td>jadelime</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>jasper</td><td>jasper</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>jasper</td><td>jasper</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>jealousy</td><td>jealousy</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>jersey cream</td><td>jerseycream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>jewel blue</td><td>jewelblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>jewel green</td><td>jewelgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>joy</td><td>joy</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>june bud</td><td>junebud</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>june bud</td><td>junebud</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>june green</td><td>junegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>jungle</td><td>jungle</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>juniper</td><td>juniper</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>juniper</td><td>juniper</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>kaffa</td><td>kaffa</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>killarney green </td><td>killarneygreen</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>king lear</td><td>kinglear</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>king neptune</td><td>kingneptune</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>king's ransom</td><td>kingsransom</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>kitten's ear</td><td>kittensear</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>lady orchid</td><td>ladyorchid</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>lagoon</td><td>lagoon</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>lake blue</td><td>lakeblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>lake como</td><td>lakecomo</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>lake louise</td><td>lakelouise</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>lamb's wool</td><td>lambswool</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>la mer</td><td>lamer</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>languid lavender</td><td>languidlavender</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>languid lavender</td><td>languidlavender</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>larkspur blue</td><td>larkspurblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>larkspur purple</td><td>larkspurpurple</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>lava</td><td>lava</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3121;width:4em;" /><td>lava</td><td>lava</td><td>##3b3121</td><td>59</td> <td>49</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>leaf green</td><td>leafgreen</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>lettuce green</td><td>lettucegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>life green</td><td>lifegreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>light hearted</td><td>lighthearted</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>light mauve</td><td>lightmauve</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>light mauve</td><td>lightmauve</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>light oak</td><td>lightoak</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>light old rose</td><td>lightoldrose</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>lilac</td><td>lilac</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>lilac gray</td><td>lilacgray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>lilac hint</td><td>lilachint</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>lilac lavender</td><td>lilaclavender</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>lilac shadow</td><td>lilacshadow</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>lilac shadow</td><td>lilacshadow</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>lilting green</td><td>liltinggreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>lily green</td><td>lilygreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>lily green</td><td>lilygreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>lime cream</td><td>limecream</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>lime yellow</td><td>limeyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>lime yellow</td><td>limeyellow</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>lime yellow</td><td>limeyellow</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>london fog</td><td>londonfog</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>love bird</td><td>lovebird</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>love light</td><td>lovelight</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>lovely</td><td>lovely</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>lover's knot</td><td>loversknot</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>lover's note</td><td>loversnote</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>lucerne blue</td><td>lucerneblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>lullaby</td><td>lullaby</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>lullaby</td><td>lullaby</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>lullaby</td><td>lullaby</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>lullaby</td><td>lullaby</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>lush gray</td><td>lushgray</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>lush green</td><td>lushgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>lustrous yellow</td><td>lustrousyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>lyons blue</td><td>lyonsblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>lyons blue</td><td>lyonsblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>lyre blue</td><td>lyreblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>magenta</td><td>magenta</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>magenta rose</td><td>magentarose</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>magical</td><td>magical</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>magic moon</td><td>magicmoon</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>magic moon</td><td>magicmoon</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#d5badb;width:4em;" /><td>maid of orleans</td><td>maidoforleans</td><td>##d5badb</td><td>213</td> <td>186</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>maid of orleans</td><td>maidoforleans</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>majolica</td><td>majolica</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>mandarin orange</td><td>mandarinorange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>mandarin orange</td><td>mandarinorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>marble</td><td>marble</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>marco polo</td><td>marcopolo</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>marine blue</td><td>marineblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>marine blue</td><td>marineblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>marine corps blue</td><td>marinecorpsblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>marine glow</td><td>marineglow</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>market green </td><td>marketgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>martinique</td><td>martinique</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>mauve decade</td><td>mauvedecade</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>mauve mist</td><td>mauvemist</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>mauve orchid</td><td>mauveorchid</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>mauve taupe</td><td>mauvetaupe</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>mauvette</td><td>mauvette</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>mayflower</td><td>mayflower</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>mayflower</td><td>mayflower</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>meadow green</td><td>meadowgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>meadow green</td><td>meadowgreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>meadow mist</td><td>meadowmist</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>mellow buff</td><td>mellowbuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>mellow buff</td><td>mellowbuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>mellow green</td><td>mellowgreen</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>mellow mauve</td><td>mellowmauve</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>mellow mood</td><td>mellowmood</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>mellow yellow</td><td>mellowyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>mellow yellow</td><td>mellowyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>mellow yellow</td><td>mellowyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>mellow yellow</td><td>mellowyellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>melodious</td><td>melodious</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>memory lane </td><td>memorylane</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>merry green </td><td>merrygreen</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>midnight </td><td>midnight</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>midnight </td><td>midnight</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>midnight bronze </td><td>midnightbronze</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>midseason </td><td>midseason</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>mignonette </td><td>mignonette</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>milano blue </td><td>milanoblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>milano blue </td><td>milanoblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>milky green </td><td>milkygreen</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>mince meat </td><td>mincemeat</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>ming </td><td>ming</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>mint lime </td><td>mintlime</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>mint lime </td><td>mintlime</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>mission white </td><td>missionwhite</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>mission white </td><td>missionwhite</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>misted yellow </td><td>mistedyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>mistletoe </td><td>mistletoe</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>mistletoe </td><td>mistletoe</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>misty cream </td><td>mistycream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>misty cream </td><td>mistycream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>misty green </td><td>mistygreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>misty jade </td><td>mistyjade</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>misty jade </td><td>mistyjade</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>misty jade </td><td>mistyjade</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>misty lilac </td><td>mistylilac</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>misty lilac </td><td>mistylilac</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>misty morn </td><td>mistymorn</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>misty morn </td><td>mistymorn</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>misty morn </td><td>mistymorn</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>misty rose </td><td>mistyrose</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>modest </td><td>modest</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>mogul </td><td>mogul</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mohawk </td><td>mohawk</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>mohawk trail </td><td>mohawktrail</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>monaco </td><td>monaco</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>monastral blue </td><td>monastralblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>monastral blue </td><td>monastralblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>monsignor </td><td>monsignor</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>monticello green </td><td>monticellogreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>monticello rose </td><td>monticellorose</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>montrose yellow </td><td>montroseyellow</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>mood beige </td><td>moodbeige</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>mood lilac </td><td>moodlilac</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>mood violet </td><td>moodviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>moonbeam </td><td>moonbeam</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>moonlight </td><td>moonlight</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>moonlight bay </td><td>moonlightbay</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>moonlit blue </td><td>moonlitblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>moonlit blue </td><td>moonlitblue</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>moonlit water </td><td>moonlitwater</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>moonlit water </td><td>moonlitwater</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>moonmist </td><td>moonmist</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>morning glory </td><td>morningglory</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>morning mist </td><td>morningmist</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>moth </td><td>moth</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>moth </td><td>moth</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>mountain haze </td><td>mountainhaze</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>mountain peak blue </td><td>mountainpeakblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>mountain top </td><td>mountaintop</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#31362b;width:4em;" /><td>mountain top </td><td>mountaintop</td><td>##31362b</td><td>49</td> <td>54</td> <td>43</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>mulberry </td><td>mulberry</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>murmur </td><td>murmur</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>murmur </td><td>murmur</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>muse </td><td>muse</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>mushroom </td><td>mushroom</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>mushroom </td><td>mushroom</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>mustard </td><td>mustard</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>mustard cream </td><td>mustardcream</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>mustard cream </td><td>mustardcream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>muted yellow </td><td>mutedyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>muted yellow </td><td>mutedyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>myrtle green </td><td>myrtlegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>mystic blue </td><td>mysticblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>mystic purple </td><td>mysticpurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>mystic white </td><td>mysticwhite</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>myth </td><td>myth</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>myth blue </td><td>mythblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>myth blue </td><td>mythblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>nabob </td><td>nabob</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>nabob </td><td>nabob</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>nabob </td><td>nabob</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>naid </td><td>naid</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>naid </td><td>naid</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>naid </td><td>naid</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>naive </td><td>naive</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>napoleon </td><td>napoleon</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>nasturtium </td><td>nasturtium</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>nasturtium buff </td><td>nasturtiumbuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>native blue</td><td>nativeblue</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>neon blue</td><td>neonblue</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>neopolitan night </td><td>neopolitannight</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>neopolitan night </td><td>neopolitannight</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>neutral</td><td>neutral</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>neutral</td><td>neutral</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>new blue</td><td>newblue</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>niagara</td><td>niagara</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>night blue</td><td>nightblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>night cloud</td><td>nightcloud</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>night fighter</td><td>nightfighter</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>night fighter</td><td>nightfighter</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>night fighter</td><td>nightfighter</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#202428;width:4em;" /><td>night horizon</td><td>nighthorizon</td><td>##202428</td><td>32</td> <td>36</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>night horizon</td><td>nighthorizon</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>night magic</td><td>nightmagic</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>nightshade</td><td>nightshade</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>nightshade</td><td>nightshade</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>night watch</td><td>nightwatch</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>nil</td><td>nil</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>nocturne</td><td>nocturne</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>noel</td><td>noel</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>nomad brown</td><td>nomadbrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>norse blue</td><td>norseblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>norse blue</td><td>norseblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>north blue</td><td>northblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>northern skies</td><td>northernskies</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>north green</td><td>northgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>north green</td><td>northgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>north sea</td><td>northsea</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>norway pine</td><td>norwaypine</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>nubian brown</td><td>nubianbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>nymph pink</td><td>nymphpink</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>oak leaf</td><td>oakleaf</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>ocean wave</td><td>oceanwave</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>octoroon rose</td><td>octoroonrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>octoroon rose</td><td>octoroonrose</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>old coral</td><td>oldcoral</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>old gold</td><td>oldgold</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>old gold</td><td>oldgold</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>old gold</td><td>oldgold</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>old lavender</td><td>oldlavender</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>old master green</td><td>oldmastergreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>old rose</td><td>oldrose</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>olive glow</td><td>oliveglow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>olive glow</td><td>oliveglow</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>olive hint</td><td>olivehint</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>olive hint</td><td>olivehint</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>ombre</td><td>ombre</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>ombre</td><td>ombre</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>opal green</td><td>opalgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>opera blue</td><td>operablue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>opera blue</td><td>operablue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>opera mauve</td><td>operamauve</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>opera pink</td><td>operapink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange</td><td>orange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>orange blush</td><td>orangeblush</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>orange cream</td><td>orangecream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>orchid</td><td>orchid</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#d5badb;width:4em;" /><td>orchid lane</td><td>orchidlane</td><td>##d5badb</td><td>213</td> <td>186</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>orchid leaf</td><td>orchidleaf</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>orchid mauve</td><td>orchidmauve</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>orchid night</td><td>orchidnight</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>orchid night</td><td>orchidnight</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>orchid pink</td><td>orchidpink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>orchid pink</td><td>orchidpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>orchid smoke</td><td>orchidsmoke</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>oriental bronze</td><td>orientalbronze</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>oriental sand</td><td>orientalsand</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>padre brown</td><td>padrebrown</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>palace blue</td><td>palaceblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>palace blue</td><td>palaceblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>pale star</td><td>palestar</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>pale star</td><td>palestar</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>pale water</td><td>palewater</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>paloma</td><td>paloma</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>paloma</td><td>paloma</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>pan</td><td>pan</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>pan</td><td>pan</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>panama blue</td><td>panamablue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>pansy purple</td><td>pansypurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>pansy purple</td><td>pansypurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>pansy yellow</td><td>pansyyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>paprica</td><td>paprica</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#b6e5af;width:4em;" /><td>paradise green</td><td>paradisegreen</td><td>##b6e5af</td><td>182</td> <td>229</td> <td>175</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>paradise green</td><td>paradisegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>paramount</td><td>paramount</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>paramount</td><td>paramount</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>paramour</td><td>paramour</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>parrakeet</td><td>parrakeet</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>peace</td><td>peace</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>peace-maker</td><td>peacemaker</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>peach amber</td><td>peachamber</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>peach bisque</td><td>peachbisque</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>peach bud</td><td>peachbud</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>peach cream</td><td>peachcream</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#eae3e1;width:4em;" /><td>peach gray</td><td>peachgray</td><td>##eae3e1</td><td>234</td> <td>227</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>peach gray</td><td>peachgray</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>peach gray</td><td>peachgray</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>peach pink</td><td>peachpink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>peach rust</td><td>peachrust</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>peach sand</td><td>peachsand</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>peach sand</td><td>peachsand</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>peacock blue</td><td>peacockblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>pea green</td><td>peagreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#eae3e1;width:4em;" /><td>pearl cream</td><td>pearlcream</td><td>##eae3e1</td><td>234</td> <td>227</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>pearly gates </td><td>pearlygates</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>peasant blue</td><td>peasantblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>peasant blue</td><td>peasantblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>persian green</td><td>persiangreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>persian gulf</td><td>persiangulf</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>persian gulf</td><td>persiangulf</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>persian melon</td><td>persianmelon</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>persian rose</td><td>persianrose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>persian rose</td><td>persianrose</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>personal</td><td>personal</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>petunia</td><td>petunia</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pewter</td><td>pewter</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#eae3e1;width:4em;" /><td>pewter cream</td><td>pewtercream</td><td>##eae3e1</td><td>234</td> <td>227</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>phantom blue</td><td>phantomblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>phantom blue</td><td>phantomblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>phantom green</td><td>phantomgreen</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>phlox pink</td><td>phloxpink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>picturesque</td><td>picturesque</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>picturesque</td><td>picturesque</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>pine frost</td><td>pinefrost</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>pink carnation</td><td>pinkcarnation</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pink dust</td><td>pinkdust</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>pink dust</td><td>pinkdust</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>pink icing</td><td>pinkicing</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>pink jewel</td><td>pinkjewel</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pink lavender</td><td>pinklavender</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>pink lily</td><td>pinklily</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pink mist</td><td>pinkmist</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pink orchid</td><td>pinkorchid</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>pink powder</td><td>pinkpowder</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>pink rapture</td><td>pinkrapture</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>pink shock</td><td>pinkshock</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pinocchio</td><td>pinocchio</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>piquant</td><td>piquant</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>piquant green</td><td>piquantgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>pistachio cream</td><td>pistachiocream</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>placid</td><td>placid</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>plantation</td><td>plantation</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>plantation yellow</td><td>plantationyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>platonic</td><td>platonic</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>plenty bright</td><td>plentybright</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>plumbago blue</td><td>plumbagoblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>plumbago blue</td><td>plumbagoblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>plume</td><td>plume</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>poet's yellow</td><td>poetsyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>polar bear</td><td>polarbear</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>pom pom</td><td>pompom</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>pom pom</td><td>pompom</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>pool green</td><td>poolgreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>porcelain green</td><td>porcelaingreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>pouf de vent</td><td>poufdevent</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pouf de vent</td><td>poufdevent</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>prairie sunset</td><td>prairiesunset</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>prairie sunset</td><td>prairiesunset</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>primeval</td><td>primeval</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>primrose yellow</td><td>primroseyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>princely blue</td><td>princelyblue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>princely blue</td><td>princelyblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>princess</td><td>princess</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>priscilla blue</td><td>priscillablue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>prism pink</td><td>prismpink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>prism violet</td><td>prismviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>profound</td><td>profound</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>profound blue</td><td>profoundblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>profound blue</td><td>profoundblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>promise </td><td>promise</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>promised land</td><td>promisedland</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>promised land</td><td>promisedland</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>promised land</td><td>promisedland</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>promised land</td><td>promisedland</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>promise green</td><td>promisegreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>prudence</td><td>prudence</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>prudence</td><td>prudence</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>pumpkin</td><td>pumpkin</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>puritan</td><td>puritan</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>puritan</td><td>puritan</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>purple aster</td><td>purpleaster</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>purple heather</td><td>purpleheather</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>purple lake</td><td>purplelake</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>purple night</td><td>purplenight</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>purple ode</td><td>purpleode</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>quail</td><td>quail</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>quaker</td><td>quaker</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>quality</td><td>quality</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>quality pink</td><td>qualitypink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>quality pink</td><td>qualitypink</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>queen anne</td><td>queenanne</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>queen blue</td><td>queenblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>queen coral</td><td>queencoral</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>queen coral</td><td>queencoral</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>queen pink</td><td>queenpink</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>quiet</td><td>quiet</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>radiance</td><td>radiance</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>radiant</td><td>radiant</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>radiant</td><td>radiant</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>radiant orchid</td><td>radiantorchid</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>rainbow mist</td><td>rainbowmist</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>raisin</td><td>raisin</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rapture</td><td>rapture</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>raspberry glace </td><td>raspberryglace</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>raven</td><td>raven</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>reed</td><td>reed</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>reflection</td><td>reflection</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>regal orchid</td><td>regalorchid</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>remote</td><td>remote</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>repose</td><td>repose</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>restrained blue</td><td>restrainedblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>retreat</td><td>retreat</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>retreat</td><td>retreat</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>rhapsody blue</td><td>rhapsodyblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>rigi blue </td><td>rigiblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>rill</td><td>rill</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>rio blue</td><td>rioblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>rio grande</td><td>riogrande</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>river mist</td><td>rivermist</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>river nile</td><td>rivernile</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>riviera</td><td>riviera</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>rivulet blue</td><td>rivuletblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>robin egg</td><td>robinegg</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>romance</td><td>romance</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>romance</td><td>romance</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>romance</td><td>romance</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>roman purple</td><td>romanpurple</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>roman purple</td><td>romanpurple</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>roman rose</td><td>romanrose</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>roman tan</td><td>romantan</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>romantic blue</td><td>romanticblue</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>romantic blue</td><td>romanticblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>room green</td><td>roomgreen</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rosario</td><td>rosario</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>rosea </td><td>rosea</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#eae3e1;width:4em;" /><td>rose ash</td><td>roseash</td><td>##eae3e1</td><td>234</td> <td>227</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>rose ash</td><td>roseash</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rose caroline</td><td>rosecaroline</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>rose castor</td><td>rosecastor</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>rose castor</td><td>rosecastor</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>rose cloud</td><td>rosecloud</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>rose dust </td><td>rosedust</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>rose garden</td><td>rosegarden</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rose glory</td><td>roseglory</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>rose leaf</td><td>roseleaf</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>rose marie</td><td>rosemarie</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>rose mist</td><td>rosemist</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>rose mist</td><td>rosemist</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>rose morn</td><td>rosemorn</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>rose morn</td><td>rosemorn</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>rose morn</td><td>rosemorn</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>rose morn</td><td>rosemorn</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>rose muse</td><td>rosemuse</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>rose nude</td><td>rosenude</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>rose pearl</td><td>rosepearl</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>rose pearl</td><td>rosepearl</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>rose shadow</td><td>roseshadow</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>rose shadow</td><td>roseshadow</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>rose smoke</td><td>rosesmoke</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>rose smoke</td><td>rosesmoke</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>rose stain</td><td>rosestain</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>rosy pink</td><td>rosypink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>royal lilac</td><td>royallilac</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>royal robe</td><td>royalrobe</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>royal violet</td><td>royalviolet</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>ruby lake</td><td>rubylake</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>ruffled petunia</td><td>ruffledpetunia</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>russet leaf</td><td>russetleaf</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>russet yellow</td><td>russetyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>russian blue</td><td>russianblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>russian blue</td><td>russianblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rust rose</td><td>rustrose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>sable</td><td>sable</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>saga blue</td><td>sagablue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>sage</td><td>sage</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#282022;width:4em;" /><td>sailor</td><td>sailor</td><td>##282022</td><td>40</td> <td>32</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>salmon buff</td><td>salmonbuff</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>salmon flush</td><td>salmonflush</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>salmon pink </td><td>salmonpink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>salmon rose</td><td>salmonrose</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>salome blue</td><td>salomeblue</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>salome green</td><td>salomegreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>salome green</td><td>salomegreen</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>salome pink</td><td>salomepink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sandlewood</td><td>sandlewood</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>sandrift</td><td>sandrift</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>sand stucco</td><td>sandstucco</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>santa anita green</td><td>santaanitagreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>saxe blue</td><td>saxeblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>saxe blue</td><td>saxeblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>scarab</td><td>scarab</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>scotch blue</td><td>scotchblue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>scotch mist</td><td>scotchmist</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>scotch mist</td><td>scotchmist</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>scotch mist</td><td>scotchmist</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>sea foam </td><td>seafoam</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>sea foam </td><td>seafoam</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>sea fog</td><td>seafog</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>sea fog</td><td>seafog</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>sea mist</td><td>seamist</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>seance</td><td>seance</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>seclusion</td><td>seclusion</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>secret</td><td>secret</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>sentimental mood</td><td>sentimentalmood</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>sentimental mood</td><td>sentimentalmood</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>serene</td><td>serene</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>serenity</td><td>serenity</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>seville</td><td>seville</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>sevres</td><td>sevres</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>sevres</td><td>sevres</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>shadow aqua</td><td>shadowaqua</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>shadow beige</td><td>shadowbeige</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>shadow blue</td><td>shadowblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>shadow green</td><td>shadowgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>shadow green</td><td>shadowgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>shadow lilac</td><td>shadowlilac</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>shadow lime</td><td>shadowlime</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>shadow mauve</td><td>shadowmauve</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>shadow olive</td><td>shadowolive</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>shamrock</td><td>shamrock</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>shell coral</td><td>shellcoral</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>shell coral</td><td>shellcoral</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>shine</td><td>shine</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>shining</td><td>shining</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>shore line</td><td>shoreline</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>shrimp pink</td><td>shrimppink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>siam sand</td><td>siamsand</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>sierra</td><td>sierra</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>sierra</td><td>sierra</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>silent night</td><td>silentnight</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>silver blue</td><td>silverblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>silver blue</td><td>silverblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>silver cloud</td><td>silvercloud</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>silver cloud</td><td>silvercloud</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>silver green</td><td>silvergreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>silver lining</td><td>silverlining</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>silver lining</td><td>silverlining</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>silver night</td><td>silvernight</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>silver pine </td><td>silverpine</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>silver pink</td><td>silverpink</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>silver pink</td><td>silverpink</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>silver salmon</td><td>silversalmon</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>silver sky</td><td>silversky</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>silver sky</td><td>silversky</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>silver wing </td><td>silverwing</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>silver wing </td><td>silverwing</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>singing blue</td><td>singingblue</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>singing blue</td><td>singingblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>sky</td><td>sky</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>sky cloud</td><td>skycloud</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>sky green</td><td>skygreen</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>sky lane</td><td>skylane</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>slate</td><td>slate</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>slate</td><td>slate</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>slate blue</td><td>slateblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>slate blue</td><td>slateblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>slate citron</td><td>slatecitron</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>slate green </td><td>slategreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>slate orchid</td><td>slateorchid</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>slate rose</td><td>slaterose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>slate turquoise</td><td>slateturquoise</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>slate turquoise</td><td>slateturquoise</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>slate violet </td><td>slateviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>sleepy hollow</td><td>sleepyhollow</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>sleepy hollow</td><td>sleepyhollow</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>sleigh bells</td><td>sleighbells</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>sleigh bells</td><td>sleighbells</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>smile</td><td>smile</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>smiles</td><td>smiles</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>smog</td><td>smog</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>smoke</td><td>smoke</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>smoke blue</td><td>smokeblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>smoke pine</td><td>smokepine</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>smoke pine</td><td>smokepine</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>smoke ring</td><td>smokering</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>smokestain rose</td><td>smokestainrose</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>snow green</td><td>snowgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>snow green</td><td>snowgreen</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>snow green</td><td>snowgreen</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>solitary</td><td>solitary</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>solitary</td><td>solitary</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>solitary</td><td>solitary</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>solitary</td><td>solitary</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>solitary blue</td><td>solitaryblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>somber blue</td><td>somberblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>sonata</td><td>sonata</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>song of norway</td><td>songofnorway</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>sophisticated lady</td><td>sophisticatedlady</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>sorcerer</td><td>sorcerer</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>sorcerer</td><td>sorcerer</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>sorcerer</td><td>sorcerer</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>sorcerer</td><td>sorcerer</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#202428;width:4em;" /><td>sorcerer</td><td>sorcerer</td><td>##202428</td><td>32</td> <td>36</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>sorrento</td><td>sorrento</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>southern rose</td><td>southernrose</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>southern sun</td><td>southernsun</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>southern sun</td><td>southernsun</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>souvenir</td><td>souvenir</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>sovereign blue</td><td>sovereignblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>sovereign blue</td><td>sovereignblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>spanish blue</td><td>spanishblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>spanish gold</td><td>spanishgold</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>spanish white</td><td>spanishwhite</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>sparkle</td><td>sparkle</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>sparrow</td><td>sparrow</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>spectra blue</td><td>spectrablue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>spectra green</td><td>spectragreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>spectra red</td><td>spectrared</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>spectra rose</td><td>spectrarose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>spectra yellow</td><td>spectrayellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>spice</td><td>spice</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>spice</td><td>spice</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>spiritual blue</td><td>spiritualblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>spitfire</td><td>spitfire</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>spray</td><td>spray</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>spring</td><td>spring</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>spring bud</td><td>springbud</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>spring dream</td><td>springdream</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>spring dream</td><td>springdream</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>spring eve</td><td>springeve</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>spring eve</td><td>springeve</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>spring eve</td><td>springeve</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>spring flower </td><td>springflower</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>spring stream</td><td>springstream</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>spring yellow</td><td>springyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>starch white</td><td>starchwhite</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>static</td><td>static</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>steam blue</td><td>steamblue</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>steel blue</td><td>steelblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>stellar</td><td>stellar</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>sterling blue</td><td>sterlingblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>sterling blue</td><td>sterlingblue</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>stoic</td><td>stoic</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>storm</td><td>storm</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>stormy night</td><td>stormynight</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>stratosphere</td><td>stratosphere</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>stratosphere</td><td>stratosphere</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>straw yellow</td><td>strawyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>streamlet</td><td>streamlet</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>streamline</td><td>streamline</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>string</td><td>string</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>style gray</td><td>stylegray</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>sublime</td><td>sublime</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>sublime</td><td>sublime</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>suet</td><td>suet</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>suez blue</td><td>suezblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>suez green</td><td>suezgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>suggestion</td><td>suggestion</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>sulphate green</td><td>sulphategreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>sulphate green</td><td>sulphategreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>sulphur</td><td>sulphur</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>sultana</td><td>sultana</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>sultan sand</td><td>sultansand</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>summer green</td><td>summergreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>summer green</td><td>summergreen</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>summer shower</td><td>summershower</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>summer sun</td><td>summersun</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>sunburst</td><td>sunburst</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>sunburst</td><td>sunburst</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>sunburst</td><td>sunburst</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>sundown</td><td>sundown</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>sundown</td><td>sundown</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>sundown</td><td>sundown</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>sung green</td><td>sunggreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>sun glow </td><td>sunglow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>sun glow </td><td>sunglow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>sun god </td><td>sungod</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>sun green</td><td>sungreen</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>sun rose</td><td>sunrose</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>sunset cream</td><td>sunsetcream</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>sunshine</td><td>sunshine</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>sun yellow</td><td>sunyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>sun yellow</td><td>sunyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>superior</td><td>superior</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>supreme</td><td>supreme</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#dfede8;width:4em;" /><td>surf spray</td><td>surfspray</td><td>##dfede8</td><td>223</td> <td>237</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>surrender</td><td>surrender</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>sussanqua pink</td><td>sussanquapink</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>sussanqua pink</td><td>sussanquapink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>swank</td><td>swank</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>swank</td><td>swank</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>sweet blue</td><td>sweetblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>sweet lady</td><td>sweetlady</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>sweet lavender</td><td>sweetlavender</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>sweet pea pink</td><td>sweetpeapink</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>swiss blue</td><td>swissblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>swiss rose</td><td>swissrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>sylvan</td><td>sylvan</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>tabu</td><td>tabu</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>talisman</td><td>talisman</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>talisman</td><td>talisman</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>tangerine</td><td>tangerine</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>tangerine</td><td>tangerine</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>tango</td><td>tango</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>tapestry beige</td><td>tapestrybeige</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>tapestry red</td><td>tapestryred</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>taupe rose</td><td>tauperose</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>taupe rose</td><td>tauperose</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>taupe sand</td><td>taupesand</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>teal blue</td><td>tealblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>teen age pink</td><td>teenagepink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>television blue</td><td>televisionblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>tempest</td><td>tempest</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>tempest blue</td><td>tempestblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>temple</td><td>temple</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>temptation</td><td>temptation</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>tete-a-tete</td><td>teteatete</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>thames river</td><td>thamesriver</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>thames river</td><td>thamesriver</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>theatrical blue</td><td>theatricalblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>thistle bloom</td><td>thistlebloom</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>thistle down</td><td>thistledown</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>tobacco brown</td><td>tobaccobrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>tomato red</td><td>tomatored</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>topaz amber</td><td>topazamber</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>torchlight</td><td>torchlight</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>torchlight</td><td>torchlight</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>toreador</td><td>toreador</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>tourmaline green</td><td>tourmalinegreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>tourmaline green</td><td>tourmalinegreen</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>tourmaline pink</td><td>tourmalinepink</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>tourmaline pink</td><td>tourmalinepink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>trade winds</td><td>tradewinds</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>trail green</td><td>trailgreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>trail green</td><td>trailgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>tranquil green</td><td>tranquilgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>tranquil green</td><td>tranquilgreen</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>transatlantic blue</td><td>transatlanticblue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>translucent blue</td><td>translucentblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>transparent yellow</td><td>transparentyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>transparent yellow</td><td>transparentyellow</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>trellis</td><td>trellis</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>tropic night</td><td>tropicnight</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>troubador</td><td>troubador</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>troubador</td><td>troubador</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>tulip yellow</td><td>tulipyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>tumbleweed</td><td>tumbleweed</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>tumbleweed</td><td>tumbleweed</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>turf green</td><td>turfgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>turf green</td><td>turfgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>turquoise blue</td><td>turquoiseblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>tuscan sand</td><td>tuscansand</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>twilight mood</td><td>twilightmood</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>twilight sun</td><td>twilightsun</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>twilight sun</td><td>twilightsun</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>twinkle</td><td>twinkle</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>tyrian blue</td><td>tyrianblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>uniform blue</td><td>uniformblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>unique</td><td>unique</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>universal</td><td>universal</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>vagabond</td><td>vagabond</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>valencia rose</td><td>valenciarose</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>valor green</td><td>valorgreen</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>vamp</td><td>vamp</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>vanda</td><td>vanda</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>vanilla custard</td><td>vanillacustard</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>vanilla custard</td><td>vanillacustard</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>vapor blue</td><td>vaporblue</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>vatican</td><td>vatican</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>veiled sun</td><td>veiledsun</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>veiled sun</td><td>veiledsun</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>venetian rose</td><td>venetianrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>venetian turquoise</td><td>venetianturquoise</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>venice</td><td>venice</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>venice blue</td><td>veniceblue</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>venus blue</td><td>venusblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>venus blue</td><td>venusblue</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>verbena lavender</td><td>verbenalavender</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>verbena lavender</td><td>verbenalavender</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8db600;width:4em;" /><td>verdant</td><td>verdant</td><td>##8db600</td><td>141</td> <td>182</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>verdugo</td><td>verdugo</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>verdugo</td><td>verdugo</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>vesta</td><td>vesta</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>vesta</td><td>vesta</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>vesta</td><td>vesta</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>vibrant green</td><td>vibrantgreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>victoria</td><td>victoria</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>viking</td><td>viking</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>viola</td><td>viola</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>violet leaf</td><td>violetleaf</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>violet pansy</td><td>violetpansy</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>virginia lavender</td><td>virginialavender</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>vista green</td><td>vistagreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>vivid</td><td>vivid</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>vivid turquoise</td><td>vividturquoise</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>wafted feather</td><td>waftedfeather</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>wafted feather</td><td>waftedfeather</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>walnut</td><td>walnut</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>walnut cream</td><td>walnutcream</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>wan blue</td><td>wanblue</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>wan blue</td><td>wanblue</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>water fall </td><td>waterfall</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>water green</td><td>watergreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>watteau</td><td>watteau</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>whimsical</td><td>whimsical</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>white clover</td><td>whiteclover</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>white fawn</td><td>whitefawn</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>white jade</td><td>whitejade</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>white jade</td><td>whitejade</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>white light</td><td>whitelight</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>white mist</td><td>whitemist</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>white mist</td><td>whitemist</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>white smoke</td><td>whitesmoke</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>white swan</td><td>whiteswan</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>white swan</td><td>whiteswan</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>wild orchid</td><td>wildorchid</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>windflower</td><td>windflower</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>wineberry</td><td>wineberry</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>wineberry</td><td>wineberry</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>winsome</td><td>winsome</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>winsome blue</td><td>winsomeblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>winter pear</td><td>winterpear</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>winter sky</td><td>wintersky</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>winter sun </td><td>wintersun</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>winter white</td><td>winterwhite</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>winter yellow</td><td>winteryellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>winter yellow</td><td>winteryellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>wisteria</td><td>wisteria</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>wisteria gray</td><td>wisteriagray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>wisteria mist</td><td>wisteriamist</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>withered rose</td><td>witheredrose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>yale blue</td><td>yaleblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>yale blue</td><td>yaleblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>yale blue</td><td>yaleblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>yama</td><td>yama</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>yellow bright</td><td>yellowbright</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>yellow bright</td><td>yellowbright</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>yellow cream</td><td>yellowcream</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>yellow essence</td><td>yellowessence</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>yellow gem</td><td>yellowgem</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>yellow mist</td><td>yellowmist</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>yellow rose</td><td>yellowrose</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow smoke</td><td>yellowsmoke</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>yellow smoke</td><td>yellowsmoke</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>yew green</td><td>yewgreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>youth yellow</td><td>youthyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>yuletime</td><td>yuletime</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>yule tree</td><td>yuletree</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>zephyr blue</td><td>zephyrblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>zephyr blue</td><td>zephyrblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>zephyr green</td><td>zephyrgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>zest pink</td><td>zestpink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>zinnia gold</td><td>zinniagold</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>zinnia gold</td><td>zinniagold</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item absinthe yellow              absintheyellow             #c9ae5d

=item abstract blue                abstractblue               #bcd4e6

=item abyss                        abyss                      #8da399

=item acacia                       acacia                     #5e716a

=item acacia gray                  acaciagray                 #7d8984

=item acacia green                 acaciagreen                #7d8984

=item aden                         aden                       #6aab8e

=item admiral                      admiral                    #50404d

=item african green                africangreen               #36454f

=item african night                africannight               #43302e

=item after glow                   afterglow                  #e8ccd7

=item agean mist                   ageanmist                  #b2beb5

=item ageratum                     ageratum                   #c3a6b1

=item air castle blue              aircastleblue              #bcd4e6

=item airy cream                   airycream                  #f2f3f4

=item aladdin's lamp               aladdinslamp               #cb6d51

=item algiers blue                 algiersblue                #367588

=item allure                       allure                     #70a3cc

=item almond                       almond                     #c19a6b

=item almond cream                 almondcream                #fad6a5

=item alpine blue                  alpineblue                 #b3bce2

=item alpine blue                  alpineblue                 #c0c8e1

=item amaranth                     amaranth                   #673147

=item amaranth                     amaranth                   #915f6d

=item amber coral                  ambercoral                 #d9a6a9

=item amber gold                   ambergold                  #c19a6b

=item amber gold                   ambergold                  #c2b280

=item amber gold                   ambergold                  #a18f60

=item ambrosia                     ambrosia                   #b6e5af

=item amethyst                     amethyst                   #836479

=item amethyst orchid              amethystorchid             #b695c0

=item amulet                       amulet                     #317873

=item ancestral                    ancestral                  #f2f3f4

=item ancestral                    ancestral                  #b9b8b5

=item angel blue                   angelblue                  #bcd4e6

=item angel wing                   angelwing                  #efbbcc

=item angora                       angora                     #fad6a5

=item angora                       angora                     #f0ead6

=item antique brass                antiquebrass               #ab9144

=item antique bronze               antiquebronze              #665d1e

=item antique fuchsia              antiquefuchsia             #915c83

=item antique yellow               antiqueyellow              #c9ae5d

=item apple green                  applegreen                 #8a9a5b

=item apricot                      apricot                    #fab57f

=item apricot cream                apricotcream               #fad6a5

=item apricot cream                apricotcream               #f3e5ab

=item apricot ice                  apricotice                 #fad6a5

=item apricot sherbet              apricotsherbet             #fbc97f

=item apricot tan                  apricottan                 #d99058

=item apricot tan                  apricottan                 #e3a857

=item april sky                    aprilsky                   #96ded1

=item aqua gray                    aquagray                   #8da399

=item aquamarine green             aquamarinegreen            #317873

=item aqua queen                   aquaqueen                  #96ded1

=item aqua sky                     aquasky                    #66ada4

=item arbor green                  arborgreen                 #679267

=item arcadia                      arcadia                    #beb72e

=item arcadia                      arcadia                    #b9b459

=item arctic                       arctic                     #536878

=item arctic                       arctic                     #36454f

=item arno blue                    arnoblue                   #367588

=item ashes of roses               ashesofroses               #c08081

=item ashes of roses               ashesofroses               #c17e91

=item asthetic blue                astheticblue               #66aabc

=item atlantis                     atlantis                   #00304e

=item atonement                    atonement                  #aa98a9

=item aurora pink                  aurorapink                 #e68fac

=item aurora pink                  aurorapink                 #d597ae

=item aurora yellow                aurorayellow               #f8de7e

=item autumn brown                 autumnbrown                #996515

=item autumn brown                 autumnbrown                #6c541e

=item autumn glory                 autumnglory                #841b2d

=item autumn glory                 autumnglory                #9e4732

=item autumn glory                 autumnglory                #be8a3d

=item autumn gold                  autumngold                 #be8a3d

=item autumn tan                   autumntan                  #826644

=item avon                         avon                       #7d8984

=item azalea                       azalea                     #a8516e

=item azurite blue                 azuriteblue                #367588

=item azurite blue                 azuriteblue                #536878

=item baby blue                    babyblue                   #a1caf1

=item baby blue eyes               babyblueeyes               #a1caf1

=item baby blue eyes               babyblueeyes               #b3bce2

=item bagdad                       bagdad                     #905d5d

=item ballad blue                  balladblue                 #8791bf

=item ballerina                    ballerina                  #dcd0ff

=item balmy air                    balmyair                   #bcd4e6

=item balsam green                 balsamgreen                #3a4b47

=item baltic                       baltic                     #36454f

=item baltic                       baltic                     #222222

=item banana                       banana                     #f8de7e

=item banshee                      banshee                    #5e716a

=item banshee                      banshee                    #3a4b47

=item banshee                      banshee                    #317873

=item banshee                      banshee                    #004b49

=item baronet                      baronet                    #70a3cc

=item basic                        basic                      #004b49

=item bath stone                   bathstone                  #fad6a5

=item bavarian blue                bavarianblue               #00304e

=item bay leaf                     bayleaf                    #996515

=item bayou                        bayou                      #36454f

=item bayou                        bayou                      #222222

=item beau blue                    beaublue                   #bcd4e6

=item beautiful                    beautiful                  #317873

=item beauty pink                  beautypink                 #ffc8d6

=item beige gray                   beigegray                  #bfb8a5

=item belladonna                   belladonna                 #86608e

=item bellflower                   bellflower                 #604e81

=item beryl green                  berylgreen                 #66ada4

=item best effort                  besteffort                 #ebe8a4

=item best effort                  besteffort                 #dadfb7

=item bewitch                      bewitch                    #00a693

=item bewitching blue              bewitchingblue             #70a3cc

=item billiard                     billiard                   #00443f

=item billiard                     billiard                   #004b49

=item billow                       billow                     #bcd4e6

=item birch                        birch                      #dfede8

=item bird's-egg-green             birdsegggreen              #8da399

=item bird's-egg-green             birdsegggreen              #66ada4

=item biscay bay                   biscaybay                  #367588

=item biscay bay                   biscaybay                  #536878

=item bishop                       bishop                     #604e81

=item bison                        bison                      #6c541e

=item bisque                       bisque                     #d9a6a9

=item bisque                       bisque                     #c7ada3

=item bittersweet                  bittersweet                #9e4732

=item bittersweet orange           bittersweetorange          #d9603b

=item bittersweet orange           bittersweetorange          #ed872d

=item blackberry cream             blackberrycream            #d597ae

=item black forest                 blackforest                #515744

=item black knight                 blackknight                #36454f

=item black knight                 blackknight                #51585e

=item black water                  blackwater                 #272458

=item black water                  blackwater                 #222222

=item blanch                       blanch                     #96ded1

=item blarney                      blarney                    #008856

=item blarney                      blarney                    #007959

=item blaze blue                   blazeblue                  #536878

=item blaze blue                   blazeblue                  #36454f

=item blend                        blend                      #dadfb7

=item blithe                       blithe                     #239eba

=item blonde green                 blondegreen                #dfede8

=item blossom                      blossom                    #ebe8a4

=item blue appeal                  blueappeal                 #a1caf1

=item blue appeal                  blueappeal                 #bcd4e6

=item blue bell                    bluebell                   #8791bf

=item blue chill                   bluechill                  #bcd4e6

=item blue danube                  bluedanube                 #007791

=item blue dash                    bluedash                   #536878

=item blue day                     blueday                    #c0c8e1

=item blue fog                     bluefog                    #536878

=item blue fog                     bluefog                    #81878b

=item blue glow                    blueglow                   #bcd4e6

=item blue grotto                  bluegrotto                 #66aabc

=item blue heaven                  blueheaven                 #4997d0

=item blue heaven                  blueheaven                 #a1caf1

=item blue heaven                  blueheaven                 #70a3cc

=item blue horizon                 bluehorizon                #91a3b0

=item blue hour                    bluehour                   #367588

=item blue idol                    blueidol                   #317873

=item blue light                   bluelight                  #bcd4e6

=item blue lightning               bluelightning              #0067a5

=item blue mist                    bluemist                   #66aabc

=item blue mist                    bluemist                   #91a3b0

=item blue prose                   blueprose                  #9cd1dc

=item blue ridge                   blueridge                  #a1caf1

=item blue ridge                   blueridge                  #b3bce2

=item blue shadow                  blueshadow                 #367588

=item blue spruce                  bluespruce                 #3b7861

=item blue swirl                   blueswirl                  #66aabc

=item blue tease                   bluetease                  #9cd1dc

=item blue turquoise               blueturquoise              #239eba

=item blue waltz                   bluewaltz                  #c7e6d7

=item blue waltz                   bluewaltz                  #96ded1

=item blue wash                    bluewash                   #e9e9ed

=item blush rose                   blushrose                  #915f6d

=item blush yellow                 blushyellow                #fbc97f

=item blush yellow                 blushyellow                #fad6a5

=item bog                          bog                        #8f9779

=item bohemian blue                bohemianblue               #436b95

=item bonnie blue                  bonnieblue                 #00a1c2

=item bonnie blue                  bonnieblue                 #30267a

=item bottle green                 bottlegreen                #3b7861

=item bottle green                 bottlegreen                #5e716a

=item bougainvillea                bougainvillea              #ce4676

=item bounding main                boundingmain               #70a3cc

=item bouquet green                bouquetgreen               #27a64c

=item bouquet green                bouquetgreen               #83d37d

=item bouquet orchid               bouquetorchid              #d5badb

=item bouquet orchid               bouquetorchid              #d6cadd

=item bouquet yellow               bouquetyellow              #f8de7e

=item brass                        brass                      #ab9144

=item brazil red                   brazilred                  #9e4732

=item breath of spring             breathofspring             #ebe8a4

=item breath of spring             breathofspring             #c9dc89

=item bridesmaid pink              bridesmaidpink             #efbbcc

=item bright sun                   brightsun                  #f3c300

=item bright sun                   brightsun                  #fada5e

=item brilliant green              brilliantgreen             #004b49

=item bronze gold                  bronzegold                 #d4af37

=item bronze gold                  bronzegold                 #c9ae5d

=item bronze mist                  bronzemist                 #867e36

=item bronze pink                  bronzepink                 #d9a6a9

=item bronze pink                  bronzepink                 #d99058

=item bronze sheen                 bronzesheen                #5b5842

=item bronzio                      bronzio                    #79443b

=item brook green                  brookgreen                 #96ded1

=item bruges                       bruges                     #51585e

=item buccaneer                    buccaneer                  #bc3f4a

=item buckskin tan                 buckskintan                #fad6a5

=item buff citron                  buffcitron                 #c2b280

=item burnt almond                 burntalmond                #6f4e37

=item burnt orange                 burntorange                #ed872d

=item burnt yellow                 burntyellow                #e3a857

=item butterfly yellow             butterflyyellow            #e9e450

=item butterfly yellow             butterflyyellow            #eae679

=item cabbage                      cabbage                    #c7e6d7

=item caen stone                   caenstone                  #fad6a5

=item california gold              californiagold             #e3a857

=item california green             californiagreen            #7d8984

=item california poppy             californiapoppy            #eaa221

=item camelia pink                 cameliapink                #ea9399

=item camelia pink                 cameliapink                #f88379

=item camelia rose                 cameliarose                #ea9399

=item cameo                        cameo                      #f9ccca

=item cameo pink                   cameopink                  #ea9399

=item cameo pink                   cameopink                  #efbbcc

=item canary bronze                canarybronze               #f3c300

=item canary yellow                canaryyellow               #f3c300

=item canary yellow                canaryyellow               #fada5e

=item candida                      candida                    #d597ae

=item canton                       canton                     #317873

=item caprice lavender             capricelavender            #e8e3e5

=item caprice pink                 capricepink                #915c83

=item caprice pink                 capricepink                #a8516e

=item caramel                      caramel                    #a67b5b

=item caramel cream                caramelcream               #fad6a5

=item caravan                      caravan                    #977f73

=item carnival red                 carnivalred                #be0032

=item castilian blue               castilianblue              #0067a5

=item cathedral                    cathedral                  #301934

=item cathedral                    cathedral                  #291e29

=item cedar                        cedar                      #8a9a5b

=item cedar bough                  cedarbough                 #8a9a5b

=item celestial blue               celestialblue              #4997d0

=item celestial blue               celestialblue              #6c79b8

=item celestial yellow             celestialyellow            #f8de7e

=item celestial yellow             celestialyellow            #f3e5ab

=item ceramic                      ceramic                    #367588

=item ceramic                      ceramic                    #436b95

=item ceres                        ceres                      #f8de7e

=item cerise pink                  cerisepink                 #b3446c

=item cerise rose                  ceriserose                 #e4717a

=item ceylon blue                  ceylonblue                 #536878

=item chalk violet                 chalkviolet                #8c82b6

=item chalk violet                 chalkviolet                #9690ab

=item chamois yellow               chamoisyellow              #e3a857

=item chamois yellow               chamoisyellow              #c19a6b

=item champagne                    champagne                  #f3e5ab

=item champagne buff               champagnebuff              #f3e5ab

=item chantilly                    chantilly                  #6aab8e

=item charcoal                     charcoal                   #3e322c

=item charcoal                     charcoal                   #222222

=item charm                        charm                      #ea9399

=item charm                        charm                      #f9ccca

=item charm                        charm                      #efbbcc

=item charm                        charm                      #9cd1dc

=item charm pink                   charmpink                  #e68fac

=item charm school                 charmschool                #aa8a9e

=item charm school                 charmschool                #af868e

=item chartreuse green             chartreusegreen            #8db600

=item chartreuse green             chartreusegreen            #bdda57

=item chartreuse yellow            chartreuseyellow           #e9e450

=item chaste                       chaste                     #f2f3f4

=item chateau                      chateau                    #66aabc

=item cheddar cheese               cheddarcheese              #e3a857

=item cheer                        cheer                      #f3c300

=item cheerful yellow              cheerfulyellow             #f3e5ab

=item cheerful yellow              cheerfulyellow             #f0ead6

=item chelsea yellow               chelseayellow              #eae679

=item chelsea yellow               chelseayellow              #ebe8a4

=item cherry                       cherry                     #be0032

=item chili                        chili                      #00a693

=item china pink                   chinapink                  #de6fa1

=item china pink                   chinapink                  #b3446c

=item china rose                   chinarose                  #905d5d

=item china sea                    chinasea                   #66aabc

=item chive                        chive                      #4a5d23

=item chive                        chive                      #355e3b

=item christmas green              christmasgreen             #3a4b47

=item chrysanthemum yelllow        chrysanthemumyelllow       #f3c300

=item chrysolite green             chrysolitegreen            #8a9a5b

=item cinderella                   cinderella                 #fada5e

=item cineraria                    cineraria                  #915f6d

=item cinnamon                     cinnamon                   #ae6938

=item cinnamon cream               cinnamoncream              #ecd5c5

=item citron bronze                citronbronze               #6c541e

=item citron gray                  citrongray                 #967117

=item citron gray                  citrongray                 #8c8767

=item citron yellow                citronyellow               #f8de7e

=item citron yellow                citronyellow               #c9ae5d

=item citron yellow                citronyellow               #eae679

=item citron yellow                citronyellow               #b9b459

=item classic blue                 classicblue                #007791

=item classic blue                 classicblue                #436b95

=item clementine                   clementine                 #efbbcc

=item cleopatra                    cleopatra                  #c7e6d7

=item clivia                       clivia                     #d99058

=item cloister                     cloister                   #c7e6d7

=item cloister                     cloister                   #bcd4e6

=item cloud cream                  cloudcream                 #f3e5ab

=item cloud cream                  cloudcream                 #f0ead6

=item cloud gray                   cloudgray                  #d6cadd

=item cloudy blue                  cloudyblue                 #bcd4e6

=item clover                       clover                     #c17e91

=item cocoa bronze                 cocoabronze                #867e36

=item cocoa brown                  cocoabrown                 #a67b5b

=item cold morn                    coldmorn                   #9690ab

=item cold morn                    coldmorn                   #aa98a9

=item colonial blue                colonialblue               #00304e

=item colonial cream               colonialcream              #f3e5ab

=item colonial exterior green      colonialexteriorgreen      #3b7861

=item conclude                     conclude                   #f0ead6

=item congo                        congo                      #79443b

=item congo blue                   congoblue                  #536878

=item congo brown                  congobrown                 #80461b

=item congo brown                  congobrown                 #6f4e37

=item conifer                      conifer                    #515744

=item continental blue             continentalblue            #5d555b

=item cool eve                     cooleve                    #8da399

=item copper                       copper                     #cb6d51

=item copper bronze                copperbronze               #ae6938

=item copper cream                 coppercream                #ecd5c5

=item coquette                     coquette                   #e8ccd7

=item coral                        coral                      #e4717a

=item coral blush                  coralblush                 #f9ccca

=item coral blush                  coralblush                 #f4c2c2

=item coral cloud                  coralcloud                 #f4c2c2

=item coral gold                   coralgold                  #cb6d51

=item coral pink                   coralpink                  #f88379

=item coral rose                   coralrose                  #e4717a

=item coronation                   coronation                 #673147

=item coronet blue                 coronetblue                #436b95

=item corsage pink                 corsagepink                #e8ccd7

=item corsair                      corsair                    #36454f

=item corydalis                    corydalis                  #c9dc89

=item corydalis                    corydalis                  #dadfb7

=item cosmic blue                  cosmicblue                 #436b95

=item cosmos pink                  cosmospink                 #d5badb

=item cosmos pink                  cosmospink                 #d6cadd

=item cowslip                      cowslip                    #fab57f

=item crab pink                    crabpink                   #f9ccca

=item crab pink                    crabpink                   #ead8d7

=item cream                        cream                      #f0ead6

=item cream blush                  creamblush                 #fad6a5

=item cream chant                  creamchant                 #ebe8a4

=item cream cheese                 creamcheese                #f0ead6

=item cream delight                creamdelight               #ebe8a4

=item cream dream                  creamdream                 #f0ead6

=item cream gold                   creamgold                  #f8de7e

=item cream pearl                  creampearl                 #f0ead6

=item cream tone                   creamtone                  #f3e5ab

=item cream tone                   creamtone                  #f0ead6

=item cream white                  creamwhite                 #f0ead6

=item cream yellow                 creamyellow                #f3e5ab

=item creole pink                  creolepink                 #ecd5c5

=item crest                        crest                      #00a693

=item crimson glory                crimsonglory               #be0032

=item crisp blue                   crispblue                  #9cd1dc

=item crocus rose                  crocusrose                 #efbbcc

=item cruise blue                  cruiseblue                 #367588

=item cruise blue                  cruiseblue                 #436b95

=item crystal blue                 crystalblue                #239eba

=item crystal blue                 crystalblue                #9cd1dc

=item cuban orchid                 cubanorchid                #b784a7

=item cuban orchid                 cubanorchid                #d597ae

=item cuban sand                   cubansand                  #c9ae5d

=item cuban sand                   cubansand                  #ab9144

=item cuddle blue                  cuddleblue                 #bcd4e6

=item cuddle blue                  cuddleblue                 #91a3b0

=item cupid blue                   cupidblue                  #9cd1dc

=item cyan blue                    cyanblue                   #367588

=item cypress                      cypress                    #679267

=item daphne pink                  daphnepink                 #c17e91

=item dark forest                  darkforest                 #3a4b47

=item dark fuchsia                 darkfuchsia                #9e4f88

=item dawn glow                    dawnglow                   #d6cadd

=item dawn glow                    dawnglow                   #e8ccd7

=item dawn pink                    dawnpink                   #efbbcc

=item daybreak                     daybreak                   #aa98a9

=item day dream                    daydream                   #9690ab

=item dazzle blue                  dazzleblue                 #007791

=item debonair                     debonair                   #91a3b0

=item debutante blue               debutanteblue              #9cd1dc

=item debutante blue               debutanteblue              #bcd4e6

=item debutante pink               debutantepink              #ea9399

=item debutante yellow             debutanteyellow            #eae679

=item deep hellebore red           deephelleborered           #915f6d

=item deep purple                  deeppurple                 #50404d

=item deep purple                  deeppurple                 #291e29

=item deep purple                  deeppurple                 #242124

=item deep ravine                  deepravine                 #6c541e

=item deep reverie                 deepreverie                #5d555b

=item deep sea                     deepsea                    #317873

=item deep twilight                deeptwilight               #8e8279

=item deep violet                  deepviolet                 #604e81

=item deep violet                  deepviolet                 #2f2140

=item deep water                   deepwater                  #436b95

=item delectable                   delectable                 #239eba

=item delectable                   delectable                 #66aabc

=item delectable                   delectable                 #70a3cc

=item delight                      delight                    #d6cadd

=item del monte                    delmonte                   #796878

=item delta                        delta                      #367588

=item delusion                     delusion                   #9cd1dc

=item demon blue                   demonblue                  #51585e

=item demure blue                  demureblue                 #bcd4e6

=item depth green                  depthgreen                 #3a4b47

=item desert brown                 desertbrown                #f9ccca

=item desert dust                  desertdust                 #f3e5ab

=item desert dust                  desertdust                 #f0ead6

=item desert glass                 desertglass                #b695c0

=item desert mist                  desertmist                 #fad6a5

=item desert palm                  desertpalm                 #5b5842

=item desert pride                 desertpride                #dadfb7

=item desert sand                  desertsand                 #c19a6b

=item desirable                    desirable                  #c7e6d7

=item desire                       desire                     #d5badb

=item dewkist                      dewkist                    #b2beb5

=item dewkist                      dewkist                    #b9b8b5

=item diadem                       diadem                     #aa8a9e

=item dignity                      dignity                    #dea5a4

=item dignity                      dignity                    #efbbcc

=item dignity                      dignity                    #e8ccd7

=item distinction                  distinction                #915f6d

=item diva blue                    divablue                   #30267a

=item diva blue                    divablue                   #6c79b8

=item divine blue                  divineblue                 #70a3cc

=item dolly varden                 dollyvarden                #f9ccca

=item dove gray                    dovegray                   #bfb9bd

=item dove gray                    dovegray                   #c3a6b1

=item drab olive                   drabolive                  #8a9a5b

=item dream blue                   dreamblue                  #a1caf1

=item dream cream                  dreamcream                 #dadfb7

=item dream fluff                  dreamfluff                 #e8e3e5

=item dream stuff                  dreamstuff                 #efbbcc

=item dreamy blue                  dreamyblue                 #91a3b0

=item dried leaf                   driedleaf                  #f8de7e

=item drizzle                      drizzle                    #b2beb5

=item dryad                        dryad                      #66ada4

=item dryad rose                   dryadrose                  #ecd5c5

=item du barry blue                dubarryblue                #00a693

=item duckling blue                ducklingblue               #536878

=item duckling blue                ducklingblue               #36454f

=item dusky blue                   duskyblue                  #91a3b0

=item dusky citron                 duskycitron                #8a9a5b

=item dusky green                  duskygreen                 #8f9779

=item dusty green                  dustygreen                 #8a9a5b

=item dusty green                  dustygreen                 #8f9779

=item dutch cream                  dutchcream                 #fad6a5

=item dutch cream                  dutchcream                 #f0ead6

=item dynasty green                dynastygreen               #007a74

=item earth brown                  earthbrown                 #6f4e37

=item easter bonnet                easterbonnet               #bcd4e6

=item easter egg yellow            eastereggyellow            #f8de7e

=item ecru                         ecru                       #f3e5ab

=item ecru cream                   ecrucream                  #f3e5ab

=item ecru cream                   ecrucream                  #f0ead6

=item eerie blue                   eerieblue                  #bcd4e6

=item egg plant                    eggplant                   #50404d

=item egg plant                    eggplant                   #291e29

=item egg shell                    eggshell                   #fad6a5

=item egg shell                    eggshell                   #f3e5ab

=item egyptian red                 egyptianred                #722f37

=item eighteenth century citron    eighteenthcenturycitron    #8a9a5b

=item eighteenth century green     eighteenthcenturygreen     #8f9779

=item eighteenth century tan       eighteenthcenturytan       #ad8884

=item eighteenth century turquoise eighteenthcenturyturquoise #367588

=item eighteenth century turquoise eighteenthcenturyturquoise #536878

=item eighteenth century violet    eighteenthcenturyviolet    #836479

=item eighteenth century yellow    eighteenthcenturyyellow    #c2b280

=item electra                      electra                    #96ded1

=item elf green                    elfgreen                   #8da399

=item elf green                    elfgreen                   #66ada4

=item elm                          elm                        #8f9779

=item emerald green                emeraldgreen               #b6e5af

=item emerald isle                 emeraldisle                #008856

=item empire yellow                empireyellow               #f3c300

=item empire yellow                empireyellow               #fada5e

=item empirical blue               empiricalblue              #66ada4

=item enchantress                  enchantress                #cb6d51

=item enduring                     enduring                   #66ada4

=item enduring                     enduring                   #66aabc

=item english mist                 englishmist                #7d8984

=item erie                         erie                       #317873

=item etherial green               etherialgreen              #c9dc89

=item etherial green               etherialgreen              #dadfb7

=item eucalyptus green             eucalyptusgreen            #8f9779

=item eve green                    evegreen                   #83d37d

=item eve green                    evegreen                   #44944a

=item evening glow                 eveningglow                #f9ccca

=item evening haze                 eveninghaze                #dea5a4

=item eventide                     eventide                   #c3a6b1

=item everglade                    everglade                  #222222

=item fable                        fable                      #e8e3e5

=item fairy gold                   fairygold                  #eae679

=item fairy land                   fairyland                  #c7e6d7

=item fairy land                   fairyland                  #96ded1

=item fairy princess               fairyprincess              #e9e9ed

=item falcon                       falcon                     #5b504f

=item fall blue                    fallblue                   #91a3b0

=item fall blue                    fallblue                   #8c92ac

=item fall bronze                  fallbronze                 #ab9144

=item fall leaf                    fallleaf                   #f8de7e

=item fall leaf                    fallleaf                   #c9ae5d

=item fall yellow                  fallyellow                 #f8de7e

=item fall yellow                  fallyellow                 #c9ae5d

=item fancy free                   fancyfree                  #c7e6d7

=item fanfare                      fanfare                    #007791

=item fantasia                     fantasia                   #c7e6d7

=item fantasy rose                 fantasyrose                #c7ada3

=item fantasy yellow               fantasyyellow              #f3e5ab

=item far horizon                  farhorizon                 #4e5755

=item favorite                     favorite                   #8da399

=item ferndell                     ferndell                   #355e3b

=item fernery                      fernery                    #1b4d3e

=item fern green                   ferngreen                  #8a9a5b

=item fern lane                    fernlane                   #c7e6d7

=item festival                     festival                   #3eb489

=item festival                     festival                   #00a693

=item festive green                festivegreen               #27a64c

=item festive green                festivegreen               #83d37d

=item festoon                      festoon                    #3eb489

=item fidelity                     fidelity                   #c0c8e1

=item finesse                      finesse                    #c7ada3

=item firecracker                  firecracker                #d9603b

=item fire fly                     firefly                    #e4717a

=item fir green                    firgreen                   #8a9a5b

=item firmament blue               firmamentblue              #545aa7

=item firmament gray               firmamentgray              #bcd4e6

=item firmament gray               firmamentgray              #e9e9ed

=item first lady                   firstlady                  #b784a7

=item first lady                   firstlady                  #de6fa1

=item flame                        flame                      #be0032

=item flame                        flame                      #bc3f4a

=item flamingo pink                flamingopink               #ea9399

=item flash                        flash                      #bc3f4a

=item flax flower blue             flaxflowerblue             #6c79b8

=item flemish blue                 flemishblue                #536878

=item flesh cream                  fleshcream                 #ecd5c5

=item flesh cream                  fleshcream                 #fad6a5

=item flesh pink                   fleshpink                  #ecd5c5

=item flesh tint                   fleshtint                  #f4c2c2

=item flesh tint                   fleshtint                  #ecd5c5

=item flint                        flint                      #5c504f

=item flirtation                   flirtation                 #aa98a9

=item flowerlet                    flowerlet                  #c9dc89

=item fog blue                     fogblue                    #8c92ac

=item fog green                    foggreen                   #8da399

=item fog yellow                   fogyellow                  #a18f60

=item foliage                      foliage                    #7e9f2e

=item forest shade                 forestshade                #679267

=item fortune                      fortune                    #7e73b8

=item fountain blue                fountainblue               #c0c8e1

=item fountain green               fountaingreen              #83d37d

=item fountain green               fountaingreen              #b6e5af

=item four-leaf clover             fourleafclover             #355e3b

=item french beige                 frenchbeige                #a67b5b

=item french blue                  frenchblue                 #8791bf

=item french lilac                 frenchlilac                #836479

=item french nude                  frenchnude                 #d9a6a9

=item frosty night                 frostynight                #e9e9ed

=item froth                        froth                      #f0ead6

=item frozen dew                   frozendew                  #bcd4e6

=item fuchsia                      fuchsia                    #bc3f4a

=item fuchsia                      fuchsia                    #b3446c

=item fuchsia pink                 fuchsiapink                #e68fac

=item fuchsia pink                 fuchsiapink                #de6fa1

=item fuchsia pink                 fuchsiapink                #de6fa1

=item fuchsia pink                 fuchsiapink                #d597ae

=item fuchsia rose                 fuchsiarose                #ce4676

=item fuchsia rose                 fuchsiarose                #b3446c

=item gale cloud                   galecloud                  #51585e

=item gale winds                   galewinds                  #51585e

=item garden pool                  gardenpool                 #c7e6d7

=item garnet rose                  garnetrose                 #722f37

=item gay yellow                   gayyellow                  #e9e450

=item gay yellow                   gayyellow                  #eae679

=item geneva blue                  genevablue                 #00304e

=item geneva blue                  genevablue                 #4c516d

=item ghostly blue                 ghostlyblue                #bcd4e6

=item ghostly blue                 ghostlyblue                #c0c8e1

=item gleam                        gleam                      #eae679

=item glint o'gold                 glintogold                 #f8de7e

=item glint o'gold                 glintogold                 #c9ae5d

=item glory green                  glorygreen                 #bdda57

=item glory green-blue             glorygreenblue             #317873

=item gold coast                   goldcoast                  #ab9144

=item golden apricot               goldenapricot              #fab57f

=item golden apricot               goldenapricot              #d99058

=item golden brown                 goldenbrown                #ae6938

=item golden buff                  goldenbuff                 #f8de7e

=item golden cream                 goldencream                #f8de7e

=item golden dawn                  goldendawn                 #f8de7e

=item golden fleece                goldenfleece               #fad6a5

=item golden fleece                goldenfleece               #f3e5ab

=item golden fleece                goldenfleece               #c2b280

=item golden gem                   goldengem                  #f8de7e

=item golden glow                  goldenglow                 #fada5e

=item golden mist                  goldenmist                 #b9b57d

=item golden mist                  goldenmist                 #c9dc89

=item golden mist                  goldenmist                 #dadfb7

=item golden peach                 goldenpeach                #e3a857

=item golden rapture               goldenrapture              #fada5e

=item golden ray                   goldenray                  #fada5e

=item golden ray                   goldenray                  #f8de7e

=item golden rod                   goldenrod                  #fada5e

=item golden sheaf                 goldensheaf                #f3e5ab

=item golden sulphur               goldensulphur              #eae679

=item golden tan                   goldentan                  #d99058

=item golden west                  goldenwest                 #be8a3d

=item golden yellow                goldenyellow               #f8de7e

=item gold fantasy                 goldfantasy                #fada5e

=item gold glow                    goldglow                   #eae679

=item gold glow                    goldglow                   #ebe8a4

=item gold pheasant                goldpheasant               #ae6938

=item gold rush                    goldrush                   #e3a857

=item good omen                    goodomen                   #8c82b6

=item good omen                    goodomen                   #70a3cc

=item gorge                        gorge                      #b2beb5

=item gorge                        gorge                      #b9b8b5

=item gracious green               graciousgreen              #c7e6d7

=item grand canyon                 grandcanyon                #a87c6d

=item grand canyon                 grandcanyon                #a67b5b

=item granite blue                 graniteblue                #536878

=item granite green                granitegreen               #8da399

=item grape                        grape                      #2f2140

=item grape                        grape                      #50404d

=item grapefruit green             grapefruitgreen            #e9e450

=item grapefruit green             grapefruitgreen            #beb72e

=item grapefruit green             grapefruitgreen            #eae679

=item grapefruit green             grapefruitgreen            #b9b459

=item grape green                  grapegreen                 #8a9a5b

=item gravel                       gravel                     #c2ac99

=item gravel                       gravel                     #ae9b82

=item gravel                       gravel                     #bfb8a5

=item gray blue                    grayblue                   #b4bcc0

=item gray dream                   graydream                  #f0ead6

=item gray dream                   graydream                  #bfb8a5

=item gray drift                   graydrift                  #bcd4e6

=item gray drift                   graydrift                  #b4bcc0

=item gray green                   graygreen                  #5e716a

=item gray lady                    graylady                   #b4bcc0

=item gray light                   graylight                  #c1b6b3

=item gray light                   graylight                  #b9b8b5

=item gray mist                    graymist                   #91a3b0

=item gray mist                    graymist                   #b4bcc0

=item gray mood                    graymood                   #5d555b

=item gray morn                    graymorn                   #8e8279

=item gray night                   graynight                  #536878

=item gray sand                    graysand                   #c2b280

=item gray sand                    graysand                   #bfb8a5

=item grecian rose                 grecianrose                #f88379

=item grecian rose                 grecianrose                #d9a6a9

=item green banana                 greenbanana                #b9b459

=item green banana                 greenbanana                #b9b57d

=item green black                  greenblack                 #3a4b47

=item green black                  greenblack                 #4e5755

=item green black                  greenblack                 #555555

=item green black                  greenblack                 #222222

=item green breath                 greenbreath                #f0ead6

=item green charm                  greencharm                 #eae679

=item green charm                  greencharm                 #c9dc89

=item green dream                  greendream                 #96ded1

=item greenery                     greenery                   #8db600

=item greenery                     greenery                   #7e9f2e

=item green eyes                   greeneyes                  #679267

=item green fog                    greenfog                   #8f9779

=item green glory                  greenglory                 #007a74

=item green glory                  greenglory                 #317873

=item green glow                   greenglow                  #c7e6d7

=item green grass                  greengrass                 #8a9a5b

=item green haze                   greenhaze                  #8f9779

=item green ice                    greenice                   #f0ead6

=item green ice                    greenice                   #dfede8

=item green lily                   greenlily                  #c7e6d7

=item green matrix                 greenmatrix                #004b49

=item green mist                   greenmist                  #8f9779

=item green moss                   greenmoss                  #8a9a5b

=item green oasis                  greenoasis                 #98943e

=item green oasis                  greenoasis                 #7e9f2e

=item green olive                  greenolive                 #8a9a5b

=item green pride                  greenpride                 #c9dc89

=item green ravine                 greenravine                #5e716a

=item green river mist             greenrivermist             #b2beb5

=item green slate                  greenslate                 #1e2321

=item green spring                 greenspring                #7e9f2e

=item green stone                  greenstone                 #dadfb7

=item green sulphur                greensulphur               #b9b459

=item green tea                    greentea                   #679267

=item green tee                    greentee                   #8a9a5b

=item growth green                 growthgreen                #bdda57

=item guinea green                 guineagreen                #317873

=item gull gray                    gullgray                   #8b8589

=item gumdrop green                gumdropgreen               #c9dc89

=item gun metal                    gunmetal                   #5b504f

=item gypsy                        gypsy                      #80461b

=item hanging garden               hanginggarden              #27a64c

=item hansa yellow                 hansayellow                #f3c300

=item happy day                    happyday                   #ebe8a4

=item happy day                    happyday                   #dadfb7

=item harbor blue                  harborblue                 #bcd4e6

=item harem blue                   haremblue                  #bcd4e6

=item harmonious blue              harmoniousblue             #536878

=item harvest gold                 harvestgold                #f8de7e

=item hawk brown                   hawkbrown                  #6c541e

=item heart's desire               heartsdesire               #ab4e52

=item heavenly charm               heavenlycharm              #f0ead6

=item heavenly day                 heavenlyday                #ebe8a4

=item heavenly flower              heavenlyflower             #4997d0

=item heavenly green               heavenlygreen              #c9dc89

=item heavenly orchid              heavenlyorchid             #e8ccd7

=item heavenly pink                heavenlypink               #f9ccca

=item heliotrope                   heliotrope                 #702963

=item heliotrope                   heliotrope                 #5d3954

=item heliotrope gray              heliotropegray             #aa98a9

=item heliotrope gray              heliotropegray             #aa8a9e

=item heliotrope gray              heliotropegray             #c3a6b1

=item hemlock                      hemlock                    #93c592

=item hemp                         hemp                       #c2b280

=item hiawatha green               hiawathagreen              #317873

=item highland                     highland                   #3a4b47

=item holiday                      holiday                    #96ded1

=item holland blue                 hollandblue                #91a3b0

=item honey beige                  honeybeige                 #d9a6a9

=item horizon                      horizon                    #91a3b0

=item hortensia                    hortensia                  #563c5c

=item hortensia                    hortensia                  #5d3954

=item huckleberry                  huckleberry                #50404d

=item huron                        huron                      #66ada4

=item hussar                       hussar                     #4c516d

=item iceberg green                iceberggreen               #8da399

=item iceberg green                iceberggreen               #91a3b0

=item ice boat                     iceboat                    #00a693

=item ice cap                      icecap                     #66aabc

=item ice flow                     iceflow                    #c7e6d7

=item iceland blue                 icelandblue                #bcd4e6

=item icy green                    icygreen                   #66ada4

=item icy morn                     icymorn                    #8ed1b2

=item icy morn                     icymorn                    #c7e6d7

=item ideal                        ideal                      #9cd1dc

=item illusion                     illusion                   #bcd4e6

=item illusion                     illusion                   #b4bcc0

=item illusive                     illusive                   #d6cadd

=item independence                 independence               #2f2140

=item independence                 independence               #563c5c

=item independence                 independence               #50404d

=item indian red                   indianred                  #9e4732

=item ink blue                     inkblue                    #00304e

=item ink blue                     inkblue                    #36454f

=item inspiration                  inspiration                #c7e6d7

=item intimate mood                intimatemood               #af868e

=item ionian blue                  ionianblue                 #00304e

=item ionian blue                  ionianblue                 #36454f

=item irish isle                   irishisle                  #27a64c

=item iris leaf                    irisleaf                   #515744

=item iris orchid                  irisorchid                 #e68fac

=item iris orchid                  irisorchid                 #de6fa1

=item iron mask                    ironmask                   #36454f

=item iron mask                    ironmask                   #222222

=item irresistible                 irresistible               #b3446c

=item island green                 islandgreen                #8ed1b2

=item italian blue                 italianblue                #66aabc

=item ivory                        ivory                      #f3e5ab

=item ivory white                  ivorywhite                 #f3e5ab

=item jade cream                   jadecream                  #ebe8a4

=item jade lime                    jadelime                   #bdda57

=item jasper                       jasper                     #3a4b47

=item jasper                       jasper                     #222222

=item jealousy                     jealousy                   #8ed1b2

=item jersey cream                 jerseycream                #f3e5ab

=item jewel blue                   jewelblue                  #66aabc

=item jewel green                  jewelgreen                 #317873

=item joy                          joy                        #93c592

=item june bud                     junebud                    #bdda57

=item june bud                     junebud                    #83d37d

=item june green                   junegreen                  #c9dc89

=item jungle                       jungle                     #3a4b47

=item juniper                      juniper                    #5e716a

=item juniper                      juniper                    #3a4b47

=item kaffa                        kaffa                      #674c47

=item killarney green              killarneygreen             #008856

=item king lear                    kinglear                   #604e81

=item king neptune                 kingneptune                #70a3cc

=item king's ransom                kingsransom                #d99058

=item kitten's ear                 kittensear                 #f3e5ab

=item lady orchid                  ladyorchid                 #915f6d

=item lagoon                       lagoon                     #317873

=item lake blue                    lakeblue                   #0067a5

=item lake como                    lakecomo                   #436b95

=item lake louise                  lakelouise                 #436b95

=item lamb's wool                  lambswool                  #f0ead6

=item la mer                       lamer                      #8ed1b2

=item languid lavender             languidlavender            #c4c3dd

=item languid lavender             languidlavender            #d6cadd

=item larkspur blue                larkspurblue               #70a3cc

=item larkspur purple              larkspurpurple             #604e97

=item lava                         lava                       #483c32

=item lava                         lava                       #3b3121

=item leaf green                   leafgreen                  #27a64c

=item lettuce green                lettucegreen               #7e9f2e

=item life green                   lifegreen                  #4a5d23

=item light hearted                lighthearted               #ebe8a4

=item light mauve                  lightmauve                 #dea5a4

=item light mauve                  lightmauve                 #d597ae

=item light oak                    lightoak                   #c19a6b

=item light old rose               lightoldrose               #f88379

=item lilac                        lilac                      #b695c0

=item lilac gray                   lilacgray                  #796878

=item lilac hint                   lilachint                  #d6cadd

=item lilac lavender               lilaclavender              #9690ab

=item lilac shadow                 lilacshadow                #563c5c

=item lilac shadow                 lilacshadow                #796878

=item lilting green                liltinggreen               #00a693

=item lily green                   lilygreen                  #b9b57d

=item lily green                   lilygreen                  #c9dc89

=item lime cream                   limecream                  #c9dc89

=item lime yellow                  limeyellow                 #e9e450

=item lime yellow                  limeyellow                 #beb72e

=item lime yellow                  limeyellow                 #bdda57

=item london fog                   londonfog                  #8b8589

=item love bird                    lovebird                   #bdda57

=item love light                   lovelight                  #eae679

=item lovely                       lovely                     #6aab8e

=item lover's knot                 loversknot                 #efbbcc

=item lover's note                 loversnote                 #bcd4e6

=item lucerne blue                 lucerneblue                #8791bf

=item lullaby                      lullaby                    #dfede8

=item lullaby                      lullaby                    #b2beb5

=item lullaby                      lullaby                    #f2f3f4

=item lullaby                      lullaby                    #b9b8b5

=item lush gray                    lushgray                   #317873

=item lush green                   lushgreen                  #3eb489

=item lustrous yellow              lustrousyellow             #eae679

=item lyons blue                   lyonsblue                  #30267a

=item lyons blue                   lyonsblue                  #545aa7

=item lyre blue                    lyreblue                   #367588

=item magenta                      magenta                    #a8516e

=item magenta rose                 magentarose                #673147

=item magical                      magical                    #e8e3e5

=item magic moon                   magicmoon                  #66aabc

=item magic moon                   magicmoon                  #91a3b0

=item maid of orleans              maidoforleans              #d5badb

=item maid of orleans              maidoforleans              #d6cadd

=item majolica                     majolica                   #00304e

=item mandarin orange              mandarinorange             #d9603b

=item mandarin orange              mandarinorange             #ed872d

=item marble                       marble                     #3a4b47

=item marco polo                   marcopolo                  #367588

=item marine blue                  marineblue                 #367588

=item marine blue                  marineblue                 #004958

=item marine corps blue            marinecorpsblue            #00304e

=item marine glow                  marineglow                 #c7e6d7

=item market green                 marketgreen                #c7e6d7

=item martinique                   martinique                 #b9b459

=item mauve decade                 mauvedecade                #915f6d

=item mauve mist                   mauvemist                  #c3a6b1

=item mauve orchid                 mauveorchid                #af868e

=item mauve taupe                  mauvetaupe                 #915f6d

=item mauvette                     mauvette                   #e8ccd7

=item mayflower                    mayflower                  #de6fa1

=item mayflower                    mayflower                  #c17e91

=item meadow green                 meadowgreen                #3eb489

=item meadow green                 meadowgreen                #6aab8e

=item meadow mist                  meadowmist                 #8da399

=item mellow buff                  mellowbuff                 #fad6a5

=item mellow buff                  mellowbuff                 #f3e5ab

=item mellow green                 mellowgreen                #eae679

=item mellow mauve                 mellowmauve                #915f6d

=item mellow mood                  mellowmood                 #aa98a9

=item mellow yellow                mellowyellow               #f8de7e

=item mellow yellow                mellowyellow               #f3e5ab

=item mellow yellow                mellowyellow               #eae679

=item mellow yellow                mellowyellow               #ebe8a4

=item melodious                    melodious                  #91a3b0

=item memory lane                  memorylane                 #dfede8

=item merry green                  merrygreen                 #008856

=item midnight                     midnight                   #00304e

=item midnight                     midnight                   #36454f

=item midnight bronze              midnightbronze             #c1b6b3

=item midseason                    midseason                  #d6cadd

=item mignonette                   mignonette                 #8a9a5b

=item milano blue                  milanoblue                 #536878

=item milano blue                  milanoblue                 #8c92ac

=item milky green                  milkygreen                 #dfede8

=item mince meat                   mincemeat                  #674c47

=item ming                         ming                       #007959

=item mint lime                    mintlime                   #93c592

=item mint lime                    mintlime                   #c7e6d7

=item mission white                missionwhite               #ecd5c5

=item mission white                missionwhite               #fad6a5

=item misted yellow                mistedyellow               #c9ae5d

=item mistletoe                    mistletoe                  #8a9a5b

=item mistletoe                    mistletoe                  #8f9779

=item misty cream                  mistycream                 #f3e5ab

=item misty cream                  mistycream                 #f0ead6

=item misty green                  mistygreen                 #8f9779

=item misty jade                   mistyjade                  #eae679

=item misty jade                   mistyjade                  #ebe8a4

=item misty jade                   mistyjade                  #c9dc89

=item misty lilac                  mistylilac                 #b695c0

=item misty lilac                  mistylilac                 #aa98a9

=item misty morn                   mistymorn                  #f0ead6

=item misty morn                   mistymorn                  #dfede8

=item misty morn                   mistymorn                  #f2f3f4

=item misty rose                   mistyrose                  #ecd5c5

=item modest                       modest                     #b2beb5

=item mogul                        mogul                      #8c82b6

=item mohawk                       mohawk                     #79443b

=item mohawk trail                 mohawktrail                #3a4b47

=item monaco                       monaco                     #66ada4

=item monastral blue               monastralblue              #00304e

=item monastral blue               monastralblue              #4e5180

=item monsignor                    monsignor                  #9e4f88

=item monticello green             monticellogreen            #355e3b

=item monticello rose              monticellorose             #d9a6a9

=item montrose yellow              montroseyellow             #bdda57

=item mood beige                   moodbeige                  #c2b280

=item mood lilac                   moodlilac                  #86608e

=item mood violet                  moodviolet                 #796878

=item moonbeam                     moonbeam                   #bfb9bd

=item moonlight                    moonlight                  #ecd5c5

=item moonlight bay                moonlightbay               #96ded1

=item moonlit blue                 moonlitblue                #bcd4e6

=item moonlit blue                 moonlitblue                #b4bcc0

=item moonlit water                moonlitwater               #91a3b0

=item moonlit water                moonlitwater               #8c92ac

=item moonmist                     moonmist                   #c1b6b3

=item morning glory                morningglory               #de6fa1

=item morning mist                 morningmist                #c2ac99

=item moth                         moth                       #bfb8a5

=item moth                         moth                       #dadfb7

=item mountain haze                mountainhaze               #dea5a4

=item mountain peak blue           mountainpeakblue           #bcd4e6

=item mountain top                 mountaintop                #515744

=item mountain top                 mountaintop                #31362b

=item mulberry                     mulberry                   #796878

=item murmur                       murmur                     #f3e5ab

=item murmur                       murmur                     #bfb8a5

=item muse                         muse                       #c9dc89

=item mushroom                     mushroom                   #f3e5ab

=item mushroom                     mushroom                   #f0ead6

=item mustard                      mustard                    #ab9144

=item mustard cream                mustardcream               #f8de7e

=item mustard cream                mustardcream               #f3e5ab

=item muted yellow                 mutedyellow                #f8de7e

=item muted yellow                 mutedyellow                #eae679

=item myrtle green                 myrtlegreen                #5e716a

=item mystic blue                  mysticblue                 #bcd4e6

=item mystic purple                mysticpurple               #915c83

=item mystic white                 mysticwhite                #e9e9ed

=item myth                         myth                       #d6cadd

=item myth blue                    mythblue                   #536878

=item myth blue                    mythblue                   #51585e

=item nabob                        nabob                      #3a4b47

=item nabob                        nabob                      #36454f

=item nabob                        nabob                      #51585e

=item naid                         naid                       #00a693

=item naid                         naid                       #96ded1

=item naid                         naid                       #66ada4

=item naive                        naive                      #dfede8

=item napoleon                     napoleon                   #272458

=item nasturtium                   nasturtium                 #ffc14f

=item nasturtium buff              nasturtiumbuff             #e3a857

=item native blue                  nativeblue                 #004b49

=item neon blue                    neonblue                   #239eba

=item neopolitan night             neopolitannight            #436b95

=item neopolitan night             neopolitannight            #4e5180

=item neutral                      neutral                    #f3e5ab

=item neutral                      neutral                    #f0ead6

=item new blue                     newblue                    #e9e9ed

=item niagara                      niagara                    #239eba

=item night blue                   nightblue                  #004958

=item night cloud                  nightcloud                 #e9e9ed

=item night fighter                nightfighter               #51585e

=item night fighter                nightfighter               #5d555b

=item night fighter                nightfighter               #555555

=item night horizon                nighthorizon               #202428

=item night horizon                nighthorizon               #222222

=item night magic                  nightmagic                 #aa98a9

=item nightshade                   nightshade                 #50404d

=item nightshade                   nightshade                 #5d555b

=item night watch                  nightwatch                 #1a2421

=item nil                          nil                        #f2f3f4

=item nocturne                     nocturne                   #bfb9bd

=item noel                         noel                       #3a4b47

=item nomad brown                  nomadbrown                 #3e322c

=item norse blue                   norseblue                  #4997d0

=item norse blue                   norseblue                  #6c79b8

=item north blue                   northblue                  #007791

=item northern skies               northernskies              #bcd4e6

=item north green                  northgreen                 #5e716a

=item north green                  northgreen                 #317873

=item north sea                    northsea                   #51585e

=item norway pine                  norwaypine                 #679267

=item nubian brown                 nubianbrown                #635147

=item nymph pink                   nymphpink                  #d597ae

=item oak leaf                     oakleaf                    #515744

=item ocean wave                   oceanwave                  #66ada4

=item octoroon rose                octoroonrose               #905d5d

=item octoroon rose                octoroonrose               #977f73

=item old coral                    oldcoral                   #ab4e52

=item old gold                     oldgold                    #eaa221

=item old gold                     oldgold                    #e3a857

=item old gold                     oldgold                    #d4af37

=item old lavender                 oldlavender                #d6cadd

=item old master green             oldmastergreen             #515744

=item old rose                     oldrose                    #c08081

=item olive glow                   oliveglow                  #ebe8a4

=item olive glow                   oliveglow                  #dadfb7

=item olive hint                   olivehint                  #ebe8a4

=item olive hint                   olivehint                  #dadfb7

=item ombre                        ombre                      #36454f

=item ombre                        ombre                      #222222

=item opal green                   opalgreen                  #317873

=item opera blue                   operablue                  #00304e

=item opera blue                   operablue                  #4e5180

=item opera mauve                  operamauve                 #b784a7

=item opera pink                   operapink                  #f4c2c2

=item orange                       orange                     #ed872d

=item orange blush                 orangeblush                #fad6a5

=item orange cream                 orangecream                #f3e5ab

=item orchid                       orchid                     #c3a6b1

=item orchid lane                  orchidlane                 #d5badb

=item orchid leaf                  orchidleaf                 #d6cadd

=item orchid mauve                 orchidmauve                #c17e91

=item orchid night                 orchidnight                #905d5d

=item orchid night                 orchidnight                #915f6d

=item orchid pink                  orchidpink                 #f9ccca

=item orchid pink                  orchidpink                 #dea5a4

=item orchid smoke                 orchidsmoke                #c3a6b1

=item oriental bronze              orientalbronze             #6c541e

=item oriental sand                orientalsand               #8c8767

=item padre brown                  padrebrown                 #3e1d1e

=item palace blue                  palaceblue                 #0067a5

=item palace blue                  palaceblue                 #436b95

=item pale star                    palestar                   #eae679

=item pale star                    palestar                   #ebe8a4

=item pale water                   palewater                  #8ed1b2

=item paloma                       paloma                     #a67b5b

=item paloma                       paloma                     #9cd1dc

=item pan                          pan                        #5e716a

=item pan                          pan                        #317873

=item panama blue                  panamablue                 #b3bce2

=item pansy purple                 pansypurple                #915c83

=item pansy purple                 pansypurple                #5d3954

=item pansy yellow                 pansyyellow                #fada5e

=item paprica                      paprica                    #9e4732

=item paradise green               paradisegreen              #b6e5af

=item paradise green               paradisegreen              #93c592

=item paramount                    paramount                  #239eba

=item paramount                    paramount                  #66aabc

=item paramour                     paramour                   #66aabc

=item parrakeet                    parrakeet                  #3eb489

=item peace                        peace                      #f0ead6

=item peace-maker                  peacemaker                 #dfede8

=item peach amber                  peachamber                 #d9a6a9

=item peach bisque                 peachbisque                #a87c6d

=item peach bud                    peachbud                   #f4c2c2

=item peach cream                  peachcream                 #fad6a5

=item peach gray                   peachgray                  #eae3e1

=item peach gray                   peachgray                  #c1b6b3

=item peach gray                   peachgray                  #ecd5c5

=item peach pink                   peachpink                  #f4c2c2

=item peach rust                   peachrust                  #cb6d51

=item peach sand                   peachsand                  #c1b6b3

=item peach sand                   peachsand                  #8e8279

=item peacock blue                 peacockblue                #004958

=item pea green                    peagreen                   #8a9a5b

=item pearl cream                  pearlcream                 #eae3e1

=item pearly gates                 pearlygates                #f0ead6

=item peasant blue                 peasantblue                #00304e

=item peasant blue                 peasantblue                #36454f

=item persian green                persiangreen               #00a693

=item persian gulf                 persiangulf                #5e716a

=item persian gulf                 persiangulf                #317873

=item persian melon                persianmelon               #cb6d51

=item persian rose                 persianrose                #ce4676

=item persian rose                 persianrose                #b3446c

=item personal                     personal                   #e8ccd7

=item petunia                      petunia                    #86608e

=item pewter                       pewter                     #c1b6b3

=item pewter cream                 pewtercream                #eae3e1

=item phantom blue                 phantomblue                #9cd1dc

=item phantom blue                 phantomblue                #bcd4e6

=item phantom green                phantomgreen               #dfede8

=item phlox pink                   phloxpink                  #de6fa1

=item picturesque                  picturesque                #00a693

=item picturesque                  picturesque                #96ded1

=item pine frost                   pinefrost                  #8ed1b2

=item pink carnation               pinkcarnation              #ffc8d6

=item pink dust                    pinkdust                   #f4c2c2

=item pink dust                    pinkdust                   #ecd5c5

=item pink icing                   pinkicing                  #efbbcc

=item pink jewel                   pinkjewel                  #f88379

=item pink lavender                pinklavender               #e8ccd7

=item pink lily                    pinklily                   #f9ccca

=item pink mist                    pinkmist                   #e8ccd7

=item pink orchid                  pinkorchid                 #e8ccd7

=item pink powder                  pinkpowder                 #ffc8d6

=item pink rapture                 pinkrapture                #9e4f88

=item pink shock                   pinkshock                  #b3446c

=item pinocchio                    pinocchio                  #f4c2c2

=item piquant                      piquant                    #96ded1

=item piquant green                piquantgreen               #8a9a5b

=item pistachio cream              pistachiocream             #bdda57

=item placid                       placid                     #e8e3e5

=item plantation                   plantation                 #79443b

=item plantation yellow            plantationyellow           #fada5e

=item platonic                     platonic                   #91a3b0

=item plenty bright                plentybright               #007a74

=item plumbago blue                plumbagoblue               #bcd4e6

=item plumbago blue                plumbagoblue               #c0c8e1

=item plume                        plume                      #96ded1

=item poet's yellow                poetsyellow                #eae679

=item polar bear                   polarbear                  #66aabc

=item pom pom                      pompom                     #f8de7e

=item pom pom                      pompom                     #eae679

=item pool green                   poolgreen                  #00a693

=item porcelain green              porcelaingreen             #6aab8e

=item pouf de vent                 poufdevent                 #efbbcc

=item pouf de vent                 poufdevent                 #e8ccd7

=item prairie sunset               prairiesunset              #d9a6a9

=item prairie sunset               prairiesunset              #fab57f

=item primeval                     primeval                   #3b7861

=item primrose yellow              primroseyellow             #e9e450

=item princely blue                princelyblue               #b3bce2

=item princely blue                princelyblue               #c0c8e1

=item princess                     princess                   #8c82b6

=item priscilla blue               priscillablue              #367588

=item prism pink                   prismpink                  #efbbcc

=item prism violet                 prismviolet                #604e97

=item profound                     profound                   #722f37

=item profound blue                profoundblue               #536878

=item profound blue                profoundblue               #8c92ac

=item promise                      promise                    #f0ead6

=item promised land                promisedland               #3eb489

=item promised land                promisedland               #007959

=item promised land                promisedland               #00a693

=item promised land                promisedland               #007a74

=item promise green                promisegreen               #c7e6d7

=item prudence                     prudence                   #66ada4

=item prudence                     prudence                   #91a3b0

=item pumpkin                      pumpkin                    #d99058

=item puritan                      puritan                    #536878

=item puritan                      puritan                    #51585e

=item purple aster                 purpleaster                #915c83

=item purple heather               purpleheather              #86608e

=item purple lake                  purplelake                 #673147

=item purple night                 purplenight                #36454f

=item purple ode                   purpleode                  #9690ab

=item quail                        quail                      #8e8279

=item quaker                       quaker                     #8b8589

=item quality                      quality                    #8c82b6

=item quality pink                 qualitypink                #e68fac

=item quality pink                 qualitypink                #d597ae

=item queen anne                   queenanne                  #8a9a5b

=item queen blue                   queenblue                  #436b95

=item queen coral                  queencoral                 #f88379

=item queen coral                  queencoral                 #f4c2c2

=item queen pink                   queenpink                  #e8ccd7

=item quiet                        quiet                      #dfede8

=item radiance                     radiance                   #fada5e

=item radiant                      radiant                    #f88379

=item radiant                      radiant                    #cb6d51

=item radiant orchid               radiantorchid              #d6cadd

=item rainbow mist                 rainbowmist                #c7ada3

=item raisin                       raisin                     #43302e

=item rapture                      rapture                    #ab4e52

=item raspberry glace              raspberryglace             #915f6d

=item raven                        raven                      #222222

=item reed                         reed                       #dadfb7

=item reflection                   reflection                 #9cd1dc

=item regal orchid                 regalorchid                #b695c0

=item remote                       remote                     #5e716a

=item repose                       repose                     #8f9779

=item restrained blue              restrainedblue             #bcd4e6

=item retreat                      retreat                    #91a3b0

=item retreat                      retreat                    #81878b

=item rhapsody blue                rhapsodyblue               #36454f

=item rigi blue                    rigiblue                   #536878

=item rill                         rill                       #66ada4

=item rio blue                     rioblue                    #91a3b0

=item rio grande                   riogrande                  #c2b280

=item river mist                   rivermist                  #536878

=item river nile                   rivernile                  #317873

=item riviera                      riviera                    #436b95

=item rivulet blue                 rivuletblue                #66aabc

=item robin egg                    robinegg                   #96ded1

=item romance                      romance                    #e8ccd7

=item romance                      romance                    #9690ab

=item romance                      romance                    #796878

=item roman purple                 romanpurple                #50404d

=item roman purple                 romanpurple                #5d555b

=item roman rose                   romanrose                  #43302e

=item roman tan                    romantan                   #a87c6d

=item romantic blue                romanticblue               #a1caf1

=item romantic blue                romanticblue               #70a3cc

=item room green                   roomgreen                  #b2beb5

=item rosario                      rosario                    #d9a6a9

=item rosea                        rosea                      #efbbcc

=item rose ash                     roseash                    #eae3e1

=item rose ash                     roseash                    #ecd5c5

=item rose caroline                rosecaroline               #d9a6a9

=item rose castor                  rosecastor                 #905d5d

=item rose castor                  rosecastor                 #8f817f

=item rose cloud                   rosecloud                  #dea5a4

=item rose dust                    rosedust                   #ecd5c5

=item rose garden                  rosegarden                 #de6fa1

=item rose glory                   roseglory                  #e4717a

=item rose leaf                    roseleaf                   #ea9399

=item rose marie                   rosemarie                  #de6fa1

=item rose mist                    rosemist                   #ad8884

=item rose mist                    rosemist                   #c7ada3

=item rose morn                    rosemorn                   #f9ccca

=item rose morn                    rosemorn                   #ead8d7

=item rose morn                    rosemorn                   #f4c2c2

=item rose morn                    rosemorn                   #ecd5c5

=item rose muse                    rosemuse                   #c7ada3

=item rose nude                    rosenude                   #ecd5c5

=item rose pearl                   rosepearl                  #ead8d7

=item rose pearl                   rosepearl                  #ecd5c5

=item rose shadow                  roseshadow                 #ead8d7

=item rose shadow                  roseshadow                 #ecd5c5

=item rose smoke                   rosesmoke                  #ad8884

=item rose smoke                   rosesmoke                  #8f817f

=item rose stain                   rosestain                  #905d5d

=item rosy pink                    rosypink                   #f9ccca

=item royal lilac                  royallilac                 #86608e

=item royal robe                   royalrobe                  #2f2140

=item royal violet                 royalviolet                #673147

=item ruby lake                    rubylake                   #673147

=item ruffled petunia              ruffledpetunia             #e68fac

=item russet leaf                  russetleaf                 #a18f60

=item russet yellow                russetyellow               #c9ae5d

=item russian blue                 russianblue                #91a3b0

=item russian blue                 russianblue                #81878b

=item rust rose                    rustrose                   #ab4e52

=item sable                        sable                      #6f4e37

=item saga blue                    sagablue                   #91a3b0

=item sage                         sage                       #8a9a5b

=item sailor                       sailor                     #282022

=item salmon buff                  salmonbuff                 #d9a6a9

=item salmon flush                 salmonflush                #f4c2c2

=item salmon pink                  salmonpink                 #f4c2c2

=item salmon rose                  salmonrose                 #f88379

=item salome blue                  salomeblue                 #00a693

=item salome green                 salomegreen                #3eb489

=item salome green                 salomegreen                #8ed1b2

=item salome pink                  salomepink                 #ea9399

=item sandlewood                   sandlewood                 #a67b5b

=item sandrift                     sandrift                   #8e8279

=item sand stucco                  sandstucco                 #977f73

=item santa anita green            santaanitagreen            #66ada4

=item saxe blue                    saxeblue                   #367588

=item saxe blue                    saxeblue                   #536878

=item scarab                       scarab                     #317873

=item scarlet                      scarlet                    #e25822

=item scotch blue                  scotchblue                 #554c69

=item scotch mist                  scotchmist                 #b2beb5

=item scotch mist                  scotchmist                 #bfb8a5

=item scotch mist                  scotchmist                 #dadfb7

=item sea foam                     seafoam                    #f0ead6

=item sea foam                     seafoam                    #dfede8

=item sea fog                      seafog                     #d6cadd

=item sea fog                      seafog                     #bfb9bd

=item sea mist                     seamist                    #dadfb7

=item seance                       seance                     #e8ccd7

=item seclusion                    seclusion                  #4e5755

=item secret                       secret                     #796878

=item sentimental mood             sentimentalmood            #bcd4e6

=item sentimental mood             sentimentalmood            #c0c8e1

=item serene                       serene                     #ecd5c5

=item serenity                     serenity                   #d597ae

=item seville                      seville                    #8a9a5b

=item sevres                       sevres                     #00a1c2

=item sevres                       sevres                     #0067a5

=item shadow aqua                  shadowaqua                 #5e716a

=item shadow beige                 shadowbeige                #967117

=item shadow blue                  shadowblue                 #91a3b0

=item shadow green                 shadowgreen                #5e716a

=item shadow green                 shadowgreen                #3a4b47

=item shadow lilac                 shadowlilac                #796878

=item shadow lime                  shadowlime                 #c9dc89

=item shadow mauve                 shadowmauve                #796878

=item shadow olive                 shadowolive                #b9b57d

=item shamrock                     shamrock                   #44944a

=item shell coral                  shellcoral                 #f4c2c2

=item shell coral                  shellcoral                 #ecd5c5

=item shine                        shine                      #ebe8a4

=item shining                      shining                    #eae679

=item shore line                   shoreline                  #536878

=item shrimp pink                  shrimppink                 #f88379

=item siam sand                    siamsand                   #c2b280

=item sierra                       sierra                     #9e4732

=item sierra                       sierra                     #80461b

=item silent night                 silentnight                #5e716a

=item silver blue                  silverblue                 #bcd4e6

=item silver blue                  silverblue                 #c0c8e1

=item silver cloud                 silvercloud                #bcd4e6

=item silver cloud                 silvercloud                #b4bcc0

=item silver green                 silvergreen                #dadfb7

=item silver lining                silverlining               #bfb8a5

=item silver lining                silverlining               #b9b8b5

=item silver night                 silvernight                #aa98a9

=item silver pine                  silverpine                 #5e716a

=item silver pink                  silverpink                 #c4aead

=item silver pink                  silverpink                 #c7ada3

=item silver salmon                silversalmon               #c7ada3

=item silver sky                   silversky                  #e8e3e5

=item silver sky                   silversky                  #bfb9bd

=item silver wing                  silverwing                 #bfb9bd

=item silver wing                  silverwing                 #8b8589

=item singing blue                 singingblue                #239eba

=item singing blue                 singingblue                #66aabc

=item sky                          sky                        #8f9779

=item sky cloud                    skycloud                   #b4bcc0

=item sky green                    skygreen                   #96ded1

=item sky lane                     skylane                    #c7e6d7

=item slate                        slate                      #5d555b

=item slate                        slate                      #555555

=item slate blue                   slateblue                  #536878

=item slate blue                   slateblue                  #51585e

=item slate citron                 slatecitron                #8a9a5b

=item slate green                  slategreen                 #5e716a

=item slate orchid                 slateorchid                #796878

=item slate rose                   slaterose                  #905d5d

=item slate turquoise              slateturquoise             #367588

=item slate turquoise              slateturquoise             #536878

=item slate violet                 slateviolet                #796878

=item sleepy hollow                sleepyhollow               #8da399

=item sleepy hollow                sleepyhollow               #91a3b0

=item sleigh bells                 sleighbells                #9cd1dc

=item sleigh bells                 sleighbells                #bcd4e6

=item smile                        smile                      #f0ead6

=item smiles                       smiles                     #f4c2c2

=item smog                         smog                       #ae9b82

=item smoke                        smoke                      #91a3b0

=item smoke blue                   smokeblue                  #8c92ac

=item smoke pine                   smokepine                  #8f9779

=item smoke pine                   smokepine                  #b2beb5

=item smoke ring                   smokering                  #91a3b0

=item smokestain rose              smokestainrose             #ad8884

=item snow green                   snowgreen                  #c7e6d7

=item snow green                   snowgreen                  #bcd4e6

=item snow green                   snowgreen                  #b4bcc0

=item solitary                     solitary                   #dfede8

=item solitary                     solitary                   #b2beb5

=item solitary                     solitary                   #f2f3f4

=item solitary                     solitary                   #b9b8b5

=item solitary blue                solitaryblue               #536878

=item somber blue                  somberblue                 #536878

=item sonata                       sonata                     #f4c2c2

=item song of norway               songofnorway               #00a693

=item sophisticated lady           sophisticatedlady          #b695c0

=item sorcerer                     sorcerer                   #554c69

=item sorcerer                     sorcerer                   #796878

=item sorcerer                     sorcerer                   #36454f

=item sorcerer                     sorcerer                   #202830

=item sorcerer                     sorcerer                   #202428

=item sorrento                     sorrento                   #317873

=item southern rose                southernrose               #a87c6d

=item southern sun                 southernsun                #fada5e

=item southern sun                 southernsun                #f8de7e

=item souvenir                     souvenir                   #c4c3dd

=item sovereign blue               sovereignblue              #70a3cc

=item sovereign blue               sovereignblue              #8791bf

=item spanish blue                 spanishblue                #317873

=item spanish gold                 spanishgold                #e3a857

=item spanish white                spanishwhite               #fad6a5

=item sparkle                      sparkle                    #9cd1dc

=item sparrow                      sparrow                    #7e6d5a

=item spectra blue                 spectrablue                #30267a

=item spectra green                spectragreen               #004b49

=item spectra red                  spectrared                 #be0032

=item spectra rose                 spectrarose                #ce4676

=item spectra yellow               spectrayellow              #f3c300

=item spice                        spice                      #ae6938

=item spice                        spice                      #a67b5b

=item spiritual blue               spiritualblue              #bcd4e6

=item spitfire                     spitfire                   #ab4e52

=item spray                        spray                      #96ded1

=item spring                       spring                     #83d37d

=item spring bud                   springbud                  #c9dc89

=item spring dream                 springdream                #eae679

=item spring dream                 springdream                #ebe8a4

=item spring eve                   springeve                  #eae679

=item spring eve                   springeve                  #bdda57

=item spring eve                   springeve                  #c9dc89

=item spring flower                springflower               #e9e450

=item spring stream                springstream               #96ded1

=item spring yellow                springyellow               #f3e5ab

=item starch white                 starchwhite                #bcd4e6

=item static                       static                     #91a3b0

=item steam blue                   steamblue                  #e9e9ed

=item steel blue                   steelblue                  #66aabc

=item stellar                      stellar                    #efbbcc

=item sterling blue                sterlingblue               #91a3b0

=item sterling blue                sterlingblue               #b4bcc0

=item stoic                        stoic                      #222222

=item storm                        storm                      #536878

=item stormy night                 stormynight                #36454f

=item stratosphere                 stratosphere               #536878

=item stratosphere                 stratosphere               #51585e

=item straw yellow                 strawyellow                #f3e5ab

=item streamlet                    streamlet                  #96ded1

=item streamline                   streamline                 #96ded1

=item string                       string                     #f0ead6

=item style gray                   stylegray                  #536878

=item sublime                      sublime                    #91a3b0

=item sublime                      sublime                    #8c92ac

=item suet                         suet                       #f0ead6

=item suez blue                    suezblue                   #36454f

=item suez green                   suezgreen                  #317873

=item suggestion                   suggestion                 #96ded1

=item sulphate green               sulphategreen              #00a693

=item sulphate green               sulphategreen              #66ada4

=item sulphur                      sulphur                    #eae679

=item sultana                      sultana                    #905d5d

=item sultan sand                  sultansand                 #c19a6b

=item summer green                 summergreen                #3eb489

=item summer green                 summergreen                #8ed1b2

=item summer shower                summershower               #c7e6d7

=item summer sun                   summersun                  #e9e450

=item sunburst                     sunburst                   #fbc97f

=item sunburst                     sunburst                   #e3a857

=item sunburst                     sunburst                   #fad6a5

=item sundown                      sundown                    #f4c2c2

=item sundown                      sundown                    #d9a6a9

=item sundown                      sundown                    #fad6a5

=item sung green                   sunggreen                  #8f9779

=item sun glow                     sunglow                    #f8de7e

=item sun glow                     sunglow                    #f3e5ab

=item sun god                      sungod                     #d9603b

=item sun green                    sungreen                   #ebe8a4

=item sun rose                     sunrose                    #f9ccca

=item sunset cream                 sunsetcream                #f0ead6

=item sunshine                     sunshine                   #eae679

=item sun yellow                   sunyellow                  #e9e450

=item sun yellow                   sunyellow                  #eae679

=item superior                     superior                   #317873

=item supreme                      supreme                    #4997d0

=item surf spray                   surfspray                  #dfede8

=item surrender                    surrender                  #b695c0

=item sussanqua pink               sussanquapink              #ffc8d6

=item sussanqua pink               sussanquapink              #e68fac

=item swank                        swank                      #c4c3dd

=item swank                        swank                      #d6cadd

=item sweet blue                   sweetblue                  #bcd4e6

=item sweet lady                   sweetlady                  #8c82b6

=item sweet lavender               sweetlavender              #c4c3dd

=item sweet pea pink               sweetpeapink               #915f6d

=item swiss blue                   swissblue                  #8c92ac

=item swiss rose                   swissrose                  #905d5d

=item sylvan                       sylvan                     #dadfb7

=item tabu                         tabu                       #536878

=item talisman                     talisman                   #fab57f

=item talisman                     talisman                   #d99058

=item tangerine                    tangerine                  #d9603b

=item tangerine                    tangerine                  #ed872d

=item tango                        tango                      #e4717a

=item tapestry beige               tapestrybeige              #977f73

=item tapestry red                 tapestryred                #722f37

=item taupe rose                   tauperose                  #5c504f

=item taupe rose                   tauperose                  #674c47

=item taupe sand                   taupesand                  #967117

=item teal blue                    tealblue                   #367588

=item teen age pink                teenagepink                #efbbcc

=item television blue              televisionblue             #36454f

=item tempest                      tempest                    #50404d

=item tempest blue                 tempestblue                #51585e

=item temple                       temple                     #8f9779

=item temptation                   temptation                 #d6cadd

=item tete-a-tete                  teteatete                  #9cd1dc

=item thames river                 thamesriver                #91a3b0

=item thames river                 thamesriver                #b4bcc0

=item theatrical blue              theatricalblue             #436b95

=item thistle bloom                thistlebloom               #a8516e

=item thistle down                 thistledown                #e8ccd7

=item tobacco brown                tobaccobrown               #674c47

=item tomato red                   tomatored                  #be0032

=item topaz amber                  topazamber                 #d99058

=item torchlight                   torchlight                 #be0032

=item torchlight                   torchlight                 #bc3f4a

=item toreador                     toreador                   #bc3f4a

=item tourmaline green             tourmalinegreen            #c7e6d7

=item tourmaline green             tourmalinegreen            #96ded1

=item tourmaline pink              tourmalinepink             #ffc8d6

=item tourmaline pink              tourmalinepink             #efbbcc

=item trade winds                  tradewinds                 #536878

=item trail green                  trailgreen                 #1b4d3e

=item trail green                  trailgreen                 #3a4b47

=item tranquil green               tranquilgreen              #3a4b47

=item tranquil green               tranquilgreen              #36454f

=item transatlantic blue           transatlanticblue          #202830

=item translucent blue             translucentblue            #91a3b0

=item transparent yellow           transparentyellow          #f3e5ab

=item transparent yellow           transparentyellow          #f0ead6

=item trellis                      trellis                    #93c592

=item tropic night                 tropicnight                #836479

=item troubador                    troubador                  #be0032

=item troubador                    troubador                  #bc3f4a

=item tulip yellow                 tulipyellow                #fada5e

=item tumbleweed                   tumbleweed                 #f3e5ab

=item tumbleweed                   tumbleweed                 #bfb8a5

=item turf green                   turfgreen                  #44944a

=item turf green                   turfgreen                  #679267

=item turquoise blue               turquoiseblue              #66ada4

=item tuscan sand                  tuscansand                 #967117

=item twilight mood                twilightmood               #bcd4e6

=item twilight sun                 twilightsun                #f3e5ab

=item twilight sun                 twilightsun                #dadfb7

=item twinkle                      twinkle                    #bcd4e6

=item tyrian blue                  tyrianblue                 #536878

=item ultramarine                  ultramarine                #30267a

=item uniform blue                 uniformblue                #00304e

=item unique                       unique                     #ebe8a4

=item universal                    universal                  #36454f

=item vagabond                     vagabond                   #317873

=item valencia rose                valenciarose               #c08081

=item valor green                  valorgreen                 #36454f

=item vamp                         vamp                       #efbbcc

=item vanda                        vanda                      #aa8a9e

=item vanilla custard              vanillacustard             #f8de7e

=item vanilla custard              vanillacustard             #f3e5ab

=item vapor blue                   vaporblue                  #e9e9ed

=item vatican                      vatican                    #673147

=item veiled sun                   veiledsun                  #e3a857

=item veiled sun                   veiledsun                  #d4af37

=item venetian rose                venetianrose               #905d5d

=item venetian turquoise           venetianturquoise          #66ada4

=item venice                       venice                     #8da399

=item venice blue                  veniceblue                 #96ded1

=item venus blue                   venusblue                  #bcd4e6

=item venus blue                   venusblue                  #e9e9ed

=item verbena lavender             verbenalavender            #915c83

=item verbena lavender             verbenalavender            #915f6d

=item verdant                      verdant                    #8db600

=item verdugo                      verdugo                    #bdda57

=item verdugo                      verdugo                    #c9dc89

=item vermilion                    vermilion                  #d9603b

=item vesta                        vesta                      #ea9399

=item vesta                        vesta                      #f9ccca

=item vesta                        vesta                      #dea5a4

=item vibrant green                vibrantgreen               #83d37d

=item victoria                     victoria                   #f4c2c2

=item viking                       viking                     #36454f

=item viola                        viola                      #b695c0

=item violet leaf                  violetleaf                 #4a5d23

=item violet pansy                 violetpansy                #50404d

=item virginia lavender            virginialavender           #e8e3e5

=item vista green                  vistagreen                 #8f9779

=item vivid                        vivid                      #c17e91

=item vivid turquoise              vividturquoise             #007a74

=item wafted feather               waftedfeather              #e8e3e5

=item wafted feather               waftedfeather              #bfb9bd

=item walnut                       walnut                     #a67b5b

=item walnut cream                 walnutcream                #fad6a5

=item wan blue                     wanblue                    #e9e9ed

=item wan blue                     wanblue                    #e8e3e5

=item water fall                   waterfall                  #367588

=item water green                  watergreen                 #dadfb7

=item watteau                      watteau                    #66aabc

=item whimsical                    whimsical                  #b695c0

=item white clover                 whiteclover                #f0ead6

=item white fawn                   whitefawn                  #fad6a5

=item white jade                   whitejade                  #f4c2c2

=item white jade                   whitejade                  #ecd5c5

=item white light                  whitelight                 #bcd4e6

=item white mist                   whitemist                  #f4c2c2

=item white mist                   whitemist                  #ecd5c5

=item white smoke                  whitesmoke                 #b4bcc0

=item white swan                   whiteswan                  #bcd4e6

=item white swan                   whiteswan                  #c0c8e1

=item wild orchid                  wildorchid                 #b784a7

=item windflower                   windflower                 #915f6d

=item wineberry                    wineberry                  #796878

=item wineberry                    wineberry                  #50404d

=item winsome                      winsome                    #d6cadd

=item winsome blue                 winsomeblue                #66aabc

=item winter pear                  winterpear                 #8a9a5b

=item winter sky                   wintersky                  #bcd4e6

=item winter sun                   wintersun                  #eae679

=item winter white                 winterwhite                #e4717a

=item winter yellow                winteryellow               #f3e5ab

=item winter yellow                winteryellow               #c2b280

=item wisteria                     wisteria                   #8c82b6

=item wisteria gray                wisteriagray               #796878

=item wisteria mist                wisteriamist               #796878

=item withered rose                witheredrose               #905d5d

=item yale blue                    yaleblue                   #545aa7

=item yale blue                    yaleblue                   #272458

=item yale blue                    yaleblue                   #4e5180

=item yama                         yama                       #66ada4

=item yellow bright                yellowbright               #e9e450

=item yellow bright                yellowbright               #eae679

=item yellow cream                 yellowcream                #f3e5ab

=item yellow essence               yellowessence              #ebe8a4

=item yellow gem                   yellowgem                  #f3e5ab

=item yellow mist                  yellowmist                 #967117

=item yellow rose                  yellowrose                 #eae679

=item yellow smoke                 yellowsmoke                #c9ae5d

=item yellow smoke                 yellowsmoke                #ab9144

=item yew green                    yewgreen                   #515744

=item youth yellow                 youthyellow                #eae679

=item yuletime                     yuletime                   #4a5d23

=item yule tree                    yuletree                   #004b49

=item zephyr blue                  zephyrblue                 #bcd4e6

=item zephyr blue                  zephyrblue                 #91a3b0

=item zephyr green                 zephyrgreen                #c7e6d7

=item zest pink                    zestpink                   #ea9399

=item zinnia gold                  zinniagold                 #fbc97f

=item zinnia gold                  zinniagold                 #f8de7e


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-p:absintheyellow.87','absintheyellow','absinthe yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:abstractblue.184','abstractblue','abstract blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:abyss.149','abyss','abyss',[141,163,153],'8da399',9282457],
['nbs-iscc-p:acacia.150','acacia','acacia',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:acaciagray.155','acaciagray','acacia gray',[125,137,132],'7d8984',8227204],
['nbs-iscc-p:acaciagreen.155','acaciagreen','acacia green',[125,137,132],'7d8984',8227204],
['nbs-iscc-p:aden.144','aden','aden',[106,171,142],'6aab8e',6990734],
['nbs-iscc-p:admiral.229','admiral','admiral',[80,64,77],'50404d',5259341],
['nbs-iscc-p:africangreen.187','africangreen','african green',[54,69,79],'36454f',3556687],
['nbs-iscc-p:africannight.47','africannight','african night',[67,48,46],'43302e',4403246],
['nbs-iscc-p:afterglow.252','afterglow','after glow',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:ageanmist.154','ageanmist','agean mist',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:ageratum.253','ageratum','ageratum',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-p:aircastleblue.184','aircastleblue','air castle blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:airycream.263','airycream','airy cream',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-p:aladdinslamp.37','aladdinslamp','aladdin\'s lamp',[203,109,81],'cb6d51',13331793],
['nbs-iscc-p:algiersblue.173','algiersblue','algiers blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:allure.181','allure','allure',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:almond.76','almond','almond',[193,154,107],'c19a6b',12687979],
['nbs-iscc-p:almondcream.73','almondcream','almond cream',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:alpineblue.198','alpineblue','alpine blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-p:alpineblue.202','alpineblue','alpine blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:amaranth.259','amaranth','amaranth',[103,49,71],'673147',6762823],
['nbs-iscc-p:amaranth.262','amaranth','amaranth',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:ambercoral.29','ambercoral','amber coral',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:ambergold.76','ambergold','amber gold',[193,154,107],'c19a6b',12687979],
['nbs-iscc-p:ambergold.90','ambergold','amber gold',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:ambergold.91','ambergold','amber gold',[161,143,96],'a18f60',10588000],
['nbs-iscc-p:ambrosia.134','ambrosia','ambrosia',[182,229,175],'b6e5af',11986351],
['nbs-iscc-p:amethyst.245','amethyst','amethyst',[131,100,121],'836479',8610937],
['nbs-iscc-p:amethystorchid.222','amethystorchid','amethyst orchid',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:amulet.164','amulet','amulet',[49,120,115],'317873',3242099],
['nbs-iscc-p:ancestral.263','ancestral','ancestral',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-p:ancestral.264','ancestral','ancestral',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-p:angelblue.184','angelblue','angel blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:angelwing.249','angelwing','angel wing',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:angora.73','angora','angora',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:angora.92','angora','angora',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:antiquebrass.88','antiquebrass','antique brass',[171,145,68],'ab9144',11243844],
['nbs-iscc-p:antiquebronze.107','antiquebronze','antique bronze',[102,93,30],'665d1e',6708510],
['nbs-iscc-p:antiquefuchsia.241','antiquefuchsia','antique fuchsia',[145,92,131],'915c83',9526403],
['nbs-iscc-p:antiqueyellow.87','antiqueyellow','antique yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:applegreen.120','applegreen','apple green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:apricot.52','apricot','apricot',[250,181,127],'fab57f',16430463],
['nbs-iscc-p:apricotcream.73','apricotcream','apricot cream',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:apricotcream.89','apricotcream','apricot cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:apricotice.73','apricotice','apricot ice',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:apricotsherbet.70','apricotsherbet','apricot sherbet',[251,201,127],'fbc97f',16501119],
['nbs-iscc-p:apricottan.53','apricottan','apricot tan',[217,144,88],'d99058',14258264],
['nbs-iscc-p:apricottan.71','apricottan','apricot tan',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:aprilsky.162','aprilsky','april sky',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:aquagray.149','aquagray','aqua gray',[141,163,153],'8da399',9282457],
['nbs-iscc-p:aquamarinegreen.164','aquamarinegreen','aquamarine green',[49,120,115],'317873',3242099],
['nbs-iscc-p:aquaqueen.162','aquaqueen','aqua queen',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:aquasky.163','aquasky','aqua sky',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:arborgreen.136','arborgreen','arbor green',[103,146,103],'679267',6787687],
['nbs-iscc-p:arcadia.99','arcadia','arcadia',[190,183,46],'beb72e',12498734],
['nbs-iscc-p:arcadia.102','arcadia','arcadia',[185,180,89],'b9b459',12170329],
['nbs-iscc-p:arctic.186','arctic','arctic',[83,104,120],'536878',5466232],
['nbs-iscc-p:arctic.187','arctic','arctic',[54,69,79],'36454f',3556687],
['nbs-iscc-p:arnoblue.173','arnoblue','arno blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:ashesofroses.6','ashesofroses','ashes of roses ',[192,128,129],'c08081',12615809],
['nbs-iscc-p:ashesofroses.251','ashesofroses','ashes of roses ',[193,126,145],'c17e91',12680849],
['nbs-iscc-p:astheticblue.172','astheticblue','asthetic blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:atlantis.183','atlantis','atlantis',[0,48,78],'00304e',12366],
['nbs-iscc-p:atonement.227','atonement','atonement',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:aurorapink.247','aurorapink','aurora pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-p:aurorapink.250','aurorapink','aurora pink',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:aurorayellow.86','aurorayellow','aurora yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:autumnbrown.74','autumnbrown','autumn brown',[153,101,21],'996515',10052885],
['nbs-iscc-p:autumnbrown.95','autumnbrown','autumn brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-p:autumnglory.13','autumnglory','autumn glory',[132,27,45],'841b2d',8657709],
['nbs-iscc-p:autumnglory.38','autumnglory','autumn glory',[158,71,50],'9e4732',10372914],
['nbs-iscc-p:autumnglory.72','autumnglory','autumn glory',[190,138,61],'be8a3d',12487229],
['nbs-iscc-p:autumngold.72','autumngold','autumn gold ',[190,138,61],'be8a3d',12487229],
['nbs-iscc-p:autumntan.77','autumntan','autumn tan',[130,102,68],'826644',8545860],
['nbs-iscc-p:avon.155','avon','avon',[125,137,132],'7d8984',8227204],
['nbs-iscc-p:azalea.258','azalea','azalea',[168,81,110],'a8516e',11030894],
['nbs-iscc-p:azuriteblue.173','azuriteblue','azurite blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:azuriteblue.186','azuriteblue','azurite blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:babyblue.180','babyblue','baby blue',[161,202,241],'a1caf1',10603249],
['nbs-iscc-p:babyblueeyes.180','babyblueeyes','baby blue eyes',[161,202,241],'a1caf1',10603249],
['nbs-iscc-p:babyblueeyes.198','babyblueeyes','baby blue eyes',[179,188,226],'b3bce2',11779298],
['nbs-iscc-p:bagdad.19','bagdad','bagdad',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:balladblue.199','balladblue','ballad blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-p:ballerina.209','ballerina','ballerina',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-p:balmyair.184','balmyair','balmy air',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:balsamgreen.151','balsamgreen','balsam green ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:baltic.187','baltic','baltic ',[54,69,79],'36454f',3556687],
['nbs-iscc-p:baltic.267','baltic','baltic ',[34,34,34],'222222',2236962],
['nbs-iscc-p:banana.86','banana','banana',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:banshee.150','banshee','banshee',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:banshee.151','banshee','banshee',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:banshee.164','banshee','banshee',[49,120,115],'317873',3242099],
['nbs-iscc-p:banshee.165','banshee','banshee',[0,75,73],'004b49',19273],
['nbs-iscc-p:baronet.181','baronet','baronet',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:basic.165','basic','basic',[0,75,73],'004b49',19273],
['nbs-iscc-p:bathstone.73','bathstone','bath stone',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:bavarianblue.183','bavarianblue','bavarian blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:bayleaf.74','bayleaf','bay leaf',[153,101,21],'996515',10052885],
['nbs-iscc-p:bayou.187','bayou','bayou',[54,69,79],'36454f',3556687],
['nbs-iscc-p:bayou.267','bayou','bayou',[34,34,34],'222222',2236962],
['nbs-iscc-p:beaublue.184','beaublue','beau blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:beautiful.164','beautiful','beautiful',[49,120,115],'317873',3242099],
['nbs-iscc-p:beautypink.246','beautypink','beauty pink',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-p:beigegray.93','beigegray','beige gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:belladonna.223','belladonna','belladonna',[134,96,142],'86608e',8806542],
['nbs-iscc-p:bellflower.211','bellflower','bellflower',[96,78,129],'604e81',6311553],
['nbs-iscc-p:berylgreen.163','berylgreen','beryl green',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:besteffort.104','besteffort','best effort',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:besteffort.121','besteffort','best effort',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:bewitch.159','bewitch','bewitch',[0,166,147],'00a693',42643],
['nbs-iscc-p:bewitchingblue.181','bewitchingblue','bewitching blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:billiard.161','billiard','billiard',[0,68,63],'00443f',17471],
['nbs-iscc-p:billiard.165','billiard','billiard',[0,75,73],'004b49',19273],
['nbs-iscc-p:billow.184','billow','billow',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:birch.153','birch','birch',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:birdsegggreen.149','birdsegggreen','bird\'s-egg-green',[141,163,153],'8da399',9282457],
['nbs-iscc-p:birdsegggreen.163','birdsegggreen','bird\'s-egg-green',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:biscaybay.173','biscaybay','biscay bay',[54,117,136],'367588',3569032],
['nbs-iscc-p:biscaybay.186','biscaybay','biscay bay',[83,104,120],'536878',5466232],
['nbs-iscc-p:bishop.211','bishop','bishop',[96,78,129],'604e81',6311553],
['nbs-iscc-p:bison.95','bison','bison',[108,84,30],'6c541e',7099422],
['nbs-iscc-p:bisque.29','bisque','bisque',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:bisque.32','bisque','bisque',[199,173,163],'c7ada3',13086115],
['nbs-iscc-p:bittersweet.38','bittersweet','bittersweet',[158,71,50],'9e4732',10372914],
['nbs-iscc-p:bittersweetorange.35','bittersweetorange','bittersweet orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-p:bittersweetorange.50','bittersweetorange','bittersweet orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-p:blackberrycream.250','blackberrycream','blackberry cream',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:blackforest.127','blackforest','black forest',[81,87,68],'515744',5330756],
['nbs-iscc-p:blackknight.187','blackknight','black knight',[54,69,79],'36454f',3556687],
['nbs-iscc-p:blackknight.192','blackknight','black knight',[81,88,94],'51585e',5331038],
['nbs-iscc-p:blackwater.187','blackwater','black water',[39,36,88],'272458',2565208],
['nbs-iscc-p:blackwater.267','blackwater','black water',[34,34,34],'222222',2236962],
['nbs-iscc-p:blanch.162','blanch','blanch',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:blarney.139','blarney','blarney',[0,136,86],'008856',34902],
['nbs-iscc-p:blarney.141','blarney','blarney',[0,121,89],'007959',31065],
['nbs-iscc-p:blazeblue.186','blazeblue','blaze blue ',[83,104,120],'536878',5466232],
['nbs-iscc-p:blazeblue.187','blazeblue','blaze blue ',[54,69,79],'36454f',3556687],
['nbs-iscc-p:blend.121','blend','blend',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:blithe.168','blithe','blithe',[35,158,186],'239eba',2334394],
['nbs-iscc-p:blondegreen.153','blondegreen','blonde green',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:blossom.104','blossom','blossom',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:blueappeal.180','blueappeal','blue appeal',[161,202,241],'a1caf1',10603249],
['nbs-iscc-p:blueappeal.184','blueappeal','blue appeal',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:bluebell.199','bluebell','blue bell',[135,145,191],'8791bf',8884671],
['nbs-iscc-p:bluechill.184','bluechill','blue chill',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:bluedanube.169','bluedanube','blue danube',[0,119,145],'007791',30609],
['nbs-iscc-p:bluedash.186','bluedash','blue dash',[83,104,120],'536878',5466232],
['nbs-iscc-p:blueday.202','blueday','blue day',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:bluefog.186','bluefog','blue fog',[83,104,120],'536878',5466232],
['nbs-iscc-p:bluefog.191','bluefog','blue fog',[129,135,139],'81878b',8488843],
['nbs-iscc-p:blueglow.184','blueglow','blue glow',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:bluegrotto.172','bluegrotto','blue grotto',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:blueheaven.177','blueheaven','blue heaven',[73,151,208],'4997d0',4822992],
['nbs-iscc-p:blueheaven.180','blueheaven','blue heaven',[161,202,241],'a1caf1',10603249],
['nbs-iscc-p:blueheaven.181','blueheaven','blue heaven',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:bluehorizon.185','bluehorizon','blue horizon',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:bluehour.173','bluehour','blue hour',[54,117,136],'367588',3569032],
['nbs-iscc-p:blueidol.164','blueidol','blue idol',[49,120,115],'317873',3242099],
['nbs-iscc-p:bluelight.184','bluelight','blue light',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:bluelightning.178','bluelightning','blue lightning',[0,103,165],'0067a5',26533],
['nbs-iscc-p:bluemist.172','bluemist','blue mist',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:bluemist.185','bluemist','blue mist',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:blueprose.171','blueprose','blue prose',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:blueridge.180','blueridge','blue ridge',[161,202,241],'a1caf1',10603249],
['nbs-iscc-p:blueridge.198','blueridge','blue ridge',[179,188,226],'b3bce2',11779298],
['nbs-iscc-p:blueshadow.173','blueshadow','blue shadow',[54,117,136],'367588',3569032],
['nbs-iscc-p:bluespruce.145','bluespruce','blue spruce',[59,120,97],'3b7861',3897441],
['nbs-iscc-p:blueswirl.172','blueswirl','blue swirl',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:bluetease.171','bluetease','blue tease',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:blueturquoise.168','blueturquoise','blue turquoise',[35,158,186],'239eba',2334394],
['nbs-iscc-p:bluewaltz.148','bluewaltz','blue waltz ',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:bluewaltz.162','bluewaltz','blue waltz ',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:bluewash.189','bluewash','blue wash',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:blushrose.262','blushrose','blush rose',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:blushyellow.70','blushyellow','blush yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-p:blushyellow.73','blushyellow','blush yellow',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:bog.122','bog','bog',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:bohemianblue.182','bohemianblue','bohemian blue',[67,107,149],'436b95',4418453],
['nbs-iscc-p:bonnieblue.176','bonnieblue','bonnie blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-p:bonnieblue.194','bonnieblue','bonnie blue',[48,38,122],'30267a',3155578],
['nbs-iscc-p:bottlegreen.145','bottlegreen','bottle green',[59,120,97],'3b7861',3897441],
['nbs-iscc-p:bottlegreen.150','bottlegreen','bottle green',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:bougainvillea.254','bougainvillea','bougainvillea ',[206,70,118],'ce4676',13518454],
['nbs-iscc-p:boundingmain.181','boundingmain','bounding main',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:bouquetgreen.129','bouquetgreen','bouquet green',[39,166,76],'27a64c',2598476],
['nbs-iscc-p:bouquetgreen.130','bouquetgreen','bouquet green',[131,211,125],'83d37d',8639357],
['nbs-iscc-p:bouquetorchid.221','bouquetorchid','bouquet orchid',[213,186,219],'d5badb',14007003],
['nbs-iscc-p:bouquetorchid.226','bouquetorchid','bouquet orchid',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:bouquetyellow.86','bouquetyellow','bouquet yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:brass.88','brass','brass',[171,145,68],'ab9144',11243844],
['nbs-iscc-p:brazilred.38','brazilred','brazil red',[158,71,50],'9e4732',10372914],
['nbs-iscc-p:breathofspring.104','breathofspring','breath of spring',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:breathofspring.119','breathofspring','breath of spring',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:bridesmaidpink.249','bridesmaidpink','bridesmaid pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:brightsun.82','brightsun','bright sun',[243,195,0],'f3c300',15975168],
['nbs-iscc-p:brightsun.83','brightsun','bright sun',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:brilliantgreen.165','brilliantgreen','brilliant green',[0,75,73],'004b49',19273],
['nbs-iscc-p:bronzegold.84','bronzegold','bronze gold ',[212,175,55],'d4af37',13938487],
['nbs-iscc-p:bronzegold.87','bronzegold','bronze gold ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:bronzemist.106','bronzemist','bronze mist',[134,126,54],'867e36',8814134],
['nbs-iscc-p:bronzepink.29','bronzepink','bronze pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:bronzepink.53','bronzepink','bronze pink',[217,144,88],'d99058',14258264],
['nbs-iscc-p:bronzesheen.110','bronzesheen','bronze sheen',[91,88,66],'5b5842',5986370],
['nbs-iscc-p:bronzio.43','bronzio','bronzio',[121,68,59],'79443b',7947323],
['nbs-iscc-p:brookgreen.162','brookgreen','brook green',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:bruges.192','bruges','bruges',[81,88,94],'51585e',5331038],
['nbs-iscc-p:buccaneer.12','buccaneer','buccaneer',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-p:buckskintan.73','buckskintan','buckskin tan',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:buffcitron.90','buffcitron','buff citron',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:burntalmond.58','burntalmond','burnt almond',[111,78,55],'6f4e37',7294519],
['nbs-iscc-p:burntorange.50','burntorange','burnt orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-p:burntyellow.71','burntyellow','burnt yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:butterflyyellow.98','butterflyyellow','butterfly yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:butterflyyellow.101','butterflyyellow','butterfly yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:cabbage.148','cabbage','cabbage',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:caenstone.73','caenstone','caen stone',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:californiagold.71','californiagold','california gold',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:californiagreen.155','californiagreen','california green',[125,137,132],'7d8984',8227204],
['nbs-iscc-p:californiapoppy.68','californiapoppy','california poppy',[234,162,33],'eaa221',15376929],
['nbs-iscc-p:cameliapink.2','cameliapink','camelia pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:cameliapink.26','cameliapink','camelia pink',[248,131,121],'f88379',16286585],
['nbs-iscc-p:cameliarose.2','cameliarose','camelia rose',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:cameo.4','cameo','cameo',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:cameopink.2','cameopink','cameo pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:cameopink.249','cameopink','cameo pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:canarybronze.82','canarybronze','canary bronze',[243,195,0],'f3c300',15975168],
['nbs-iscc-p:canaryyellow.82','canaryyellow','canary yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-p:canaryyellow.83','canaryyellow','canary yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:candida.250','candida','candida',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:canton.164','canton','canton',[49,120,115],'317873',3242099],
['nbs-iscc-p:capricelavender.231','capricelavender','caprice lavender',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:capricepink.241','capricepink','caprice pink',[145,92,131],'915c83',9526403],
['nbs-iscc-p:capricepink.258','capricepink','caprice pink',[168,81,110],'a8516e',11030894],
['nbs-iscc-p:caramel.57','caramel','caramel',[166,123,91],'a67b5b',10910555],
['nbs-iscc-p:caramelcream.73','caramelcream','caramel cream',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:caravan.45','caravan','caravan',[151,127,115],'977f73',9928563],
['nbs-iscc-p:carnivalred.11','carnivalred','carnival red',[190,0,50],'be0032',12451890],
['nbs-iscc-p:castilianblue.178','castilianblue','castilian blue',[0,103,165],'0067a5',26533],
['nbs-iscc-p:cathedral.225','cathedral','cathedral',[48,25,52],'301934',3152180],
['nbs-iscc-p:cathedral.230','cathedral','cathedral',[41,30,41],'291e29',2694697],
['nbs-iscc-p:cedar.120','cedar','cedar',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:cedarbough.120','cedarbough','cedar bough',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:celestialblue.177','celestialblue','celestial blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-p:celestialblue.195','celestialblue','celestial blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-p:celestialyellow.86','celestialyellow','celestial yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:celestialyellow.89','celestialyellow','celestial yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:ceramic.173','ceramic','ceramic',[54,117,136],'367588',3569032],
['nbs-iscc-p:ceramic.182','ceramic','ceramic',[67,107,149],'436b95',4418453],
['nbs-iscc-p:ceres.86','ceres','ceres',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:cerisepink.255','cerisepink','cerise pink',[179,68,108],'b3446c',11748460],
['nbs-iscc-p:ceriserose.3','ceriserose','cerise rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-p:ceylonblue.186','ceylonblue','ceylon blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:chalkviolet.210','chalkviolet','chalk violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-p:chalkviolet.214','chalkviolet','chalk violet',[150,144,171],'9690ab',9867435],
['nbs-iscc-p:chamoisyellow.71','chamoisyellow','chamois yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:chamoisyellow.76','chamoisyellow','chamois yellow',[193,154,107],'c19a6b',12687979],
['nbs-iscc-p:champagne.89','champagne','champagne',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:champagnebuff.89','champagnebuff','champagne buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:chantilly.144','chantilly','chantilly',[106,171,142],'6aab8e',6990734],
['nbs-iscc-p:charcoal.62','charcoal','charcoal',[62,50,44],'3e322c',4076076],
['nbs-iscc-p:charcoal.267','charcoal','charcoal',[34,34,34],'222222',2236962],
['nbs-iscc-p:charm.2','charm','charm',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:charm.4','charm','charm',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:charm.249','charm','charm',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:charm.171','charm','charm',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:charmpink.247','charmpink','charm pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-p:charmschool.244','charmschool','charm school',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-p:charmschool.261','charmschool','charm school',[175,134,142],'af868e',11503246],
['nbs-iscc-p:chartreusegreen.115','chartreusegreen','chartreuse green',[141,182,0],'8db600',9287168],
['nbs-iscc-p:chartreusegreen.116','chartreusegreen','chartreuse green',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:chartreuseyellow.98','chartreuseyellow','chartreuse yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:chaste.263','chaste','chaste',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-p:chateau.172','chateau','chateau',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:cheddarcheese.71','cheddarcheese','cheddar cheese',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:cheer.82','cheer','cheer',[243,195,0],'f3c300',15975168],
['nbs-iscc-p:cheerfulyellow.89','cheerfulyellow','cheerful yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:cheerfulyellow.92','cheerfulyellow','cheerful yellow',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:chelseayellow.101','chelseayellow','chelsea yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:chelseayellow.104','chelseayellow','chelsea yellow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:cherry.11','cherry','cherry',[190,0,50],'be0032',12451890],
['nbs-iscc-p:chili.159','chili','chili ',[0,166,147],'00a693',42643],
['nbs-iscc-p:chinapink.248','chinapink','china pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:chinapink.255','chinapink','china pink',[179,68,108],'b3446c',11748460],
['nbs-iscc-p:chinarose.19','chinarose','china rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:chinasea.172','chinasea','china sea',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:chive.125','chive','chive',[74,93,35],'4a5d23',4873507],
['nbs-iscc-p:chive.137','chive','chive',[53,94,59],'355e3b',3497531],
['nbs-iscc-p:christmasgreen.151','christmasgreen','christmas green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:chrysanthemumyelllow.82','chrysanthemumyelllow','chrysanthemum yelllow',[243,195,0],'f3c300',15975168],
['nbs-iscc-p:chrysolitegreen.120','chrysolitegreen','chrysolite green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:cinderella.83','cinderella','cinderella',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:cineraria.262','cineraria','cineraria',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:cinnamon.54','cinnamon','cinnamon',[174,105,56],'ae6938',11430200],
['nbs-iscc-p:cinnamoncream.31','cinnamoncream','cinnamon cream',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:citronbronze.95','citronbronze','citron bronze',[108,84,30],'6c541e',7099422],
['nbs-iscc-p:citrongray.94','citrongray','citron gray',[150,113,23],'967117',9859351],
['nbs-iscc-p:citrongray.109','citrongray','citron gray',[140,135,103],'8c8767',9209703],
['nbs-iscc-p:citronyellow.86','citronyellow','citron yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:citronyellow.87','citronyellow','citron yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:citronyellow.101','citronyellow','citron yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:citronyellow.102','citronyellow','citron yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-p:classicblue.169','classicblue','classic blue',[0,119,145],'007791',30609],
['nbs-iscc-p:classicblue.182','classicblue','classic blue',[67,107,149],'436b95',4418453],
['nbs-iscc-p:clementine.249','clementine','clementine',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:cleopatra.148','cleopatra','cleopatra',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:clivia.53','clivia','clivia',[217,144,88],'d99058',14258264],
['nbs-iscc-p:cloister.148','cloister','cloister',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:cloister.184','cloister','cloister',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:cloudcream.89','cloudcream','cloud cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:cloudcream.92','cloudcream','cloud cream',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:cloudgray.226','cloudgray','cloud gray',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:cloudyblue.184','cloudyblue','cloudy blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:clover.251','clover','clover',[193,126,145],'c17e91',12680849],
['nbs-iscc-p:cocoabronze.106','cocoabronze','cocoa bronze',[134,126,54],'867e36',8814134],
['nbs-iscc-p:cocoabrown.57','cocoabrown','cocoa brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-p:coldmorn.214','coldmorn','cold morn',[150,144,171],'9690ab',9867435],
['nbs-iscc-p:coldmorn.227','coldmorn','cold morn',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:colonialblue.183','colonialblue','colonial blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:colonialcream.89','colonialcream','colonial cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:colonialexteriorgreen.145','colonialexteriorgreen','colonial exterior green',[59,120,97],'3b7861',3897441],
['nbs-iscc-p:conclude.92','conclude','conclude',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:congo.43','congo','congo',[121,68,59],'79443b',7947323],
['nbs-iscc-p:congoblue.186','congoblue','congo blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:congobrown.55','congobrown','congo brown',[128,70,27],'80461b',8406555],
['nbs-iscc-p:congobrown.58','congobrown','congo brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-p:conifer.127','conifer','conifer',[81,87,68],'515744',5330756],
['nbs-iscc-p:continentalblue.234','continentalblue','continental blue',[93,85,91],'5d555b',6116699],
['nbs-iscc-p:cooleve.149','cooleve','cool eve',[141,163,153],'8da399',9282457],
['nbs-iscc-p:copper.37','copper','copper',[203,109,81],'cb6d51',13331793],
['nbs-iscc-p:copperbronze.54','copperbronze','copper bronze',[174,105,56],'ae6938',11430200],
['nbs-iscc-p:coppercream.31','coppercream','copper cream',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:coquette.252','coquette','coquette',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:coral.3','coral','coral',[228,113,122],'e4717a',14971258],
['nbs-iscc-p:coralblush.4','coralblush','coral blush',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:coralblush.28','coralblush','coral blush',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:coralcloud.28','coralcloud','coral cloud',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:coralgold.37','coralgold','coral gold',[203,109,81],'cb6d51',13331793],
['nbs-iscc-p:coralpink.26','coralpink','coral pink',[248,131,121],'f88379',16286585],
['nbs-iscc-p:coralrose.3','coralrose','coral rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-p:coronation.259','coronation','coronation',[103,49,71],'673147',6762823],
['nbs-iscc-p:coronetblue.182','coronetblue','coronet blue',[67,107,149],'436b95',4418453],
['nbs-iscc-p:corsagepink.252','corsagepink','corsage pink',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:corsair.187','corsair','corsair',[54,69,79],'36454f',3556687],
['nbs-iscc-p:corydalis.119','corydalis','corydalis',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:corydalis.121','corydalis','corydalis',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:cosmicblue.182','cosmicblue','cosmic blue',[67,107,149],'436b95',4418453],
['nbs-iscc-p:cosmospink.221','cosmospink','cosmos pink',[213,186,219],'d5badb',14007003],
['nbs-iscc-p:cosmospink.226','cosmospink','cosmos pink',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:cowslip.52','cowslip','cowslip',[250,181,127],'fab57f',16430463],
['nbs-iscc-p:crabpink.4','crabpink','crab pink',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:crabpink.7','crabpink','crab pink',[234,216,215],'ead8d7',15390935],
['nbs-iscc-p:cream.92','cream','cream',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:creamblush.73','creamblush','cream blush',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:creamchant.104','creamchant','cream chant',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:creamcheese.92','creamcheese','cream cheese',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:creamdelight.104','creamdelight','cream delight',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:creamdream.92','creamdream','cream dream',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:creamgold.86','creamgold','cream gold',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:creampearl.92','creampearl','cream pearl',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:creamtone.89','creamtone','cream tone',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:creamtone.92','creamtone','cream tone',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:creamwhite.92','creamwhite','cream white',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:creamyellow.89','creamyellow','cream yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:creolepink.31','creolepink','creole pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:crest.159','crest','crest',[0,166,147],'00a693',42643],
['nbs-iscc-p:crimsonglory.11','crimsonglory','crimson glory',[190,0,50],'be0032',12451890],
['nbs-iscc-p:crispblue.171','crispblue','crisp blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:crocusrose.249','crocusrose','crocus rose',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:cruiseblue.173','cruiseblue','cruise blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:cruiseblue.182','cruiseblue','cruise blue',[67,107,149],'436b95',4418453],
['nbs-iscc-p:crystalblue.168','crystalblue','crystal blue',[35,158,186],'239eba',2334394],
['nbs-iscc-p:crystalblue.171','crystalblue','crystal blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:cubanorchid.240','cubanorchid','cuban orchid',[183,132,167],'b784a7',12027047],
['nbs-iscc-p:cubanorchid.250','cubanorchid','cuban orchid',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:cubansand.87','cubansand','cuban sand',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:cubansand.88','cubansand','cuban sand',[171,145,68],'ab9144',11243844],
['nbs-iscc-p:cuddleblue.184','cuddleblue','cuddle blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:cuddleblue.185','cuddleblue','cuddle blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:cupidblue.171','cupidblue','cupid blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:cyanblue.173','cyanblue','cyan blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:cypress.136','cypress','cypress',[103,146,103],'679267',6787687],
['nbs-iscc-p:daphnepink.251','daphnepink','daphne pink',[193,126,145],'c17e91',12680849],
['nbs-iscc-p:darkforest.151','darkforest','dark forest',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:darkfuchsia.237','darkfuchsia','dark fuchsia',[158,79,136],'9e4f88',10375048],
['nbs-iscc-p:dawnglow.226','dawnglow','dawn glow',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:dawnglow.252','dawnglow','dawn glow',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:dawnpink.249','dawnpink','dawn pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:daybreak.227','daybreak','daybreak',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:daydream.214','daydream','day dream',[150,144,171],'9690ab',9867435],
['nbs-iscc-p:dazzleblue.169','dazzleblue','dazzle blue',[0,119,145],'007791',30609],
['nbs-iscc-p:debonair.185','debonair','debonair',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:debutanteblue.171','debutanteblue','debutante blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:debutanteblue.184','debutanteblue','debutante blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:debutantepink.2','debutantepink','debutante pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:debutanteyellow.101','debutanteyellow','debutante yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:deephelleborered.262','deephelleborered','deep hellebore red ',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:deeppurple.229','deeppurple','deep purple',[80,64,77],'50404d',5259341],
['nbs-iscc-p:deeppurple.230','deeppurple','deep purple',[41,30,41],'291e29',2694697],
['nbs-iscc-p:deeppurple.235','deeppurple','deep purple',[36,33,36],'242124',2367780],
['nbs-iscc-p:deepravine.95','deepravine','deep ravine',[108,84,30],'6c541e',7099422],
['nbs-iscc-p:deepreverie.234','deepreverie','deep reverie',[93,85,91],'5d555b',6116699],
['nbs-iscc-p:deepsea.164','deepsea','deep sea',[49,120,115],'317873',3242099],
['nbs-iscc-p:deeptwilight.63','deeptwilight','deep twilight',[142,130,121],'8e8279',9339513],
['nbs-iscc-p:deepviolet.211','deepviolet','deep violet',[96,78,129],'604e81',6311553],
['nbs-iscc-p:deepviolet.212','deepviolet','deep violet',[47,33,64],'2f2140',3088704],
['nbs-iscc-p:deepwater.182','deepwater','deep water',[67,107,149],'436b95',4418453],
['nbs-iscc-p:delectable.168','delectable','delectable',[35,158,186],'239eba',2334394],
['nbs-iscc-p:delectable.172','delectable','delectable',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:delectable.181','delectable','delectable',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:delight.226','delight','delight',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:delmonte.228','delmonte','del monte',[121,104,120],'796878',7956600],
['nbs-iscc-p:delta.173','delta','delta',[54,117,136],'367588',3569032],
['nbs-iscc-p:delusion.171','delusion','delusion ',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:demonblue.192','demonblue','demon blue',[81,88,94],'51585e',5331038],
['nbs-iscc-p:demureblue.184','demureblue','demure blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:depthgreen.151','depthgreen','depth green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:desertbrown.4','desertbrown','desert brown',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:desertdust.89','desertdust','desert dust',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:desertdust.92','desertdust','desert dust',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:desertglass.222','desertglass','desert glass',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:desertmist.73','desertmist','desert mist',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:desertpalm.110','desertpalm','desert palm',[91,88,66],'5b5842',5986370],
['nbs-iscc-p:desertpride.121','desertpride','desert pride',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:desertsand.76','desertsand','desert sand',[193,154,107],'c19a6b',12687979],
['nbs-iscc-p:desirable.148','desirable','desirable',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:desire.221','desire','desire',[213,186,219],'d5badb',14007003],
['nbs-iscc-p:dewkist.154','dewkist','dewkist ',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:dewkist.264','dewkist','dewkist ',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-p:diadem.244','diadem','diadem',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-p:dignity.5','dignity','dignity',[222,165,164],'dea5a4',14591396],
['nbs-iscc-p:dignity.249','dignity','dignity',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:dignity.252','dignity','dignity',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:distinction.262','distinction','distinction',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:divablue.194','divablue','diva blue',[48,38,122],'30267a',3155578],
['nbs-iscc-p:divablue.195','divablue','diva blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-p:divineblue.181','divineblue','divine blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:dollyvarden.4','dollyvarden','dolly varden',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:dovegray.232','dovegray','dove gray',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-p:dovegray.253','dovegray','dove gray',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-p:drabolive.120','drabolive','drab olive',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:dreamblue.180','dreamblue','dream blue',[161,202,241],'a1caf1',10603249],
['nbs-iscc-p:dreamcream.121','dreamcream','dream cream',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:dreamfluff.231','dreamfluff','dream fluff',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:dreamstuff.249','dreamstuff','dream stuff',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:dreamyblue.185','dreamyblue','dreamy blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:driedleaf.86','driedleaf','dried leaf',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:drizzle.154','drizzle','drizzle',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:dryad.163','dryad','dryad',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:dryadrose.31','dryadrose','dryad rose ',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:dubarryblue.159','dubarryblue','du barry blue',[0,166,147],'00a693',42643],
['nbs-iscc-p:ducklingblue.186','ducklingblue','duckling blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:ducklingblue.187','ducklingblue','duckling blue',[54,69,79],'36454f',3556687],
['nbs-iscc-p:duskyblue.185','duskyblue','dusky blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:duskycitron.120','duskycitron','dusky citron',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:duskygreen.122','duskygreen','dusky green',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:dustygreen.120','dustygreen','dusty green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:dustygreen.122','dustygreen','dusty green',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:dutchcream.73','dutchcream','dutch cream',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:dutchcream.92','dutchcream','dutch cream',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:dynastygreen.160','dynastygreen','dynasty green',[0,122,116],'007a74',31348],
['nbs-iscc-p:earthbrown.58','earthbrown','earth brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-p:easterbonnet.184','easterbonnet','easter bonnet',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:eastereggyellow.86','eastereggyellow','easter egg yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:ecru.89','ecru','ecru',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:ecrucream.89','ecrucream','ecru cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:ecrucream.92','ecrucream','ecru cream',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:eerieblue.184','eerieblue','eerie blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:eggplant.229','eggplant','egg plant ',[80,64,77],'50404d',5259341],
['nbs-iscc-p:eggplant.230','eggplant','egg plant ',[41,30,41],'291e29',2694697],
['nbs-iscc-p:eggshell.73','eggshell','egg shell',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:eggshell.89','eggshell','egg shell',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:egyptianred.16','egyptianred','egyptian red',[114,47,55],'722f37',7483191],
['nbs-iscc-p:eighteenthcenturycitron.120','eighteenthcenturycitron','eighteenth century citron',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:eighteenthcenturygreen.122','eighteenthcenturygreen','eighteenth century green',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:eighteenthcenturytan.18','eighteenthcenturytan','eighteenth century tan',[173,136,132],'ad8884',11372676],
['nbs-iscc-p:eighteenthcenturyturquoise.173','eighteenthcenturyturquoise','eighteenth century turquoise',[54,117,136],'367588',3569032],
['nbs-iscc-p:eighteenthcenturyturquoise.186','eighteenthcenturyturquoise','eighteenth century turquoise',[83,104,120],'536878',5466232],
['nbs-iscc-p:eighteenthcenturyviolet.245','eighteenthcenturyviolet','eighteenth century violet',[131,100,121],'836479',8610937],
['nbs-iscc-p:eighteenthcenturyyellow.90','eighteenthcenturyyellow','eighteenth century yellow',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:electra.162','electra','electra',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:elfgreen.149','elfgreen','elf green',[141,163,153],'8da399',9282457],
['nbs-iscc-p:elfgreen.163','elfgreen','elf green',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:elm.122','elm','elm',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:emeraldgreen.134','emeraldgreen','emerald green',[182,229,175],'b6e5af',11986351],
['nbs-iscc-p:emeraldisle.139','emeraldisle','emerald isle',[0,136,86],'008856',34902],
['nbs-iscc-p:empireyellow.82','empireyellow','empire yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-p:empireyellow.83','empireyellow','empire yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:empiricalblue.163','empiricalblue','empirical blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:enchantress.37','enchantress','enchantress',[203,109,81],'cb6d51',13331793],
['nbs-iscc-p:enduring.163','enduring','enduring',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:enduring.172','enduring','enduring',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:englishmist.155','englishmist','english mist',[125,137,132],'7d8984',8227204],
['nbs-iscc-p:erie.164','erie','erie',[49,120,115],'317873',3242099],
['nbs-iscc-p:etherialgreen.119','etherialgreen','etherial green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:etherialgreen.121','etherialgreen','etherial green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:eucalyptusgreen.122','eucalyptusgreen','eucalyptus green ',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:evegreen.130','evegreen','eve green',[131,211,125],'83d37d',8639357],
['nbs-iscc-p:evegreen.131','evegreen','eve green',[68,148,74],'44944a',4494410],
['nbs-iscc-p:eveningglow.4','eveningglow','evening glow',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:eveninghaze.5','eveninghaze','evening haze',[222,165,164],'dea5a4',14591396],
['nbs-iscc-p:eventide.253','eventide','eventide',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-p:everglade.267','everglade','everglade',[34,34,34],'222222',2236962],
['nbs-iscc-p:fable.231','fable','fable',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:fairygold.101','fairygold','fairy gold',[234,230,121],'eae679',15394425],
['nbs-iscc-p:fairyland.148','fairyland','fairy land ',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:fairyland.162','fairyland','fairy land ',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:fairyprincess.189','fairyprincess','fairy princess',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:falcon.64','falcon','falcon',[91,80,79],'5b504f',5984335],
['nbs-iscc-p:fallblue.185','fallblue','fall blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:fallblue.203','fallblue','fall blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-p:fallbronze.88','fallbronze','fall bronze',[171,145,68],'ab9144',11243844],
['nbs-iscc-p:fallleaf.86','fallleaf','fall leaf',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:fallleaf.87','fallleaf','fall leaf',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:fallyellow.86','fallyellow','fall yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:fallyellow.87','fallyellow','fall yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:fancyfree.148','fancyfree','fancy free',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:fanfare.169','fanfare','fanfare',[0,119,145],'007791',30609],
['nbs-iscc-p:fantasia.148','fantasia','fantasia',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:fantasyrose.32','fantasyrose','fantasy rose',[199,173,163],'c7ada3',13086115],
['nbs-iscc-p:fantasyyellow.89','fantasyyellow','fantasy yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:farhorizon.156','farhorizon','far horizon',[78,87,85],'4e5755',5134165],
['nbs-iscc-p:favorite.149','favorite','favorite',[141,163,153],'8da399',9282457],
['nbs-iscc-p:ferndell.137','ferndell','ferndell',[53,94,59],'355e3b',3497531],
['nbs-iscc-p:fernery.146','fernery','fernery',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-p:ferngreen.120','ferngreen','fern green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:fernlane.148','fernlane','fern lane ',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:festival.140','festival','festival',[62,180,137],'3eb489',4109449],
['nbs-iscc-p:festival.159','festival','festival',[0,166,147],'00a693',42643],
['nbs-iscc-p:festivegreen.129','festivegreen','festive green',[39,166,76],'27a64c',2598476],
['nbs-iscc-p:festivegreen.130','festivegreen','festive green',[131,211,125],'83d37d',8639357],
['nbs-iscc-p:festoon.140','festoon','festoon',[62,180,137],'3eb489',4109449],
['nbs-iscc-p:fidelity.202','fidelity','fidelity',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:finesse.32','finesse','finesse',[199,173,163],'c7ada3',13086115],
['nbs-iscc-p:firecracker.35','firecracker','firecracker',[217,96,59],'d9603b',14245947],
['nbs-iscc-p:firefly.3','firefly','fire fly ',[228,113,122],'e4717a',14971258],
['nbs-iscc-p:firgreen.120','firgreen','fir green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:firmamentblue.196','firmamentblue','firmament blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-p:firmamentgray.184','firmamentgray','firmament gray',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:firmamentgray.189','firmamentgray','firmament gray',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:firstlady.240','firstlady','first lady',[183,132,167],'b784a7',12027047],
['nbs-iscc-p:firstlady.248','firstlady','first lady',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:flame.11','flame','flame',[190,0,50],'be0032',12451890],
['nbs-iscc-p:flame.12','flame','flame',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-p:flamingopink.2','flamingopink','flamingo pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:flash.12','flash','flash',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-p:flaxflowerblue.195','flaxflowerblue','flax flower blue ',[108,121,184],'6c79b8',7109048],
['nbs-iscc-p:flemishblue.186','flemishblue','flemish blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:fleshcream.31','fleshcream','flesh cream',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:fleshcream.73','fleshcream','flesh cream',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:fleshpink.31','fleshpink','flesh pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:fleshtint.28','fleshtint','flesh tint',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:fleshtint.31','fleshtint','flesh tint',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:flint.23','flint','flint',[92,80,79],'5c504f',6049871],
['nbs-iscc-p:flirtation.227','flirtation','flirtation',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:flowerlet.119','flowerlet','flowerlet',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:fogblue.203','fogblue','fog blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-p:foggreen.149','foggreen','fog green',[141,163,153],'8da399',9282457],
['nbs-iscc-p:fogyellow.91','fogyellow','fog yellow',[161,143,96],'a18f60',10588000],
['nbs-iscc-p:foliage.117','foliage','foliage',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-p:forestshade.136','forestshade','forest shade',[103,146,103],'679267',6787687],
['nbs-iscc-p:fortune.206','fortune','fortune',[126,115,184],'7e73b8',8287160],
['nbs-iscc-p:fountainblue.202','fountainblue','fountain blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:fountaingreen.130','fountaingreen','fountain green',[131,211,125],'83d37d',8639357],
['nbs-iscc-p:fountaingreen.134','fountaingreen','fountain green',[182,229,175],'b6e5af',11986351],
['nbs-iscc-p:fourleafclover.137','fourleafclover','four-leaf clover',[53,94,59],'355e3b',3497531],
['nbs-iscc-p:frenchbeige.57','frenchbeige','french beige',[166,123,91],'a67b5b',10910555],
['nbs-iscc-p:frenchblue.199','frenchblue','french blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-p:frenchlilac.245','frenchlilac','french lilac',[131,100,121],'836479',8610937],
['nbs-iscc-p:frenchnude.29','frenchnude','french nude',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:frostynight.189','frostynight','frosty night',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:froth.92','froth','froth',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:frozendew.184','frozendew','frozen dew',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:fuchsia.12','fuchsia','fuchsia',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-p:fuchsia.255','fuchsia','fuchsia',[179,68,108],'b3446c',11748460],
['nbs-iscc-p:fuchsiapink.247','fuchsiapink','fuchsia pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-p:fuchsiapink.248','fuchsiapink','fuchsia pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:fuchsiapink.248','fuchsiapink','fuchsia pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:fuchsiapink.250','fuchsiapink','fuchsia pink',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:fuchsiarose.254','fuchsiarose','fuchsia rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-p:fuchsiarose.255','fuchsiarose','fuchsia rose',[179,68,108],'b3446c',11748460],
['nbs-iscc-p:galecloud.192','galecloud','gale cloud',[81,88,94],'51585e',5331038],
['nbs-iscc-p:galewinds.192','galewinds','gale winds',[81,88,94],'51585e',5331038],
['nbs-iscc-p:gardenpool.148','gardenpool','garden pool',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:garnetrose.16','garnetrose','garnet rose',[114,47,55],'722f37',7483191],
['nbs-iscc-p:gayyellow.98','gayyellow','gay yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:gayyellow.101','gayyellow','gay yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:genevablue.183','genevablue','geneva blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:genevablue.204','genevablue','geneva blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-p:ghostlyblue.184','ghostlyblue','ghostly blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:ghostlyblue.202','ghostlyblue','ghostly blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:gleam.101','gleam','gleam',[234,230,121],'eae679',15394425],
['nbs-iscc-p:glintogold.86','glintogold','glint o\'gold',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:glintogold.87','glintogold','glint o\'gold',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:glorygreen.116','glorygreen','glory green',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:glorygreenblue.164','glorygreenblue','glory green-blue',[49,120,115],'317873',3242099],
['nbs-iscc-p:goldcoast.88','goldcoast','gold coast',[171,145,68],'ab9144',11243844],
['nbs-iscc-p:goldenapricot.52','goldenapricot','golden apricot',[250,181,127],'fab57f',16430463],
['nbs-iscc-p:goldenapricot.53','goldenapricot','golden apricot',[217,144,88],'d99058',14258264],
['nbs-iscc-p:goldenbrown.54','goldenbrown','golden brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-p:goldenbuff.86','goldenbuff','golden buff',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:goldencream.86','goldencream','golden cream',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:goldendawn.86','goldendawn','golden dawn',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:goldenfleece.73','goldenfleece','golden fleece',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:goldenfleece.89','goldenfleece','golden fleece',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:goldenfleece.90','goldenfleece','golden fleece',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:goldengem.86','goldengem','golden gem',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:goldenglow.83','goldenglow','golden glow',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:goldenmist.105','goldenmist','golden mist',[185,181,125],'b9b57d',12170621],
['nbs-iscc-p:goldenmist.119','goldenmist','golden mist',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:goldenmist.121','goldenmist','golden mist',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:goldenpeach.71','goldenpeach','golden peach',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:goldenrapture.83','goldenrapture','golden rapture',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:goldenray.83','goldenray','golden ray',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:goldenray.86','goldenray','golden ray',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:goldenrod.83','goldenrod','golden rod',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:goldensheaf.89','goldensheaf','golden sheaf',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:goldensulphur.101','goldensulphur','golden sulphur',[234,230,121],'eae679',15394425],
['nbs-iscc-p:goldentan.53','goldentan','golden tan',[217,144,88],'d99058',14258264],
['nbs-iscc-p:goldenwest.72','goldenwest','golden west',[190,138,61],'be8a3d',12487229],
['nbs-iscc-p:goldenyellow.86','goldenyellow','golden yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:goldfantasy.83','goldfantasy','gold fantasy',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:goldglow.101','goldglow','gold glow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:goldglow.104','goldglow','gold glow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:goldpheasant.54','goldpheasant','gold pheasant',[174,105,56],'ae6938',11430200],
['nbs-iscc-p:goldrush.71','goldrush','gold rush',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:goodomen.210','goodomen','good omen',[140,130,182],'8c82b6',9208502],
['nbs-iscc-p:goodomen.181','goodomen','good omen',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:gorge.154','gorge','gorge',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:gorge.264','gorge','gorge',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-p:graciousgreen.148','graciousgreen','gracious green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:grandcanyon.42','grandcanyon','grand canyon',[168,124,109],'a87c6d',11041901],
['nbs-iscc-p:grandcanyon.57','grandcanyon','grand canyon',[166,123,91],'a67b5b',10910555],
['nbs-iscc-p:graniteblue.186','graniteblue','granite blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:granitegreen.149','granitegreen','granite green',[141,163,153],'8da399',9282457],
['nbs-iscc-p:grape.212','grape','grape',[47,33,64],'2f2140',3088704],
['nbs-iscc-p:grape.229','grape','grape',[80,64,77],'50404d',5259341],
['nbs-iscc-p:grapefruitgreen.98','grapefruitgreen','grapefruit green',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:grapefruitgreen.99','grapefruitgreen','grapefruit green',[190,183,46],'beb72e',12498734],
['nbs-iscc-p:grapefruitgreen.101','grapefruitgreen','grapefruit green',[234,230,121],'eae679',15394425],
['nbs-iscc-p:grapefruitgreen.102','grapefruitgreen','grapefruit green',[185,180,89],'b9b459',12170329],
['nbs-iscc-p:grapegreen.120','grapegreen','grape green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:gravel.33','gravel','gravel',[194,172,153],'c2ac99',12758169],
['nbs-iscc-p:gravel.79','gravel','gravel',[174,155,130],'ae9b82',11443074],
['nbs-iscc-p:gravel.93','gravel','gravel',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:grayblue.190','grayblue','gray blue',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:graydream.92','graydream','gray dream',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:graydream.93','graydream','gray dream',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:graydrift.184','graydrift','gray drift',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:graydrift.190','graydrift','gray drift',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:graygreen.150','graygreen','gray green',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:graylady.190','graylady','gray lady',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:graylight.10','graylight','gray light',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-p:graylight.264','graylight','gray light',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-p:graymist.185','graymist','gray mist',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:graymist.190','graymist','gray mist',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:graymood.234','graymood','gray mood',[93,85,91],'5d555b',6116699],
['nbs-iscc-p:graymorn.63','graymorn','gray morn',[142,130,121],'8e8279',9339513],
['nbs-iscc-p:graynight.186','graynight','gray night',[83,104,120],'536878',5466232],
['nbs-iscc-p:graysand.90','graysand','gray sand',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:graysand.93','graysand','gray sand',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:grecianrose.26','grecianrose','grecian rose',[248,131,121],'f88379',16286585],
['nbs-iscc-p:grecianrose.29','grecianrose','grecian rose',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:greenbanana.102','greenbanana','green banana',[185,180,89],'b9b459',12170329],
['nbs-iscc-p:greenbanana.105','greenbanana','green banana',[185,181,125],'b9b57d',12170621],
['nbs-iscc-p:greenblack.151','greenblack','green black',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:greenblack.156','greenblack','green black',[78,87,85],'4e5755',5134165],
['nbs-iscc-p:greenblack.266','greenblack','green black',[85,85,85],'555555',5592405],
['nbs-iscc-p:greenblack.267','greenblack','green black',[34,34,34],'222222',2236962],
['nbs-iscc-p:greenbreath.92','greenbreath','green breath',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:greencharm.101','greencharm','green charm',[234,230,121],'eae679',15394425],
['nbs-iscc-p:greencharm.119','greencharm','green charm',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:greendream.162','greendream','green dream',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:greenery.115','greenery','greenery',[141,182,0],'8db600',9287168],
['nbs-iscc-p:greenery.117','greenery','greenery',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-p:greeneyes.136','greeneyes','green eyes',[103,146,103],'679267',6787687],
['nbs-iscc-p:greenfog.122','greenfog','green fog',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:greenglory.160','greenglory','green glory',[0,122,116],'007a74',31348],
['nbs-iscc-p:greenglory.164','greenglory','green glory',[49,120,115],'317873',3242099],
['nbs-iscc-p:greenglow.148','greenglow','green glow',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:greengrass.120','greengrass','green grass',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:greenhaze.122','greenhaze','green haze',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:greenice.92','greenice','green ice',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:greenice.153','greenice','green ice',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:greenlily.148','greenlily','green lily',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:greenmatrix.165','greenmatrix','green matrix',[0,75,73],'004b49',19273],
['nbs-iscc-p:greenmist.122','greenmist','green mist',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:greenmoss.120','greenmoss','green moss',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:greenoasis.103','greenoasis','green oasis',[152,148,62],'98943e',9999422],
['nbs-iscc-p:greenoasis.117','greenoasis','green oasis',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-p:greenolive.120','greenolive','green olive ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:greenpride.119','greenpride','green pride',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:greenravine.150','greenravine','green ravine',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:greenrivermist.154','greenrivermist','green river mist',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:greenslate.157','greenslate','green slate',[30,35,33],'1e2321',1975073],
['nbs-iscc-p:greenspring.117','greenspring','green spring',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-p:greenstone.121','greenstone','green stone',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:greensulphur.102','greensulphur','green sulphur',[185,180,89],'b9b459',12170329],
['nbs-iscc-p:greentea.136','greentea','green tea',[103,146,103],'679267',6787687],
['nbs-iscc-p:greentee.120','greentee','green tee ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:growthgreen.116','growthgreen','growth green',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:guineagreen.164','guineagreen','guinea green',[49,120,115],'317873',3242099],
['nbs-iscc-p:gullgray.233','gullgray','gull gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-p:gumdropgreen.119','gumdropgreen','gumdrop green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:gunmetal.64','gunmetal','gun metal',[91,80,79],'5b504f',5984335],
['nbs-iscc-p:gypsy.55','gypsy','gypsy',[128,70,27],'80461b',8406555],
['nbs-iscc-p:hanginggarden.129','hanginggarden','hanging garden',[39,166,76],'27a64c',2598476],
['nbs-iscc-p:hansayellow.82','hansayellow','hansa yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-p:happyday.104','happyday','happy day',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:happyday.121','happyday','happy day',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:harborblue.184','harborblue','harbor blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:haremblue.184','haremblue','harem blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:harmoniousblue.186','harmoniousblue','harmonious blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:harvestgold.86','harvestgold','harvest gold',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:hawkbrown.95','hawkbrown','hawk brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-p:heartsdesire.15','heartsdesire','heart\'s desire',[171,78,82],'ab4e52',11226706],
['nbs-iscc-p:heavenlycharm.92','heavenlycharm','heavenly charm',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:heavenlyday.104','heavenlyday','heavenly day',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:heavenlyflower.177','heavenlyflower','heavenly flower',[73,151,208],'4997d0',4822992],
['nbs-iscc-p:heavenlygreen.119','heavenlygreen','heavenly green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:heavenlyorchid.252','heavenlyorchid','heavenly orchid',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:heavenlypink.4','heavenlypink','heavenly pink',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:heliotrope.238','heliotrope','heliotrope',[112,41,99],'702963',7350627],
['nbs-iscc-p:heliotrope.242','heliotrope','heliotrope',[93,57,84],'5d3954',6109524],
['nbs-iscc-p:heliotropegray.227','heliotropegray','heliotrope gray',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:heliotropegray.244','heliotropegray','heliotrope gray',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-p:heliotropegray.253','heliotropegray','heliotrope gray',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-p:hemlock.135','hemlock','hemlock',[147,197,146],'93c592',9684370],
['nbs-iscc-p:hemp.90','hemp','hemp',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:hiawathagreen.164','hiawathagreen','hiawatha green',[49,120,115],'317873',3242099],
['nbs-iscc-p:highland.151','highland','highland',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:holiday.162','holiday','holiday',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:hollandblue.185','hollandblue','holland blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:honeybeige.29','honeybeige','honey beige',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:horizon.185','horizon','horizon',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:hortensia.224','hortensia','hortensia',[86,60,92],'563c5c',5651548],
['nbs-iscc-p:hortensia.242','hortensia','hortensia',[93,57,84],'5d3954',6109524],
['nbs-iscc-p:huckleberry.229','huckleberry','huckleberry',[80,64,77],'50404d',5259341],
['nbs-iscc-p:huron.163','huron','huron',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:hussar.204','hussar','hussar',[76,81,109],'4c516d',5001581],
['nbs-iscc-p:iceberggreen.149','iceberggreen','iceberg green',[141,163,153],'8da399',9282457],
['nbs-iscc-p:iceberggreen.185','iceberggreen','iceberg green',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:iceboat.159','iceboat','ice boat',[0,166,147],'00a693',42643],
['nbs-iscc-p:icecap.172','icecap','ice cap',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:iceflow.148','iceflow','ice flow',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:icelandblue.184','icelandblue','iceland blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:icygreen.163','icygreen','icy green',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:icymorn.143','icymorn','icy morn',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-p:icymorn.148','icymorn','icy morn',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:ideal.171','ideal','ideal',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:illusion.184','illusion','illusion',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:illusion.190','illusion','illusion',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:illusive.226','illusive','illusive',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:independence.212','independence','independence',[47,33,64],'2f2140',3088704],
['nbs-iscc-p:independence.224','independence','independence',[86,60,92],'563c5c',5651548],
['nbs-iscc-p:independence.229','independence','independence',[80,64,77],'50404d',5259341],
['nbs-iscc-p:indianred.38','indianred','indian red',[158,71,50],'9e4732',10372914],
['nbs-iscc-p:inkblue.183','inkblue','ink blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:inkblue.187','inkblue','ink blue',[54,69,79],'36454f',3556687],
['nbs-iscc-p:inspiration.148','inspiration','inspiration',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:intimatemood.261','intimatemood','intimate mood',[175,134,142],'af868e',11503246],
['nbs-iscc-p:ionianblue.183','ionianblue','ionian blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:ionianblue.187','ionianblue','ionian blue',[54,69,79],'36454f',3556687],
['nbs-iscc-p:irishisle.129','irishisle','irish isle',[39,166,76],'27a64c',2598476],
['nbs-iscc-p:irisleaf.127','irisleaf','iris leaf',[81,87,68],'515744',5330756],
['nbs-iscc-p:irisorchid.247','irisorchid','iris orchid',[230,143,172],'e68fac',15110060],
['nbs-iscc-p:irisorchid.248','irisorchid','iris orchid',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:ironmask.187','ironmask','iron mask',[54,69,79],'36454f',3556687],
['nbs-iscc-p:ironmask.267','ironmask','iron mask',[34,34,34],'222222',2236962],
['nbs-iscc-p:irresistible.255','irresistible','irresistible',[179,68,108],'b3446c',11748460],
['nbs-iscc-p:islandgreen.143','islandgreen','island green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-p:italianblue.172','italianblue','italian blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:ivory.89','ivory','ivory',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:ivorywhite.89','ivorywhite','ivory white',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:jadecream.104','jadecream','jade cream',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:jadelime.116','jadelime','jade lime',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:jasper.151','jasper','jasper',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:jasper.267','jasper','jasper',[34,34,34],'222222',2236962],
['nbs-iscc-p:jealousy.143','jealousy','jealousy',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-p:jerseycream.89','jerseycream','jersey cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:jewelblue.172','jewelblue','jewel blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:jewelgreen.164','jewelgreen','jewel green',[49,120,115],'317873',3242099],
['nbs-iscc-p:joy.135','joy','joy',[147,197,146],'93c592',9684370],
['nbs-iscc-p:junebud.116','junebud','june bud',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:junebud.130','junebud','june bud',[131,211,125],'83d37d',8639357],
['nbs-iscc-p:junegreen.119','junegreen','june green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:jungle.151','jungle','jungle',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:juniper.150','juniper','juniper',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:juniper.151','juniper','juniper',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:kaffa.46','kaffa','kaffa',[103,76,71],'674c47',6769735],
['nbs-iscc-p:killarneygreen.139','killarneygreen','killarney green ',[0,136,86],'008856',34902],
['nbs-iscc-p:kinglear.211','kinglear','king lear',[96,78,129],'604e81',6311553],
['nbs-iscc-p:kingneptune.181','kingneptune','king neptune',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:kingsransom.53','kingsransom','king\'s ransom',[217,144,88],'d99058',14258264],
['nbs-iscc-p:kittensear.89','kittensear','kitten\'s ear',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:ladyorchid.262','ladyorchid','lady orchid',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:lagoon.164','lagoon','lagoon',[49,120,115],'317873',3242099],
['nbs-iscc-p:lakeblue.178','lakeblue','lake blue',[0,103,165],'0067a5',26533],
['nbs-iscc-p:lakecomo.182','lakecomo','lake como',[67,107,149],'436b95',4418453],
['nbs-iscc-p:lakelouise.182','lakelouise','lake louise',[67,107,149],'436b95',4418453],
['nbs-iscc-p:lambswool.92','lambswool','lamb\'s wool',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:lamer.143','lamer','la mer',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-p:languidlavender.213','languidlavender','languid lavender',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-p:languidlavender.226','languidlavender','languid lavender',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:larkspurblue.181','larkspurblue','larkspur blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:larkspurpurple.207','larkspurpurple','larkspur purple',[96,78,151],'604e97',6311575],
['nbs-iscc-p:lava.81','lava','lava',[72,60,50],'483c32',4734002],
['nbs-iscc-p:lava.96','lava','lava',[59,49,33],'3b3121',3879201],
['nbs-iscc-p:leafgreen.129','leafgreen','leaf green',[39,166,76],'27a64c',2598476],
['nbs-iscc-p:lettucegreen.117','lettucegreen','lettuce green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-p:lifegreen.125','lifegreen','life green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-p:lighthearted.104','lighthearted','light hearted',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:lightmauve.5','lightmauve','light mauve',[222,165,164],'dea5a4',14591396],
['nbs-iscc-p:lightmauve.250','lightmauve','light mauve',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:lightoak.76','lightoak','light oak',[193,154,107],'c19a6b',12687979],
['nbs-iscc-p:lightoldrose.26','lightoldrose','light old rose',[248,131,121],'f88379',16286585],
['nbs-iscc-p:lilac.222','lilac','lilac',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:lilacgray.228','lilacgray','lilac gray',[121,104,120],'796878',7956600],
['nbs-iscc-p:lilachint.226','lilachint','lilac hint',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:lilaclavender.214','lilaclavender','lilac lavender',[150,144,171],'9690ab',9867435],
['nbs-iscc-p:lilacshadow.224','lilacshadow','lilac shadow',[86,60,92],'563c5c',5651548],
['nbs-iscc-p:lilacshadow.228','lilacshadow','lilac shadow',[121,104,120],'796878',7956600],
['nbs-iscc-p:liltinggreen.159','liltinggreen','lilting green',[0,166,147],'00a693',42643],
['nbs-iscc-p:lilygreen.105','lilygreen','lily green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-p:lilygreen.119','lilygreen','lily green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:limecream.119','limecream','lime cream',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:limeyellow.98','limeyellow','lime yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:limeyellow.99','limeyellow','lime yellow',[190,183,46],'beb72e',12498734],
['nbs-iscc-p:limeyellow.116','limeyellow','lime yellow',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:londonfog.233','londonfog','london fog',[139,133,137],'8b8589',9143689],
['nbs-iscc-p:lovebird.116','lovebird','love bird',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:lovelight.101','lovelight','love light',[234,230,121],'eae679',15394425],
['nbs-iscc-p:lovely.144','lovely','lovely',[106,171,142],'6aab8e',6990734],
['nbs-iscc-p:loversknot.249','loversknot','lover\'s knot',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:loversnote.184','loversnote','lover\'s note',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:lucerneblue.199','lucerneblue','lucerne blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-p:lullaby.153','lullaby','lullaby',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:lullaby.154','lullaby','lullaby',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:lullaby.263','lullaby','lullaby',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-p:lullaby.264','lullaby','lullaby',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-p:lushgray.164','lushgray','lush gray',[49,120,115],'317873',3242099],
['nbs-iscc-p:lushgreen.140','lushgreen','lush green',[62,180,137],'3eb489',4109449],
['nbs-iscc-p:lustrousyellow.101','lustrousyellow','lustrous yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:lyonsblue.194','lyonsblue','lyons blue',[48,38,122],'30267a',3155578],
['nbs-iscc-p:lyonsblue.196','lyonsblue','lyons blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-p:lyreblue.173','lyreblue','lyre blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:magenta.258','magenta','magenta',[168,81,110],'a8516e',11030894],
['nbs-iscc-p:magentarose.259','magentarose','magenta rose',[103,49,71],'673147',6762823],
['nbs-iscc-p:magical.231','magical','magical',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:magicmoon.172','magicmoon','magic moon',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:magicmoon.185','magicmoon','magic moon',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:maidoforleans.221','maidoforleans','maid of orleans',[213,186,219],'d5badb',14007003],
['nbs-iscc-p:maidoforleans.226','maidoforleans','maid of orleans',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:majolica.183','majolica','majolica',[0,48,78],'00304e',12366],
['nbs-iscc-p:mandarinorange.35','mandarinorange','mandarin orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-p:mandarinorange.50','mandarinorange','mandarin orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-p:marble.151','marble','marble',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:marcopolo.173','marcopolo','marco polo',[54,117,136],'367588',3569032],
['nbs-iscc-p:marineblue.173','marineblue','marine blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:marineblue.174','marineblue','marine blue',[0,73,88],'004958',18776],
['nbs-iscc-p:marinecorpsblue.183','marinecorpsblue','marine corps blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:marineglow.148','marineglow','marine glow',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:marketgreen.148','marketgreen','market green ',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:martinique.102','martinique','martinique',[185,180,89],'b9b459',12170329],
['nbs-iscc-p:mauvedecade.262','mauvedecade','mauve decade',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:mauvemist.253','mauvemist','mauve mist',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-p:mauveorchid.261','mauveorchid','mauve orchid',[175,134,142],'af868e',11503246],
['nbs-iscc-p:mauvetaupe.262','mauvetaupe','mauve taupe',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:mauvette.252','mauvette','mauvette',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:mayflower.248','mayflower','mayflower',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:mayflower.251','mayflower','mayflower',[193,126,145],'c17e91',12680849],
['nbs-iscc-p:meadowgreen.140','meadowgreen','meadow green',[62,180,137],'3eb489',4109449],
['nbs-iscc-p:meadowgreen.144','meadowgreen','meadow green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-p:meadowmist.149','meadowmist','meadow mist',[141,163,153],'8da399',9282457],
['nbs-iscc-p:mellowbuff.73','mellowbuff','mellow buff',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:mellowbuff.89','mellowbuff','mellow buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:mellowgreen.101','mellowgreen','mellow green',[234,230,121],'eae679',15394425],
['nbs-iscc-p:mellowmauve.262','mellowmauve','mellow mauve',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:mellowmood.227','mellowmood','mellow mood',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:mellowyellow.86','mellowyellow','mellow yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:mellowyellow.89','mellowyellow','mellow yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:mellowyellow.101','mellowyellow','mellow yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:mellowyellow.104','mellowyellow','mellow yellow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:melodious.185','melodious','melodious',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:memorylane.153','memorylane','memory lane ',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:merrygreen.139','merrygreen','merry green ',[0,136,86],'008856',34902],
['nbs-iscc-p:midnight.183','midnight','midnight ',[0,48,78],'00304e',12366],
['nbs-iscc-p:midnight.187','midnight','midnight ',[54,69,79],'36454f',3556687],
['nbs-iscc-p:midnightbronze.10','midnightbronze','midnight bronze ',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-p:midseason.226','midseason','midseason ',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:mignonette.120','mignonette','mignonette ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:milanoblue.186','milanoblue','milano blue ',[83,104,120],'536878',5466232],
['nbs-iscc-p:milanoblue.203','milanoblue','milano blue ',[140,146,172],'8c92ac',9212588],
['nbs-iscc-p:milkygreen.153','milkygreen','milky green ',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:mincemeat.46','mincemeat','mince meat ',[103,76,71],'674c47',6769735],
['nbs-iscc-p:ming.141','ming','ming ',[0,121,89],'007959',31065],
['nbs-iscc-p:mintlime.135','mintlime','mint lime ',[147,197,146],'93c592',9684370],
['nbs-iscc-p:mintlime.148','mintlime','mint lime ',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:missionwhite.31','missionwhite','mission white ',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:missionwhite.73','missionwhite','mission white ',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:mistedyellow.87','mistedyellow','misted yellow ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:mistletoe.120','mistletoe','mistletoe ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:mistletoe.122','mistletoe','mistletoe ',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:mistycream.89','mistycream','misty cream ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:mistycream.92','mistycream','misty cream ',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:mistygreen.122','mistygreen','misty green ',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:mistyjade.101','mistyjade','misty jade ',[234,230,121],'eae679',15394425],
['nbs-iscc-p:mistyjade.104','mistyjade','misty jade ',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:mistyjade.119','mistyjade','misty jade ',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:mistylilac.222','mistylilac','misty lilac ',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:mistylilac.227','mistylilac','misty lilac ',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:mistymorn.92','mistymorn','misty morn ',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:mistymorn.153','mistymorn','misty morn ',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:mistymorn.263','mistymorn','misty morn ',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-p:mistyrose.31','mistyrose','misty rose ',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:modest.154','modest','modest ',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:mogul.210','mogul','mogul ',[140,130,182],'8c82b6',9208502],
['nbs-iscc-p:mohawk.43','mohawk','mohawk ',[121,68,59],'79443b',7947323],
['nbs-iscc-p:mohawktrail.151','mohawktrail','mohawk trail ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:monaco.163','monaco','monaco ',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:monastralblue.183','monastralblue','monastral blue ',[0,48,78],'00304e',12366],
['nbs-iscc-p:monastralblue.200','monastralblue','monastral blue ',[78,81,128],'4e5180',5132672],
['nbs-iscc-p:monsignor.237','monsignor','monsignor ',[158,79,136],'9e4f88',10375048],
['nbs-iscc-p:monticellogreen.137','monticellogreen','monticello green ',[53,94,59],'355e3b',3497531],
['nbs-iscc-p:monticellorose.29','monticellorose','monticello rose ',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:montroseyellow.116','montroseyellow','montrose yellow ',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:moodbeige.90','moodbeige','mood beige ',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:moodlilac.223','moodlilac','mood lilac ',[134,96,142],'86608e',8806542],
['nbs-iscc-p:moodviolet.228','moodviolet','mood violet ',[121,104,120],'796878',7956600],
['nbs-iscc-p:moonbeam.232','moonbeam','moonbeam ',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-p:moonlight.31','moonlight','moonlight ',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:moonlightbay.162','moonlightbay','moonlight bay ',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:moonlitblue.184','moonlitblue','moonlit blue ',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:moonlitblue.190','moonlitblue','moonlit blue ',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:moonlitwater.185','moonlitwater','moonlit water ',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:moonlitwater.203','moonlitwater','moonlit water ',[140,146,172],'8c92ac',9212588],
['nbs-iscc-p:moonmist.10','moonmist','moonmist ',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-p:morningglory.248','morningglory','morning glory ',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:morningmist.33','morningmist','morning mist ',[194,172,153],'c2ac99',12758169],
['nbs-iscc-p:moth.93','moth','moth ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:moth.121','moth','moth ',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:mountainhaze.5','mountainhaze','mountain haze ',[222,165,164],'dea5a4',14591396],
['nbs-iscc-p:mountainpeakblue.184','mountainpeakblue','mountain peak blue ',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:mountaintop.127','mountaintop','mountain top ',[81,87,68],'515744',5330756],
['nbs-iscc-p:mountaintop.128','mountaintop','mountain top ',[49,54,43],'31362b',3225131],
['nbs-iscc-p:mulberry.228','mulberry','mulberry ',[121,104,120],'796878',7956600],
['nbs-iscc-p:murmur.89','murmur','murmur ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:murmur.93','murmur','murmur ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:muse.119','muse','muse ',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:mushroom.89','mushroom','mushroom ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:mushroom.92','mushroom','mushroom ',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:mustard.88','mustard','mustard ',[171,145,68],'ab9144',11243844],
['nbs-iscc-p:mustardcream.86','mustardcream','mustard cream ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:mustardcream.89','mustardcream','mustard cream ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:mutedyellow.86','mutedyellow','muted yellow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:mutedyellow.101','mutedyellow','muted yellow ',[234,230,121],'eae679',15394425],
['nbs-iscc-p:myrtlegreen.150','myrtlegreen','myrtle green ',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:mysticblue.184','mysticblue','mystic blue ',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:mysticpurple.241','mysticpurple','mystic purple ',[145,92,131],'915c83',9526403],
['nbs-iscc-p:mysticwhite.189','mysticwhite','mystic white ',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:myth.226','myth','myth ',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:mythblue.186','mythblue','myth blue ',[83,104,120],'536878',5466232],
['nbs-iscc-p:mythblue.192','mythblue','myth blue ',[81,88,94],'51585e',5331038],
['nbs-iscc-p:nabob.151','nabob','nabob ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:nabob.187','nabob','nabob ',[54,69,79],'36454f',3556687],
['nbs-iscc-p:nabob.192','nabob','nabob ',[81,88,94],'51585e',5331038],
['nbs-iscc-p:naid.159','naid','naid ',[0,166,147],'00a693',42643],
['nbs-iscc-p:naid.162','naid','naid ',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:naid.163','naid','naid ',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:naive.153','naive','naive ',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:napoleon.197','napoleon','napoleon ',[39,36,88],'272458',2565208],
['nbs-iscc-p:nasturtium.67','nasturtium','nasturtium ',[255,193,79],'ffc14f',16761167],
['nbs-iscc-p:nasturtiumbuff.71','nasturtiumbuff','nasturtium buff ',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:nativeblue.165','nativeblue','native blue',[0,75,73],'004b49',19273],
['nbs-iscc-p:neonblue.168','neonblue','neon blue',[35,158,186],'239eba',2334394],
['nbs-iscc-p:neopolitannight.182','neopolitannight','neopolitan night ',[67,107,149],'436b95',4418453],
['nbs-iscc-p:neopolitannight.200','neopolitannight','neopolitan night ',[78,81,128],'4e5180',5132672],
['nbs-iscc-p:neutral.89','neutral','neutral',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:neutral.92','neutral','neutral',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:newblue.189','newblue','new blue',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:niagara.168','niagara','niagara',[35,158,186],'239eba',2334394],
['nbs-iscc-p:nightblue.174','nightblue','night blue',[0,73,88],'004958',18776],
['nbs-iscc-p:nightcloud.189','nightcloud','night cloud',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:nightfighter.192','nightfighter','night fighter',[81,88,94],'51585e',5331038],
['nbs-iscc-p:nightfighter.234','nightfighter','night fighter',[93,85,91],'5d555b',6116699],
['nbs-iscc-p:nightfighter.266','nightfighter','night fighter',[85,85,85],'555555',5592405],
['nbs-iscc-p:nighthorizon.193','nighthorizon','night horizon',[32,36,40],'202428',2106408],
['nbs-iscc-p:nighthorizon.267','nighthorizon','night horizon',[34,34,34],'222222',2236962],
['nbs-iscc-p:nightmagic.227','nightmagic','night magic',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:nightshade.229','nightshade','nightshade',[80,64,77],'50404d',5259341],
['nbs-iscc-p:nightshade.234','nightshade','nightshade',[93,85,91],'5d555b',6116699],
['nbs-iscc-p:nightwatch.152','nightwatch','night watch',[26,36,33],'1a2421',1713185],
['nbs-iscc-p:nil.263','nil','nil',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-p:nocturne.232','nocturne','nocturne',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-p:noel.151','noel','noel',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:nomadbrown.62','nomadbrown','nomad brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-p:norseblue.177','norseblue','norse blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-p:norseblue.195','norseblue','norse blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-p:northblue.169','northblue','north blue',[0,119,145],'007791',30609],
['nbs-iscc-p:northernskies.184','northernskies','northern skies',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:northgreen.150','northgreen','north green',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:northgreen.164','northgreen','north green',[49,120,115],'317873',3242099],
['nbs-iscc-p:northsea.192','northsea','north sea',[81,88,94],'51585e',5331038],
['nbs-iscc-p:norwaypine.136','norwaypine','norway pine',[103,146,103],'679267',6787687],
['nbs-iscc-p:nubianbrown.61','nubianbrown','nubian brown',[99,81,71],'635147',6508871],
['nbs-iscc-p:nymphpink.250','nymphpink','nymph pink',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:oakleaf.127','oakleaf','oak leaf',[81,87,68],'515744',5330756],
['nbs-iscc-p:oceanwave.163','oceanwave','ocean wave',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:octoroonrose.19','octoroonrose','octoroon rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:octoroonrose.45','octoroonrose','octoroon rose',[151,127,115],'977f73',9928563],
['nbs-iscc-p:oldcoral.15','oldcoral','old coral',[171,78,82],'ab4e52',11226706],
['nbs-iscc-p:oldgold.68','oldgold','old gold',[234,162,33],'eaa221',15376929],
['nbs-iscc-p:oldgold.71','oldgold','old gold',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:oldgold.84','oldgold','old gold',[212,175,55],'d4af37',13938487],
['nbs-iscc-p:oldlavender.226','oldlavender','old lavender',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:oldmastergreen.127','oldmastergreen','old master green',[81,87,68],'515744',5330756],
['nbs-iscc-p:oldrose.6','oldrose','old rose',[192,128,129],'c08081',12615809],
['nbs-iscc-p:oliveglow.104','oliveglow','olive glow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:oliveglow.121','oliveglow','olive glow',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:olivehint.104','olivehint','olive hint',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:olivehint.121','olivehint','olive hint',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:ombre.187','ombre','ombre',[54,69,79],'36454f',3556687],
['nbs-iscc-p:ombre.267','ombre','ombre',[34,34,34],'222222',2236962],
['nbs-iscc-p:opalgreen.164','opalgreen','opal green',[49,120,115],'317873',3242099],
['nbs-iscc-p:operablue.183','operablue','opera blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:operablue.200','operablue','opera blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-p:operamauve.240','operamauve','opera mauve',[183,132,167],'b784a7',12027047],
['nbs-iscc-p:operapink.28','operapink','opera pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:orange.50','orange','orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-p:orangeblush.73','orangeblush','orange blush',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:orangecream.89','orangecream','orange cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:orchid.253','orchid','orchid',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-p:orchidlane.221','orchidlane','orchid lane',[213,186,219],'d5badb',14007003],
['nbs-iscc-p:orchidleaf.226','orchidleaf','orchid leaf',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:orchidmauve.251','orchidmauve','orchid mauve',[193,126,145],'c17e91',12680849],
['nbs-iscc-p:orchidnight.19','orchidnight','orchid night',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:orchidnight.262','orchidnight','orchid night',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:orchidpink.4','orchidpink','orchid pink',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:orchidpink.5','orchidpink','orchid pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-p:orchidsmoke.253','orchidsmoke','orchid smoke',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-p:orientalbronze.95','orientalbronze','oriental bronze',[108,84,30],'6c541e',7099422],
['nbs-iscc-p:orientalsand.109','orientalsand','oriental sand',[140,135,103],'8c8767',9209703],
['nbs-iscc-p:padrebrown.44','padrebrown','padre brown',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-p:palaceblue.178','palaceblue','palace blue',[0,103,165],'0067a5',26533],
['nbs-iscc-p:palaceblue.182','palaceblue','palace blue',[67,107,149],'436b95',4418453],
['nbs-iscc-p:palestar.101','palestar','pale star',[234,230,121],'eae679',15394425],
['nbs-iscc-p:palestar.104','palestar','pale star',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:palewater.143','palewater','pale water',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-p:paloma.57','paloma','paloma',[166,123,91],'a67b5b',10910555],
['nbs-iscc-p:paloma.171','paloma','paloma',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:pan.150','pan','pan',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:pan.164','pan','pan',[49,120,115],'317873',3242099],
['nbs-iscc-p:panamablue.198','panamablue','panama blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-p:pansypurple.241','pansypurple','pansy purple',[145,92,131],'915c83',9526403],
['nbs-iscc-p:pansypurple.242','pansypurple','pansy purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-p:pansyyellow.83','pansyyellow','pansy yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:paprica.38','paprica','paprica',[158,71,50],'9e4732',10372914],
['nbs-iscc-p:paradisegreen.134','paradisegreen','paradise green',[182,229,175],'b6e5af',11986351],
['nbs-iscc-p:paradisegreen.135','paradisegreen','paradise green',[147,197,146],'93c592',9684370],
['nbs-iscc-p:paramount.168','paramount','paramount',[35,158,186],'239eba',2334394],
['nbs-iscc-p:paramount.172','paramount','paramount',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:paramour.172','paramour','paramour',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:parrakeet.140','parrakeet','parrakeet',[62,180,137],'3eb489',4109449],
['nbs-iscc-p:peace.92','peace','peace',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:peacemaker.153','peacemaker','peace-maker',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:peachamber.29','peachamber','peach amber',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:peachbisque.42','peachbisque','peach bisque',[168,124,109],'a87c6d',11041901],
['nbs-iscc-p:peachbud.28','peachbud','peach bud',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:peachcream.73','peachcream','peach cream',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:peachgray.9','peachgray','peach gray',[234,227,225],'eae3e1',15393761],
['nbs-iscc-p:peachgray.10','peachgray','peach gray',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-p:peachgray.31','peachgray','peach gray',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:peachpink.28','peachpink','peach pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:peachrust.37','peachrust','peach rust',[203,109,81],'cb6d51',13331793],
['nbs-iscc-p:peachsand.10','peachsand','peach sand',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-p:peachsand.63','peachsand','peach sand',[142,130,121],'8e8279',9339513],
['nbs-iscc-p:peacockblue.174','peacockblue','peacock blue',[0,73,88],'004958',18776],
['nbs-iscc-p:peagreen.120','peagreen','pea green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:pearlcream.9','pearlcream','pearl cream',[234,227,225],'eae3e1',15393761],
['nbs-iscc-p:pearlygates.92','pearlygates','pearly gates ',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:peasantblue.183','peasantblue','peasant blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:peasantblue.187','peasantblue','peasant blue',[54,69,79],'36454f',3556687],
['nbs-iscc-p:persiangreen.159','persiangreen','persian green',[0,166,147],'00a693',42643],
['nbs-iscc-p:persiangulf.150','persiangulf','persian gulf',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:persiangulf.164','persiangulf','persian gulf',[49,120,115],'317873',3242099],
['nbs-iscc-p:persianmelon.37','persianmelon','persian melon',[203,109,81],'cb6d51',13331793],
['nbs-iscc-p:persianrose.254','persianrose','persian rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-p:persianrose.255','persianrose','persian rose',[179,68,108],'b3446c',11748460],
['nbs-iscc-p:personal.252','personal','personal',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:petunia.223','petunia','petunia',[134,96,142],'86608e',8806542],
['nbs-iscc-p:pewter.10','pewter','pewter',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-p:pewtercream.9','pewtercream','pewter cream',[234,227,225],'eae3e1',15393761],
['nbs-iscc-p:phantomblue.171','phantomblue','phantom blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:phantomblue.184','phantomblue','phantom blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:phantomgreen.153','phantomgreen','phantom green',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:phloxpink.248','phloxpink','phlox pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:picturesque.159','picturesque','picturesque',[0,166,147],'00a693',42643],
['nbs-iscc-p:picturesque.162','picturesque','picturesque',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:pinefrost.143','pinefrost','pine frost',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-p:pinkcarnation.246','pinkcarnation','pink carnation',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-p:pinkdust.28','pinkdust','pink dust',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:pinkdust.31','pinkdust','pink dust',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:pinkicing.249','pinkicing','pink icing',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:pinkjewel.26','pinkjewel','pink jewel',[248,131,121],'f88379',16286585],
['nbs-iscc-p:pinklavender.252','pinklavender','pink lavender',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:pinklily.4','pinklily','pink lily',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:pinkmist.252','pinkmist','pink mist',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:pinkorchid.252','pinkorchid','pink orchid',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:pinkpowder.246','pinkpowder','pink powder',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-p:pinkrapture.237','pinkrapture','pink rapture',[158,79,136],'9e4f88',10375048],
['nbs-iscc-p:pinkshock.255','pinkshock','pink shock',[179,68,108],'b3446c',11748460],
['nbs-iscc-p:pinocchio.28','pinocchio','pinocchio',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:piquant.162','piquant','piquant',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:piquantgreen.120','piquantgreen','piquant green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:pistachiocream.116','pistachiocream','pistachio cream',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:placid.231','placid','placid',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:plantation.43','plantation','plantation',[121,68,59],'79443b',7947323],
['nbs-iscc-p:plantationyellow.83','plantationyellow','plantation yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:platonic.185','platonic','platonic',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:plentybright.160','plentybright','plenty bright',[0,122,116],'007a74',31348],
['nbs-iscc-p:plumbagoblue.184','plumbagoblue','plumbago blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:plumbagoblue.202','plumbagoblue','plumbago blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:plume.162','plume','plume',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:poetsyellow.101','poetsyellow','poet\'s yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:polarbear.172','polarbear','polar bear',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:pompom.86','pompom','pom pom',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:pompom.101','pompom','pom pom',[234,230,121],'eae679',15394425],
['nbs-iscc-p:poolgreen.159','poolgreen','pool green',[0,166,147],'00a693',42643],
['nbs-iscc-p:porcelaingreen.144','porcelaingreen','porcelain green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-p:poufdevent.249','poufdevent','pouf de vent',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:poufdevent.252','poufdevent','pouf de vent',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:prairiesunset.29','prairiesunset','prairie sunset',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:prairiesunset.52','prairiesunset','prairie sunset',[250,181,127],'fab57f',16430463],
['nbs-iscc-p:primeval.145','primeval','primeval',[59,120,97],'3b7861',3897441],
['nbs-iscc-p:primroseyellow.98','primroseyellow','primrose yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:princelyblue.198','princelyblue','princely blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-p:princelyblue.202','princelyblue','princely blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:princess.210','princess','princess',[140,130,182],'8c82b6',9208502],
['nbs-iscc-p:priscillablue.173','priscillablue','priscilla blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:prismpink.249','prismpink','prism pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:prismviolet.207','prismviolet','prism violet',[96,78,151],'604e97',6311575],
['nbs-iscc-p:profound.16','profound','profound',[114,47,55],'722f37',7483191],
['nbs-iscc-p:profoundblue.186','profoundblue','profound blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:profoundblue.203','profoundblue','profound blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-p:promise.92','promise','promise ',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:promisedland.140','promisedland','promised land',[62,180,137],'3eb489',4109449],
['nbs-iscc-p:promisedland.141','promisedland','promised land',[0,121,89],'007959',31065],
['nbs-iscc-p:promisedland.159','promisedland','promised land',[0,166,147],'00a693',42643],
['nbs-iscc-p:promisedland.160','promisedland','promised land',[0,122,116],'007a74',31348],
['nbs-iscc-p:promisegreen.148','promisegreen','promise green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:prudence.163','prudence','prudence',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:prudence.185','prudence','prudence',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:pumpkin.53','pumpkin','pumpkin',[217,144,88],'d99058',14258264],
['nbs-iscc-p:puritan.186','puritan','puritan',[83,104,120],'536878',5466232],
['nbs-iscc-p:puritan.192','puritan','puritan',[81,88,94],'51585e',5331038],
['nbs-iscc-p:purpleaster.241','purpleaster','purple aster',[145,92,131],'915c83',9526403],
['nbs-iscc-p:purpleheather.223','purpleheather','purple heather',[134,96,142],'86608e',8806542],
['nbs-iscc-p:purplelake.259','purplelake','purple lake',[103,49,71],'673147',6762823],
['nbs-iscc-p:purplenight.187','purplenight','purple night',[54,69,79],'36454f',3556687],
['nbs-iscc-p:purpleode.214','purpleode','purple ode',[150,144,171],'9690ab',9867435],
['nbs-iscc-p:quail.63','quail','quail',[142,130,121],'8e8279',9339513],
['nbs-iscc-p:quaker.233','quaker','quaker',[139,133,137],'8b8589',9143689],
['nbs-iscc-p:quality.210','quality','quality',[140,130,182],'8c82b6',9208502],
['nbs-iscc-p:qualitypink.247','qualitypink','quality pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-p:qualitypink.250','qualitypink','quality pink',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:queenanne.120','queenanne','queen anne',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:queenblue.182','queenblue','queen blue',[67,107,149],'436b95',4418453],
['nbs-iscc-p:queencoral.26','queencoral','queen coral',[248,131,121],'f88379',16286585],
['nbs-iscc-p:queencoral.28','queencoral','queen coral',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:queenpink.252','queenpink','queen pink',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:quiet.153','quiet','quiet',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:radiance.83','radiance','radiance',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:radiant.26','radiant','radiant',[248,131,121],'f88379',16286585],
['nbs-iscc-p:radiant.37','radiant','radiant',[203,109,81],'cb6d51',13331793],
['nbs-iscc-p:radiantorchid.226','radiantorchid','radiant orchid',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:rainbowmist.32','rainbowmist','rainbow mist',[199,173,163],'c7ada3',13086115],
['nbs-iscc-p:raisin.47','raisin','raisin',[67,48,46],'43302e',4403246],
['nbs-iscc-p:rapture.15','rapture','rapture',[171,78,82],'ab4e52',11226706],
['nbs-iscc-p:raspberryglace.262','raspberryglace','raspberry glace ',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:raven.267','raven','raven',[34,34,34],'222222',2236962],
['nbs-iscc-p:reed.121','reed','reed',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:reflection.171','reflection','reflection',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:regalorchid.222','regalorchid','regal orchid',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:remote.150','remote','remote',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:repose.122','repose','repose',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:restrainedblue.184','restrainedblue','restrained blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:retreat.185','retreat','retreat',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:retreat.191','retreat','retreat',[129,135,139],'81878b',8488843],
['nbs-iscc-p:rhapsodyblue.187','rhapsodyblue','rhapsody blue',[54,69,79],'36454f',3556687],
['nbs-iscc-p:rigiblue.186','rigiblue','rigi blue ',[83,104,120],'536878',5466232],
['nbs-iscc-p:rill.163','rill','rill',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:rioblue.185','rioblue','rio blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:riogrande.90','riogrande','rio grande',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:rivermist.186','rivermist','river mist',[83,104,120],'536878',5466232],
['nbs-iscc-p:rivernile.164','rivernile','river nile',[49,120,115],'317873',3242099],
['nbs-iscc-p:riviera.182','riviera','riviera',[67,107,149],'436b95',4418453],
['nbs-iscc-p:rivuletblue.172','rivuletblue','rivulet blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:robinegg.162','robinegg','robin egg',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:romance.252','romance','romance',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:romance.214','romance','romance',[150,144,171],'9690ab',9867435],
['nbs-iscc-p:romance.228','romance','romance',[121,104,120],'796878',7956600],
['nbs-iscc-p:romanpurple.229','romanpurple','roman purple',[80,64,77],'50404d',5259341],
['nbs-iscc-p:romanpurple.234','romanpurple','roman purple',[93,85,91],'5d555b',6116699],
['nbs-iscc-p:romanrose.47','romanrose','roman rose',[67,48,46],'43302e',4403246],
['nbs-iscc-p:romantan.42','romantan','roman tan',[168,124,109],'a87c6d',11041901],
['nbs-iscc-p:romanticblue.180','romanticblue','romantic blue',[161,202,241],'a1caf1',10603249],
['nbs-iscc-p:romanticblue.181','romanticblue','romantic blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:roomgreen.154','roomgreen','room green',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:rosario.29','rosario','rosario',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:rosea.249','rosea','rosea ',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:roseash.9','roseash','rose ash',[234,227,225],'eae3e1',15393761],
['nbs-iscc-p:roseash.31','roseash','rose ash',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:rosecaroline.29','rosecaroline','rose caroline',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:rosecastor.19','rosecastor','rose castor',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:rosecastor.22','rosecastor','rose castor',[143,129,127],'8f817f',9404799],
['nbs-iscc-p:rosecloud.5','rosecloud','rose cloud',[222,165,164],'dea5a4',14591396],
['nbs-iscc-p:rosedust.31','rosedust','rose dust ',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:rosegarden.248','rosegarden','rose garden',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:roseglory.3','roseglory','rose glory',[228,113,122],'e4717a',14971258],
['nbs-iscc-p:roseleaf.2','roseleaf','rose leaf',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:rosemarie.248','rosemarie','rose marie',[222,111,161],'de6fa1',14577569],
['nbs-iscc-p:rosemist.18','rosemist','rose mist',[173,136,132],'ad8884',11372676],
['nbs-iscc-p:rosemist.32','rosemist','rose mist',[199,173,163],'c7ada3',13086115],
['nbs-iscc-p:rosemorn.4','rosemorn','rose morn',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:rosemorn.7','rosemorn','rose morn',[234,216,215],'ead8d7',15390935],
['nbs-iscc-p:rosemorn.28','rosemorn','rose morn',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:rosemorn.31','rosemorn','rose morn',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:rosemuse.32','rosemuse','rose muse',[199,173,163],'c7ada3',13086115],
['nbs-iscc-p:rosenude.31','rosenude','rose nude',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:rosepearl.7','rosepearl','rose pearl',[234,216,215],'ead8d7',15390935],
['nbs-iscc-p:rosepearl.31','rosepearl','rose pearl',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:roseshadow.7','roseshadow','rose shadow',[234,216,215],'ead8d7',15390935],
['nbs-iscc-p:roseshadow.31','roseshadow','rose shadow',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:rosesmoke.18','rosesmoke','rose smoke',[173,136,132],'ad8884',11372676],
['nbs-iscc-p:rosesmoke.22','rosesmoke','rose smoke',[143,129,127],'8f817f',9404799],
['nbs-iscc-p:rosestain.19','rosestain','rose stain',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:rosypink.4','rosypink','rosy pink',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:royallilac.223','royallilac','royal lilac',[134,96,142],'86608e',8806542],
['nbs-iscc-p:royalrobe.212','royalrobe','royal robe',[47,33,64],'2f2140',3088704],
['nbs-iscc-p:royalviolet.259','royalviolet','royal violet',[103,49,71],'673147',6762823],
['nbs-iscc-p:rubylake.259','rubylake','ruby lake',[103,49,71],'673147',6762823],
['nbs-iscc-p:ruffledpetunia.247','ruffledpetunia','ruffled petunia',[230,143,172],'e68fac',15110060],
['nbs-iscc-p:russetleaf.91','russetleaf','russet leaf',[161,143,96],'a18f60',10588000],
['nbs-iscc-p:russetyellow.87','russetyellow','russet yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:russianblue.185','russianblue','russian blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:russianblue.191','russianblue','russian blue',[129,135,139],'81878b',8488843],
['nbs-iscc-p:rustrose.15','rustrose','rust rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-p:sable.58','sable','sable',[111,78,55],'6f4e37',7294519],
['nbs-iscc-p:sagablue.185','sagablue','saga blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:sage.120','sage','sage',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:sailor.24','sailor','sailor',[40,32,34],'282022',2629666],
['nbs-iscc-p:salmonbuff.29','salmonbuff','salmon buff',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:salmonflush.28','salmonflush','salmon flush',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:salmonpink.28','salmonpink','salmon pink ',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:salmonrose.26','salmonrose','salmon rose',[248,131,121],'f88379',16286585],
['nbs-iscc-p:salomeblue.159','salomeblue','salome blue',[0,166,147],'00a693',42643],
['nbs-iscc-p:salomegreen.140','salomegreen','salome green',[62,180,137],'3eb489',4109449],
['nbs-iscc-p:salomegreen.143','salomegreen','salome green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-p:salomepink.2','salomepink','salome pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:sandlewood.57','sandlewood','sandlewood',[166,123,91],'a67b5b',10910555],
['nbs-iscc-p:sandrift.63','sandrift','sandrift',[142,130,121],'8e8279',9339513],
['nbs-iscc-p:sandstucco.45','sandstucco','sand stucco',[151,127,115],'977f73',9928563],
['nbs-iscc-p:santaanitagreen.163','santaanitagreen','santa anita green',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:saxeblue.173','saxeblue','saxe blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:saxeblue.186','saxeblue','saxe blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:scarab.164','scarab','scarab',[49,120,115],'317873',3242099],
['nbs-iscc-p:scarlet.34','scarlet','scarlet',[226,88,34],'e25822',14833698],
['nbs-iscc-p:scotchblue.215','scotchblue','scotch blue',[85,76,105],'554c69',5590121],
['nbs-iscc-p:scotchmist.154','scotchmist','scotch mist',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:scotchmist.93','scotchmist','scotch mist',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:scotchmist.121','scotchmist','scotch mist',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:seafoam.92','seafoam','sea foam ',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:seafoam.153','seafoam','sea foam ',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:seafog.226','seafog','sea fog',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:seafog.232','seafog','sea fog',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-p:seamist.121','seamist','sea mist',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:seance.252','seance','seance',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:seclusion.156','seclusion','seclusion',[78,87,85],'4e5755',5134165],
['nbs-iscc-p:secret.228','secret','secret',[121,104,120],'796878',7956600],
['nbs-iscc-p:sentimentalmood.184','sentimentalmood','sentimental mood',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:sentimentalmood.202','sentimentalmood','sentimental mood',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:serene.31','serene','serene',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:serenity.250','serenity','serenity',[213,151,174],'d597ae',13997998],
['nbs-iscc-p:seville.120','seville','seville',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:sevres.176','sevres','sevres',[0,161,194],'00a1c2',41410],
['nbs-iscc-p:sevres.178','sevres','sevres',[0,103,165],'0067a5',26533],
['nbs-iscc-p:shadowaqua.150','shadowaqua','shadow aqua',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:shadowbeige.94','shadowbeige','shadow beige',[150,113,23],'967117',9859351],
['nbs-iscc-p:shadowblue.185','shadowblue','shadow blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:shadowgreen.150','shadowgreen','shadow green',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:shadowgreen.151','shadowgreen','shadow green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:shadowlilac.228','shadowlilac','shadow lilac',[121,104,120],'796878',7956600],
['nbs-iscc-p:shadowlime.119','shadowlime','shadow lime',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:shadowmauve.228','shadowmauve','shadow mauve',[121,104,120],'796878',7956600],
['nbs-iscc-p:shadowolive.105','shadowolive','shadow olive',[185,181,125],'b9b57d',12170621],
['nbs-iscc-p:shamrock.131','shamrock','shamrock',[68,148,74],'44944a',4494410],
['nbs-iscc-p:shellcoral.28','shellcoral','shell coral',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:shellcoral.31','shellcoral','shell coral',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:shine.104','shine','shine',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:shining.101','shining','shining',[234,230,121],'eae679',15394425],
['nbs-iscc-p:shoreline.186','shoreline','shore line',[83,104,120],'536878',5466232],
['nbs-iscc-p:shrimppink.26','shrimppink','shrimp pink',[248,131,121],'f88379',16286585],
['nbs-iscc-p:siamsand.90','siamsand','siam sand',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:sierra.38','sierra','sierra',[158,71,50],'9e4732',10372914],
['nbs-iscc-p:sierra.55','sierra','sierra',[128,70,27],'80461b',8406555],
['nbs-iscc-p:silentnight.150','silentnight','silent night',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:silverblue.184','silverblue','silver blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:silverblue.202','silverblue','silver blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:silvercloud.184','silvercloud','silver cloud',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:silvercloud.190','silvercloud','silver cloud',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:silvergreen.121','silvergreen','silver green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:silverlining.93','silverlining','silver lining',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:silverlining.264','silverlining','silver lining',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-p:silvernight.227','silvernight','silver night',[170,152,169],'aa98a9',11180201],
['nbs-iscc-p:silverpine.150','silverpine','silver pine ',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:silverpink.8','silverpink','silver pink',[196,174,173],'c4aead',12889773],
['nbs-iscc-p:silverpink.32','silverpink','silver pink',[199,173,163],'c7ada3',13086115],
['nbs-iscc-p:silversalmon.32','silversalmon','silver salmon',[199,173,163],'c7ada3',13086115],
['nbs-iscc-p:silversky.231','silversky','silver sky',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:silversky.232','silversky','silver sky',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-p:silverwing.232','silverwing','silver wing ',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-p:silverwing.233','silverwing','silver wing ',[139,133,137],'8b8589',9143689],
['nbs-iscc-p:singingblue.168','singingblue','singing blue',[35,158,186],'239eba',2334394],
['nbs-iscc-p:singingblue.172','singingblue','singing blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:sky.122','sky','sky',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:skycloud.190','skycloud','sky cloud',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:skygreen.162','skygreen','sky green',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:skylane.148','skylane','sky lane',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:slate.234','slate','slate',[93,85,91],'5d555b',6116699],
['nbs-iscc-p:slate.266','slate','slate',[85,85,85],'555555',5592405],
['nbs-iscc-p:slateblue.186','slateblue','slate blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:slateblue.192','slateblue','slate blue',[81,88,94],'51585e',5331038],
['nbs-iscc-p:slatecitron.120','slatecitron','slate citron',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:slategreen.150','slategreen','slate green ',[94,113,106],'5e716a',6189418],
['nbs-iscc-p:slateorchid.228','slateorchid','slate orchid',[121,104,120],'796878',7956600],
['nbs-iscc-p:slaterose.19','slaterose','slate rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:slateturquoise.173','slateturquoise','slate turquoise',[54,117,136],'367588',3569032],
['nbs-iscc-p:slateturquoise.186','slateturquoise','slate turquoise',[83,104,120],'536878',5466232],
['nbs-iscc-p:slateviolet.228','slateviolet','slate violet ',[121,104,120],'796878',7956600],
['nbs-iscc-p:sleepyhollow.149','sleepyhollow','sleepy hollow',[141,163,153],'8da399',9282457],
['nbs-iscc-p:sleepyhollow.185','sleepyhollow','sleepy hollow',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:sleighbells.171','sleighbells','sleigh bells',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:sleighbells.184','sleighbells','sleigh bells',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:smile.92','smile','smile',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:smiles.28','smiles','smiles',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:smog.79','smog','smog',[174,155,130],'ae9b82',11443074],
['nbs-iscc-p:smoke.185','smoke','smoke',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:smokeblue.203','smokeblue','smoke blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-p:smokepine.122','smokepine','smoke pine',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:smokepine.154','smokepine','smoke pine',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:smokering.185','smokering','smoke ring',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:smokestainrose.18','smokestainrose','smokestain rose',[173,136,132],'ad8884',11372676],
['nbs-iscc-p:snowgreen.148','snowgreen','snow green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:snowgreen.184','snowgreen','snow green',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:snowgreen.190','snowgreen','snow green',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:solitary.153','solitary','solitary',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:solitary.154','solitary','solitary',[178,190,181],'b2beb5',11714229],
['nbs-iscc-p:solitary.263','solitary','solitary',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-p:solitary.264','solitary','solitary',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-p:solitaryblue.186','solitaryblue','solitary blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:somberblue.186','somberblue','somber blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:sonata.28','sonata','sonata',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:songofnorway.159','songofnorway','song of norway',[0,166,147],'00a693',42643],
['nbs-iscc-p:sophisticatedlady.222','sophisticatedlady','sophisticated lady',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:sorcerer.215','sorcerer','sorcerer',[85,76,105],'554c69',5590121],
['nbs-iscc-p:sorcerer.228','sorcerer','sorcerer',[121,104,120],'796878',7956600],
['nbs-iscc-p:sorcerer.187','sorcerer','sorcerer',[54,69,79],'36454f',3556687],
['nbs-iscc-p:sorcerer.188','sorcerer','sorcerer',[32,40,48],'202830',2107440],
['nbs-iscc-p:sorcerer.193','sorcerer','sorcerer',[32,36,40],'202428',2106408],
['nbs-iscc-p:sorrento.164','sorrento','sorrento',[49,120,115],'317873',3242099],
['nbs-iscc-p:southernrose.42','southernrose','southern rose',[168,124,109],'a87c6d',11041901],
['nbs-iscc-p:southernsun.83','southernsun','southern sun',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:southernsun.86','southernsun','southern sun',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:souvenir.213','souvenir','souvenir',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-p:sovereignblue.181','sovereignblue','sovereign blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-p:sovereignblue.199','sovereignblue','sovereign blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-p:spanishblue.164','spanishblue','spanish blue',[49,120,115],'317873',3242099],
['nbs-iscc-p:spanishgold.71','spanishgold','spanish gold',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:spanishwhite.73','spanishwhite','spanish white',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:sparkle.171','sparkle','sparkle',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:sparrow.80','sparrow','sparrow',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-p:spectrablue.194','spectrablue','spectra blue',[48,38,122],'30267a',3155578],
['nbs-iscc-p:spectragreen.165','spectragreen','spectra green',[0,75,73],'004b49',19273],
['nbs-iscc-p:spectrared.11','spectrared','spectra red',[190,0,50],'be0032',12451890],
['nbs-iscc-p:spectrarose.254','spectrarose','spectra rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-p:spectrayellow.82','spectrayellow','spectra yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-p:spice.54','spice','spice',[174,105,56],'ae6938',11430200],
['nbs-iscc-p:spice.57','spice','spice',[166,123,91],'a67b5b',10910555],
['nbs-iscc-p:spiritualblue.184','spiritualblue','spiritual blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:spitfire.15','spitfire','spitfire',[171,78,82],'ab4e52',11226706],
['nbs-iscc-p:spray.162','spray','spray',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:spring.130','spring','spring',[131,211,125],'83d37d',8639357],
['nbs-iscc-p:springbud.119','springbud','spring bud',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:springdream.101','springdream','spring dream',[234,230,121],'eae679',15394425],
['nbs-iscc-p:springdream.104','springdream','spring dream',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:springeve.101','springeve','spring eve',[234,230,121],'eae679',15394425],
['nbs-iscc-p:springeve.116','springeve','spring eve',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:springeve.119','springeve','spring eve',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:springflower.98','springflower','spring flower ',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:springstream.162','springstream','spring stream',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:springyellow.89','springyellow','spring yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:starchwhite.184','starchwhite','starch white',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:static.185','static','static',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:steamblue.189','steamblue','steam blue',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:steelblue.172','steelblue','steel blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:stellar.249','stellar','stellar',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:sterlingblue.185','sterlingblue','sterling blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:sterlingblue.190','sterlingblue','sterling blue',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:stoic.267','stoic','stoic',[34,34,34],'222222',2236962],
['nbs-iscc-p:storm.186','storm','storm',[83,104,120],'536878',5466232],
['nbs-iscc-p:stormynight.187','stormynight','stormy night',[54,69,79],'36454f',3556687],
['nbs-iscc-p:stratosphere.186','stratosphere','stratosphere',[83,104,120],'536878',5466232],
['nbs-iscc-p:stratosphere.192','stratosphere','stratosphere',[81,88,94],'51585e',5331038],
['nbs-iscc-p:strawyellow.89','strawyellow','straw yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:streamlet.162','streamlet','streamlet',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:streamline.162','streamline','streamline',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:string.92','string','string',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:stylegray.186','stylegray','style gray',[83,104,120],'536878',5466232],
['nbs-iscc-p:sublime.185','sublime','sublime',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:sublime.203','sublime','sublime',[140,146,172],'8c92ac',9212588],
['nbs-iscc-p:suet.92','suet','suet',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:suezblue.187','suezblue','suez blue',[54,69,79],'36454f',3556687],
['nbs-iscc-p:suezgreen.164','suezgreen','suez green',[49,120,115],'317873',3242099],
['nbs-iscc-p:suggestion.162','suggestion','suggestion',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:sulphategreen.159','sulphategreen','sulphate green',[0,166,147],'00a693',42643],
['nbs-iscc-p:sulphategreen.163','sulphategreen','sulphate green',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:sulphur.101','sulphur','sulphur',[234,230,121],'eae679',15394425],
['nbs-iscc-p:sultana.19','sultana','sultana',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:sultansand.76','sultansand','sultan sand',[193,154,107],'c19a6b',12687979],
['nbs-iscc-p:summergreen.140','summergreen','summer green',[62,180,137],'3eb489',4109449],
['nbs-iscc-p:summergreen.143','summergreen','summer green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-p:summershower.148','summershower','summer shower',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:summersun.98','summersun','summer sun',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:sunburst.70','sunburst','sunburst',[251,201,127],'fbc97f',16501119],
['nbs-iscc-p:sunburst.71','sunburst','sunburst',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:sunburst.73','sunburst','sunburst',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:sundown.28','sundown','sundown',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:sundown.29','sundown','sundown',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-p:sundown.73','sundown','sundown',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:sunggreen.122','sunggreen','sung green',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:sunglow.86','sunglow','sun glow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:sunglow.89','sunglow','sun glow ',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:sungod.35','sungod','sun god ',[217,96,59],'d9603b',14245947],
['nbs-iscc-p:sungreen.104','sungreen','sun green',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:sunrose.4','sunrose','sun rose',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:sunsetcream.92','sunsetcream','sunset cream',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:sunshine.101','sunshine','sunshine',[234,230,121],'eae679',15394425],
['nbs-iscc-p:sunyellow.98','sunyellow','sun yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:sunyellow.101','sunyellow','sun yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:superior.164','superior','superior',[49,120,115],'317873',3242099],
['nbs-iscc-p:supreme.177','supreme','supreme',[73,151,208],'4997d0',4822992],
['nbs-iscc-p:surfspray.153','surfspray','surf spray',[223,237,232],'dfede8',14675432],
['nbs-iscc-p:surrender.222','surrender','surrender',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:sussanquapink.246','sussanquapink','sussanqua pink',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-p:sussanquapink.247','sussanquapink','sussanqua pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-p:swank.213','swank','swank',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-p:swank.226','swank','swank',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:sweetblue.184','sweetblue','sweet blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:sweetlady.210','sweetlady','sweet lady',[140,130,182],'8c82b6',9208502],
['nbs-iscc-p:sweetlavender.213','sweetlavender','sweet lavender',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-p:sweetpeapink.262','sweetpeapink','sweet pea pink',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:swissblue.203','swissblue','swiss blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-p:swissrose.19','swissrose','swiss rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:sylvan.121','sylvan','sylvan',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:tabu.186','tabu','tabu',[83,104,120],'536878',5466232],
['nbs-iscc-p:talisman.52','talisman','talisman',[250,181,127],'fab57f',16430463],
['nbs-iscc-p:talisman.53','talisman','talisman',[217,144,88],'d99058',14258264],
['nbs-iscc-p:tangerine.35','tangerine','tangerine',[217,96,59],'d9603b',14245947],
['nbs-iscc-p:tangerine.50','tangerine','tangerine',[237,135,45],'ed872d',15566637],
['nbs-iscc-p:tango.3','tango','tango',[228,113,122],'e4717a',14971258],
['nbs-iscc-p:tapestrybeige.45','tapestrybeige','tapestry beige',[151,127,115],'977f73',9928563],
['nbs-iscc-p:tapestryred.16','tapestryred','tapestry red',[114,47,55],'722f37',7483191],
['nbs-iscc-p:tauperose.23','tauperose','taupe rose',[92,80,79],'5c504f',6049871],
['nbs-iscc-p:tauperose.46','tauperose','taupe rose',[103,76,71],'674c47',6769735],
['nbs-iscc-p:taupesand.94','taupesand','taupe sand',[150,113,23],'967117',9859351],
['nbs-iscc-p:tealblue.173','tealblue','teal blue',[54,117,136],'367588',3569032],
['nbs-iscc-p:teenagepink.249','teenagepink','teen age pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:televisionblue.187','televisionblue','television blue',[54,69,79],'36454f',3556687],
['nbs-iscc-p:tempest.229','tempest','tempest',[80,64,77],'50404d',5259341],
['nbs-iscc-p:tempestblue.192','tempestblue','tempest blue',[81,88,94],'51585e',5331038],
['nbs-iscc-p:temple.122','temple','temple',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:temptation.226','temptation','temptation',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:teteatete.171','teteatete','tete-a-tete',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-p:thamesriver.185','thamesriver','thames river',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:thamesriver.190','thamesriver','thames river',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:theatricalblue.182','theatricalblue','theatrical blue',[67,107,149],'436b95',4418453],
['nbs-iscc-p:thistlebloom.258','thistlebloom','thistle bloom',[168,81,110],'a8516e',11030894],
['nbs-iscc-p:thistledown.252','thistledown','thistle down',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-p:tobaccobrown.46','tobaccobrown','tobacco brown',[103,76,71],'674c47',6769735],
['nbs-iscc-p:tomatored.11','tomatored','tomato red',[190,0,50],'be0032',12451890],
['nbs-iscc-p:topazamber.53','topazamber','topaz amber',[217,144,88],'d99058',14258264],
['nbs-iscc-p:torchlight.11','torchlight','torchlight',[190,0,50],'be0032',12451890],
['nbs-iscc-p:torchlight.12','torchlight','torchlight',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-p:toreador.12','toreador','toreador',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-p:tourmalinegreen.148','tourmalinegreen','tourmaline green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:tourmalinegreen.162','tourmalinegreen','tourmaline green',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:tourmalinepink.246','tourmalinepink','tourmaline pink',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-p:tourmalinepink.249','tourmalinepink','tourmaline pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:tradewinds.186','tradewinds','trade winds',[83,104,120],'536878',5466232],
['nbs-iscc-p:trailgreen.146','trailgreen','trail green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-p:trailgreen.151','trailgreen','trail green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:tranquilgreen.151','tranquilgreen','tranquil green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-p:tranquilgreen.187','tranquilgreen','tranquil green',[54,69,79],'36454f',3556687],
['nbs-iscc-p:transatlanticblue.188','transatlanticblue','transatlantic blue',[32,40,48],'202830',2107440],
['nbs-iscc-p:translucentblue.185','translucentblue','translucent blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:transparentyellow.89','transparentyellow','transparent yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:transparentyellow.92','transparentyellow','transparent yellow',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:trellis.135','trellis','trellis',[147,197,146],'93c592',9684370],
['nbs-iscc-p:tropicnight.245','tropicnight','tropic night',[131,100,121],'836479',8610937],
['nbs-iscc-p:troubador.11','troubador','troubador',[190,0,50],'be0032',12451890],
['nbs-iscc-p:troubador.12','troubador','troubador',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-p:tulipyellow.83','tulipyellow','tulip yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-p:tumbleweed.89','tumbleweed','tumbleweed',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:tumbleweed.93','tumbleweed','tumbleweed',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-p:turfgreen.131','turfgreen','turf green',[68,148,74],'44944a',4494410],
['nbs-iscc-p:turfgreen.136','turfgreen','turf green',[103,146,103],'679267',6787687],
['nbs-iscc-p:turquoiseblue.163','turquoiseblue','turquoise blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:tuscansand.94','tuscansand','tuscan sand',[150,113,23],'967117',9859351],
['nbs-iscc-p:twilightmood.184','twilightmood','twilight mood',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:twilightsun.89','twilightsun','twilight sun',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:twilightsun.121','twilightsun','twilight sun',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:twinkle.184','twinkle','twinkle',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:tyrianblue.186','tyrianblue','tyrian blue',[83,104,120],'536878',5466232],
['nbs-iscc-p:ultramarine.194','ultramarine','ultramarine',[48,38,122],'30267a',3155578],
['nbs-iscc-p:uniformblue.183','uniformblue','uniform blue',[0,48,78],'00304e',12366],
['nbs-iscc-p:unique.104','unique','unique',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:universal.187','universal','universal',[54,69,79],'36454f',3556687],
['nbs-iscc-p:vagabond.164','vagabond','vagabond',[49,120,115],'317873',3242099],
['nbs-iscc-p:valenciarose.6','valenciarose','valencia rose',[192,128,129],'c08081',12615809],
['nbs-iscc-p:valorgreen.187','valorgreen','valor green',[54,69,79],'36454f',3556687],
['nbs-iscc-p:vamp.249','vamp','vamp',[239,187,204],'efbbcc',15711180],
['nbs-iscc-p:vanda.244','vanda','vanda',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-p:vanillacustard.86','vanillacustard','vanilla custard',[248,222,126],'f8de7e',16309886],
['nbs-iscc-p:vanillacustard.89','vanillacustard','vanilla custard',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:vaporblue.189','vaporblue','vapor blue',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:vatican.259','vatican','vatican',[103,49,71],'673147',6762823],
['nbs-iscc-p:veiledsun.71','veiledsun','veiled sun',[227,168,87],'e3a857',14919767],
['nbs-iscc-p:veiledsun.84','veiledsun','veiled sun',[212,175,55],'d4af37',13938487],
['nbs-iscc-p:venetianrose.19','venetianrose','venetian rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:venetianturquoise.163','venetianturquoise','venetian turquoise',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:venice.149','venice','venice',[141,163,153],'8da399',9282457],
['nbs-iscc-p:veniceblue.162','veniceblue','venice blue',[150,222,209],'96ded1',9887441],
['nbs-iscc-p:venusblue.184','venusblue','venus blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:venusblue.189','venusblue','venus blue',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:verbenalavender.241','verbenalavender','verbena lavender',[145,92,131],'915c83',9526403],
['nbs-iscc-p:verbenalavender.262','verbenalavender','verbena lavender',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:verdant.115','verdant','verdant',[141,182,0],'8db600',9287168],
['nbs-iscc-p:verdugo.116','verdugo','verdugo',[189,218,87],'bdda57',12442199],
['nbs-iscc-p:verdugo.119','verdugo','verdugo',[201,220,137],'c9dc89',13229193],
['nbs-iscc-p:vermilion.35','vermilion','vermilion',[217,96,59],'d9603b',14245947],
['nbs-iscc-p:vesta.2','vesta','vesta',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:vesta.4','vesta','vesta',[249,204,202],'f9ccca',16370890],
['nbs-iscc-p:vesta.5','vesta','vesta',[222,165,164],'dea5a4',14591396],
['nbs-iscc-p:vibrantgreen.130','vibrantgreen','vibrant green',[131,211,125],'83d37d',8639357],
['nbs-iscc-p:victoria.28','victoria','victoria',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:viking.187','viking','viking',[54,69,79],'36454f',3556687],
['nbs-iscc-p:viola.222','viola','viola',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:violetleaf.125','violetleaf','violet leaf',[74,93,35],'4a5d23',4873507],
['nbs-iscc-p:violetpansy.229','violetpansy','violet pansy',[80,64,77],'50404d',5259341],
['nbs-iscc-p:virginialavender.231','virginialavender','virginia lavender',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:vistagreen.122','vistagreen','vista green',[143,151,121],'8f9779',9410425],
['nbs-iscc-p:vivid.251','vivid','vivid',[193,126,145],'c17e91',12680849],
['nbs-iscc-p:vividturquoise.160','vividturquoise','vivid turquoise',[0,122,116],'007a74',31348],
['nbs-iscc-p:waftedfeather.231','waftedfeather','wafted feather',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:waftedfeather.232','waftedfeather','wafted feather',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-p:walnut.57','walnut','walnut',[166,123,91],'a67b5b',10910555],
['nbs-iscc-p:walnutcream.73','walnutcream','walnut cream',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:wanblue.189','wanblue','wan blue',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-p:wanblue.231','wanblue','wan blue',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-p:waterfall.173','waterfall','water fall ',[54,117,136],'367588',3569032],
['nbs-iscc-p:watergreen.121','watergreen','water green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-p:watteau.172','watteau','watteau',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:whimsical.222','whimsical','whimsical',[182,149,192],'b695c0',11965888],
['nbs-iscc-p:whiteclover.92','whiteclover','white clover',[240,234,214],'f0ead6',15788758],
['nbs-iscc-p:whitefawn.73','whitefawn','white fawn',[250,214,165],'fad6a5',16438949],
['nbs-iscc-p:whitejade.28','whitejade','white jade',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:whitejade.31','whitejade','white jade',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:whitelight.184','whitelight','white light',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:whitemist.28','whitemist','white mist',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-p:whitemist.31','whitemist','white mist',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-p:whitesmoke.190','whitesmoke','white smoke',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-p:whiteswan.184','whiteswan','white swan',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:whiteswan.202','whiteswan','white swan',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-p:wildorchid.240','wildorchid','wild orchid',[183,132,167],'b784a7',12027047],
['nbs-iscc-p:windflower.262','windflower','windflower',[145,95,109],'915f6d',9527149],
['nbs-iscc-p:wineberry.228','wineberry','wineberry',[121,104,120],'796878',7956600],
['nbs-iscc-p:wineberry.229','wineberry','wineberry',[80,64,77],'50404d',5259341],
['nbs-iscc-p:winsome.226','winsome','winsome',[214,202,221],'d6cadd',14076637],
['nbs-iscc-p:winsomeblue.172','winsomeblue','winsome blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-p:winterpear.120','winterpear','winter pear',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-p:wintersky.184','wintersky','winter sky',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:wintersun.101','wintersun','winter sun ',[234,230,121],'eae679',15394425],
['nbs-iscc-p:winterwhite.3','winterwhite','winter white',[228,113,122],'e4717a',14971258],
['nbs-iscc-p:winteryellow.89','winteryellow','winter yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:winteryellow.90','winteryellow','winter yellow',[194,178,128],'c2b280',12759680],
['nbs-iscc-p:wisteria.210','wisteria','wisteria',[140,130,182],'8c82b6',9208502],
['nbs-iscc-p:wisteriagray.228','wisteriagray','wisteria gray',[121,104,120],'796878',7956600],
['nbs-iscc-p:wisteriamist.228','wisteriamist','wisteria mist',[121,104,120],'796878',7956600],
['nbs-iscc-p:witheredrose.19','witheredrose','withered rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-p:yaleblue.196','yaleblue','yale blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-p:yaleblue.197','yaleblue','yale blue',[39,36,88],'272458',2565208],
['nbs-iscc-p:yaleblue.200','yaleblue','yale blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-p:yama.163','yama','yama',[102,173,164],'66ada4',6729124],
['nbs-iscc-p:yellowbright.98','yellowbright','yellow bright',[233,228,80],'e9e450',15328336],
['nbs-iscc-p:yellowbright.101','yellowbright','yellow bright',[234,230,121],'eae679',15394425],
['nbs-iscc-p:yellowcream.89','yellowcream','yellow cream',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:yellowessence.104','yellowessence','yellow essence',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-p:yellowgem.89','yellowgem','yellow gem',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-p:yellowmist.94','yellowmist','yellow mist',[150,113,23],'967117',9859351],
['nbs-iscc-p:yellowrose.101','yellowrose','yellow rose',[234,230,121],'eae679',15394425],
['nbs-iscc-p:yellowsmoke.87','yellowsmoke','yellow smoke',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-p:yellowsmoke.88','yellowsmoke','yellow smoke',[171,145,68],'ab9144',11243844],
['nbs-iscc-p:yewgreen.127','yewgreen','yew green',[81,87,68],'515744',5330756],
['nbs-iscc-p:youthyellow.101','youthyellow','youth yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-p:yuletime.125','yuletime','yuletime',[74,93,35],'4a5d23',4873507],
['nbs-iscc-p:yuletree.165','yuletree','yule tree',[0,75,73],'004b49',19273],
['nbs-iscc-p:zephyrblue.184','zephyrblue','zephyr blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-p:zephyrblue.185','zephyrblue','zephyr blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-p:zephyrgreen.148','zephyrgreen','zephyr green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-p:zestpink.2','zestpink','zest pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-p:zinniagold.70','zinniagold','zinnia gold',[251,201,127],'fbc97f',16501119],
['nbs-iscc-p:zinniagold.86','zinniagold','zinnia gold',[248,222,126],'f8de7e',16309886]
    ];
}

sub _description {
    return {
          'subtitle' => 'Plochere Color System',
          'title' => 'NBS/ISCC P',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (P) Plochere Color System

        Plochere Color System

    This idiosyncratic dictionary for interior decorating has 1246 names mapping to 1606 colors, using 206 of the 267 centroids.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#P]
'
        }

}

1;
