package Color::Library::Dictionary::NBS_ISCC::R;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::R;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::R - (NBS/ISCC R) Color Standards and Color Nomenclature

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (R) Color Standards and Color Nomenclature

        Ridgway,
        Color Standards and Color Nomenclature 

    While using some modifiers, this primarily idiosyncratic dictionary was intended for biology and botany. It maps 1096 names to 1602 colors, using 214 of the 267 centroids.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#R>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>absinthe green</td><td>absinthegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>acajou red</td><td>acajoured</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>acetin blue </td><td>acetinblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>acetin blue </td><td>acetinblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>ackermann's green</td><td>ackermannsgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>aconite violet</td><td>aconiteviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>ageratum violet</td><td>ageratumviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>alice blue</td><td>aliceblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>alizarine blue</td><td>alizarineblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>alizarine pink</td><td>alizarinepink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>alizarine pink</td><td>alizarinepink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>amaranth pink</td><td>amaranthpink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>amaranth purple</td><td>amaranthpurple</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>amber brown</td><td>amberbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>amber yellow </td><td>amberyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>amber yellow </td><td>amberyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>amber yellow </td><td>amberyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>amber yellow </td><td>amberyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>american green</td><td>americangreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>amethyst violet</td><td>amethystviolet</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>amparo blue</td><td>amparoblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#d399e6;width:4em;" /><td>amparo purple</td><td>amparopurple</td><td>##d399e6</td><td>211</td> <td>153</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>amparo purple</td><td>amparopurple</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>andover green</td><td>andovergreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>aniline black</td><td>anilineblack</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>aniline black</td><td>anilineblack</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>aniline lilac</td><td>anilinelilac</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>aniline yellow</td><td>anilineyellow</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>anthracene green</td><td>anthracenegreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>anthracene green</td><td>anthracenegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>anthracene purple</td><td>anthracenepurple</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>anthracene purple</td><td>anthracenepurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>anthracene violet</td><td>anthraceneviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>antimony yellow</td><td>antimonyyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>antique brown</td><td>antiquebrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>antique brown</td><td>antiquebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>antique green</td><td>antiquegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>antique green</td><td>antiquegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>antwerp blue</td><td>antwerpblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>antwerp blue</td><td>antwerpblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>antwerp blue</td><td>antwerpblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>apple green</td><td>applegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>apricot buff</td><td>apricotbuff</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>apricot orange</td><td>apricotorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>apricot yellow</td><td>apricotyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>argus brown</td><td>argusbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>argyle purple</td><td>argylepurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>army brown</td><td>armybrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>army brown</td><td>armybrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>artemesia green</td><td>artemesiagreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>asphodel green</td><td>asphodelgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>aster purple</td><td>asterpurple</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>auburn</td><td>auburn</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>auricula purple</td><td>auriculapurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>avellaneous</td><td>avellaneous</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>avellaneous</td><td>avellaneous</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>azurite blue</td><td>azuriteblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>barium yellow</td><td>bariumyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>barium yellow</td><td>bariumyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>baryta yellow</td><td>barytayellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>bay</td><td>bay</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>begonia rose</td><td>begoniarose</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>benzo brown</td><td>benzobrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>benzo brown</td><td>benzobrown</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>benzo brown</td><td>benzobrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>benzol green</td><td>benzolgreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>berlin blue</td><td>berlinblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>beryl blue</td><td>berylblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>beryl green</td><td>berylgreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>bice green</td><td>bicegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>biscay green</td><td>biscaygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>bishop's purple</td><td>bishopspurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>bister</td><td>bister</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>bister</td><td>bister</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>bittersweet orange</td><td>bittersweetorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>bittersweet pink</td><td>bittersweetpink</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black</td><td>black</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>blackish green-blue</td><td>blackishgreenblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>blackish green-gray</td><td>blackishgreengray</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>blackish mouse-gray</td><td>blackishmousegray</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>blackish mouse-gray</td><td>blackishmousegray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>blackish plumbeous</td><td>blackishplumbeous</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>blackish purple</td><td>blackishpurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#341731;width:4em;" /><td>blackish purple</td><td>blackishpurple</td><td>##341731</td><td>52</td> <td>23</td> <td>49</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>blackish red-purple</td><td>blackishredpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>blackish slate</td><td>blackishslate</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>blackish violet</td><td>blackishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>blackish violet</td><td>blackishviolet</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>blackish violet</td><td>blackishviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>blackish violet-gray</td><td>blackishvioletgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>blackish violet-gray</td><td>blackishvioletgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blanc's blue</td><td>blancsblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>blanc's violet</td><td>blancsviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>blanc's violet</td><td>blancsviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>blanc's violet</td><td>blancsviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>blue-violet</td><td>blueviolet</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>blue-violet</td><td>blueviolet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>blue-violet black</td><td>bluevioletblack</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>blue-violet black</td><td>bluevioletblack</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>bluish black</td><td>bluishblack</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>bluish black</td><td>bluishblack</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>bluish glaucous</td><td>bluishglaucous</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>bluish glaucous</td><td>bluishglaucous</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>bluish gray-green</td><td>bluishgraygreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>bluish gray-green</td><td>bluishgraygreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>bluish lavender</td><td>bluishlavender</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>bluish slate-black</td><td>bluishslateblack</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>bluish slate-black</td><td>bluishslateblack</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>bluish violet</td><td>bluishviolet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>bone brown</td><td>bonebrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>bone brown</td><td>bonebrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>bordeaux</td><td>bordeaux</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>bottle green</td><td>bottlegreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>bradley's blue</td><td>bradleysblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>bradley's violet</td><td>bradleysviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>bradley's violet</td><td>bradleysviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>bradley's violet</td><td>bradleysviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>bradley's violet</td><td>bradleysviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>brazil red</td><td>brazilred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>bremen blue</td><td>bremenblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>brick red</td><td>brickred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>bright chalcedony yellow</td><td>brightchalcedonyyellow</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>bright chalcedony yellow</td><td>brightchalcedonyyellow</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8db600;width:4em;" /><td>bright green-yellow</td><td>brightgreenyellow</td><td>##8db600</td><td>141</td> <td>182</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>brownish drab</td><td>brownishdrab</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>brownish drab</td><td>brownishdrab</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>brownish olive</td><td>brownisholive</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>brownish vinaceous</td><td>brownishvinaceous</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brussels brown</td><td>brusselsbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>buckthorn brown</td><td>buckthornbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>buff-pink or buff pink</td><td>buffpinkorbuffpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>buffy brown </td><td>buffybrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>buffy brown </td><td>buffybrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>buffy citrine</td><td>buffycitrine</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>buff-yellow or buff yellow</td><td>buffyelloworbuffyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>buff-yellow or buff yellow</td><td>buffyelloworbuffyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>buffy olive</td><td>buffyolive</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>burn blue</td><td>burnblue</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>burn blue</td><td>burnblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>burn blue</td><td>burnblue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>burn blue</td><td>burnblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>burnt lake</td><td>burntlake</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>burnt sienna</td><td>burntsienna</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>burnt umber</td><td>burntumber</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>cacao brown</td><td>cacaobrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>cadet blue</td><td>cadetblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>cadet blue</td><td>cadetblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>cadet gray</td><td>cadetgray</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>cadmium orange</td><td>cadmiumorange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>cadmium orange</td><td>cadmiumorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>cadmium yellow</td><td>cadmiumyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>cadmium yellow</td><td>cadmiumyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>calamine blue</td><td>calamineblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>calamine blue</td><td>calamineblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>calla green</td><td>callagreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>calliste green</td><td>callistegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>cameo brown</td><td>cameobrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>cameo brown</td><td>cameobrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>cameo pink</td><td>cameopink</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>cameo pink</td><td>cameopink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>capri blue </td><td>capriblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>capucine buff </td><td>capucinebuff</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>capucine buff </td><td>capucinebuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>capucine buff </td><td>capucinebuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>capucine orange </td><td>capucineorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>capucine yellow </td><td>capucineyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carmine</td><td>carmine</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>carnelian red</td><td>carnelianred</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>carob brown</td><td>carobbrown</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>carrot red</td><td>carrotred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>cartridge buff</td><td>cartridgebuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>castor gray</td><td>castorgray</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>castor gray</td><td>castorgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>cedar green</td><td>cedargreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>cedar green</td><td>cedargreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>celandine green</td><td>celandinegreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>cendre blue</td><td>cendreblue</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>cendre green</td><td>cendregreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>cerulean blue</td><td>ceruleanblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>chaetura black</td><td>chaeturablack</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>chaetura drab</td><td>chaeturadrab</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>chalcedony yellow</td><td>chalcedonyyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>chamois</td><td>chamois</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>chapman's blue</td><td>chapmansblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>chartreuse yellow</td><td>chartreuseyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>chatenay pink</td><td>chatenaypink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>chatenay pink</td><td>chatenaypink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>chessylite blue</td><td>chessyliteblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>chessylite blue</td><td>chessyliteblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>chessylite blue</td><td>chessyliteblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>chessylite blue</td><td>chessyliteblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>chestnut</td><td>chestnut</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>chestnut-brown</td><td>chestnutbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>chestnut-brown</td><td>chestnutbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>chicory blue</td><td>chicoryblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>chicory blue</td><td>chicoryblue</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>china blue</td><td>chinablue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>chinese violet</td><td>chineseviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>chocolate</td><td>chocolate</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>chromium green</td><td>chromiumgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>chrysolite green</td><td>chrysolitegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>chrysopraise green</td><td>chrysopraisegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>cinereous</td><td>cinereous</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>cinereous</td><td>cinereous</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>cinnamon</td><td>cinnamon</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>cinnamon</td><td>cinnamon</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>cinnamon-brown</td><td>cinnamonbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>cinnamon-buff</td><td>cinnamonbuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>cinnamon-buff</td><td>cinnamonbuff</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>cinnamon-buff</td><td>cinnamonbuff</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>cinnamon-drab</td><td>cinnamondrab</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>cinnamon-drab</td><td>cinnamondrab</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>cinnamon-rufous</td><td>cinnamonrufous</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>citrine</td><td>citrine</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>citrine</td><td>citrine</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>citrine-drab</td><td>citrinedrab</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>citron green</td><td>citrongreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b57d;width:4em;" /><td>citron green</td><td>citrongreen</td><td>##b9b57d</td><td>185</td> <td>181</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>citron yellow</td><td>citronyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>citron yellow</td><td>citronyellow</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>citron yellow</td><td>citronyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>citron yellow</td><td>citronyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>civette green</td><td>civettegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>claret brown</td><td>claretbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>clay color</td><td>claycolor</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>clay color</td><td>claycolor</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>clay color</td><td>claycolor</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>clear cadet blue</td><td>clearcadetblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>clear cadet blue</td><td>clearcadetblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>clear dull green-yellow</td><td>cleardullgreenyellow</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>clear dull green-yellow</td><td>cleardullgreenyellow</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>clear dull green-yellow</td><td>cleardullgreenyellow</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>clear dull green-yellow</td><td>cleardullgreenyellow</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>clear fluorite green</td><td>clearfluoritegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>clear green-blue gray</td><td>cleargreenbluegray</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>clear green-blue gray</td><td>cleargreenbluegray</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>clear payne's gray </td><td>clearpaynesgray</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>clear payne's gray </td><td>clearpaynesgray</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>clear windsor blue</td><td>clearwindsorblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>clear yellow-green</td><td>clearyellowgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>clove brown</td><td>clovebrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>cobalt green</td><td>cobaltgreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>colonial buff</td><td>colonialbuff</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>columbia blue</td><td>columbiablue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>columbia blue</td><td>columbiablue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>commelina blue</td><td>commelinablue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>congo pink</td><td>congopink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>congo pink</td><td>congopink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>coral pink</td><td>coralpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>coral red</td><td>coralred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>corinthian pink</td><td>corinthianpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>corinthian purple</td><td>corinthianpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>corinthian red</td><td>corinthianred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>cornflower blue</td><td>cornflowerblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>corydalis green</td><td>corydalisgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>corydalis green</td><td>corydalisgreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>cossack green</td><td>cossackgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>cossack green</td><td>cossackgreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>cosse green</td><td>cossegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>cotinga purple</td><td>cotingapurple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>cotinga purple</td><td>cotingapurple</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>courge green</td><td>courgegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>court gray</td><td>courtgray</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>court grey </td><td>courtgrey</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>cream buff</td><td>creambuff</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>cream buff</td><td>creambuff</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>cream color</td><td>creamcolor</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>cress green</td><td>cressgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>cress green</td><td>cressgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>cyanine blue</td><td>cyanineblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dahlia carmine</td><td>dahliacarmine</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dahlia purple</td><td>dahliapurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>daphne pink</td><td>daphnepink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>daphne pink</td><td>daphnepink</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>daphne red</td><td>daphnered</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>dark american green</td><td>darkamericangreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dark american green</td><td>darkamericangreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark american green</td><td>darkamericangreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dark aniline blue</td><td>darkanilineblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dark aniline blue</td><td>darkanilineblue</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>dark anthracene violet</td><td>darkanthraceneviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dark anthracene violet</td><td>darkanthraceneviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>dark bluish glaucous</td><td>darkbluishglaucous</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>dark bluish glaucous</td><td>darkbluishglaucous</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dark bluish gray-green</td><td>darkbluishgraygreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark bluish gray-green</td><td>darkbluishgraygreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>dark bluish gray-green</td><td>darkbluishgraygreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>dark bluish gray-green</td><td>darkbluishgraygreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dark bluish violet</td><td>darkbluishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>dark bluish violet</td><td>darkbluishviolet</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dark bluish violet</td><td>darkbluishviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>dark cadet blue</td><td>darkcadetblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dark cadet blue</td><td>darkcadetblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>dark chessylite blue</td><td>darkchessyliteblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>dark chessylite blue</td><td>darkchessyliteblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>dark chessylite blue</td><td>darkchessyliteblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dark chessylite blue</td><td>darkchessyliteblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>dark cinnabar green</td><td>darkcinnabargreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>dark citrine</td><td>darkcitrine</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dark corinthian purple</td><td>darkcorinthianpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>dark cress green</td><td>darkcressgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>dark delft blue</td><td>darkdelftblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dark delft blue</td><td>darkdelftblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>dark diva blue</td><td>darkdivablue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>dark diva blue</td><td>darkdivablue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dark dull bluish violet</td><td>darkdullbluishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dark dull bluish violet</td><td>darkdullbluishviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dark dull bluish violet</td><td>darkdullbluishviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>dark dull bluish violet</td><td>darkdullbluishviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dark dull violet-blue</td><td>darkdullvioletblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dark dull violet-blue</td><td>darkdullvioletblue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dark dull violet-blue</td><td>darkdullvioletblue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>dark dull yellow-green</td><td>darkdullyellowgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>dark dull yellow-green</td><td>darkdullyellowgreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dark glaucous-gray</td><td>darkglaucousgray</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>dark grayish blue-green</td><td>darkgrayishbluegreen</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dark grayish blue-green</td><td>darkgrayishbluegreen</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dark grayish blue-violet</td><td>darkgrayishblueviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dark grayish brown</td><td>darkgrayishbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>dark grayish brown</td><td>darkgrayishbrown</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>dark grayish lavender</td><td>darkgrayishlavender</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>dark grayish olive</td><td>darkgrayisholive</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dark green-blue gray</td><td>darkgreenbluegray</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>dark green-blue slate</td><td>darkgreenblueslate</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dark green-blue slate</td><td>darkgreenblueslate</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>dark greenish glaucous</td><td>darkgreenishglaucous</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>dark greenish glaucous</td><td>darkgreenishglaucous</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>dark greenish olive</td><td>darkgreenisholive</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>dark greenish olive</td><td>darkgreenisholive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dark gull gray</td><td>darkgullgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dark heliotrope gray</td><td>darkheliotropegray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dark heliotrope slate</td><td>darkheliotropeslate</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dark heliotrope slate</td><td>darkheliotropeslate</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>dark hyssop violet</td><td>darkhyssopviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dark hyssop violet</td><td>darkhyssopviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dark indian red</td><td>darkindianred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>dark indian red</td><td>darkindianred</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>dark ivy green</td><td>darkivygreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>dark lavender</td><td>darklavender</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dark livid brown</td><td>darklividbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dark livid purple</td><td>darklividpurple</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dark livid purple</td><td>darklividpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dark madder blue</td><td>darkmadderblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dark madder blue</td><td>darkmadderblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>dark madder violet</td><td>darkmadderviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dark madder violet</td><td>darkmadderviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>dark maroon purple</td><td>darkmaroonpurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>dark medici blue</td><td>darkmediciblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dark mineral red </td><td>darkmineralred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>dark mineral red </td><td>darkmineralred</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>dark mouse gray </td><td>darkmousegray</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dark mouse gray </td><td>darkmousegray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dark naphthalene violet </td><td>darknaphthaleneviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>dark naphthalene violet </td><td>darknaphthaleneviolet</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dark neutral gray</td><td>darkneutralgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>dark nigrosin violet</td><td>darknigrosinviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>dark olive</td><td>darkolive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>dark olive-buff</td><td>darkolivebuff</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>dark olive-gray</td><td>darkolivegray</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>dark olive-gray</td><td>darkolivegray</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dark orient blue</td><td>darkorientblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dark payne's gray</td><td>darkpaynesgray</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>dark payne's gray</td><td>darkpaynesgray</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dark perilla purple</td><td>darkperillapurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>dark plumbago blue</td><td>darkplumbagoblue</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>dark plumbago blue</td><td>darkplumbagoblue</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dark plumbago gray</td><td>darkplumbagogray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>dark plumbago gray</td><td>darkplumbagogray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dark plumbago gray</td><td>darkplumbagogray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dark plumbago slate</td><td>darkplumbagoslate</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>dark plumbeous</td><td>darkplumbeous</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dark porcelain green</td><td>darkporcelaingreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dark purple-drab</td><td>darkpurpledrab</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dark purplish gray</td><td>darkpurplishgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dark purplish gray</td><td>darkpurplishgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dark quaker drab</td><td>darkquakerdrab</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dark russian green</td><td>darkrussiangreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark russian green</td><td>darkrussiangreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>dark slate-purple</td><td>darkslatepurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dark slate-violet </td><td>darkslateviolet</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dark slate-violet </td><td>darkslateviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>dark soft blue-violet</td><td>darksoftblueviolet</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dark soft blue-violet</td><td>darksoftblueviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dark soft bluish violet</td><td>darksoftbluishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>dark sulphate green</td><td>darksulphategreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dark terre verte</td><td>darkterreverte</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dark tyrian blue</td><td>darktyrianblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dark tyrian blue</td><td>darktyrianblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dark varley's gray</td><td>darkvarleysgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dark vinaceous</td><td>darkvinaceous</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dark vinaceous-brown</td><td>darkvinaceousbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>dark vinaceous-drab</td><td>darkvinaceousdrab</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>dark vinaceous-drab</td><td>darkvinaceousdrab</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dark vinaceous-gray</td><td>darkvinaceousgray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dark vinaceous-purple</td><td>darkvinaceouspurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dark violet</td><td>darkviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dark violet-gray</td><td>darkvioletgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dark violet-gray</td><td>darkvioletgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dark violet-slate</td><td>darkvioletslate</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>dark viridian green</td><td>darkviridiangreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>dark yellowish green</td><td>darkyellowishgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dark yvette violet</td><td>darkyvetteviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>dark zinc green</td><td>darkzincgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dauphin's violet</td><td>dauphinsviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>dawn gray</td><td>dawngray</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>dawn gray</td><td>dawngray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>deep aniline lilac</td><td>deepanilinelilac</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>deep blue-violet</td><td>deepblueviolet</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>deep blue-violet</td><td>deepblueviolet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>deep bluish glaucous</td><td>deepbluishglaucous</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>deep bluish gray-green</td><td>deepbluishgraygreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>deep bluish gray-green</td><td>deepbluishgraygreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>deep brownish drab</td><td>deepbrownishdrab</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>deep brownish vinaceous</td><td>deepbrownishvinaceous</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>deep cadet blue</td><td>deepcadetblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>deep chicory blue</td><td>deepchicoryblue</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>deep chrome</td><td>deepchrome</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>deep chrysolite green</td><td>deepchrysolitegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>deep colonial buff</td><td>deepcolonialbuff</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>deep corinthian red</td><td>deepcorinthianred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>deep delft blue</td><td>deepdelftblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>deep dull bluish violet</td><td>deepdullbluishviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>deep dull bluish violet</td><td>deepdullbluishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>deep dull bluish violet</td><td>deepdullbluishviolet</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>deep dull bluish violet</td><td>deepdullbluishviolet</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>deep dull bluish violet</td><td>deepdullbluishviolet</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>deep dull bluish violet</td><td>deepdullbluishviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>deep dull bluish violet</td><td>deepdullbluishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>deep dull lavender</td><td>deepdulllavender</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>deep dull violaceous blue</td><td>deepdullviolaceousblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>deep dull violet-blue</td><td>deepdullvioletblue</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>deep dutch blue</td><td>deepdutchblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>deep dutch blue</td><td>deepdutchblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>deep glaucous-gray</td><td>deepglaucousgray</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>deep glaucous-green</td><td>deepglaucousgreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>deep grape green</td><td>deepgrapegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>deep grape green</td><td>deepgrapegreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>deep grayish blue-green</td><td>deepgrayishbluegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>deep grayish lavender </td><td>deepgrayishlavender</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>deep grayish lavender </td><td>deepgrayishlavender</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>deep grayish olive</td><td>deepgrayisholive</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>deep green-blue gray</td><td>deepgreenbluegray</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>deep greenish glaucous</td><td>deepgreenishglaucous</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>deep gull gray</td><td>deepgullgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>deep heliotrope gray </td><td>deepheliotropegray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>deep hyssop violet</td><td>deephyssopviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>deep lavender</td><td>deeplavender</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>deep lavender-blue</td><td>deeplavenderblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>deep lichen green</td><td>deeplichengreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>deep livid brown</td><td>deeplividbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>deep livid purple</td><td>deeplividpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>deep madder blue</td><td>deepmadderblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>deep malachite green</td><td>deepmalachitegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>deep medici blue</td><td>deepmediciblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>deep mouse gray </td><td>deepmousegray</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>deep mouse gray </td><td>deepmousegray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>deep mouse gray </td><td>deepmousegray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>deep neutral gray</td><td>deepneutralgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>deep olive</td><td>deepolive</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>deep olive</td><td>deepolive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>deep olive-buff</td><td>deepolivebuff</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>deep olive-gray</td><td>deepolivegray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>deep orient blue</td><td>deeporientblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>deep payne's gray</td><td>deeppaynesgray</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>deep plumbago blue</td><td>deepplumbagoblue</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>deep plumbago gray</td><td>deepplumbagogray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>deep plumbeous</td><td>deepplumbeous</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>deep plumbeous</td><td>deepplumbeous</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>deep purplish gray</td><td>deeppurplishgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>deep purplish vinaceous</td><td>deeppurplishvinaceous</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>deep quaker drab</td><td>deepquakerdrab</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>deep rose pink</td><td>deeprosepink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>deep sea-foam green </td><td>deepseafoamgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>deep slate-blue</td><td>deepslateblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>deep slate-green</td><td>deepslategreen</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>deep slate-olive</td><td>deepslateolive</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>deep slate-violet</td><td>deepslateviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>deep slaty brown</td><td>deepslatybrown</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>deep soft blue-violet</td><td>deepsoftblueviolet</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>deep soft blue-violet</td><td>deepsoftblueviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>deep soft bluish violet</td><td>deepsoftbluishviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>deep turtle green</td><td>deepturtlegreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>deep turtle green</td><td>deepturtlegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>deep varley's gray</td><td>deepvarleysgray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>deep varley's gray</td><td>deepvarleysgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>deep vinaceous</td><td>deepvinaceous</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>deep vinaceous-gray</td><td>deepvinaceousgray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>deep vinaceous-lavender</td><td>deepvinaceouslavender</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>deep vinaceous-lavender</td><td>deepvinaceouslavender</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>deep violet-gray</td><td>deepvioletgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>deep violet-gray</td><td>deepvioletgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>deep violet-gray</td><td>deepvioletgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>deep violet-gray</td><td>deepvioletgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>deep violet-plumbeous </td><td>deepvioletplumbeous</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>deep wedgewood blue</td><td>deepwedgewoodblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>delft blue</td><td>delftblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>diamin-azo blue</td><td>diaminazoblue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>diamin-azo blue</td><td>diaminazoblue</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>diamine brown</td><td>diaminebrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>diamine green</td><td>diaminegreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>diamine green</td><td>diaminegreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>diva blue</td><td>divablue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>diva blue</td><td>divablue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>drab</td><td>drab</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>drab</td><td>drab</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>drab</td><td>drab</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>drab</td><td>drab</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>drab-gray</td><td>drabgray</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>drab-gray</td><td>drabgray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>dragons-blood red</td><td>dragonsbloodred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>dresden brown</td><td>dresdenbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>duck green</td><td>duckgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dull blackish green</td><td>dullblackishgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dull blue-green black</td><td>dullbluegreenblack</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>dull blue-green black</td><td>dullbluegreenblack</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#202428;width:4em;" /><td>dull blue-green black</td><td>dullbluegreenblack</td><td>##202428</td><td>32</td> <td>36</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>dull blue-violet</td><td>dullblueviolet</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>dull blue-violet</td><td>dullblueviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>dull blue-violet</td><td>dullblueviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dull blue-violet</td><td>dullblueviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dull bluish violet</td><td>dullbluishviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>dull citrine</td><td>dullcitrine</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>dull citrine</td><td>dullcitrine</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>dull dark purple</td><td>dulldarkpurple</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>dull dark purple</td><td>dulldarkpurple</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>dull dark purple</td><td>dulldarkpurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dull dusky purple</td><td>dullduskypurple</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>dull dusky purple</td><td>dullduskypurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>dull greenish black </td><td>dullgreenishblack</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dull greenish black </td><td>dullgreenishblack</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>dull greenish black </td><td>dullgreenishblack</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dull greenish black </td><td>dullgreenishblack</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>dull green-yellow</td><td>dullgreenyellow</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>dull indian purple</td><td>dullindianpurple</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>dull lavender</td><td>dulllavender</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>dull magenta purple</td><td>dullmagentapurple</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>dull opaline green</td><td>dullopalinegreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dull purplish black</td><td>dullpurplishblack</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>dull violaceous blue</td><td>dullviolaceousblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dull violet-black </td><td>dullvioletblack</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dull violet-black </td><td>dullvioletblack</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>dull violet-black </td><td>dullvioletblack</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dull violet-black </td><td>dullvioletblack</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dull violet-black </td><td>dullvioletblack</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dull violet-black </td><td>dullvioletblack</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>dull violet-black </td><td>dullvioletblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>dull violet-blue</td><td>dullvioletblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dull violet-blue</td><td>dullvioletblue</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>dusky auricula purple</td><td>duskyauriculapurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dusky blue</td><td>duskyblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dusky blue-green</td><td>duskybluegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dusky blue-violet</td><td>duskyblueviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>dusky blue-violet</td><td>duskyblueviolet</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dusky blue-violet</td><td>duskyblueviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>dusky bluish green</td><td>duskybluishgreen</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dusky brown </td><td>duskybrown</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dusky brown </td><td>duskybrown</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>dusky drab</td><td>duskydrab</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dusky dull bluish green</td><td>duskydullbluishgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dusky dull green</td><td>duskydullgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>dusky dull green</td><td>duskydullgreen</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>dusky dull violet </td><td>duskydullviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>dusky dull violet </td><td>duskydullviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>dusky dull violet </td><td>duskydullviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dusky dull violet </td><td>duskydullviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dusky dull violet-blue </td><td>duskydullvioletblue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dusky green</td><td>duskygreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dusky green</td><td>duskygreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>dusky green-blue </td><td>duskygreenblue</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>dusky green-blue </td><td>duskygreenblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dusky green-blue </td><td>duskygreenblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dusky green-blue </td><td>duskygreenblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dusky green-blue </td><td>duskygreenblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dusky green-gray</td><td>duskygreengray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>dusky greenish blue</td><td>duskygreenishblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>dusky greenish blue</td><td>duskygreenishblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>dusky greenish blue</td><td>duskygreenishblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dusky neutral gray</td><td>duskyneutralgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>dusky olive-green</td><td>duskyolivegreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dusky orient blue</td><td>duskyorientblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dusky purplish gray</td><td>duskypurplishgray</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dusky purplish gray</td><td>duskypurplishgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>dusky purplish gray</td><td>duskypurplishgray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>dusky purplish gray</td><td>duskypurplishgray</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dusky slate-blue</td><td>duskyslateblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dusky slate-violet</td><td>duskyslateviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>dusky slate-violet</td><td>duskyslateviolet</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dusky violet</td><td>duskyviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dusky violet-blue </td><td>duskyvioletblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>dusky violet-blue </td><td>duskyvioletblue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dusky violet-blue </td><td>duskyvioletblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>dusky yellowish green</td><td>duskyyellowishgreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>dutch blue</td><td>dutchblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>dutch blue</td><td>dutchblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>ecru-drab</td><td>ecrudrab</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>ecru-olive</td><td>ecruolive</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>ecru-olive</td><td>ecruolive</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>elm green</td><td>elmgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>elm green</td><td>elmgreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>emerald green</td><td>emeraldgreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>empire green</td><td>empiregreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>empire green</td><td>empiregreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>empire yellow</td><td>empireyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>endive blue</td><td>endiveblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>endive blue</td><td>endiveblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>english red</td><td>englishred</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>eosine pink</td><td>eosinepink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>ethyl green</td><td>ethylgreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>ethyl green</td><td>ethylgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>eton blue</td><td>etonblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>etruscan red</td><td>etruscanred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>eugenia red</td><td>eugeniared</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>eupatorium purple</td><td>eupatoriumpurple</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>eupatorium purple</td><td>eupatoriumpurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>fawn color</td><td>fawncolor</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>fawn color</td><td>fawncolor</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>fawn color</td><td>fawncolor</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>ferruginous</td><td>ferruginous</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>ferruginous</td><td>ferruginous</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>flame scarlet </td><td>flamescarlet</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>flax-flower blue </td><td>flaxflowerblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>flesh color</td><td>fleshcolor</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>flesh-ochre </td><td>fleshochre</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>flesh pink</td><td>fleshpink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>flesh pink</td><td>fleshpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>fluorite green</td><td>fluoritegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>fluorite violet</td><td>fluoriteviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>forest green</td><td>forestgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>forest green</td><td>forestgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>forget-me-not blue</td><td>forgetmenotblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>french gray</td><td>frenchgray</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>french gray</td><td>frenchgray</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>french green</td><td>frenchgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>fuscous</td><td>fuscous</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>fuscous-black</td><td>fuscousblack</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>fuscous-black</td><td>fuscousblack</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>garnet brown</td><td>garnetbrown</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>gendarme blue</td><td>gendarmeblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>gentian blue</td><td>gentianblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>geranium pink</td><td>geraniumpink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>geranium pink</td><td>geraniumpink</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>glass green</td><td>glassgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>glaucous</td><td>glaucous</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>glaucous-blue</td><td>glaucousblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>glaucous-gray</td><td>glaucousgray</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>glaucous-green</td><td>glaucousgreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>gnaphalium green</td><td>gnaphaliumgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>gnaphalium green</td><td>gnaphaliumgreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>grass green</td><td>grassgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>grayish blue-green</td><td>grayishbluegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>grayish blue-violet </td><td>grayishblueviolet</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>grayish blue-violet </td><td>grayishblueviolet</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>grayish blue-violet </td><td>grayishblueviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>grayish blue-violet </td><td>grayishblueviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>grayish blue-violet </td><td>grayishblueviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>grayish lavender</td><td>grayishlavender</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>grayish olive</td><td>grayisholive</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>grayish violaceous blue</td><td>grayishviolaceousblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>grayish violet-blue</td><td>grayishvioletblue</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>grayish violet-blue</td><td>grayishvioletblue</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>green-blue slate</td><td>greenblueslate</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>greenish glaucous</td><td>greenishglaucous</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>greenish glaucous-blue</td><td>greenishglaucousblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>greenish slate-black</td><td>greenishslateblack</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>greenish slate-black</td><td>greenishslateblack</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>greenish slate-black</td><td>greenishslateblack</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>greenish slate-black</td><td>greenishslateblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>greenish yellow</td><td>greenishyellow</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>green-yellow</td><td>greenyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>grenadine</td><td>grenadine</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>grenadine pink</td><td>grenadinepink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>grenadine red </td><td>grenadinered</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>guinea green</td><td>guineagreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gull gray</td><td>gullgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>haematite red</td><td>haematitered</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>haematoxylin violet</td><td>haematoxylinviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>hair brown</td><td>hairbrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>hathi gray</td><td>hathigray</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>hathi gray</td><td>hathigray</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>hathi gray</td><td>hathigray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>hathi gray</td><td>hathigray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>hay's blue</td><td>haysblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>hay's brown</td><td>haysbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>hay's brown</td><td>haysbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>hay's green</td><td>haysgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>hay's green</td><td>haysgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>hay's lilac</td><td>hayslilac</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>hay's maroon</td><td>haysmaroon</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>hay's russet</td><td>haysrusset</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>hazel</td><td>hazel</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>heliotrope gray</td><td>heliotropegray</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>heliotrope gray</td><td>heliotropegray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>heliotrope slate</td><td>heliotropeslate</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>hellebore red</td><td>helleborered</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>helvetia blue</td><td>helvetiablue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>hermosa pink</td><td>hermosapink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>hessian brown</td><td>hessianbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#43302e;width:4em;" /><td>hessian brown</td><td>hessianbrown</td><td>##43302e</td><td>67</td> <td>48</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>honey yellow</td><td>honeyyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>honey yellow</td><td>honeyyellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>hortense blue</td><td>hortenseblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#d399e6;width:4em;" /><td>hortense violet</td><td>hortenseviolet</td><td>##d399e6</td><td>211</td> <td>153</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>hyacinth blue</td><td>hyacinthblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>hyacinth blue</td><td>hyacinthblue</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>hyacinth violet</td><td>hyacinthviolet</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>hydrangea pink</td><td>hydrangeapink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>hydrangea pink</td><td>hydrangeapink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>hydrangea red</td><td>hydrangeared</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>hyssop violet</td><td>hyssopviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>indian lake</td><td>indianlake</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>indian lake</td><td>indianlake</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>indian purple</td><td>indianpurple</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>indian purple</td><td>indianpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>indian red</td><td>indianred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>indigo blue</td><td>indigoblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>indigo blue</td><td>indigoblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>indigo blue</td><td>indigoblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>indigo blue</td><td>indigoblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>indulin blue</td><td>indulinblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>invisible green</td><td>invisiblegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>invisible green</td><td>invisiblegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>iron gray</td><td>irongray</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>isabella color</td><td>isabellacolor</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>italian blue</td><td>italianblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>ivory yellow</td><td>ivoryyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>ivy green</td><td>ivygreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>ivy green</td><td>ivygreen</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>jade green</td><td>jadegreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>jade green</td><td>jadegreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>japan rose</td><td>japanrose</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>jasper green</td><td>jaspergreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>jasper pink</td><td>jasperpink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>jasper pink</td><td>jasperpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>jasper pink</td><td>jasperpink</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>jasper red</td><td>jasperred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>javel green</td><td>javelgreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>jay blue </td><td>jayblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>jay blue </td><td>jayblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>jouvence blue</td><td>jouvenceblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>jouvence blue</td><td>jouvenceblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>kaiser brown</td><td>kaiserbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>kildare green</td><td>kildaregreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>killarney green </td><td>killarneygreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>king's blue</td><td>kingsblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>kronberg's green</td><td>kronbergsgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>kronberg's green</td><td>kronbergsgreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>laelia pink</td><td>laeliapink</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>laelia pink</td><td>laeliapink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb5ba;width:4em;" /><td>la france pink</td><td>lafrancepink</td><td>##ffb5ba</td><td>255</td> <td>181</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>lavender</td><td>lavender</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>lavender</td><td>lavender</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>lavender-blue</td><td>lavenderblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>lavender-blue</td><td>lavenderblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>lavender-gray</td><td>lavendergray</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>lavender-gray</td><td>lavendergray</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>lavender-gray</td><td>lavendergray</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>lavender-gray</td><td>lavendergray</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>lavender-violet</td><td>lavenderviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>leaf green</td><td>leafgreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>leitch's blue</td><td>leitchsblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>lemon chrome</td><td>lemonchrome</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>lettuce green</td><td>lettucegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>lichen green</td><td>lichengreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>light alice blue</td><td>lightaliceblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>light alice blue</td><td>lightaliceblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>light amparo blue</td><td>lightamparoblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#d399e6;width:4em;" /><td>light amparo purple</td><td>lightamparopurple</td><td>##d399e6</td><td>211</td> <td>153</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>light bice green</td><td>lightbicegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>light blue-green</td><td>lightbluegreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>light blue-green</td><td>lightbluegreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>light blue-violet</td><td>lightblueviolet</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>light bluish violet</td><td>lightbluishviolet</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>light bluish violet</td><td>lightbluishviolet</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>light bluish violet</td><td>lightbluishviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>light brownish drab</td><td>lightbrownishdrab</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>light brownish olive</td><td>lightbrownisholive</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>light brownish vinaceous</td><td>lightbrownishvinaceous</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>light buff</td><td>lightbuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>light buff</td><td>lightbuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>light cadet blue</td><td>lightcadetblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>light cadmium</td><td>lightcadmium</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>light campanula blue</td><td>lightcampanulablue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>light celandine green</td><td>lightcelandinegreen</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>light celandine green</td><td>lightcelandinegreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>light cendre green</td><td>lightcendregreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>light cendre green</td><td>lightcendregreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>light cerulean blue</td><td>lightceruleanblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>light chalcedony yellow</td><td>lightchalcedonyyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>light chicory blue</td><td>lightchicoryblue</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>light cinnamon-drab</td><td>lightcinnamondrab</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>light cinnamon-drab</td><td>lightcinnamondrab</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>light columbia blue</td><td>lightcolumbiablue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>light congo pink</td><td>lightcongopink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>light congo pink</td><td>lightcongopink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>light coral red</td><td>lightcoralred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>light corinthian red</td><td>lightcorinthianred</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>light cress green</td><td>lightcressgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>light danube green</td><td>lightdanubegreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>light drab</td><td>lightdrab</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>light dull bluish violet</td><td>lightdullbluishviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>light dull glaucous-blue</td><td>lightdullglaucousblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>light dull glaucous-blue</td><td>lightdullglaucousblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>light dull green-yellow</td><td>lightdullgreenyellow</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>light elm green</td><td>lightelmgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>light fluorite green</td><td>lightfluoritegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>light forget-me-not blue </td><td>lightforgetmenotblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>light glaucous-blue</td><td>lightglaucousblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>light grape green</td><td>lightgrapegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>light grayish blue-violet</td><td>lightgrayishblueviolet</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>light grayish blue-violet</td><td>lightgrayishblueviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>light grayish olive</td><td>lightgrayisholive</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>light grayish olive</td><td>lightgrayisholive</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>light grayish vinaceous</td><td>lightgrayishvinaceous</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>light grayish violet-blue</td><td>lightgrayishvioletblue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>light greenish yellow</td><td>lightgreenishyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>light greenish yellow</td><td>lightgreenishyellow</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>light green-yellow</td><td>lightgreenyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>light gull gray</td><td>lightgullgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>light heliotrope gray</td><td>lightheliotropegray</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>light hellebore green</td><td>lighthelleboregreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>light hellebore green</td><td>lighthelleboregreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d399e6;width:4em;" /><td>light hortense violet</td><td>lighthortenseviolet</td><td>##d399e6</td><td>211</td> <td>153</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>light hyssop violet</td><td>lighthyssopviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>light jasper red</td><td>lightjasperred</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>light jasper red</td><td>lightjasperred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>light king's blue</td><td>lightkingsblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>light king's blue</td><td>lightkingsblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>light lavender-blue</td><td>lightlavenderblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>light lavender-violet</td><td>lightlavenderviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>light lobelia violet</td><td>lightlobeliaviolet</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>light lumiere green</td><td>lightlumieregreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>light mallow purple</td><td>lightmallowpurple</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>light mauve</td><td>lightmauve</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>light medici blue</td><td>lightmediciblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>light methyl blue </td><td>lightmethylblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>light methyl blue </td><td>lightmethylblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>light mineral gray </td><td>lightmineralgray</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>light mouse gray </td><td>lightmousegray</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>light neropalin blue</td><td>lightneropalinblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>light neutral gray</td><td>lightneutralgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>light niagara green</td><td>lightniagaragreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>light ochraceous-buff</td><td>lightochraceousbuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>light ochraceous-salmon</td><td>lightochraceoussalmon</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>light olive-gray</td><td>lightolivegray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>light orange-yellow</td><td>lightorangeyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>light orange-yellow</td><td>lightorangeyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>light oriental green</td><td>lightorientalgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>light paris green</td><td>lightparisgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>light payne's gray</td><td>lightpaynesgray</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>light payne's gray</td><td>lightpaynesgray</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>light perilla purple</td><td>lightperillapurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>light perilla purple</td><td>lightperillapurple</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>light phlox purple</td><td>lightphloxpurple</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>light pinkish cinnamon</td><td>lightpinkishcinnamon</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>light pinkish cinnamon</td><td>lightpinkishcinnamon</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>light pinkish lilac</td><td>lightpinkishlilac</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>light plumbago gray</td><td>lightplumbagogray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>light porcelain green</td><td>lightporcelaingreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>light porcelain green</td><td>lightporcelaingreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>light purple-drab</td><td>lightpurpledrab</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>light purplish gray</td><td>lightpurplishgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>light purplish gray</td><td>lightpurplishgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>light purplish vinaceous</td><td>lightpurplishvinaceous</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>light quaker drab </td><td>lightquakerdrab</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>light rosolane purple</td><td>lightrosolanepurple</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>light russet-vinaceous</td><td>lightrussetvinaceous</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>light salmon-orange</td><td>lightsalmonorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>light seal brown</td><td>lightsealbrown</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>light sky blue</td><td>lightskyblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>light soft blue-violet</td><td>lightsoftblueviolet</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>light soft blue-violet</td><td>lightsoftblueviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>light squill blue</td><td>lightsquillblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>light sulphate green</td><td>lightsulphategreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>light terre verte</td><td>lightterreverte</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>light turtle green</td><td>lightturtlegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>light tyrian blue</td><td>lighttyrianblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>light tyrian blue</td><td>lighttyrianblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>light tyrian blue</td><td>lighttyrianblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>light varley's gray</td><td>lightvarleysgray</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>light vinaceous-cinnamon</td><td>lightvinaceouscinnamon</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>light vinaceous-drab</td><td>lightvinaceousdrab</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>light vinaceous-fawn</td><td>lightvinaceousfawn</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>light vinaceous-fawn</td><td>lightvinaceousfawn</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>light vinaceous-gray</td><td>lightvinaceousgray</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>light vinaceous-gray</td><td>lightvinaceousgray</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>light vinaceous-gray</td><td>lightvinaceousgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>light vinaceous-gray</td><td>lightvinaceousgray</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>light vinaceous-lilac</td><td>lightvinaceouslilac</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>light vinaceous-lilac</td><td>lightvinaceouslilac</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>light vinaceous-lilac</td><td>lightvinaceouslilac</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>light vinaceous-lilac</td><td>lightvinaceouslilac</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>light vinaceous-purple</td><td>lightvinaceouspurple</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>light violet</td><td>lightviolet</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>light violet</td><td>lightviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>light violet-blue</td><td>lightvioletblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>light violet-gray</td><td>lightvioletgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>light violet-gray</td><td>lightvioletgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>light violet-plumbeous </td><td>lightvioletplumbeous</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>light violet-plumbeous </td><td>lightvioletplumbeous</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>light violet-plumbeous </td><td>lightvioletplumbeous</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>light viridine green</td><td>lightviridinegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>light viridine yellow</td><td>lightviridineyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>light windsor blue</td><td>lightwindsorblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>light wistaria blue </td><td>lightwistariablue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>light wistaria blue </td><td>lightwistariablue</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>light wistaria violet</td><td>lightwistariaviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>light yellow-green</td><td>lightyellowgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>light yellow-green</td><td>lightyellowgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>light yellowish olive</td><td>lightyellowisholive</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>lilac</td><td>lilac</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>lilac</td><td>lilac</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>lilac gray</td><td>lilacgray</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>lily green</td><td>lilygreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>lime green</td><td>limegreen</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>lime green</td><td>limegreen</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>lime green</td><td>limegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>lincoln green</td><td>lincolngreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>liseran purple</td><td>liseranpurple</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>liseran purple</td><td>liseranpurple</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>liseran purple</td><td>liseranpurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>liseran purple</td><td>liseranpurple</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>litho purple</td><td>lithopurple</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>litho purple</td><td>lithopurple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>litho purple</td><td>lithopurple</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>liver brown</td><td>liverbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>livid brown</td><td>lividbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>livid pink</td><td>lividpink</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>livid pink</td><td>lividpink</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>livid pink</td><td>lividpink</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>livid pink</td><td>lividpink</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>livid purple</td><td>lividpurple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>livid violet</td><td>lividviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>livid violet</td><td>lividviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>lobelia violet</td><td>lobeliaviolet</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>lumiere blue</td><td>lumiereblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>lumiere blue</td><td>lumiereblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>lumiere green</td><td>lumieregreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>lumiere green</td><td>lumieregreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>lyons blue</td><td>lyonsblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>madder blue</td><td>madderblue</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>madder blue</td><td>madderblue</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>madder brown</td><td>madderbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>madder violet</td><td>madderviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>magenta</td><td>magenta</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>mahogany red</td><td>mahoganyred</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>maize yellow</td><td>maizeyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>malachite green</td><td>malachitegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>mallow pink</td><td>mallowpink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>mallow purple</td><td>mallowpurple</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>mallow purple</td><td>mallowpurple</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>manganese violet</td><td>manganeseviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>marguerite yellow</td><td>margueriteyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>marine blue</td><td>marineblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#3e1d1e;width:4em;" /><td>maroon</td><td>maroon</td><td>##3e1d1e</td><td>62</td> <td>29</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>mars brown</td><td>marsbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>mars orange</td><td>marsorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>mars orange</td><td>marsorange</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>mars violet</td><td>marsviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#c98500;width:4em;" /><td>mars yellow</td><td>marsyellow</td><td>##c98500</td><td>201</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>mars yellow</td><td>marsyellow</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>martius yellow</td><td>martiusyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>massicot yellow</td><td>massicotyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>massicot yellow</td><td>massicotyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>mathew's blue</td><td>mathewsblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>mathew's purple</td><td>mathewspurple</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>mathew's purple</td><td>mathewspurple</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>mauve</td><td>mauve</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>mauvette</td><td>mauvette</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>mazarine blue</td><td>mazarineblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>mazarine blue</td><td>mazarineblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>meadow green</td><td>meadowgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>medal bronze</td><td>medalbronze</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>medici blue</td><td>mediciblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>methyl blue </td><td>methylblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>methyl green </td><td>methylgreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>methyl green </td><td>methylgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>microcline green </td><td>microclinegreen</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>mignonette green </td><td>mignonettegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>mikado brown </td><td>mikadobrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>mikado orange </td><td>mikadoorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>mineral gray </td><td>mineralgray</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>mineral green </td><td>mineralgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>mineral red </td><td>mineralred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>montpellier green </td><td>montpelliergreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>montpellier green </td><td>montpelliergreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>morocco red </td><td>moroccored</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>motmot blue </td><td>motmotblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>motmot green </td><td>motmotgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>motmot green </td><td>motmotgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>mouse gray </td><td>mousegray</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>mulberry purple </td><td>mulberrypurple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>mulberry purple </td><td>mulberrypurple</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>mummy brown </td><td>mummybrown</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>munich lake </td><td>munichlake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>munich lake </td><td>munichlake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>mustard yellow </td><td>mustardyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>myrtle green </td><td>myrtlegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>mytho green </td><td>mythogreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>mytho green </td><td>mythogreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>naphthalene violet </td><td>naphthaleneviolet</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>naphthalene yellow </td><td>naphthaleneyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>naphthalene yellow </td><td>naphthaleneyellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>naples yellow </td><td>naplesyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>natal brown</td><td>natalbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>navy blue</td><td>navyblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>navy blue</td><td>navyblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>neropalin blue</td><td>neropalinblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>neutral gray</td><td>neutralgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>neutral red</td><td>neutralred</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>neutral red</td><td>neutralred</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>neuvider green</td><td>neuvidergreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>neva green</td><td>nevagreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>niagara green</td><td>niagaragreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>niagara green</td><td>niagaragreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>nickel green</td><td>nickelgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>nickel green</td><td>nickelgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#8db600;width:4em;" /><td>night green</td><td>nightgreen</td><td>##8db600</td><td>141</td> <td>182</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>nigrosin blue</td><td>nigrosinblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>nigrosin violet </td><td>nigrosinviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>nile blue</td><td>nileblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>nopal red</td><td>nopalred</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>ocher red</td><td>ocherred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>ochraceous-buff</td><td>ochraceousbuff</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>ochraceous-buff</td><td>ochraceousbuff</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>ochraceous-orange</td><td>ochraceousorange</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#c98500;width:4em;" /><td>ochraceous-orange</td><td>ochraceousorange</td><td>##c98500</td><td>201</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>ochraceous-salmon</td><td>ochraceoussalmon</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>ochraceous-tawny</td><td>ochraceoustawny</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>ochraceous-tawny</td><td>ochraceoustawny</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>oil green</td><td>oilgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#2e1d21;width:4em;" /><td>old burgundy</td><td>oldburgundy</td><td>##2e1d21</td><td>46</td> <td>29</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>old gold</td><td>oldgold</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>old gold</td><td>oldgold</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>old rose</td><td>oldrose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olive</td><td>olive</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive</td><td>olive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>olive-brown </td><td>olivebrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>olive-buff</td><td>olivebuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>olive-buff</td><td>olivebuff</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olive-citrine</td><td>olivecitrine</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>olive-gray </td><td>olivegray</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>olive-gray </td><td>olivegray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>olive lake</td><td>olivelake</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>olive lake</td><td>olivelake</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>olive-ocher</td><td>oliveocher</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>olive-ocher</td><td>oliveocher</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>olive-yellow </td><td>oliveyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>olivine</td><td>olivine</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>olympic blue</td><td>olympicblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>onion-skin pink</td><td>onionskinpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>onion-skin pink</td><td>onionskinpink</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>ontario violet</td><td>ontarioviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>opaline green</td><td>opalinegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>opaline green</td><td>opalinegreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange</td><td>orange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>orange-buff </td><td>orangebuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>orange chrome</td><td>orangechrome</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>orange-cinnamon</td><td>orangecinnamon</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>orange-citrine</td><td>orangecitrine</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#fd943f;width:4em;" /><td>orange-pink</td><td>orangepink</td><td>##fd943f</td><td>253</td> <td>148</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>orange-pink</td><td>orangepink</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>orange-rufous </td><td>orangerufous</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>orange-vinaceous </td><td>orangevinaceous</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>orange-vinaceous </td><td>orangevinaceous</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>oriental green</td><td>orientalgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>orient blue</td><td>orientblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>orient blue</td><td>orientblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>orient pink</td><td>orientpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b6e5af;width:4em;" /><td>oural green</td><td>ouralgreen</td><td>##b6e5af</td><td>182</td> <td>229</td> <td>175</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>oural green</td><td>ouralgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>ox-blood red </td><td>oxbloodred</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>oxide blue</td><td>oxideblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>oxide blue</td><td>oxideblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>pale amaranth pink</td><td>paleamaranthpink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pale amparo blue</td><td>paleamparoblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pale amparo blue</td><td>paleamparoblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>pale amparo purple</td><td>paleamparopurple</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>pale aniline lilac</td><td>paleanilinelilac</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>pale aniline lilac</td><td>paleanilinelilac</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>pale blue</td><td>paleblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pale blue</td><td>paleblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>pale blue-green</td><td>palebluegreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>pale blue-violet</td><td>paleblueviolet</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>pale bluish lavender </td><td>palebluishlavender</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>pale bluish lavender </td><td>palebluishlavender</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>pale bluish violet</td><td>palebluishviolet</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pale brownish drab</td><td>palebrownishdrab</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#ead8d7;width:4em;" /><td>pale brownish vinaceous</td><td>palebrownishvinaceous</td><td>##ead8d7</td><td>234</td> <td>216</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>pale brownish vinaceous</td><td>palebrownishvinaceous</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>pale cadet blue</td><td>palecadetblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pale cadet blue</td><td>palecadetblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pale cadet blue</td><td>palecadetblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>pale cadet blue</td><td>palecadetblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>pale campanula blue</td><td>palecampanulablue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pale campanula blue</td><td>palecampanulablue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale cendre green</td><td>palecendregreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>pale cendre green</td><td>palecendregreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>pale cerulean blue</td><td>paleceruleanblue</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>pale cerulean blue</td><td>paleceruleanblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>pale chalcedony yellow</td><td>palechalcedonyyellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pale cinnamon-pink</td><td>palecinnamonpink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>pale cinnamon-pink</td><td>palecinnamonpink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>pale cinnamon-pink</td><td>palecinnamonpink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>pale cinnamon-pink</td><td>palecinnamonpink</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pale congo pink</td><td>palecongopink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>pale congo pink</td><td>palecongopink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>pale congo pink</td><td>palecongopink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>pale congo pink</td><td>palecongopink</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>pale drab-gray</td><td>paledrabgray</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pale drab-gray</td><td>paledrabgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pale dull glaucous-blue</td><td>paledullglaucousblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pale dull glaucous-blue</td><td>paledullglaucousblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale dull green-yellow</td><td>paledullgreenyellow</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pale ecru-drab</td><td>paleecrudrab</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pale flesh color</td><td>palefleshcolor</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>pale flesh color</td><td>palefleshcolor</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>pale fluorite green</td><td>palefluoritegreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale glass green</td><td>paleglassgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>pale glass green</td><td>paleglassgreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>pale glaucous-blue</td><td>paleglaucousblue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pale glaucous-blue</td><td>paleglaucousblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>pale glaucous-green </td><td>paleglaucousgreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pale grayish blue</td><td>palegrayishblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>pale grayish blue</td><td>palegrayishblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>pale grayish blue-violet</td><td>palegrayishblueviolet</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pale grayish vinaceous</td><td>palegrayishvinaceous</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>pale grayish vinaceous</td><td>palegrayishvinaceous</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>pale grayish vinaceous</td><td>palegrayishvinaceous</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pale grayish violet-blue</td><td>palegrayishvioletblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pale green-blue gray</td><td>palegreenbluegray</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>pale greenish yellow</td><td>palegreenishyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>pale greenish yellow</td><td>palegreenishyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>pale green-yellow</td><td>palegreenyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>pale green-yellow</td><td>palegreenyellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pale gull gray</td><td>palegullgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#d5badb;width:4em;" /><td>pale hortense violet</td><td>palehortenseviolet</td><td>##d5badb</td><td>213</td> <td>186</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>pale hortense violet</td><td>palehortenseviolet</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>pale king's blue</td><td>palekingsblue</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>pale laelia pink </td><td>palelaeliapink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>pale laelia pink </td><td>palelaeliapink</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>pale lavender-violet</td><td>palelavenderviolet</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>pale lavender-violet</td><td>palelavenderviolet</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>pale lemon yellow</td><td>palelemonyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pale lilac</td><td>palelilac</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>pale lobelia violet</td><td>palelobeliaviolet</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>pale lobelia violet</td><td>palelobeliaviolet</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale lumiere green</td><td>palelumieregreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>pale mauve</td><td>palemauve</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pale mazarine blue</td><td>palemazarineblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pale mazarine blue</td><td>palemazarineblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>pale mazarine blue</td><td>palemazarineblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>pale mazarine blue</td><td>palemazarineblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pale medici blue</td><td>palemediciblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>pale medici blue</td><td>palemediciblue</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>pale medici blue</td><td>palemediciblue</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>pale methyl blue </td><td>palemethylblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>pale mouse gray </td><td>palemousegray</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>pale mouse gray </td><td>palemousegray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pale neropalin blue</td><td>paleneropalinblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>pale neutral gray</td><td>paleneutralgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>pale niagara green</td><td>paleniagaragreen</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>pale nile blue</td><td>palenileblue</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pale ochraceous-buff</td><td>paleochraceousbuff</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>pale ochraceous-salmon</td><td>paleochraceoussalmon</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>pale ochraceous-salmon</td><td>paleochraceoussalmon</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>pale olive-buff</td><td>paleolivebuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>pale olive-gray</td><td>paleolivegray</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>pale olive-gray</td><td>paleolivegray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>pale olivine</td><td>paleolivine</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>pale orange-yellow</td><td>paleorangeyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>pale orange-yellow</td><td>paleorangeyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>pale orange-yellow</td><td>paleorangeyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>pale orange-yellow</td><td>paleorangeyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>pale orange-yellow</td><td>paleorangeyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>pale orange-yellow</td><td>paleorangeyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pale payne's gray</td><td>palepaynesgray</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>pale persian lilac</td><td>palepersianlilac</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>pale pinkish buff</td><td>palepinkishbuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>pale pinkish cinnamon</td><td>palepinkishcinnamon</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>pale purple-drab</td><td>palepurpledrab</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>pale purplish gray</td><td>palepurplishgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>pale purplish vinaceous</td><td>palepurplishvinaceous</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>pale purplish vinaceous</td><td>palepurplishvinaceous</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>pale quaker drab</td><td>palequakerdrab</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>pale quaker drab</td><td>palequakerdrab</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>pale rhodonite pink</td><td>palerhodonitepink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>pale rose-purple </td><td>palerosepurple</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>pale rosolane purple</td><td>palerosolanepurple</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>pale russian blue</td><td>palerussianblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>pale salmon color</td><td>palesalmoncolor</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>pale smoke gray</td><td>palesmokegray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pale soft blue-violet</td><td>palesoftblueviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>pale soft blue-violet</td><td>palesoftblueviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>pale sulphate green</td><td>palesulphategreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale tiber green</td><td>paletibergreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>pale turquoise green</td><td>paleturquoisegreen</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale turtle green</td><td>paleturtlegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>pale turtle green</td><td>paleturtlegreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>pale varley's gray </td><td>palevarleysgray</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>pale varley's gray </td><td>palevarleysgray</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>pale verbena violet</td><td>paleverbenaviolet</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale veronese green</td><td>paleveronesegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>pale veronese green</td><td>paleveronesegreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>pale vinaceous</td><td>palevinaceous</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>pale vinaceous-drab</td><td>palevinaceousdrab</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pale vinaceous-drab</td><td>palevinaceousdrab</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>pale vinaceous-drab</td><td>palevinaceousdrab</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>pale vinaceous-drab</td><td>palevinaceousdrab</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pale vinaceous-fawn</td><td>palevinaceousfawn</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>pale vinaceous-fawn</td><td>palevinaceousfawn</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>pale vinaceous-fawn</td><td>palevinaceousfawn</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>pale vinaceous-fawn</td><td>palevinaceousfawn</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>pale vinaceous-lilac</td><td>palevinaceouslilac</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pale vinaceous-lilac</td><td>palevinaceouslilac</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>pale vinaceous-pink</td><td>palevinaceouspink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>pale vinaceous-pink</td><td>palevinaceouspink</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pale violet</td><td>paleviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>pale violet</td><td>paleviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>pale violet-blue</td><td>palevioletblue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>pale violet-gray</td><td>palevioletgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>pale violet-gray</td><td>palevioletgray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>pale violet-plumbeous </td><td>palevioletplumbeous</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>pale violet-plumbeous </td><td>palevioletplumbeous</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>pale viridine yellow</td><td>paleviridineyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>pale viridine yellow</td><td>paleviridineyellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>pale windsor blue</td><td>palewindsorblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pale windsor blue</td><td>palewindsorblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>pale wistaria blue</td><td>palewistariablue</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>pale wistaria blue</td><td>palewistariablue</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>pale wistaria violet</td><td>palewistariaviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>pale wistaria violet</td><td>palewistariaviolet</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale yellow-green</td><td>paleyellowgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pale yellow-orange</td><td>paleyelloworange</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>pallid blue-violet</td><td>pallidblueviolet</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pallid blue-violet</td><td>pallidblueviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>pallid bluish violet</td><td>pallidbluishviolet</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pallid bluish violet</td><td>pallidbluishviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>pallid bluish violet</td><td>pallidbluishviolet</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>pallid bluish violet</td><td>pallidbluishviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pallid brownish drab</td><td>pallidbrownishdrab</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pallid grayish violet-blue</td><td>pallidgrayishvioletblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>pallid grayish violet-blue</td><td>pallidgrayishvioletblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>pallid methyl blue </td><td>pallidmethylblue</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>pallid mouse gray </td><td>pallidmousegray</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pallid mouse gray </td><td>pallidmousegray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pallid neutral gray</td><td>pallidneutralgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>pallid purple-drab</td><td>pallidpurpledrab</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>pallid purple-drab</td><td>pallidpurpledrab</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>pallid purplish gray </td><td>pallidpurplishgray</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>pallid quaker drab</td><td>pallidquakerdrab</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>pallid soft blue-violet </td><td>pallidsoftblueviolet</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pallid soft blue-violet </td><td>pallidsoftblueviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>pallid soft blue-violet </td><td>pallidsoftblueviolet</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>pallid soft blue-violet </td><td>pallidsoftblueviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>pallid vinaceous-drab</td><td>pallidvinaceousdrab</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pallid vinaceous-drab</td><td>pallidvinaceousdrab</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>pallid violet</td><td>pallidviolet</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pallid violet</td><td>pallidviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>pallid violet</td><td>pallidviolet</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>pallid violet</td><td>pallidviolet</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>pallid violet</td><td>pallidviolet</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>pallid violet</td><td>pallidviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c3dd;width:4em;" /><td>pallid violet</td><td>pallidviolet</td><td>##c4c3dd</td><td>196</td> <td>195</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>pallid violet</td><td>pallidviolet</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>pallid violet-blue</td><td>pallidvioletblue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>pallid violet-blue</td><td>pallidvioletblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>pansy purple</td><td>pansypurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>pansy violet</td><td>pansyviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>paris blue</td><td>parisblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>paris blue</td><td>parisblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>paris green</td><td>parisgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>parrot green</td><td>parrotgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>parula blue</td><td>parulablue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>parula blue</td><td>parulablue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>patent blue</td><td>patentblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>payne's gray</td><td>paynesgray</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>peach red</td><td>peachred</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>peacock blue</td><td>peacockblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>peacock green</td><td>peacockgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>pea green</td><td>peagreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>pearl blue</td><td>pearlblue</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>pearl blue</td><td>pearlblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>pearl gray</td><td>pearlgray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>pecan brown</td><td>pecanbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>perilla purple</td><td>perillapurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>persian blue</td><td>persianblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>persian blue</td><td>persianblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>persian lilac</td><td>persianlilac</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>petunia violet</td><td>petuniaviolet</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>phenyl blue</td><td>phenylblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>phlox pink</td><td>phloxpink</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>phlox purple</td><td>phloxpurple</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e450;width:4em;" /><td>picric yellow</td><td>picricyellow</td><td>##e9e450</td><td>233</td> <td>228</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>pinard yellow</td><td>pinardyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>pinard yellow</td><td>pinardyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>pinkish buff</td><td>pinkishbuff</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>pinkish buff</td><td>pinkishbuff</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>pinkish cinnamon</td><td>pinkishcinnamon</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>pinkish cinnamon</td><td>pinkishcinnamon</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>pinkish vinaceous</td><td>pinkishvinaceous</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>pistachio green</td><td>pistachiogreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>pleroma violet</td><td>pleromaviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>pleroma violet</td><td>pleromaviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>plumbago blue</td><td>plumbagoblue</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>plumbago blue</td><td>plumbagoblue</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>plumbago gray</td><td>plumbagogray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>plumbeous</td><td>plumbeous</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>plumbeous</td><td>plumbeous</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>plumbeous black </td><td>plumbeousblack</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>plumbeous black </td><td>plumbeousblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>plum purple</td><td>plumpurple</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>pois green</td><td>poisgreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>pompeian red</td><td>pompeianred</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>porcelain blue</td><td>porcelainblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>porcelain green</td><td>porcelaingreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>primrose yellow</td><td>primroseyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>primuline yellow</td><td>primulineyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>prout's brown</td><td>proutsbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>prune purple</td><td>prunepurple</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>prussian blue</td><td>prussianblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>prussian blue</td><td>prussianblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>prussian green</td><td>prussiangreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>prussian red</td><td>prussianred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>puritan gray</td><td>puritangray</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>purple</td><td>purple</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>purple-drab</td><td>purpledrab</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>purplish gray</td><td>purplishgray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>purplish gray</td><td>purplishgray</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>purplish lilac</td><td>purplishlilac</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>purplish lilac</td><td>purplishlilac</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>purplish vinaceous</td><td>purplishvinaceous</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>pyrite yellow</td><td>pyriteyellow</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>quaker drab</td><td>quakerdrab</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>quaker drab</td><td>quakerdrab</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>rainette green</td><td>rainettegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>raisin black</td><td>raisinblack</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>raisin purple</td><td>raisinpurple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>ramier blue</td><td>ramierblue</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>ramier blue</td><td>ramierblue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>ramier blue</td><td>ramierblue</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>raw sienna</td><td>rawsienna</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>raw sienna</td><td>rawsienna</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>reed yellow</td><td>reedyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>rejane green</td><td>rejanegreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>rejane green</td><td>rejanegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rhodamine purple</td><td>rhodaminepurple</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>rhodonite pink</td><td>rhodonitepink</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>rinnemann's green</td><td>rinnemannsgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>rivage green</td><td>rivagegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>rivage green</td><td>rivagegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>rocellin purple</td><td>rocellinpurple</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>rocellin purple</td><td>rocellinpurple</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>roman green</td><td>romangreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>rood's blue</td><td>roodsblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>rood's brown</td><td>roodsbrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>rood's brown</td><td>roodsbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>rood's brown</td><td>roodsbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>rood's lavender</td><td>roodslavender</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>rood's violet</td><td>roodsviolet</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>rose color</td><td>rosecolor</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rose color</td><td>rosecolor</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>rose doree </td><td>rosedoree</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>rose pink</td><td>rosepink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#d399e6;width:4em;" /><td>rose-purple </td><td>rosepurple</td><td>##d399e6</td><td>211</td> <td>153</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>rose red</td><td>rosered</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>roslyn blue</td><td>roslynblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>roslyn blue</td><td>roslynblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>roslyn blue</td><td>roslynblue</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>rosolane pink</td><td>rosolanepink</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>rosolane pink</td><td>rosolanepink</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>rosolane purple</td><td>rosolanepurple</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>royal purple</td><td>royalpurple</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>rufous</td><td>rufous</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>russet</td><td>russet</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>russet-vinaceous</td><td>russetvinaceous</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>russet-vinaceous</td><td>russetvinaceous</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>russian blue</td><td>russianblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>russian blue</td><td>russianblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>russian green</td><td>russiangreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>saccardo's olive</td><td>saccardosolive</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>saccardo's olive</td><td>saccardosolive</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>saccardo's slate</td><td>saccardosslate</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>saccardo's umber</td><td>saccardosumber</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>saccardo's umber</td><td>saccardosumber</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>saccardo's violet</td><td>saccardosviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>saccardo's violet</td><td>saccardosviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>safrano pink</td><td>safranopink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>sage green</td><td>sagegreen</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>sailor blue</td><td>sailorblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>salmon-buff </td><td>salmonbuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>salmon-buff </td><td>salmonbuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>salmon color</td><td>salmoncolor</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>salmon color</td><td>salmoncolor</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>salmon color</td><td>salmoncolor</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>salmon-orange</td><td>salmonorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>salvia blue</td><td>salviablue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>sanford's brown</td><td>sanfordsbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>sanford's brown</td><td>sanfordsbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>sayal brown</td><td>sayalbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>sayal brown</td><td>sayalbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>scarlet-red </td><td>scarletred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>scheele's green</td><td>scheelesgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>scheele's green</td><td>scheelesgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>schoenfeld's purple</td><td>schoenfeldspurple</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>sea-foam green </td><td>seafoamgreen</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>sea-foam yellow </td><td>seafoamyellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>sea-foam yellow </td><td>seafoamyellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>sea green</td><td>seagreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>seal brown</td><td>sealbrown</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>seal brown</td><td>sealbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>seashell pink</td><td>seashellpink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>seashell pink</td><td>seashellpink</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>seashell pink</td><td>seashellpink</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>sepia</td><td>sepia</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>sepia</td><td>sepia</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>serpentine green</td><td>serpentinegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>shamrock green</td><td>shamrockgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>shell pink</td><td>shellpink</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>shell pink</td><td>shellpink</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>shrimp pink</td><td>shrimppink</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>shrimp pink</td><td>shrimppink</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>skobeloff green</td><td>skobeloffgreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>sky blue</td><td>skyblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>sky gray</td><td>skygray</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>slate-black</td><td>slateblack</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>slate-blue </td><td>slateblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>slate color</td><td>slatecolor</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>slate-gray</td><td>slategray</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>slate-olive</td><td>slateolive</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>slate-purple</td><td>slatepurple</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>slate-purple</td><td>slatepurple</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>slate-violet </td><td>slateviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>slate-violet </td><td>slateviolet</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>slate-violet </td><td>slateviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>smalt blue</td><td>smaltblue</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>smoke gray</td><td>smokegray</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>smoke gray</td><td>smokegray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>snuff brown</td><td>snuffbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>snuff brown</td><td>snuffbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>soft blue-violet</td><td>softblueviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>soft bluish violet</td><td>softbluishviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>sooty black</td><td>sootyblack</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>sorghum brown</td><td>sorghumbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>sorrento green</td><td>sorrentogreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>spectrum blue</td><td>spectrumblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>spectrum red</td><td>spectrumred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>spectrum violet</td><td>spectrumviolet</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>spinach green</td><td>spinachgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>spinel pink</td><td>spinelpink</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>spinel red</td><td>spinelred</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>squill blue</td><td>squillblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>stone green</td><td>stonegreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>storm gray</td><td>stormgray</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>strawberry pink</td><td>strawberrypink</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>straw yellow</td><td>strawyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>strontian yellow </td><td>strontianyellow</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>sudan brown</td><td>sudanbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>sudan brown</td><td>sudanbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>sudan brown</td><td>sudanbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>sulphate green</td><td>sulphategreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>sulphate green</td><td>sulphategreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>sulphine yellow</td><td>sulphineyellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#eae679;width:4em;" /><td>sulphur yellow</td><td>sulphuryellow</td><td>##eae679</td><td>234</td> <td>230</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ebe8a4;width:4em;" /><td>sulphur yellow</td><td>sulphuryellow</td><td>##ebe8a4</td><td>235</td> <td>232</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>taupe brown</td><td>taupebrown</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>tawny</td><td>tawny</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>tawny-olive</td><td>tawnyolive</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>tawny-olive</td><td>tawnyolive</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>tea green</td><td>teagreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>terra cotta</td><td>terracotta</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>terre verte</td><td>terreverte</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>testaceous</td><td>testaceous</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>testaceous</td><td>testaceous</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>thulite pink</td><td>thulitepink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>tiber green</td><td>tibergreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>tilleul-buff</td><td>tilleulbuff</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>tourmaline pink</td><td>tourmalinepink</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>tourmaline pink</td><td>tourmalinepink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>turquoise green</td><td>turquoisegreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>turtle green</td><td>turtlegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>tyrian blue</td><td>tyrianblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>tyrian blue</td><td>tyrianblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>tyrian pink</td><td>tyrianpink</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>tyrian rose</td><td>tyrianrose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>tyrolite green</td><td>tyrolitegreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>ultramarine ash</td><td>ultramarineash</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>ultramarine blue</td><td>ultramarineblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#2f2140;width:4em;" /><td>urania blue</td><td>uraniablue</td><td>##2f2140</td><td>47</td> <td>33</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>urania blue</td><td>uraniablue</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>urania blue</td><td>uraniablue</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>vanderpoel's blue</td><td>vanderpoelsblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>vanderpoel's blue</td><td>vanderpoelsblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>vanderpoel's green</td><td>vanderpoelsgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>vanderpoel's green</td><td>vanderpoelsgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>vanderpoel's violet</td><td>vanderpoelsviolet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>vandyke brown</td><td>vandykebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>vandyke brown</td><td>vandykebrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>vandyke red</td><td>vandykered</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>variscite green</td><td>variscitegreen</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>varley's gray</td><td>varleysgray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>varley's green</td><td>varleysgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>venetian blue</td><td>venetianblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>venetian pink</td><td>venetianpink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>venice green</td><td>venicegreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>verbena violet</td><td>verbenaviolet</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>verdigris green</td><td>verdigrisgreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>vernonia purple</td><td>vernoniapurple</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>verona brown</td><td>veronabrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>veronese green</td><td>veronesegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>veronese green</td><td>veronesegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>vetiver green</td><td>vetivergreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>vetiver green</td><td>vetivergreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>victoria lake</td><td>victorialake</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#3f1728;width:4em;" /><td>victoria lake</td><td>victorialake</td><td>##3f1728</td><td>63</td> <td>23</td> <td>40</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>vinaceous</td><td>vinaceous</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>vinaceous</td><td>vinaceous</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>vinaceous</td><td>vinaceous</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>vinaceous</td><td>vinaceous</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>vinaceous-brown</td><td>vinaceousbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>vinaceous-buff</td><td>vinaceousbuff</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>vinaceous-buff</td><td>vinaceousbuff</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>vinaceous-buff</td><td>vinaceousbuff</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>vinaceous-buff</td><td>vinaceousbuff</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>vinaceous-cinnamon</td><td>vinaceouscinnamon</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>vinaceous-cinnamon</td><td>vinaceouscinnamon</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>vinaceous-drab</td><td>vinaceousdrab</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>vinaceous-fawn</td><td>vinaceousfawn</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>vinaceous-fawn</td><td>vinaceousfawn</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>vinaceous-gray</td><td>vinaceousgray</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>vinaceous-gray</td><td>vinaceousgray</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>vinaceous-lavender</td><td>vinaceouslavender</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>vinaceous-lilac</td><td>vinaceouslilac</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>vinaceous-lilac</td><td>vinaceouslilac</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>vinaceous-pink</td><td>vinaceouspink</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>vinaceous-pink</td><td>vinaceouspink</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>vinaceous-purple </td><td>vinaceouspurple</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>vinaceous-purple </td><td>vinaceouspurple</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>vinaceous-purple </td><td>vinaceouspurple</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>vinaceous-rufous</td><td>vinaceousrufous</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>vinaceous-russet</td><td>vinaceousrusset</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>vinaceous-russet</td><td>vinaceousrusset</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>vinaceous-slate</td><td>vinaceousslate</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>vinaceous-tawny</td><td>vinaceoustawny</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>violet carmine </td><td>violetcarmine</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>violet-gray</td><td>violetgray</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>violet-plumbeous</td><td>violetplumbeous</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>violet-purple </td><td>violetpurple</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>violet-slate</td><td>violetslate</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>violet ultramarine</td><td>violetultramarine</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>violet ultramarine</td><td>violetultramarine</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>viridian green</td><td>viridiangreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>viridian green</td><td>viridiangreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>viridine green</td><td>viridinegreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#beb72e;width:4em;" /><td>viridine yellow</td><td>viridineyellow</td><td>##beb72e</td><td>190</td> <td>183</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>viridine yellow</td><td>viridineyellow</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>vivid green</td><td>vividgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>wall green</td><td>wallgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>walnut brown</td><td>walnutbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>walnut brown</td><td>walnutbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>warbler green</td><td>warblergreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>warm blackish brown </td><td>warmblackishbrown</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>warm blackish brown </td><td>warmblackishbrown</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>warm buff </td><td>warmbuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>warm buff </td><td>warmbuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>warm buff </td><td>warmbuff</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>warm sepia </td><td>warmsepia</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>water green</td><td>watergreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>wax yellow</td><td>waxyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#a1caf1;width:4em;" /><td>wedgewood blue</td><td>wedgewoodblue</td><td>##a1caf1</td><td>161</td> <td>202</td> <td>241</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>wedgewood blue</td><td>wedgewoodblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>wedgewood blue</td><td>wedgewoodblue</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>wedgewood blue</td><td>wedgewoodblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f3f4;width:4em;" /><td>white</td><td>white</td><td>##f2f3f4</td><td>242</td> <td>243</td> <td>244</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>windsor blue</td><td>windsorblue</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>winter green</td><td>wintergreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>wistaria blue</td><td>wistariablue</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>wistaria blue</td><td>wistariablue</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>wistaria violet</td><td>wistariaviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>wood brown</td><td>woodbrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>wood brown</td><td>woodbrown</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>xanthine orange</td><td>xanthineorange</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>yale blue</td><td>yaleblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#98943e;width:4em;" /><td>yellowish citrine</td><td>yellowishcitrine</td><td>##98943e</td><td>152</td> <td>148</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>yellowish glaucous</td><td>yellowishglaucous</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>yellowish oil green</td><td>yellowishoilgreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>yellowish olive</td><td>yellowisholive</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>yellowish olive</td><td>yellowisholive</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>yellow ochre</td><td>yellowochre</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>yew green</td><td>yewgreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>yvette violet</td><td>yvetteviolet</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>zinc green</td><td>zincgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>zinc orange</td><td>zincorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>zinc orange</td><td>zincorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item absinthe green             absinthegreen           #8a9a5b

=item acajou red                 acajoured               #905d5d

=item acetin blue                acetinblue              #367588

=item acetin blue                acetinblue              #4c516d

=item ackermann's green          ackermannsgreen         #3b7861

=item aconite violet             aconiteviolet           #86608e

=item ageratum violet            ageratumviolet          #86608e

=item alice blue                 aliceblue               #91a3b0

=item alizarine blue             alizarineblue           #436b95

=item alizarine pink             alizarinepink           #ea9399

=item alizarine pink             alizarinepink           #e4717a

=item amaranth pink              amaranthpink            #de6fa1

=item amaranth purple            amaranthpurple          #78184a

=item amber brown                amberbrown              #80461b

=item amber yellow               amberyellow             #fada5e

=item amber yellow               amberyellow             #d4af37

=item amber yellow               amberyellow             #f8de7e

=item amber yellow               amberyellow             #c9ae5d

=item american green             americangreen           #679267

=item amethyst violet            amethystviolet          #9a4eae

=item amparo blue                amparoblue              #6c79b8

=item amparo purple              amparopurple            #d399e6

=item amparo purple              amparopurple            #875692

=item andover green              andovergreen            #8f9779

=item aniline black              anilineblack            #50404d

=item aniline black              anilineblack            #5d555b

=item aniline lilac              anilinelilac            #8c82b6

=item aniline yellow             anilineyellow           #af8d13

=item anthracene green           anthracenegreen         #317873

=item anthracene green           anthracenegreen         #004b49

=item anthracene purple          anthracenepurple        #50404d

=item anthracene purple          anthracenepurple        #673147

=item anthracene violet          anthraceneviolet        #604e81

=item antimony yellow            antimonyyellow          #e3a857

=item antique brown              antiquebrown            #80461b

=item antique brown              antiquebrown            #6f4e37

=item antique green              antiquegreen            #5e716a

=item antique green              antiquegreen            #3a4b47

=item antwerp blue               antwerpblue             #436b95

=item antwerp blue               antwerpblue             #00304e

=item antwerp blue               antwerpblue             #536878

=item apple green                applegreen              #7e9f2e

=item apricot buff               apricotbuff             #d99058

=item apricot orange             apricotorange           #d99058

=item apricot yellow             apricotyellow           #d4af37

=item argus brown                argusbrown              #6f4e37

=item argyle purple              argylepurple            #915c83

=item army brown                 armybrown               #6f4e37

=item army brown                 armybrown               #635147

=item artemesia green            artemesiagreen          #7d8984

=item asphodel green             asphodelgreen           #8a9a5b

=item aster purple               asterpurple             #78184a

=item auburn                     auburn                  #79443b

=item auricula purple            auriculapurple          #673147

=item avellaneous                avellaneous             #c19a6b

=item avellaneous                avellaneous             #ae9b82

=item azurite blue               azuriteblue             #4e5180

=item barium yellow              bariumyellow            #eae679

=item barium yellow              bariumyellow            #b9b459

=item baryta yellow              barytayellow            #f8de7e

=item bay                        bay                     #79443b

=item begonia rose               begoniarose             #e66761

=item benzo brown                benzobrown              #977f73

=item benzo brown                benzobrown              #958070

=item benzo brown                benzobrown              #635147

=item benzol green               benzolgreen             #007a74

=item berlin blue                berlinblue              #00304e

=item beryl blue                 berylblue               #9cd1dc

=item beryl green                berylgreen              #00a693

=item bice green                 bicegreen               #8a9a5b

=item biscay green               biscaygreen             #8a9a5b

=item bishop's purple            bishopspurple           #915c83

=item bister                     bister                  #7e6d5a

=item bister                     bister                  #483c32

=item bittersweet orange         bittersweetorange       #cb6d51

=item bittersweet pink           bittersweetpink         #d99058

=item black                      black                   #222222

=item blackish green-blue        blackishgreenblue       #004958

=item blackish green-gray        blackishgreengray       #222222

=item blackish mouse-gray        blackishmousegray       #5b504f

=item blackish mouse-gray        blackishmousegray       #555555

=item blackish plumbeous         blackishplumbeous       #51585e

=item blackish purple            blackishpurple          #5d3954

=item blackish purple            blackishpurple          #341731

=item blackish red-purple        blackishredpurple       #673147

=item blackish slate             blackishslate           #555555

=item blackish violet            blackishviolet          #604e81

=item blackish violet            blackishviolet          #2f2140

=item blackish violet            blackishviolet          #554c69

=item blackish violet-gray       blackishvioletgray      #5d555b

=item blackish violet-gray       blackishvioletgray      #555555

=item blanc's blue               blancsblue              #436b95

=item blanc's violet             blancsviolet            #554c69

=item blanc's violet             blancsviolet            #796878

=item blanc's violet             blancsviolet            #50404d

=item blue-violet                blueviolet              #30267a

=item blue-violet                blueviolet              #9065ca

=item blue-violet black          bluevioletblack         #5d555b

=item blue-violet black          bluevioletblack         #555555

=item bluish black               bluishblack             #36454f

=item bluish black               bluishblack             #202830

=item bluish glaucous            bluishglaucous          #c7e6d7

=item bluish glaucous            bluishglaucous          #96ded1

=item bluish gray-green          bluishgraygreen         #8da399

=item bluish gray-green          bluishgraygreen         #5e716a

=item bluish lavender            bluishlavender          #8c82b6

=item bluish slate-black         bluishslateblack        #00304e

=item bluish slate-black         bluishslateblack        #36454f

=item bluish violet              bluishviolet            #30267a

=item bluish violet              bluishviolet            #9065ca

=item bone brown                 bonebrown               #635147

=item bone brown                 bonebrown               #5b504f

=item bordeaux                   bordeaux                #673147

=item bottle green               bottlegreen             #1b4d3e

=item bradley's blue             bradleysblue            #00a1c2

=item bradley's violet           bradleysviolet          #7e73b8

=item bradley's violet           bradleysviolet          #604e97

=item bradley's violet           bradleysviolet          #8c82b6

=item bradley's violet           bradleysviolet          #604e81

=item brazil red                 brazilred               #9e4732

=item bremen blue                bremenblue              #66aabc

=item brick red                  brickred                #79443b

=item bright chalcedony yellow   brightchalcedonyyellow  #bdda57

=item bright chalcedony yellow   brightchalcedonyyellow  #c9dc89

=item bright green-yellow        brightgreenyellow       #8db600

=item brownish drab              brownishdrab            #977f73

=item brownish drab              brownishdrab            #958070

=item brownish olive             brownisholive           #6c541e

=item brownish vinaceous         brownishvinaceous       #ad8884

=item brussels brown             brusselsbrown           #6f4e37

=item buckthorn brown            buckthornbrown          #996515

=item buff-pink or buff pink     buffpinkorbuffpink      #d9a6a9

=item buffy brown                buffybrown              #c19a6b

=item buffy brown                buffybrown              #826644

=item buffy citrine              buffycitrine            #967117

=item buff-yellow or buff yellow buffyelloworbuffyellow  #f8de7e

=item buff-yellow or buff yellow buffyelloworbuffyellow  #c9ae5d

=item buffy olive                buffyolive              #867e36

=item burn blue                  burnblue                #a1caf1

=item burn blue                  burnblue                #70a3cc

=item burn blue                  burnblue                #b3bce2

=item burn blue                  burnblue                #8791bf

=item burnt lake                 burntlake               #5d3954

=item burnt sienna               burntsienna             #882d17

=item burnt umber                burntumber              #674c47

=item cacao brown                cacaobrown              #a87c6d

=item cadet blue                 cadetblue               #0067a5

=item cadet blue                 cadetblue               #436b95

=item cadet gray                 cadetgray               #91a3b0

=item cadmium orange             cadmiumorange           #f38400

=item cadmium orange             cadmiumorange           #ed872d

=item cadmium yellow             cadmiumyellow           #ed872d

=item cadmium yellow             cadmiumyellow           #eaa221

=item calamine blue              calamineblue            #9cd1dc

=item calamine blue              calamineblue            #66aabc

=item calla green                callagreen              #665d1e

=item calliste green             callistegreen           #7e9f2e

=item cameo brown                cameobrown              #79443b

=item cameo brown                cameobrown              #674c47

=item cameo pink                 cameopink               #ffc8d6

=item cameo pink                 cameopink               #efbbcc

=item capri blue                 capriblue               #367588

=item capucine buff              capucinebuff            #fbc97f

=item capucine buff              capucinebuff            #e3a857

=item capucine buff              capucinebuff            #fad6a5

=item capucine orange            capucineorange          #d99058

=item capucine yellow            capucineyellow          #eaa221

=item carmine                    carmine                 #be0032

=item carnelian red              carnelianred            #d9603b

=item carob brown                carobbrown              #3e1d1e

=item carrot red                 carrotred               #cb6d51

=item cartridge buff             cartridgebuff           #f3e5ab

=item castor gray                castorgray              #7d8984

=item castor gray                castorgray              #848482

=item cedar green                cedargreen              #8a9a5b

=item cedar green                cedargreen              #4a5d23

=item celandine green            celandinegreen          #8da399

=item cendre blue                cendreblue              #239eba

=item cendre green               cendregreen             #83d37d

=item cerulean blue              ceruleanblue            #0067a5

=item chaetura black             chaeturablack           #483c32

=item chaetura drab              chaeturadrab            #5b504f

=item chalcedony yellow          chalcedonyyellow        #eae679

=item chamois                    chamois                 #c9ae5d

=item chapman's blue             chapmansblue            #436b95

=item chartreuse yellow          chartreuseyellow        #eae679

=item chatenay pink              chatenaypink            #dea5a4

=item chatenay pink              chatenaypink            #d9a6a9

=item chessylite blue            chessyliteblue          #367588

=item chessylite blue            chessyliteblue          #004958

=item chessylite blue            chessyliteblue          #436b95

=item chessylite blue            chessyliteblue          #536878

=item chestnut                   chestnut                #79443b

=item chestnut-brown             chestnutbrown           #79443b

=item chestnut-brown             chestnutbrown           #674c47

=item chicory blue               chicoryblue             #8791bf

=item chicory blue               chicoryblue             #8c82b6

=item china blue                 chinablue               #436b95

=item chinese violet             chineseviolet           #86608e

=item chocolate                  chocolate               #674c47

=item chromium green             chromiumgreen           #8a9a5b

=item chrysolite green           chrysolitegreen         #8a9a5b

=item chrysopraise green         chrysopraisegreen       #93c592

=item cinereous                  cinereous               #b4bcc0

=item cinereous                  cinereous               #81878b

=item cinnamon                   cinnamon                #a67b5b

=item cinnamon                   cinnamon                #be8a3d

=item cinnamon-brown             cinnamonbrown           #6f4e37

=item cinnamon-buff              cinnamonbuff            #e3a857

=item cinnamon-buff              cinnamonbuff            #c19a6b

=item cinnamon-buff              cinnamonbuff            #c9ae5d

=item cinnamon-drab              cinnamondrab            #977f73

=item cinnamon-drab              cinnamondrab            #958070

=item cinnamon-rufous            cinnamonrufous          #ae6938

=item citrine                    citrine                 #867e36

=item citrine                    citrine                 #665d1e

=item citrine-drab               citrinedrab             #867e36

=item citron green               citrongreen             #b9b459

=item citron green               citrongreen             #b9b57d

=item citron yellow              citronyellow            #e9e450

=item citron yellow              citronyellow            #beb72e

=item citron yellow              citronyellow            #eae679

=item citron yellow              citronyellow            #b9b459

=item civette green              civettegreen            #679267

=item claret brown               claretbrown             #79443b

=item clay color                 claycolor               #996515

=item clay color                 claycolor               #826644

=item clay color                 claycolor               #967117

=item clear cadet blue           clearcadetblue          #4997d0

=item clear cadet blue           clearcadetblue          #0067a5

=item clear dull green-yellow    cleardullgreenyellow    #bdda57

=item clear dull green-yellow    cleardullgreenyellow    #7e9f2e

=item clear dull green-yellow    cleardullgreenyellow    #c9dc89

=item clear dull green-yellow    cleardullgreenyellow    #8a9a5b

=item clear fluorite green       clearfluoritegreen      #93c592

=item clear green-blue gray      cleargreenbluegray      #91a3b0

=item clear green-blue gray      cleargreenbluegray      #81878b

=item clear payne's gray         clearpaynesgray         #536878

=item clear payne's gray         clearpaynesgray         #81878b

=item clear windsor blue         clearwindsorblue        #8791bf

=item clear yellow-green         clearyellowgreen        #bdda57

=item clove brown                clovebrown              #483c32

=item cobalt green               cobaltgreen             #6aab8e

=item colonial buff              colonialbuff            #f8de7e

=item columbia blue              columbiablue            #70a3cc

=item columbia blue              columbiablue            #436b95

=item commelina blue             commelinablue           #30267a

=item congo pink                 congopink               #f88379

=item congo pink                 congopink               #d9a6a9

=item coral pink                 coralpink               #f88379

=item coral red                  coralred                #cb6d51

=item corinthian pink            corinthianpink          #dea5a4

=item corinthian purple          corinthianpurple        #673147

=item corinthian red             corinthianred           #905d5d

=item cornflower blue            cornflowerblue          #30267a

=item corydalis green            corydalisgreen          #c9dc89

=item corydalis green            corydalisgreen          #dadfb7

=item cossack green              cossackgreen            #4a5d23

=item cossack green              cossackgreen            #515744

=item cosse green                cossegreen              #7e9f2e

=item cotinga purple             cotingapurple           #602f6b

=item cotinga purple             cotingapurple           #86608e

=item courge green               courgegreen             #8a9a5b

=item court gray                 courtgray               #c7e6d7

=item court grey                 courtgrey               #c7e6d7

=item cream buff                 creambuff               #f8de7e

=item cream buff                 creambuff               #c9ae5d

=item cream color                creamcolor              #f8de7e

=item cress green                cressgreen              #8a9a5b

=item cress green                cressgreen              #4a5d23

=item cyanine blue               cyanineblue             #4e5180

=item dahlia carmine             dahliacarmine           #673147

=item dahlia purple              dahliapurple            #673147

=item daphne pink                daphnepink              #de6fa1

=item daphne pink                daphnepink              #c17e91

=item daphne red                 daphnered               #a8516e

=item dark american green        darkamericangreen       #355e3b

=item dark american green        darkamericangreen       #5e716a

=item dark american green        darkamericangreen       #3a4b47

=item dark aniline blue          darkanilineblue         #36454f

=item dark aniline blue          darkanilineblue         #50404d

=item dark anthracene violet     darkanthraceneviolet    #563c5c

=item dark anthracene violet     darkanthraceneviolet    #50404d

=item dark bluish glaucous       darkbluishglaucous      #6aab8e

=item dark bluish glaucous       darkbluishglaucous      #8da399

=item dark bluish gray-green     darkbluishgraygreen     #5e716a

=item dark bluish gray-green     darkbluishgraygreen     #3a4b47

=item dark bluish gray-green     darkbluishgraygreen     #317873

=item dark bluish gray-green     darkbluishgraygreen     #004b49

=item dark bluish violet         darkbluishviolet        #604e81

=item dark bluish violet         darkbluishviolet        #2f2140

=item dark bluish violet         darkbluishviolet        #554c69

=item dark cadet blue            darkcadetblue           #436b95

=item dark cadet blue            darkcadetblue           #4c516d

=item dark chessylite blue       darkchessyliteblue      #004958

=item dark chessylite blue       darkchessyliteblue      #436b95

=item dark chessylite blue       darkchessyliteblue      #00304e

=item dark chessylite blue       darkchessyliteblue      #536878

=item dark cinnabar green        darkcinnabargreen       #317873

=item dark citrine               darkcitrine             #665d1e

=item dark corinthian purple     darkcorinthianpurple    #673147

=item dark cress green           darkcressgreen          #4a5d23

=item dark delft blue            darkdelftblue           #00304e

=item dark delft blue            darkdelftblue           #36454f

=item dark diva blue             darkdivablue            #545aa7

=item dark diva blue             darkdivablue            #4e5180

=item dark dull bluish violet    darkdullbluishviolet    #604e81

=item dark dull bluish violet    darkdullbluishviolet    #554c69

=item dark dull bluish violet    darkdullbluishviolet    #554c69

=item dark dull bluish violet    darkdullbluishviolet    #563c5c

=item dark dull violet-blue      darkdullvioletblue      #4c516d

=item dark dull violet-blue      darkdullvioletblue      #554c69

=item dark dull violet-blue      darkdullvioletblue      #554c69

=item dark dull yellow-green     darkdullyellowgreen     #4a5d23

=item dark dull yellow-green     darkdullyellowgreen     #515744

=item dark glaucous-gray         darkglaucousgray        #5e716a

=item dark grayish blue-green    darkgrayishbluegreen    #4e5755

=item dark grayish blue-green    darkgrayishbluegreen    #555555

=item dark grayish blue-violet   darkgrayishblueviolet   #554c69

=item dark grayish brown         darkgrayishbrown        #905d5d

=item dark grayish brown         darkgrayishbrown        #5c504f

=item dark grayish lavender      darkgrayishlavender     #9690ab

=item dark grayish olive         darkgrayisholive        #57554c

=item dark green                 darkgreen               #355e3b

=item dark green                 darkgreen               #5e716a

=item dark green                 darkgreen               #3a4b47

=item dark green-blue gray       darkgreenbluegray       #536878

=item dark green-blue slate      darkgreenblueslate      #00304e

=item dark green-blue slate      darkgreenblueslate      #36454f

=item dark greenish glaucous     darkgreenishglaucous    #93c592

=item dark greenish glaucous     darkgreenishglaucous    #679267

=item dark greenish olive        darkgreenisholive       #665d1e

=item dark greenish olive        darkgreenisholive       #5b5842

=item dark gull gray             darkgullgray            #555555

=item dark heliotrope gray       darkheliotropegray      #796878

=item dark heliotrope slate      darkheliotropeslate     #50404d

=item dark heliotrope slate      darkheliotropeslate     #5d555b

=item dark hyssop violet         darkhyssopviolet        #563c5c

=item dark hyssop violet         darkhyssopviolet        #796878

=item dark indian red            darkindianred           #905d5d

=item dark indian red            darkindianred           #543d3f

=item dark ivy green             darkivygreen            #515744

=item dark lavender              darklavender            #b695c0

=item dark livid brown           darklividbrown          #905d5d

=item dark livid purple          darklividpurple         #50404d

=item dark livid purple          darklividpurple         #673147

=item dark madder blue           darkmadderblue          #536878

=item dark madder blue           darkmadderblue          #4c516d

=item dark madder violet         darkmadderviolet        #563c5c

=item dark madder violet         darkmadderviolet        #50404d

=item dark maroon purple         darkmaroonpurple        #5d3954

=item dark medici blue           darkmediciblue          #51585e

=item dark mineral red           darkmineralred          #905d5d

=item dark mineral red           darkmineralred          #543d3f

=item dark mouse gray            darkmousegray           #5b504f

=item dark mouse gray            darkmousegray           #555555

=item dark naphthalene violet    darknaphthaleneviolet   #50404d

=item dark naphthalene violet    darknaphthaleneviolet   #5d3954

=item dark neutral gray          darkneutralgray         #555555

=item dark nigrosin violet       darknigrosinviolet      #563c5c

=item dark olive                 darkolive               #5b5842

=item dark olive-buff            darkolivebuff           #a18f60

=item dark olive-gray            darkolivegray           #5b5842

=item dark olive-gray            darkolivegray           #57554c

=item dark orient blue           darkorientblue          #536878

=item dark payne's gray          darkpaynesgray          #36454f

=item dark payne's gray          darkpaynesgray          #51585e

=item dark perilla purple        darkperillapurple       #673147

=item dark plumbago blue         darkplumbagoblue        #9690ab

=item dark plumbago blue         darkplumbagoblue        #aa98a9

=item dark plumbago gray         darkplumbagogray        #796878

=item dark plumbago gray         darkplumbagogray        #8b8589

=item dark plumbago gray         darkplumbagogray        #5d555b

=item dark plumbago slate        darkplumbagoslate       #5d555b

=item dark plumbeous             darkplumbeous           #51585e

=item dark porcelain green       darkporcelaingreen      #5e716a

=item dark purple-drab           darkpurpledrab          #796878

=item dark purplish gray         darkpurplishgray        #5d555b

=item dark purplish gray         darkpurplishgray        #555555

=item dark quaker drab           darkquakerdrab          #5d555b

=item dark russian green         darkrussiangreen        #5e716a

=item dark russian green         darkrussiangreen        #3a4b47

=item dark slate-purple          darkslatepurple         #5d3954

=item dark slate-violet          darkslateviolet         #5d555b

=item dark slate-violet          darkslateviolet         #796878

=item dark soft blue-violet      darksoftblueviolet      #4e5180

=item dark soft blue-violet      darksoftblueviolet      #604e81

=item dark soft bluish violet    darksoftbluishviolet    #604e81

=item dark sulphate green        darksulphategreen       #317873

=item dark terre verte           darkterreverte          #5e716a

=item dark tyrian blue           darktyrianblue          #536878

=item dark tyrian blue           darktyrianblue          #4c516d

=item dark varley's gray         darkvarleysgray         #5d555b

=item dark vinaceous             darkvinaceous           #905d5d

=item dark vinaceous-brown       darkvinaceousbrown      #905d5d

=item dark vinaceous-drab        darkvinaceousdrab       #905d5d

=item dark vinaceous-drab        darkvinaceousdrab       #5c504f

=item dark vinaceous-gray        darkvinaceousgray       #796878

=item dark vinaceous-purple      darkvinaceouspurple     #673147

=item dark violet                darkviolet              #604e81

=item dark violet-gray           darkvioletgray          #5d555b

=item dark violet-gray           darkvioletgray          #555555

=item dark violet-slate          darkvioletslate         #536878

=item dark viridian green        darkviridiangreen       #3b7861

=item dark yellowish green       darkyellowishgreen      #355e3b

=item dark yvette violet         darkyvetteviolet        #50404d

=item dark zinc green            darkzincgreen           #3b7861

=item dauphin's violet           dauphinsviolet          #604e81

=item dawn gray                  dawngray                #b4bcc0

=item dawn gray                  dawngray                #b9b8b5

=item deep aniline lilac         deepanilinelilac        #4997d0

=item deep blue-violet           deepblueviolet          #30267a

=item deep blue-violet           deepblueviolet          #9065ca

=item deep bluish glaucous       deepbluishglaucous      #96ded1

=item deep bluish gray-green     deepbluishgraygreen     #5e716a

=item deep bluish gray-green     deepbluishgraygreen     #317873

=item deep brownish drab         deepbrownishdrab        #635147

=item deep brownish vinaceous    deepbrownishvinaceous   #905d5d

=item deep cadet blue            deepcadetblue           #436b95

=item deep chicory blue          deepchicoryblue         #7e73b8

=item deep chrome                deepchrome              #eaa221

=item deep chrysolite green      deepchrysolitegreen     #8a9a5b

=item deep colonial buff         deepcolonialbuff        #c9ae5d

=item deep corinthian red        deepcorinthianred       #905d5d

=item deep delft blue            deepdelftblue           #536878

=item deep dull bluish violet    deepdullbluishviolet    #604e97

=item deep dull bluish violet    deepdullbluishviolet    #604e81

=item deep dull bluish violet    deepdullbluishviolet    #8c92ac

=item deep dull bluish violet    deepdullbluishviolet    #4c516d

=item deep dull bluish violet    deepdullbluishviolet    #9690ab

=item deep dull bluish violet    deepdullbluishviolet    #554c69

=item deep dull bluish violet    deepdullbluishviolet    #604e81

=item deep dull lavender         deepdulllavender        #aa98a9

=item deep dull violaceous blue  deepdullviolaceousblue  #4e5180

=item deep dull violet-blue      deepdullvioletblue      #604e81

=item deep dutch blue            deepdutchblue           #536878

=item deep dutch blue            deepdutchblue           #8c92ac

=item deep glaucous-gray         deepglaucousgray        #81878b

=item deep glaucous-green        deepglaucousgreen       #6aab8e

=item deep grape green           deepgrapegreen          #8a9a5b

=item deep grape green           deepgrapegreen          #8f9779

=item deep grayish blue-green    deepgrayishbluegreen    #5e716a

=item deep grayish lavender      deepgrayishlavender     #9690ab

=item deep grayish lavender      deepgrayishlavender     #aa98a9

=item deep grayish olive         deepgrayisholive        #57554c

=item deep green-blue gray       deepgreenbluegray       #536878

=item deep greenish glaucous     deepgreenishglaucous    #8ed1b2

=item deep gull gray             deepgullgray            #848482

=item deep heliotrope gray       deepheliotropegray      #796878

=item deep hyssop violet         deephyssopviolet        #86608e

=item deep lavender              deeplavender            #8c82b6

=item deep lavender-blue         deeplavenderblue        #6c79b8

=item deep lichen green          deeplichengreen         #93c592

=item deep livid brown           deeplividbrown          #905d5d

=item deep livid purple          deeplividpurple         #673147

=item deep madder blue           deepmadderblue          #4c516d

=item deep malachite green       deepmalachitegreen      #679267

=item deep medici blue           deepmediciblue          #81878b

=item deep mouse gray            deepmousegray           #5b504f

=item deep mouse gray            deepmousegray           #848482

=item deep mouse gray            deepmousegray           #555555

=item deep neutral gray          deepneutralgray         #555555

=item deep olive                 deepolive               #665d1e

=item deep olive                 deepolive               #5b5842

=item deep olive-buff            deepolivebuff           #c2b280

=item deep olive-gray            deepolivegray           #8a8776

=item deep orient blue           deeporientblue          #536878

=item deep payne's gray          deeppaynesgray          #536878

=item deep plumbago blue         deepplumbagoblue        #aa98a9

=item deep plumbago gray         deepplumbagogray        #8b8589

=item deep plumbeous             deepplumbeous           #536878

=item deep plumbeous             deepplumbeous           #81878b

=item deep purplish gray         deeppurplishgray        #5d555b

=item deep purplish vinaceous    deeppurplishvinaceous   #915f6d

=item deep quaker drab           deepquakerdrab          #5d555b

=item deep rose pink             deeprosepink            #e68fac

=item deep sea-foam green        deepseafoamgreen        #c9dc89

=item deep slate-blue            deepslateblue           #536878

=item deep slate-green           deepslategreen          #4e5755

=item deep slate-olive           deepslateolive          #4e5755

=item deep slate-violet          deepslateviolet         #796878

=item deep slaty brown           deepslatybrown          #50404d

=item deep soft blue-violet      deepsoftblueviolet      #4e5180

=item deep soft blue-violet      deepsoftblueviolet      #604e81

=item deep soft bluish violet    deepsoftbluishviolet    #604e97

=item deep turtle green          deepturtlegreen         #44944a

=item deep turtle green          deepturtlegreen         #679267

=item deep varley's gray         deepvarleysgray         #796878

=item deep varley's gray         deepvarleysgray         #5d555b

=item deep vinaceous             deepvinaceous           #c08081

=item deep vinaceous-gray        deepvinaceousgray       #796878

=item deep vinaceous-lavender    deepvinaceouslavender   #aa8a9e

=item deep vinaceous-lavender    deepvinaceouslavender   #c3a6b1

=item deep violet-gray           deepvioletgray          #8b8589

=item deep violet-gray           deepvioletgray          #5d555b

=item deep violet-gray           deepvioletgray          #848482

=item deep violet-gray           deepvioletgray          #555555

=item deep violet-plumbeous      deepvioletplumbeous     #4c516d

=item deep wedgewood blue        deepwedgewoodblue       #6c79b8

=item delft blue                 delftblue               #536878

=item diamin-azo blue            diaminazoblue           #554c69

=item diamin-azo blue            diaminazoblue           #50404d

=item diamine brown              diaminebrown            #674c47

=item diamine green              diaminegreen            #3b7861

=item diamine green              diaminegreen            #1b4d3e

=item diva blue                  divablue                #6c79b8

=item diva blue                  divablue                #545aa7

=item drab                       drab                    #c19a6b

=item drab                       drab                    #826644

=item drab                       drab                    #ae9b82

=item drab                       drab                    #7e6d5a

=item drab-gray                  drabgray                #ae9b82

=item drab-gray                  drabgray                #bfb8a5

=item dragons-blood red          dragonsbloodred         #9e4732

=item dresden brown              dresdenbrown            #826644

=item duck green                 duckgreen               #3a4b47

=item dull blackish green        dullblackishgreen       #3a4b47

=item dull blue-green black      dullbluegreenblack      #36454f

=item dull blue-green black      dullbluegreenblack      #202830

=item dull blue-green black      dullbluegreenblack      #202428

=item dull blue-violet           dullblueviolet          #545aa7

=item dull blue-violet           dullblueviolet          #7e73b8

=item dull blue-violet           dullblueviolet          #604e97

=item dull blue-violet           dullblueviolet          #604e81

=item dull bluish violet         dullbluishviolet        #7e73b8

=item dull bluish violet         dullbluishviolet        #604e97

=item dull bluish violet         dullbluishviolet        #8c82b6

=item dull bluish violet         dullbluishviolet        #604e81

=item dull bluish violet         dullbluishviolet        #604e97

=item dull bluish violet         dullbluishviolet        #604e81

=item dull citrine               dullcitrine             #867e36

=item dull citrine               dullcitrine             #665d1e

=item dull dark purple           dulldarkpurple          #9e4f88

=item dull dark purple           dulldarkpurple          #702963

=item dull dark purple           dulldarkpurple          #915c83

=item dull dusky purple          dullduskypurple         #50404d

=item dull dusky purple          dullduskypurple         #5d3954

=item dull greenish black        dullgreenishblack       #4e5755

=item dull greenish black        dullgreenishblack       #555555

=item dull greenish black        dullgreenishblack       #4e5755

=item dull greenish black        dullgreenishblack       #555555

=item dull green-yellow          dullgreenyellow         #7e9f2e

=item dull indian purple         dullindianpurple        #915f6d

=item dull lavender              dulllavender            #c3a6b1

=item dull magenta purple        dullmagentapurple       #9e4f88

=item dull opaline green         dullopalinegreen        #c7e6d7

=item dull purplish black        dullpurplishblack       #5d555b

=item dull violaceous blue       dullviolaceousblue      #545aa7

=item dull violet-black          dullvioletblack         #5d555b

=item dull violet-black          dullvioletblack         #36454f

=item dull violet-black          dullvioletblack         #51585e

=item dull violet-black          dullvioletblack         #50404d

=item dull violet-black          dullvioletblack         #5d555b

=item dull violet-black          dullvioletblack         #555555

=item dull violet-black          dullvioletblack         #222222

=item dull violet-blue           dullvioletblue          #545aa7

=item dull violet-blue           dullvioletblue          #604e81

=item dusky auricula purple      duskyauriculapurple     #5d3954

=item dusky blue                 duskyblue               #4c516d

=item dusky blue-green           duskybluegreen          #3a4b47

=item dusky blue-violet          duskyblueviolet         #554c69

=item dusky blue-violet          duskyblueviolet         #2f2140

=item dusky blue-violet          duskyblueviolet         #50404d

=item dusky bluish green         duskybluishgreen        #4e5755

=item dusky brown                duskybrown              #50404d

=item dusky brown                duskybrown              #5d555b

=item dusky drab                 duskydrab               #5b504f

=item dusky dull bluish green    duskydullbluishgreen    #3a4b47

=item dusky dull green           duskydullgreen          #3a4b47

=item dusky dull green           duskydullgreen          #4e5755

=item dusky dull violet          duskydullviolet         #563c5c

=item dusky dull violet          duskydullviolet         #86608e

=item dusky dull violet          duskydullviolet         #563c5c

=item dusky dull violet          duskydullviolet         #796878

=item dusky dull violet-blue     duskydullvioletblue     #554c69

=item dusky green                duskygreen              #5e716a

=item dusky green                duskygreen              #3a4b47

=item dusky green-blue           duskygreenblue          #004b49

=item dusky green-blue           duskygreenblue          #004958

=item dusky green-blue           duskygreenblue          #536878

=item dusky green-blue           duskygreenblue          #536878

=item dusky green-blue           duskygreenblue          #36454f

=item dusky green-gray           duskygreengray          #555555

=item dusky greenish blue        duskygreenishblue       #00416a

=item dusky greenish blue        duskygreenishblue       #436b95

=item dusky greenish blue        duskygreenishblue       #00304e

=item dusky neutral gray         duskyneutralgray        #555555

=item dusky olive-green          duskyolivegreen         #515744

=item dusky orient blue          duskyorientblue         #536878

=item dusky purplish gray        duskypurplishgray       #50404d

=item dusky purplish gray        duskypurplishgray       #5d555b

=item dusky purplish gray        duskypurplishgray       #555555

=item dusky purplish gray        duskypurplishgray       #222222

=item dusky slate-blue           duskyslateblue          #36454f

=item dusky slate-violet         duskyslateviolet        #50404d

=item dusky slate-violet         duskyslateviolet        #5d555b

=item dusky violet               duskyviolet             #50404d

=item dusky violet-blue          duskyvioletblue         #4c516d

=item dusky violet-blue          duskyvioletblue         #554c69

=item dusky violet-blue          duskyvioletblue         #36454f

=item dusky yellowish green      duskyyellowishgreen     #515744

=item dutch blue                 dutchblue               #91a3b0

=item dutch blue                 dutchblue               #8c92ac

=item ecru-drab                  ecrudrab                #c2ac99

=item ecru-olive                 ecruolive               #ab9144

=item ecru-olive                 ecruolive               #a18f60

=item elm green                  elmgreen                #4a5d23

=item elm green                  elmgreen                #515744

=item emerald green              emeraldgreen            #83d37d

=item empire green               empiregreen             #5e716a

=item empire green               empiregreen             #3a4b47

=item empire yellow              empireyellow            #fada5e

=item endive blue                endiveblue              #8791bf

=item endive blue                endiveblue              #8c92ac

=item english red                englishred              #9e4732

=item eosine pink                eosinepink              #e4717a

=item ethyl green                ethylgreen              #007a74

=item ethyl green                ethylgreen              #317873

=item eton blue                  etonblue                #436b95

=item etruscan red               etruscanred             #905d5d

=item eugenia red                eugeniared              #ab4e52

=item eupatorium purple          eupatoriumpurple        #b784a7

=item eupatorium purple          eupatoriumpurple        #915c83

=item fawn color                 fawncolor               #977f73

=item fawn color                 fawncolor               #a67b5b

=item fawn color                 fawncolor               #958070

=item ferruginous                ferruginous             #cb6d51

=item ferruginous                ferruginous             #9e4732

=item flame scarlet              flamescarlet            #e25822

=item flax-flower blue           flaxflowerblue          #6c79b8

=item flesh color                fleshcolor              #dea5a4

=item flesh-ochre                fleshochre              #d99058

=item flesh pink                 fleshpink               #f4c2c2

=item flesh pink                 fleshpink               #d9a6a9

=item fluorite green             fluoritegreen           #679267

=item fluorite violet            fluoriteviolet          #563c5c

=item forest green               forestgreen             #8a9a5b

=item forest green               forestgreen             #4a5d23

=item forget-me-not blue         forgetmenotblue         #6c79b8

=item french gray                frenchgray              #91a3b0

=item french gray                frenchgray              #b4bcc0

=item french green               frenchgreen             #3b7861

=item fuscous                    fuscous                 #5b504f

=item fuscous-black              fuscousblack            #5b504f

=item fuscous-black              fuscousblack            #555555

=item garnet brown               garnetbrown             #841b2d

=item gendarme blue              gendarmeblue            #436b95

=item gentian blue               gentianblue             #545aa7

=item geranium pink              geraniumpink            #e4717a

=item geranium pink              geraniumpink            #e66761

=item glass green                glassgreen              #c9dc89

=item glaucous                   glaucous                #dadfb7

=item glaucous-blue              glaucousblue            #66aabc

=item glaucous-gray              glaucousgray            #b4bcc0

=item glaucous-green             glaucousgreen           #8da399

=item gnaphalium green           gnaphaliumgreen         #c7e6d7

=item gnaphalium green           gnaphaliumgreen         #8da399

=item grass green                grassgreen              #8a9a5b

=item grayish blue-green         grayishbluegreen        #5e716a

=item grayish blue-violet        grayishblueviolet       #545aa7

=item grayish blue-violet        grayishblueviolet       #4e5180

=item grayish blue-violet        grayishblueviolet       #604e97

=item grayish blue-violet        grayishblueviolet       #604e81

=item grayish blue-violet        grayishblueviolet       #8791bf

=item grayish lavender           grayishlavender         #aa98a9

=item grayish olive              grayisholive            #8c8767

=item grayish violaceous blue    grayishviolaceousblue   #8791bf

=item grayish violet-blue        grayishvioletblue       #8c82b6

=item grayish violet-blue        grayishvioletblue       #604e81

=item green-blue slate           greenblueslate          #536878

=item greenish glaucous          greenishglaucous        #c7e6d7

=item greenish glaucous-blue     greenishglaucousblue    #66ada4

=item greenish slate-black       greenishslateblack      #3a4b47

=item greenish slate-black       greenishslateblack      #4e5755

=item greenish slate-black       greenishslateblack      #555555

=item greenish slate-black       greenishslateblack      #222222

=item greenish yellow            greenishyellow          #beb72e

=item green-yellow               greenyellow             #e9e450

=item grenadine                  grenadine               #d9603b

=item grenadine pink             grenadinepink           #f88379

=item grenadine red              grenadinered            #e25822

=item guinea green               guineagreen             #007a74

=item gull gray                  gullgray                #848482

=item haematite red              haematitered            #674c47

=item haematoxylin violet        haematoxylinviolet      #86608e

=item hair brown                 hairbrown               #5b504f

=item hathi gray                 hathigray               #b2beb5

=item hathi gray                 hathigray               #7d8984

=item hathi gray                 hathigray               #b9b8b5

=item hathi gray                 hathigray               #848482

=item hay's blue                 haysblue                #545aa7

=item hay's brown                haysbrown               #905d5d

=item hay's brown                haysbrown               #674c47

=item hay's green                haysgreen               #679267

=item hay's green                haysgreen               #355e3b

=item hay's lilac                hayslilac               #b695c0

=item hay's maroon               haysmaroon              #543d3f

=item hay's russet               haysrusset              #79443b

=item hazel                      hazel                   #80461b

=item heliotrope gray            heliotropegray          #aa98a9

=item heliotrope gray            heliotropegray          #796878

=item heliotrope slate           heliotropeslate         #796878

=item hellebore red              helleborered            #a8516e

=item helvetia blue              helvetiablue            #545aa7

=item hermosa pink               hermosapink             #ea9399

=item hessian brown              hessianbrown            #674c47

=item hessian brown              hessianbrown            #43302e

=item honey yellow               honeyyellow             #c9ae5d

=item honey yellow               honeyyellow             #ab9144

=item hortense blue              hortenseblue            #436b95

=item hortense violet            hortenseviolet          #d399e6

=item hyacinth blue              hyacinthblue            #272458

=item hyacinth blue              hyacinthblue            #604e81

=item hyacinth violet            hyacinthviolet          #602f6b

=item hydrangea pink             hydrangeapink           #f4c2c2

=item hydrangea pink             hydrangeapink           #d9a6a9

=item hydrangea red              hydrangeared            #905d5d

=item hyssop violet              hyssopviolet            #86608e

=item indian lake                indianlake              #a8516e

=item indian lake                indianlake              #915f6d

=item indian purple              indianpurple            #50404d

=item indian purple              indianpurple            #673147

=item indian red                 indianred               #905d5d

=item indigo blue                indigoblue              #00304e

=item indigo blue                indigoblue              #536878

=item indigo blue                indigoblue              #36454f

=item indigo blue                indigoblue              #4c516d

=item indulin blue               indulinblue             #4c516d

=item invisible green            invisiblegreen          #3a4b47

=item invisible green            invisiblegreen          #004b49

=item iron gray                  irongray                #57554c

=item isabella color             isabellacolor           #a18f60

=item italian blue               italianblue             #007791

=item ivory yellow               ivoryyellow             #f3e5ab

=item ivy green                  ivygreen                #665d1e

=item ivy green                  ivygreen                #5b5842

=item jade green                 jadegreen               #4a5d23

=item jade green                 jadegreen               #515744

=item japan rose                 japanrose               #d9a6a9

=item jasper green               jaspergreen             #3b7861

=item jasper pink                jasperpink              #e4717a

=item jasper pink                jasperpink              #f88379

=item jasper pink                jasperpink              #e66761

=item jasper red                 jasperred               #ab4e52

=item javel green                javelgreen              #b9b459

=item jay blue                   jayblue                 #436b95

=item jay blue                   jayblue                 #8791bf

=item jouvence blue              jouvenceblue            #317873

=item jouvence blue              jouvenceblue            #367588

=item kaiser brown               kaiserbrown             #80461b

=item kildare green              kildaregreen            #8a9a5b

=item killarney green            killarneygreen          #679267

=item king's blue                kingsblue               #70a3cc

=item kronberg's green           kronbergsgreen          #867e36

=item kronberg's green           kronbergsgreen          #665d1e

=item laelia pink                laeliapink              #b784a7

=item laelia pink                laeliapink              #de6fa1

=item la france pink             lafrancepink            #ffb5ba

=item lavender                   lavender                #dcd0ff

=item lavender                   lavender                #c4c3dd

=item lavender-blue              lavenderblue            #6c79b8

=item lavender-blue              lavenderblue            #8791bf

=item lavender-gray              lavendergray            #c0c8e1

=item lavender-gray              lavendergray            #8c92ac

=item lavender-gray              lavendergray            #c4c3dd

=item lavender-gray              lavendergray            #9690ab

=item lavender-violet            lavenderviolet          #7e73b8

=item leaf green                 leafgreen               #515744

=item leitch's blue              leitchsblue             #0067a5

=item lemon chrome               lemonchrome             #d4af37

=item lemon yellow               lemonyellow             #e9e450

=item lemon yellow               lemonyellow             #beb72e

=item lettuce green              lettucegreen            #8a9a5b

=item lichen green               lichengreen             #c7e6d7

=item light alice blue           lightaliceblue          #70a3cc

=item light alice blue           lightaliceblue          #91a3b0

=item light amparo blue          lightamparoblue         #4997d0

=item light amparo purple        lightamparopurple       #d399e6

=item light bice green           lightbicegreen          #8a9a5b

=item light blue-green           lightbluegreen          #3eb489

=item light blue-green           lightbluegreen          #6aab8e

=item light blue-violet          lightblueviolet         #30267a

=item light bluish violet        lightbluishviolet       #6c79b8

=item light bluish violet        lightbluishviolet       #545aa7

=item light bluish violet        lightbluishviolet       #7e73b8

=item light brownish drab        lightbrownishdrab       #958070

=item light brownish olive       lightbrownisholive      #967117

=item light brownish vinaceous   lightbrownishvinaceous  #c4aead

=item light buff                 lightbuff               #fad6a5

=item light buff                 lightbuff               #f3e5ab

=item light cadet blue           lightcadetblue          #4997d0

=item light cadmium              lightcadmium            #f3c300

=item light campanula blue       lightcampanulablue      #6c79b8

=item light celandine green      lightcelandinegreen     #b2beb5

=item light celandine green      lightcelandinegreen     #7d8984

=item light cendre green         lightcendregreen        #83d37d

=item light cendre green         lightcendregreen        #93c592

=item light cerulean blue        lightceruleanblue       #70a3cc

=item light chalcedony yellow    lightchalcedonyyellow   #eae679

=item light chicory blue         lightchicoryblue        #8c82b6

=item light cinnamon-drab        lightcinnamondrab       #977f73

=item light cinnamon-drab        lightcinnamondrab       #958070

=item light columbia blue        lightcolumbiablue       #70a3cc

=item light congo pink           lightcongopink          #f4c2c2

=item light congo pink           lightcongopink          #d9a6a9

=item light coral red            lightcoralred           #cb6d51

=item light corinthian red       lightcorinthianred      #c08081

=item light cress green          lightcressgreen         #8a9a5b

=item light danube green         lightdanubegreen        #3b7861

=item light drab                 lightdrab               #ae9b82

=item light dull bluish violet   lightdullbluishviolet   #8c82b6

=item light dull glaucous-blue   lightdullglaucousblue   #66aabc

=item light dull glaucous-blue   lightdullglaucousblue   #91a3b0

=item light dull green-yellow    lightdullgreenyellow    #c9dc89

=item light elm green            lightelmgreen           #8a9a5b

=item light fluorite green       lightfluoritegreen      #c9dc89

=item light forget-me-not blue   lightforgetmenotblue    #70a3cc

=item light glaucous-blue        lightglaucousblue       #9cd1dc

=item light grape green          lightgrapegreen         #8a9a5b

=item light grayish blue-violet  lightgrayishblueviolet  #70a3cc

=item light grayish blue-violet  lightgrayishblueviolet  #8791bf

=item light grayish olive        lightgrayisholive       #8c8767

=item light grayish olive        lightgrayisholive       #8a8776

=item light grayish vinaceous    lightgrayishvinaceous   #c7ada3

=item light grayish violet-blue  lightgrayishvioletblue  #6c79b8

=item light greenish yellow      lightgreenishyellow     #e9e450

=item light greenish yellow      lightgreenishyellow     #beb72e

=item light green-yellow         lightgreenyellow        #eae679

=item light gull gray            lightgullgray           #b9b8b5

=item light heliotrope gray      lightheliotropegray     #aa98a9

=item light hellebore green      lighthelleboregreen     #8a9a5b

=item light hellebore green      lighthelleboregreen     #8f9779

=item light hortense violet      lighthortenseviolet     #d399e6

=item light hyssop violet        lighthyssopviolet       #8c82b6

=item light jasper red           lightjasperred          #e4717a

=item light jasper red           lightjasperred          #ab4e52

=item light king's blue          lightkingsblue          #bcd4e6

=item light king's blue          lightkingsblue          #91a3b0

=item light lavender-blue        lightlavenderblue       #8791bf

=item light lavender-violet      lightlavenderviolet     #8c82b6

=item light lobelia violet       lightlobeliaviolet      #b695c0

=item light lumiere green        lightlumieregreen       #c9dc89

=item light mallow purple        lightmallowpurple       #de6fa1

=item light mauve                lightmauve              #8c82b6

=item light medici blue          lightmediciblue         #536878

=item light methyl blue          lightmethylblue         #4997d0

=item light methyl blue          lightmethylblue         #0067a5

=item light mineral gray         lightmineralgray        #b2beb5

=item light mouse gray           lightmousegray          #8e8279

=item light neropalin blue       lightneropalinblue      #91a3b0

=item light neutral gray         lightneutralgray        #848482

=item light niagara green        lightniagaragreen       #66ada4

=item light ochraceous-buff      lightochraceousbuff     #e3a857

=item light ochraceous-salmon    lightochraceoussalmon   #fad6a5

=item light olive-gray           lightolivegray          #bfb8a5

=item light orange-yellow        lightorangeyellow       #e3a857

=item light orange-yellow        lightorangeyellow       #d4af37

=item light oriental green       lightorientalgreen      #93c592

=item light paris green          lightparisgreen         #93c592

=item light payne's gray         lightpaynesgray         #91a3b0

=item light payne's gray         lightpaynesgray         #81878b

=item light perilla purple       lightperillapurple      #915c83

=item light perilla purple       lightperillapurple      #836479

=item light phlox purple         lightphloxpurple        #de6fa1

=item light pinkish cinnamon     lightpinkishcinnamon    #f4c2c2

=item light pinkish cinnamon     lightpinkishcinnamon    #d9a6a9

=item light pinkish lilac        lightpinkishlilac       #efbbcc

=item light plumbago gray        lightplumbagogray       #8b8589

=item light porcelain green      lightporcelaingreen     #66ada4

=item light porcelain green      lightporcelaingreen     #317873

=item light purple-drab          lightpurpledrab         #796878

=item light purplish gray        lightpurplishgray       #8b8589

=item light purplish gray        lightpurplishgray       #848482

=item light purplish vinaceous   lightpurplishvinaceous  #dea5a4

=item light quaker drab          lightquakerdrab         #8b8589

=item light rosolane purple      lightrosolanepurple     #de6fa1

=item light russet-vinaceous     lightrussetvinaceous    #a87c6d

=item light salmon-orange        lightsalmonorange       #d99058

=item light seal brown           lightsealbrown          #5c504f

=item light sky blue             lightskyblue            #91a3b0

=item light soft blue-violet     lightsoftblueviolet     #6c79b8

=item light soft blue-violet     lightsoftblueviolet     #7e73b8

=item light squill blue          lightsquillblue         #70a3cc

=item light sulphate green       lightsulphategreen      #66ada4

=item light terre verte          lightterreverte         #317873

=item light turtle green         lightturtlegreen        #c9dc89

=item light tyrian blue          lighttyrianblue         #536878

=item light tyrian blue          lighttyrianblue         #8c92ac

=item light tyrian blue          lighttyrianblue         #4c516d

=item light varley's gray        lightvarleysgray        #aa98a9

=item light vinaceous-cinnamon   lightvinaceouscinnamon  #fad6a5

=item light vinaceous-drab       lightvinaceousdrab      #905d5d

=item light vinaceous-fawn       lightvinaceousfawn      #c7ada3

=item light vinaceous-fawn       lightvinaceousfawn      #c2ac99

=item light vinaceous-gray       lightvinaceousgray      #aa98a9

=item light vinaceous-gray       lightvinaceousgray      #bfb9bd

=item light vinaceous-gray       lightvinaceousgray      #8b8589

=item light vinaceous-gray       lightvinaceousgray      #c3a6b1

=item light vinaceous-lilac      lightvinaceouslilac     #b784a7

=item light vinaceous-lilac      lightvinaceouslilac     #aa8a9e

=item light vinaceous-lilac      lightvinaceouslilac     #d597ae

=item light vinaceous-lilac      lightvinaceouslilac     #c3a6b1

=item light vinaceous-purple     lightvinaceouspurple    #836479

=item light violet               lightviolet             #6c79b8

=item light violet               lightviolet             #7e73b8

=item light violet-blue          lightvioletblue         #545aa7

=item light violet-gray          lightvioletgray         #8b8589

=item light violet-gray          lightvioletgray         #848482

=item light violet-plumbeous     lightvioletplumbeous    #91a3b0

=item light violet-plumbeous     lightvioletplumbeous    #536878

=item light violet-plumbeous     lightvioletplumbeous    #8c92ac

=item light viridine green       lightviridinegreen      #c9dc89

=item light viridine yellow      lightviridineyellow     #eae679

=item light windsor blue         lightwindsorblue        #8791bf

=item light wistaria blue        lightwistariablue       #8791bf

=item light wistaria blue        lightwistariablue       #8c82b6

=item light wistaria violet      lightwistariaviolet     #8c82b6

=item light yellow-green         lightyellowgreen        #bdda57

=item light yellow-green         lightyellowgreen        #c9dc89

=item light yellowish olive      lightyellowisholive     #98943e

=item lilac                      lilac                   #b695c0

=item lilac                      lilac                   #aa98a9

=item lilac gray                 lilacgray               #bfb9bd

=item lily green                 lilygreen               #7d8984

=item lime green                 limegreen               #b9b459

=item lime green                 limegreen               #98943e

=item lime green                 limegreen               #867e36

=item lincoln green              lincolngreen            #515744

=item liseran purple             liseranpurple           #9e4f88

=item liseran purple             liseranpurple           #b784a7

=item liseran purple             liseranpurple           #915c83

=item liseran purple             liseranpurple           #de6fa1

=item litho purple               lithopurple             #875692

=item litho purple               lithopurple             #602f6b

=item litho purple               lithopurple             #86608e

=item liver brown                liverbrown              #79443b

=item livid brown                lividbrown              #905d5d

=item livid pink                 lividpink               #f9ccca

=item livid pink                 lividpink               #dea5a4

=item livid pink                 lividpink               #ead8d7

=item livid pink                 lividpink               #c4aead

=item livid purple               lividpurple             #915c83

=item livid violet               lividviolet             #86608e

=item livid violet               lividviolet             #796878

=item lobelia violet             lobeliaviolet           #b695c0

=item lumiere blue               lumiereblue             #66ada4

=item lumiere blue               lumiereblue             #66aabc

=item lumiere green              lumieregreen            #c9dc89

=item lumiere green              lumieregreen            #8a9a5b

=item lyons blue                 lyonsblue               #0067a5

=item madder blue                madderblue              #9690ab

=item madder blue                madderblue              #796878

=item madder brown               madderbrown             #905d5d

=item madder violet              madderviolet            #563c5c

=item magenta                    magenta                 #9e4f88

=item mahogany red               mahoganyred             #79443b

=item maize yellow               maizeyellow             #f8de7e

=item malachite green            malachitegreen          #93c592

=item mallow pink                mallowpink              #e68fac

=item mallow purple              mallowpurple            #870074

=item mallow purple              mallowpurple            #de6fa1

=item manganese violet           manganeseviolet         #875692

=item marguerite yellow          margueriteyellow        #f3e5ab

=item marine blue                marineblue              #436b95

=item maroon                     maroon                  #3e1d1e

=item mars brown                 marsbrown               #6f4e37

=item mars orange                marsorange              #cb6d51

=item mars orange                marsorange              #9e4732

=item mars violet                marsviolet              #50404d

=item mars yellow                marsyellow              #c98500

=item mars yellow                marsyellow              #be8a3d

=item martius yellow             martiusyellow           #eae679

=item massicot yellow            massicotyellow          #f8de7e

=item massicot yellow            massicotyellow          #f3e5ab

=item mathew's blue              mathewsblue             #0067a5

=item mathew's purple            mathewspurple           #875692

=item mathew's purple            mathewspurple           #86608e

=item mauve                      mauve                   #7e73b8

=item mauvette                   mauvette                #efbbcc

=item mazarine blue              mazarineblue            #4997d0

=item mazarine blue              mazarineblue            #70a3cc

=item meadow green               meadowgreen             #679267

=item medal bronze               medalbronze             #6c541e

=item medici blue                mediciblue              #81878b

=item methyl blue                methylblue              #00a1c2

=item methyl green               methylgreen             #007a74

=item methyl green               methylgreen             #317873

=item microcline green           microclinegreen         #96ded1

=item mignonette green           mignonettegreen         #867e36

=item mikado brown               mikadobrown             #a67b5b

=item mikado orange              mikadoorange            #ed872d

=item mineral gray               mineralgray             #8f9779

=item mineral green              mineralgreen            #7e9f2e

=item mineral red                mineralred              #905d5d

=item montpellier green          montpelliergreen        #6aab8e

=item montpellier green          montpelliergreen        #3b7861

=item morocco red                moroccored              #79443b

=item motmot blue                motmotblue              #367588

=item motmot green               motmotgreen             #44944a

=item motmot green               motmotgreen             #679267

=item mouse gray                 mousegray               #8e8279

=item mulberry purple            mulberrypurple          #602f6b

=item mulberry purple            mulberrypurple          #563c5c

=item mummy brown                mummybrown              #4b3621

=item munich lake                munichlake              #be0032

=item munich lake                munichlake              #bc3f4a

=item mustard yellow             mustardyellow           #d4af37

=item myrtle green               myrtlegreen             #004b49

=item mytho green                mythogreen              #8a9a5b

=item mytho green                mythogreen              #8f9779

=item naphthalene violet         naphthaleneviolet       #5d3954

=item naphthalene yellow         naphthaleneyellow       #eae679

=item naphthalene yellow         naphthaleneyellow       #ebe8a4

=item naples yellow              naplesyellow            #f8de7e

=item natal brown                natalbrown              #635147

=item navy blue                  navyblue                #4e5180

=item navy blue                  navyblue                #4c516d

=item neropalin blue             neropalinblue           #70a3cc

=item neutral gray               neutralgray             #848482

=item neutral red                neutralred              #673147

=item neutral red                neutralred              #915f6d

=item neuvider green             neuvidergreen           #93c592

=item neva green                 nevagreen               #bdda57

=item niagara green              niagaragreen            #8da399

=item niagara green              niagaragreen            #66ada4

=item nickel green               nickelgreen             #3b7861

=item nickel green               nickelgreen             #5e716a

=item night green                nightgreen              #8db600

=item nigrosin blue              nigrosinblue            #4c516d

=item nigrosin violet            nigrosinviolet          #563c5c

=item nile blue                  nileblue                #66ada4

=item nopal red                  nopalred                #bc3f4a

=item ocher red                  ocherred                #905d5d

=item ochraceous-buff            ochraceousbuff          #f4c2c2

=item ochraceous-buff            ochraceousbuff          #d9a6a9

=item ochraceous-orange          ochraceousorange        #eaa221

=item ochraceous-orange          ochraceousorange        #c98500

=item ochraceous-salmon          ochraceoussalmon        #d99058

=item ochraceous-tawny           ochraceoustawny         #be8a3d

=item ochraceous-tawny           ochraceoustawny         #996515

=item oil green                  oilgreen                #8a9a5b

=item old burgundy               oldburgundy             #2e1d21

=item old gold                   oldgold                 #ab9144

=item old gold                   oldgold                 #967117

=item old rose                   oldrose                 #ab4e52

=item olive                      olive                   #665d1e

=item olive                      olive                   #5b5842

=item olive-brown                olivebrown              #7e6d5a

=item olive-buff                 olivebuff               #f3e5ab

=item olive-buff                 olivebuff               #c2b280

=item olive-citrine              olivecitrine            #665d1e

=item olive-gray                 olivegray               #8c8767

=item olive-gray                 olivegray               #8a8776

=item olive green                olivegreen              #665d1e

=item olive lake                 olivelake               #a18f60

=item olive lake                 olivelake               #867e36

=item olive-ocher                oliveocher              #c9ae5d

=item olive-ocher                oliveocher              #ab9144

=item olive-yellow               oliveyellow             #b9b459

=item olivine                    olivine                 #93c592

=item olympic blue               olympicblue             #0067a5

=item onion-skin pink            onionskinpink           #d9a6a9

=item onion-skin pink            onionskinpink           #d99058

=item ontario violet             ontarioviolet           #8c82b6

=item opaline green              opalinegreen            #c9dc89

=item opaline green              opalinegreen            #dadfb7

=item orange                     orange                  #ed872d

=item orange-buff                orangebuff              #e3a857

=item orange chrome              orangechrome            #f38400

=item orange-cinnamon            orangecinnamon          #d99058

=item orange-citrine             orangecitrine           #967117

=item orange-pink                orangepink              #fd943f

=item orange-pink                orangepink              #fab57f

=item orange-rufous              orangerufous            #be6516

=item orange-vinaceous           orangevinaceous         #e4717a

=item orange-vinaceous           orangevinaceous         #f88379

=item oriental green             orientalgreen           #679267

=item orient blue                orientblue              #436b95

=item orient blue                orientblue              #536878

=item orient pink                orientpink              #f88379

=item oural green                ouralgreen              #b6e5af

=item oural green                ouralgreen              #93c592

=item ox-blood red               oxbloodred              #841b2d

=item oxide blue                 oxideblue               #0067a5

=item oxide blue                 oxideblue               #436b95

=item pale amaranth pink         paleamaranthpink        #e68fac

=item pale amparo blue           paleamparoblue          #bcd4e6

=item pale amparo blue           paleamparoblue          #91a3b0

=item pale amparo purple         paleamparopurple        #b695c0

=item pale aniline lilac         paleanilinelilac        #a1caf1

=item pale aniline lilac         paleanilinelilac        #70a3cc

=item pale blue                  paleblue                #9cd1dc

=item pale blue                  paleblue                #bcd4e6

=item pale blue-green            palebluegreen           #c7e6d7

=item pale blue-violet           paleblueviolet          #6c79b8

=item pale bluish lavender       palebluishlavender      #c4c3dd

=item pale bluish lavender       palebluishlavender      #d6cadd

=item pale bluish violet         palebluishviolet        #6c79b8

=item pale brownish drab         palebrownishdrab        #c1b6b3

=item pale brownish vinaceous    palebrownishvinaceous   #ead8d7

=item pale brownish vinaceous    palebrownishvinaceous   #c4aead

=item pale cadet blue            palecadetblue           #70a3cc

=item pale cadet blue            palecadetblue           #91a3b0

=item pale cadet blue            palecadetblue           #8791bf

=item pale cadet blue            palecadetblue           #8c92ac

=item pale campanula blue        palecampanulablue       #b3bce2

=item pale campanula blue        palecampanulablue       #8791bf

=item pale cendre green          palecendregreen         #c9dc89

=item pale cendre green          palecendregreen         #dadfb7

=item pale cerulean blue         paleceruleanblue        #a1caf1

=item pale cerulean blue         paleceruleanblue        #70a3cc

=item pale chalcedony yellow     palechalcedonyyellow    #ebe8a4

=item pale cinnamon-pink         palecinnamonpink        #f4c2c2

=item pale cinnamon-pink         palecinnamonpink        #d9a6a9

=item pale cinnamon-pink         palecinnamonpink        #ecd5c5

=item pale cinnamon-pink         palecinnamonpink        #c2ac99

=item pale congo pink            palecongopink           #f4c2c2

=item pale congo pink            palecongopink           #d9a6a9

=item pale congo pink            palecongopink           #ecd5c5

=item pale congo pink            palecongopink           #c7ada3

=item pale drab-gray             paledrabgray            #f2f3f4

=item pale drab-gray             paledrabgray            #b9b8b5

=item pale dull glaucous-blue    paledullglaucousblue    #bcd4e6

=item pale dull glaucous-blue    paledullglaucousblue    #91a3b0

=item pale dull green-yellow     paledullgreenyellow     #c9dc89

=item pale ecru-drab             paleecrudrab            #c1b6b3

=item pale flesh color           palefleshcolor          #f4c2c2

=item pale flesh color           palefleshcolor          #d9a6a9

=item pale fluorite green        palefluoritegreen       #c7e6d7

=item pale glass green           paleglassgreen          #c9dc89

=item pale glass green           paleglassgreen          #dadfb7

=item pale glaucous-blue         paleglaucousblue        #9cd1dc

=item pale glaucous-blue         paleglaucousblue        #bcd4e6

=item pale glaucous-green        paleglaucousgreen       #c7e6d7

=item pale grayish blue          palegrayishblue         #bcd4e6

=item pale grayish blue          palegrayishblue         #c0c8e1

=item pale grayish blue-violet   palegrayishblueviolet   #c0c8e1

=item pale grayish vinaceous     palegrayishvinaceous    #c1b6b3

=item pale grayish vinaceous     palegrayishvinaceous    #ecd5c5

=item pale grayish vinaceous     palegrayishvinaceous    #c7ada3

=item pale grayish violet-blue   palegrayishvioletblue   #8791bf

=item pale green-blue gray       palegreenbluegray       #91a3b0

=item pale greenish yellow       palegreenishyellow      #eae679

=item pale greenish yellow       palegreenishyellow      #b9b459

=item pale green-yellow          palegreenyellow         #eae679

=item pale green-yellow          palegreenyellow         #ebe8a4

=item pale gull gray             palegullgray            #b9b8b5

=item pale hortense violet       palehortenseviolet      #d5badb

=item pale hortense violet       palehortenseviolet      #b695c0

=item pale king's blue           palekingsblue           #c4c3dd

=item pale laelia pink           palelaeliapink          #efbbcc

=item pale laelia pink           palelaeliapink          #d597ae

=item pale lavender-violet       palelavenderviolet      #b695c0

=item pale lavender-violet       palelavenderviolet      #aa98a9

=item pale lemon yellow          palelemonyellow         #e9e450

=item pale lilac                 palelilac               #e8ccd7

=item pale lobelia violet        palelobeliaviolet       #d6cadd

=item pale lobelia violet        palelobeliaviolet       #aa98a9

=item pale lumiere green         palelumieregreen        #c9dc89

=item pale mauve                 palemauve               #d6cadd

=item pale mazarine blue         palemazarineblue        #bcd4e6

=item pale mazarine blue         palemazarineblue        #91a3b0

=item pale mazarine blue         palemazarineblue        #c0c8e1

=item pale mazarine blue         palemazarineblue        #8c92ac

=item pale medici blue           palemediciblue          #91a3b0

=item pale medici blue           palemediciblue          #b4bcc0

=item pale medici blue           palemediciblue          #81878b

=item pale methyl blue           palemethylblue          #70a3cc

=item pale mouse gray            palemousegray           #8e8279

=item pale mouse gray            palemousegray           #bfb8a5

=item pale neropalin blue        paleneropalinblue       #bcd4e6

=item pale neutral gray          paleneutralgray         #848482

=item pale niagara green         paleniagaragreen        #c7e6d7

=item pale nile blue             palenileblue            #96ded1

=item pale ochraceous-buff       paleochraceousbuff      #f4c2c2

=item pale ochraceous-salmon     paleochraceoussalmon    #fad6a5

=item pale ochraceous-salmon     paleochraceoussalmon    #f3e5ab

=item pale olive-buff            paleolivebuff           #f3e5ab

=item pale olive-gray            paleolivegray           #f0ead6

=item pale olive-gray            paleolivegray           #bfb8a5

=item pale olivine               paleolivine             #c7e6d7

=item pale orange-yellow         paleorangeyellow        #fbc97f

=item pale orange-yellow         paleorangeyellow        #e3a857

=item pale orange-yellow         paleorangeyellow        #fada5e

=item pale orange-yellow         paleorangeyellow        #d4af37

=item pale orange-yellow         paleorangeyellow        #f8de7e

=item pale orange-yellow         paleorangeyellow        #c9ae5d

=item pale payne's gray          palepaynesgray          #91a3b0

=item pale persian lilac         palepersianlilac        #d597ae

=item pale pinkish buff          palepinkishbuff         #fad6a5

=item pale pinkish cinnamon      palepinkishcinnamon     #fad6a5

=item pale purple-drab           palepurpledrab          #c3a6b1

=item pale purplish gray         palepurplishgray        #8b8589

=item pale purplish vinaceous    palepurplishvinaceous   #f9ccca

=item pale purplish vinaceous    palepurplishvinaceous   #dea5a4

=item pale quaker drab           palequakerdrab          #bfb9bd

=item pale quaker drab           palequakerdrab          #8b8589

=item pale rhodonite pink        palerhodonitepink       #efbbcc

=item pale rose-purple           palerosepurple          #b695c0

=item pale rosolane purple       palerosolanepurple      #de6fa1

=item pale russian blue          palerussianblue         #bcd4e6

=item pale salmon color          palesalmoncolor         #fad6a5

=item pale smoke gray            palesmokegray           #bfb8a5

=item pale soft blue-violet      palesoftblueviolet      #8791bf

=item pale soft blue-violet      palesoftblueviolet      #8c82b6

=item pale sulphate green        palesulphategreen       #66ada4

=item pale tiber green           paletibergreen          #c9dc89

=item pale turquoise green       paleturquoisegreen      #96ded1

=item pale turtle green          paleturtlegreen         #c9dc89

=item pale turtle green          paleturtlegreen         #dadfb7

=item pale varley's gray         palevarleysgray         #9690ab

=item pale varley's gray         palevarleysgray         #aa98a9

=item pale verbena violet        paleverbenaviolet       #dcd0ff

=item pale veronese green        paleveronesegreen       #c9dc89

=item pale veronese green        paleveronesegreen       #dadfb7

=item pale vinaceous             palevinaceous           #dea5a4

=item pale vinaceous-drab        palevinaceousdrab       #c4aead

=item pale vinaceous-drab        palevinaceousdrab       #c1b6b3

=item pale vinaceous-drab        palevinaceousdrab       #ad8884

=item pale vinaceous-drab        palevinaceousdrab       #8f817f

=item pale vinaceous-fawn        palevinaceousfawn       #c1b6b3

=item pale vinaceous-fawn        palevinaceousfawn       #ecd5c5

=item pale vinaceous-fawn        palevinaceousfawn       #c7ada3

=item pale vinaceous-fawn        palevinaceousfawn       #c2ac99

=item pale vinaceous-lilac       palevinaceouslilac      #efbbcc

=item pale vinaceous-lilac       palevinaceouslilac      #e8ccd7

=item pale vinaceous-pink        palevinaceouspink       #ecd5c5

=item pale vinaceous-pink        palevinaceouspink       #c7ada3

=item pale violet                paleviolet              #8791bf

=item pale violet                paleviolet              #8c82b6

=item pale violet-blue           palevioletblue          #4997d0

=item pale violet-gray           palevioletgray          #8b8589

=item pale violet-gray           palevioletgray          #848482

=item pale violet-plumbeous      palevioletplumbeous     #91a3b0

=item pale violet-plumbeous      palevioletplumbeous     #8c92ac

=item pale viridine yellow       paleviridineyellow      #eae679

=item pale viridine yellow       paleviridineyellow      #ebe8a4

=item pale windsor blue          palewindsorblue         #70a3cc

=item pale windsor blue          palewindsorblue         #8791bf

=item pale wistaria blue         palewistariablue        #dcd0ff

=item pale wistaria blue         palewistariablue        #8c82b6

=item pale wistaria violet       palewistariaviolet      #8c82b6

=item pale wistaria violet       palewistariaviolet      #9690ab

=item pale yellow-green          paleyellowgreen         #c9dc89

=item pale yellow-orange         paleyelloworange        #f4c2c2

=item pallid blue-violet         pallidblueviolet        #b3bce2

=item pallid blue-violet         pallidblueviolet        #8791bf

=item pallid bluish violet       pallidbluishviolet      #b3bce2

=item pallid bluish violet       pallidbluishviolet      #8791bf

=item pallid bluish violet       pallidbluishviolet      #dcd0ff

=item pallid bluish violet       pallidbluishviolet      #8c82b6

=item pallid brownish drab       pallidbrownishdrab      #c1b6b3

=item pallid grayish violet-blue pallidgrayishvioletblue #8791bf

=item pallid grayish violet-blue pallidgrayishvioletblue #8c92ac

=item pallid methyl blue         pallidmethylblue        #a1caf1

=item pallid mouse gray          pallidmousegray         #c1b6b3

=item pallid mouse gray          pallidmousegray         #b9b8b5

=item pallid neutral gray        pallidneutralgray       #b9b8b5

=item pallid purple-drab         pallidpurpledrab        #bfb9bd

=item pallid purple-drab         pallidpurpledrab        #c3a6b1

=item pallid purplish gray       pallidpurplishgray      #bfb9bd

=item pallid quaker drab         pallidquakerdrab        #bfb9bd

=item pallid soft blue-violet    pallidsoftblueviolet    #b3bce2

=item pallid soft blue-violet    pallidsoftblueviolet    #8791bf

=item pallid soft blue-violet    pallidsoftblueviolet    #dcd0ff

=item pallid soft blue-violet    pallidsoftblueviolet    #8c82b6

=item pallid vinaceous-drab      pallidvinaceousdrab     #bfb9bd

=item pallid vinaceous-drab      pallidvinaceousdrab     #e8ccd7

=item pallid violet              pallidviolet            #b3bce2

=item pallid violet              pallidviolet            #8791bf

=item pallid violet              pallidviolet            #c0c8e1

=item pallid violet              pallidviolet            #8c92ac

=item pallid violet              pallidviolet            #dcd0ff

=item pallid violet              pallidviolet            #8c82b6

=item pallid violet              pallidviolet            #c4c3dd

=item pallid violet              pallidviolet            #9690ab

=item pallid violet-blue         pallidvioletblue        #b3bce2

=item pallid violet-blue         pallidvioletblue        #8791bf

=item pansy purple               pansypurple             #673147

=item pansy violet               pansyviolet             #875692

=item paris blue                 parisblue               #0067a5

=item paris blue                 parisblue               #00416a

=item paris green                parisgreen              #93c592

=item parrot green               parrotgreen             #8a9a5b

=item parula blue                parulablue              #91a3b0

=item parula blue                parulablue              #536878

=item patent blue                patentblue              #004958

=item payne's gray               paynesgray              #536878

=item peach red                  peachred                #cb6d51

=item peacock blue               peacockblue             #007791

=item peacock green              peacockgreen            #8a9a5b

=item pea green                  peagreen                #7d8984

=item pearl blue                 pearlblue               #c0c8e1

=item pearl blue                 pearlblue               #8c92ac

=item pearl gray                 pearlgray               #b9b8b5

=item pecan brown                pecanbrown              #a67b5b

=item perilla purple             perillapurple           #673147

=item persian blue               persianblue             #bcd4e6

=item persian blue               persianblue             #91a3b0

=item persian lilac              persianlilac            #c17e91

=item petunia violet             petuniaviolet           #602f6b

=item phenyl blue                phenylblue              #30267a

=item phlox pink                 phloxpink               #b695c0

=item phlox purple               phloxpurple             #9e4f88

=item picric yellow              picricyellow            #e9e450

=item pinard yellow              pinardyellow            #fada5e

=item pinard yellow              pinardyellow            #f8de7e

=item pinkish buff               pinkishbuff             #f4c2c2

=item pinkish buff               pinkishbuff             #d9a6a9

=item pinkish cinnamon           pinkishcinnamon         #e3a857

=item pinkish cinnamon           pinkishcinnamon         #c19a6b

=item pinkish vinaceous          pinkishvinaceous        #d9a6a9

=item pistachio green            pistachiogreen          #679267

=item pleroma violet             pleromaviolet           #7e73b8

=item pleroma violet             pleromaviolet           #604e97

=item plumbago blue              plumbagoblue            #9690ab

=item plumbago blue              plumbagoblue            #aa98a9

=item plumbago gray              plumbagogray            #8b8589

=item plumbeous                  plumbeous               #91a3b0

=item plumbeous                  plumbeous               #81878b

=item plumbeous black            plumbeousblack          #36454f

=item plumbeous black            plumbeousblack          #222222

=item plum purple                plumpurple              #2f2140

=item pois green                 poisgreen               #8f9779

=item pompeian red               pompeianred             #ab4e52

=item porcelain blue             porcelainblue           #66aabc

=item porcelain green            porcelaingreen          #317873

=item primrose yellow            primroseyellow          #eae679

=item primuline yellow           primulineyellow         #d4af37

=item prout's brown              proutsbrown             #6f4e37

=item prune purple               prunepurple             #563c5c

=item prussian blue              prussianblue            #0067a5

=item prussian blue              prussianblue            #436b95

=item prussian green             prussiangreen           #004b49

=item prussian red               prussianred             #905d5d

=item puritan gray               puritangray             #81878b

=item purple                     purple                  #870074

=item purple-drab                purpledrab              #796878

=item purplish gray              purplishgray            #796878

=item purplish gray              purplishgray            #5d555b

=item purplish lilac             purplishlilac           #b784a7

=item purplish lilac             purplishlilac           #d597ae

=item purplish vinaceous         purplishvinaceous       #ad8884

=item pyrite yellow              pyriteyellow            #98943e

=item quaker drab                quakerdrab              #8b8589

=item quaker drab                quakerdrab              #848482

=item rainette green             rainettegreen           #8a9a5b

=item raisin black               raisinblack             #50404d

=item raisin purple              raisinpurple            #5d3954

=item ramier blue                ramierblue              #9690ab

=item ramier blue                ramierblue              #554c69

=item ramier blue                ramierblue              #796878

=item raw sienna                 rawsienna               #be8a3d

=item raw sienna                 rawsienna               #996515

=item reed yellow                reedyellow              #b9b459

=item rejane green               rejanegreen             #93c592

=item rejane green               rejanegreen             #679267

=item rhodamine purple           rhodaminepurple         #ce4676

=item rhodonite pink             rhodonitepink           #c17e91

=item rinnemann's green          rinnemannsgreen         #8a9a5b

=item rivage green               rivagegreen             #c9dc89

=item rivage green               rivagegreen             #8a9a5b

=item rocellin purple            rocellinpurple          #de6fa1

=item rocellin purple            rocellinpurple          #c17e91

=item roman green                romangreen              #665d1e

=item rood's blue                roodsblue               #00a1c2

=item rood's brown               roodsbrown              #977f73

=item rood's brown               roodsbrown              #a67b5b

=item rood's brown               roodsbrown              #6f4e37

=item rood's lavender            roodslavender           #aa98a9

=item rood's violet              roodsviolet             #702963

=item rose color                 rosecolor               #de6fa1

=item rose color                 rosecolor               #ce4676

=item rose doree                 rosedoree               #e66761

=item rose pink                  rosepink                #efbbcc

=item rose-purple                rosepurple              #d399e6

=item rose red                   rosered                 #be0032

=item roslyn blue                roslynblue              #272458

=item roslyn blue                roslynblue              #4e5180

=item roslyn blue                roslynblue              #604e81

=item rosolane pink              rosolanepink            #ffc8d6

=item rosolane pink              rosolanepink            #efbbcc

=item rosolane purple            rosolanepurple          #b3446c

=item royal purple               royalpurple             #604e81

=item rufous                     rufous                  #cb6d51

=item russet                     russet                  #6f4e37

=item russet-vinaceous           russetvinaceous         #905d5d

=item russet-vinaceous           russetvinaceous         #a87c6d

=item russian blue               russianblue             #bcd4e6

=item russian blue               russianblue             #91a3b0

=item russian green              russiangreen            #5e716a

=item saccardo's olive           saccardosolive          #967117

=item saccardo's olive           saccardosolive          #6c541e

=item saccardo's slate           saccardosslate          #51585e

=item saccardo's umber           saccardosumber          #7e6d5a

=item saccardo's umber           saccardosumber          #6c541e

=item saccardo's violet          saccardosviolet         #875692

=item saccardo's violet          saccardosviolet         #86608e

=item safrano pink               safranopink             #f88379

=item sage green                 sagegreen               #8da399

=item sailor blue                sailorblue              #545aa7

=item salmon-buff                salmonbuff              #e3a857

=item salmon-buff                salmonbuff              #fad6a5

=item salmon color               salmoncolor             #d9a6a9

=item salmon color               salmoncolor             #fab57f

=item salmon color               salmoncolor             #d99058

=item salmon-orange              salmonorange            #ed872d

=item salvia blue                salviablue              #30267a

=item sanford's brown            sanfordsbrown           #ae6938

=item sanford's brown            sanfordsbrown           #80461b

=item sayal brown                sayalbrown              #996515

=item sayal brown                sayalbrown              #826644

=item scarlet                    scarlet                 #d9603b

=item scarlet-red                scarletred              #be0032

=item scheele's green            scheelesgreen           #7e9f2e

=item scheele's green            scheelesgreen           #8a9a5b

=item schoenfeld's purple        schoenfeldspurple       #78184a

=item sea-foam green             seafoamgreen            #ebe8a4

=item sea-foam yellow            seafoamyellow           #eae679

=item sea-foam yellow            seafoamyellow           #ebe8a4

=item sea green                  seagreen                #317873

=item seal brown                 sealbrown               #5c504f

=item seal brown                 sealbrown               #674c47

=item seashell pink              seashellpink            #ecd5c5

=item seashell pink              seashellpink            #c2ac99

=item seashell pink              seashellpink            #fad6a5

=item sepia                      sepia                   #483c32

=item sepia                      sepia                   #6c541e

=item serpentine green           serpentinegreen         #867e36

=item shamrock green             shamrockgreen           #679267

=item shell pink                 shellpink               #ecd5c5

=item shell pink                 shellpink               #c7ada3

=item shrimp pink                shrimppink              #f4c2c2

=item shrimp pink                shrimppink              #d9a6a9

=item skobeloff green            skobeloffgreen          #007a74

=item sky blue                   skyblue                 #70a3cc

=item sky gray                   skygray                 #bcd4e6

=item slate-black                slateblack              #222222

=item slate-blue                 slateblue               #4c516d

=item slate color                slatecolor              #555555

=item slate-gray                 slategray               #555555

=item slate-olive                slateolive              #7d8984

=item slate-purple               slatepurple             #796878

=item slate-purple               slatepurple             #836479

=item slate-violet               slateviolet             #50404d

=item slate-violet               slateviolet             #5d555b

=item slate-violet               slateviolet             #796878

=item smalt blue                 smaltblue               #30267a

=item smoke gray                 smokegray               #c2b280

=item smoke gray                 smokegray               #bfb8a5

=item snuff brown                snuffbrown              #826644

=item snuff brown                snuffbrown              #7e6d5a

=item soft blue-violet           softblueviolet          #7e73b8

=item soft bluish violet         softbluishviolet        #604e97

=item sooty black                sootyblack              #555555

=item sorghum brown              sorghumbrown            #674c47

=item sorrento green             sorrentogreen           #317873

=item spectrum blue              spectrumblue            #00a1c2

=item spectrum red               spectrumred             #be0032

=item spectrum violet            spectrumviolet          #604e97

=item spinach green              spinachgreen            #8a9a5b

=item spinel pink                spinelpink              #b3446c

=item spinel red                 spinelred               #b3446c

=item squill blue                squillblue              #70a3cc

=item stone green                stonegreen              #679267

=item storm gray                 stormgray               #7d8984

=item strawberry pink            strawberrypink          #cb6d51

=item straw yellow               strawyellow             #f8de7e

=item strontian yellow           strontianyellow         #beb72e

=item sudan brown                sudanbrown              #80461b

=item sudan brown                sudanbrown              #a67b5b

=item sudan brown                sudanbrown              #996515

=item sulphate green             sulphategreen           #66ada4

=item sulphate green             sulphategreen           #317873

=item sulphine yellow            sulphineyellow          #ab9144

=item sulphur yellow             sulphuryellow           #eae679

=item sulphur yellow             sulphuryellow           #ebe8a4

=item taupe brown                taupebrown              #50404d

=item tawny                      tawny                   #ae6938

=item tawny-olive                tawnyolive              #826644

=item tawny-olive                tawnyolive              #967117

=item tea green                  teagreen                #8f9779

=item terra cotta                terracotta              #b4745e

=item terre verte                terreverte              #5e716a

=item testaceous                 testaceous              #b4745e

=item testaceous                 testaceous              #a87c6d

=item thulite pink               thulitepink             #e68fac

=item tiber green                tibergreen              #93c592

=item tilleul-buff               tilleulbuff             #ecd5c5

=item tourmaline pink            tourmalinepink          #9e4f88

=item tourmaline pink            tourmalinepink          #de6fa1

=item turquoise green            turquoisegreen          #66ada4

=item turtle green               turtlegreen             #8a9a5b

=item tyrian blue                tyrianblue              #536878

=item tyrian blue                tyrianblue              #4c516d

=item tyrian pink                tyrianpink              #9e4f88

=item tyrian rose                tyrianrose              #ce4676

=item tyrolite green             tyrolitegreen           #66ada4

=item ultramarine ash            ultramarineash          #0067a5

=item ultramarine blue           ultramarineblue         #00a1c2

=item urania blue                uraniablue              #2f2140

=item urania blue                uraniablue              #554c69

=item urania blue                uraniablue              #50404d

=item vanderpoel's blue          vanderpoelsblue         #0067a5

=item vanderpoel's blue          vanderpoelsblue         #436b95

=item vanderpoel's green         vanderpoelsgreen        #bdda57

=item vanderpoel's green         vanderpoelsgreen        #7e9f2e

=item vanderpoel's violet        vanderpoelsviolet       #8c82b6

=item vandyke brown              vandykebrown            #6f4e37

=item vandyke brown              vandykebrown            #635147

=item vandyke red                vandykered              #905d5d

=item variscite green            variscitegreen          #8ed1b2

=item varley's gray              varleysgray             #796878

=item varley's green             varleysgreen            #355e3b

=item venetian blue              venetianblue            #0067a5

=item venetian pink              venetianpink            #f88379

=item venice green               venicegreen             #00a693

=item verbena violet             verbenaviolet           #9690ab

=item verdigris green            verdigrisgreen          #6aab8e

=item vernonia purple            vernoniapurple          #915f6d

=item verona brown               veronabrown             #6f4e37

=item veronese green             veronesegreen           #c9dc89

=item veronese green             veronesegreen           #8a9a5b

=item vetiver green              vetivergreen            #8a9a5b

=item vetiver green              vetivergreen            #8f9779

=item victoria lake              victorialake            #722f37

=item victoria lake              victorialake            #3f1728

=item vinaceous                  vinaceous               #ea9399

=item vinaceous                  vinaceous               #e4717a

=item vinaceous                  vinaceous               #dea5a4

=item vinaceous                  vinaceous               #c08081

=item vinaceous-brown            vinaceousbrown          #905d5d

=item vinaceous-buff             vinaceousbuff           #f4c2c2

=item vinaceous-buff             vinaceousbuff           #d9a6a9

=item vinaceous-buff             vinaceousbuff           #ecd5c5

=item vinaceous-buff             vinaceousbuff           #c2ac99

=item vinaceous-cinnamon         vinaceouscinnamon       #d9a6a9

=item vinaceous-cinnamon         vinaceouscinnamon       #c19a6b

=item vinaceous-drab             vinaceousdrab           #905d5d

=item vinaceous-fawn             vinaceousfawn           #d9a6a9

=item vinaceous-fawn             vinaceousfawn           #c7ada3

=item vinaceous-gray             vinaceousgray           #aa98a9

=item vinaceous-gray             vinaceousgray           #796878

=item vinaceous-lavender         vinaceouslavender       #dea5a4

=item vinaceous-lilac            vinaceouslilac          #c17e91

=item vinaceous-lilac            vinaceouslilac          #915f6d

=item vinaceous-pink             vinaceouspink           #b4745e

=item vinaceous-pink             vinaceouspink           #a87c6d

=item vinaceous-purple           vinaceouspurple         #a8516e

=item vinaceous-purple           vinaceouspurple         #915f6d

=item vinaceous-purple           vinaceouspurple         #836479

=item vinaceous-rufous           vinaceousrufous         #9e4732

=item vinaceous-russet           vinaceousrusset         #a87c6d

=item vinaceous-russet           vinaceousrusset         #79443b

=item vinaceous-slate            vinaceousslate          #796878

=item vinaceous-tawny            vinaceoustawny          #b4745e

=item violet carmine             violetcarmine           #673147

=item violet-gray                violetgray              #8b8589

=item violet-plumbeous           violetplumbeous         #8c92ac

=item violet-purple              violetpurple            #9a4eae

=item violet-slate               violetslate             #536878

=item violet ultramarine         violetultramarine       #545aa7

=item violet ultramarine         violetultramarine       #604e97

=item viridian green             viridiangreen           #3eb489

=item viridian green             viridiangreen           #007959

=item viridine green             viridinegreen           #bdda57

=item viridine yellow            viridineyellow          #beb72e

=item viridine yellow            viridineyellow          #b9b459

=item vivid green                vividgreen              #3eb489

=item wall green                 wallgreen               #317873

=item walnut brown               walnutbrown             #79443b

=item walnut brown               walnutbrown             #674c47

=item warbler green              warblergreen            #867e36

=item warm blackish brown        warmblackishbrown       #543d3f

=item warm blackish brown        warmblackishbrown       #5c504f

=item warm buff                  warmbuff                #e3a857

=item warm buff                  warmbuff                #fad6a5

=item warm buff                  warmbuff                #c9ae5d

=item warm sepia                 warmsepia               #635147

=item water green                watergreen              #dadfb7

=item wax yellow                 waxyellow               #d4af37

=item wedgewood blue             wedgewoodblue           #a1caf1

=item wedgewood blue             wedgewoodblue           #70a3cc

=item wedgewood blue             wedgewoodblue           #b3bce2

=item wedgewood blue             wedgewoodblue           #8791bf

=item white                      white                   #f2f3f4

=item windsor blue               windsorblue             #4e5180

=item winter green               wintergreen             #679267

=item wistaria blue              wistariablue            #6c79b8

=item wistaria blue              wistariablue            #7e73b8

=item wistaria violet            wistariaviolet          #7e73b8

=item wood brown                 woodbrown               #c19a6b

=item wood brown                 woodbrown               #ae9b82

=item xanthine orange            xanthineorange          #be6516

=item yale blue                  yaleblue                #70a3cc

=item yellow green               yellowgreen             #bdda57

=item yellowish citrine          yellowishcitrine        #98943e

=item yellowish glaucous         yellowishglaucous       #dadfb7

=item yellowish oil green        yellowishoilgreen       #867e36

=item yellowish olive            yellowisholive          #867e36

=item yellowish olive            yellowisholive          #665d1e

=item yellow ochre               yellowochre             #be8a3d

=item yew green                  yewgreen                #4a5d23

=item yvette violet              yvetteviolet            #554c69

=item zinc green                 zincgreen               #3b7861

=item zinc orange                zincorange              #ed872d

=item zinc orange                zincorange              #d99058


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-r:absinthegreen.120','absinthegreen','absinthe green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:acajoured.19','acajoured','acajou red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:acetinblue.173-','acetinblue','acetin blue ',[54,117,136],'367588',3569032],
['nbs-iscc-r:acetinblue.204','acetinblue','acetin blue ',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:ackermannsgreen.145','ackermannsgreen','ackermann\'s green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:aconiteviolet.223','aconiteviolet','aconite violet',[134,96,142],'86608e',8806542],
['nbs-iscc-r:ageratumviolet.223','ageratumviolet','ageratum violet',[134,96,142],'86608e',8806542],
['nbs-iscc-r:aliceblue.185','aliceblue','alice blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:alizarineblue.182','alizarineblue','alizarine blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:alizarinepink.2','alizarinepink','alizarine pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-r:alizarinepink.3','alizarinepink','alizarine pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-r:amaranthpink.248','amaranthpink','amaranth pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:amaranthpurple.256','amaranthpurple','amaranth purple',[120,24,74],'78184a',7870538],
['nbs-iscc-r:amberbrown.55','amberbrown','amber brown',[128,70,27],'80461b',8406555],
['nbs-iscc-r:amberyellow.83','amberyellow','amber yellow ',[250,218,94],'fada5e',16439902],
['nbs-iscc-r:amberyellow.84','amberyellow','amber yellow ',[212,175,55],'d4af37',13938487],
['nbs-iscc-r:amberyellow.86','amberyellow','amber yellow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:amberyellow.87','amberyellow','amber yellow ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:americangreen.136','americangreen','american green',[103,146,103],'679267',6787687],
['nbs-iscc-r:amethystviolet.216','amethystviolet','amethyst violet',[154,78,174],'9a4eae',10112686],
['nbs-iscc-r:amparoblue.195','amparoblue','amparo blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:amparopurple.217','amparopurple','amparo purple',[211,153,230],'d399e6',13867494],
['nbs-iscc-r:amparopurple.218','amparopurple','amparo purple',[135,86,146],'875692',8869522],
['nbs-iscc-r:andovergreen.122','andovergreen','andover green',[143,151,121],'8f9779',9410425],
['nbs-iscc-r:anilineblack.229','anilineblack','aniline black',[80,64,77],'50404d',5259341],
['nbs-iscc-r:anilineblack.234','anilineblack','aniline black',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:anilinelilac.210','anilinelilac','aniline lilac',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:anilineyellow.85','anilineyellow','aniline yellow',[175,141,19],'af8d13',11504915],
['nbs-iscc-r:anthracenegreen.164','anthracenegreen','anthracene green',[49,120,115],'317873',3242099],
['nbs-iscc-r:anthracenegreen.165','anthracenegreen','anthracene green',[0,75,73],'004b49',19273],
['nbs-iscc-r:anthracenepurple.229','anthracenepurple','anthracene purple',[80,64,77],'50404d',5259341],
['nbs-iscc-r:anthracenepurple.259','anthracenepurple','anthracene purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:anthraceneviolet.211','anthraceneviolet','anthracene violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:antimonyyellow.71','antimonyyellow','antimony yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:antiquebrown.55','antiquebrown','antique brown',[128,70,27],'80461b',8406555],
['nbs-iscc-r:antiquebrown.58','antiquebrown','antique brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:antiquegreen.150','antiquegreen','antique green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:antiquegreen.151','antiquegreen','antique green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:antwerpblue.182','antwerpblue','antwerp blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:antwerpblue.183','antwerpblue','antwerp blue',[0,48,78],'00304e',12366],
['nbs-iscc-r:antwerpblue.186','antwerpblue','antwerp blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:applegreen.117','applegreen','apple green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-r:apricotbuff.53','apricotbuff','apricot buff',[217,144,88],'d99058',14258264],
['nbs-iscc-r:apricotorange.53','apricotorange','apricot orange',[217,144,88],'d99058',14258264],
['nbs-iscc-r:apricotyellow.84','apricotyellow','apricot yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-r:argusbrown.58','argusbrown','argus brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:argylepurple.241','argylepurple','argyle purple',[145,92,131],'915c83',9526403],
['nbs-iscc-r:armybrown.58','armybrown','army brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:armybrown.61','armybrown','army brown',[99,81,71],'635147',6508871],
['nbs-iscc-r:artemesiagreen.155','artemesiagreen','artemesia green',[125,137,132],'7d8984',8227204],
['nbs-iscc-r:asphodelgreen.120','asphodelgreen','asphodel green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:asterpurple.256','asterpurple','aster purple',[120,24,74],'78184a',7870538],
['nbs-iscc-r:auburn.43','auburn','auburn',[121,68,59],'79443b',7947323],
['nbs-iscc-r:auriculapurple.259','auriculapurple','auricula purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:avellaneous.76','avellaneous','avellaneous',[193,154,107],'c19a6b',12687979],
['nbs-iscc-r:avellaneous.79','avellaneous','avellaneous',[174,155,130],'ae9b82',11443074],
['nbs-iscc-r:azuriteblue.200','azuriteblue','azurite blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:bariumyellow.101','bariumyellow','barium yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:bariumyellow.102','bariumyellow','barium yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:barytayellow.86','barytayellow','baryta yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:bay.43','bay','bay',[121,68,59],'79443b',7947323],
['nbs-iscc-r:begoniarose.27','begoniarose','begonia rose',[230,103,97],'e66761',15099745],
['nbs-iscc-r:benzobrown.45','benzobrown','benzo brown',[151,127,115],'977f73',9928563],
['nbs-iscc-r:benzobrown.60','benzobrown','benzo brown',[149,128,112],'958070',9797744],
['nbs-iscc-r:benzobrown.61','benzobrown','benzo brown',[99,81,71],'635147',6508871],
['nbs-iscc-r:benzolgreen.160','benzolgreen','benzol green',[0,122,116],'007a74',31348],
['nbs-iscc-r:berlinblue.183','berlinblue','berlin blue',[0,48,78],'00304e',12366],
['nbs-iscc-r:berylblue.171','berylblue','beryl blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-r:berylgreen.159','berylgreen','beryl green',[0,166,147],'00a693',42643],
['nbs-iscc-r:bicegreen.120','bicegreen','bice green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:biscaygreen.120','biscaygreen','biscay green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:bishopspurple.241','bishopspurple','bishop\'s purple',[145,92,131],'915c83',9526403],
['nbs-iscc-r:bister.80','bister','bister',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-r:bister.81','bister','bister',[72,60,50],'483c32',4734002],
['nbs-iscc-r:bittersweetorange.37','bittersweetorange','bittersweet orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:bittersweetpink.53','bittersweetpink','bittersweet pink',[217,144,88],'d99058',14258264],
['nbs-iscc-r:black.267','black','black',[34,34,34],'222222',2236962],
['nbs-iscc-r:blackishgreenblue.174','blackishgreenblue','blackish green-blue',[0,73,88],'004958',18776],
['nbs-iscc-r:blackishgreengray.267','blackishgreengray','blackish green-gray',[34,34,34],'222222',2236962],
['nbs-iscc-r:blackishmousegray.64','blackishmousegray','blackish mouse-gray',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:blackishmousegray.266','blackishmousegray','blackish mouse-gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:blackishplumbeous.192','blackishplumbeous','blackish plumbeous',[81,88,94],'51585e',5331038],
['nbs-iscc-r:blackishpurple.242','blackishpurple','blackish purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:blackishpurple.243','blackishpurple','blackish purple',[52,23,49],'341731',3413809],
['nbs-iscc-r:blackishredpurple.259','blackishredpurple','blackish red-purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:blackishslate.266','blackishslate','blackish slate',[85,85,85],'555555',5592405],
['nbs-iscc-r:blackishviolet.211','blackishviolet','blackish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:blackishviolet.212','blackishviolet','blackish violet',[47,33,64],'2f2140',3088704],
['nbs-iscc-r:blackishviolet.215','blackishviolet','blackish violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:blackishvioletgray.234','blackishvioletgray','blackish violet-gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:blackishvioletgray.266','blackishvioletgray','blackish violet-gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:blancsblue.182','blancsblue','blanc\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:blancsviolet.215','blancsviolet','blanc\'s violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:blancsviolet.228','blancsviolet','blanc\'s violet',[121,104,120],'796878',7956600],
['nbs-iscc-r:blancsviolet.229','blancsviolet','blanc\'s violet',[80,64,77],'50404d',5259341],
['nbs-iscc-r:blueviolet.194','blueviolet','blue-violet',[48,38,122],'30267a',3155578],
['nbs-iscc-r:blueviolet.205','blueviolet','blue-violet',[144,101,202],'9065ca',9463242],
['nbs-iscc-r:bluevioletblack.234','bluevioletblack','blue-violet black',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:bluevioletblack.266','bluevioletblack','blue-violet black',[85,85,85],'555555',5592405],
['nbs-iscc-r:bluishblack.187','bluishblack','bluish black',[54,69,79],'36454f',3556687],
['nbs-iscc-r:bluishblack.188','bluishblack','bluish black',[32,40,48],'202830',2107440],
['nbs-iscc-r:bluishglaucous.148','bluishglaucous','bluish glaucous',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:bluishglaucous.162','bluishglaucous','bluish glaucous',[150,222,209],'96ded1',9887441],
['nbs-iscc-r:bluishgraygreen.149','bluishgraygreen','bluish gray-green',[141,163,153],'8da399',9282457],
['nbs-iscc-r:bluishgraygreen.150','bluishgraygreen','bluish gray-green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:bluishlavender.210','bluishlavender','bluish lavender',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:bluishslateblack.183','bluishslateblack','bluish slate-black',[0,48,78],'00304e',12366],
['nbs-iscc-r:bluishslateblack.187','bluishslateblack','bluish slate-black',[54,69,79],'36454f',3556687],
['nbs-iscc-r:bluishviolet.194','bluishviolet','bluish violet',[48,38,122],'30267a',3155578],
['nbs-iscc-r:bluishviolet.205','bluishviolet','bluish violet',[144,101,202],'9065ca',9463242],
['nbs-iscc-r:bonebrown.61','bonebrown','bone brown',[99,81,71],'635147',6508871],
['nbs-iscc-r:bonebrown.64','bonebrown','bone brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:bordeaux.259','bordeaux','bordeaux',[103,49,71],'673147',6762823],
['nbs-iscc-r:bottlegreen.146','bottlegreen','bottle green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-r:bradleysblue.176','bradleysblue','bradley\'s blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-r:bradleysviolet.206','bradleysviolet','bradley\'s violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:bradleysviolet.207','bradleysviolet','bradley\'s violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:bradleysviolet.210','bradleysviolet','bradley\'s violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:bradleysviolet.211','bradleysviolet','bradley\'s violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:brazilred.38','brazilred','brazil red',[158,71,50],'9e4732',10372914],
['nbs-iscc-r:bremenblue.172','bremenblue','bremen blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-r:brickred.43','brickred','brick red',[121,68,59],'79443b',7947323],
['nbs-iscc-r:brightchalcedonyyellow.116','brightchalcedonyyellow','bright chalcedony yellow',[189,218,87],'bdda57',12442199],
['nbs-iscc-r:brightchalcedonyyellow.119','brightchalcedonyyellow','bright chalcedony yellow',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:brightgreenyellow.115','brightgreenyellow','bright green-yellow',[141,182,0],'8db600',9287168],
['nbs-iscc-r:brownishdrab.45','brownishdrab','brownish drab',[151,127,115],'977f73',9928563],
['nbs-iscc-r:brownishdrab.70','brownishdrab','brownish drab',[149,128,112],'958070',9797744],
['nbs-iscc-r:brownisholive.95','brownisholive','brownish olive',[108,84,30],'6c541e',7099422],
['nbs-iscc-r:brownishvinaceous.18','brownishvinaceous','brownish vinaceous',[173,136,132],'ad8884',11372676],
['nbs-iscc-r:brusselsbrown.58','brusselsbrown','brussels brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:buckthornbrown.74','buckthornbrown','buckthorn brown',[153,101,21],'996515',10052885],
['nbs-iscc-r:buffpinkorbuffpink.29','buffpinkorbuffpink','buff-pink or buff pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:buffybrown.76','buffybrown','buffy brown ',[193,154,107],'c19a6b',12687979],
['nbs-iscc-r:buffybrown.77','buffybrown','buffy brown ',[130,102,68],'826644',8545860],
['nbs-iscc-r:buffycitrine.94','buffycitrine','buffy citrine',[150,113,23],'967117',9859351],
['nbs-iscc-r:buffyelloworbuffyellow.86','buffyelloworbuffyellow','buff-yellow or buff yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:buffyelloworbuffyellow.87','buffyelloworbuffyellow','buff-yellow or buff yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:buffyolive.106','buffyolive','buffy olive',[134,126,54],'867e36',8814134],
['nbs-iscc-r:burnblue.180','burnblue','burn blue',[161,202,241],'a1caf1',10603249],
['nbs-iscc-r:burnblue.181','burnblue','burn blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:burnblue.198','burnblue','burn blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-r:burnblue.199','burnblue','burn blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:burntlake.242','burntlake','burnt lake',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:burntsienna.40','burntsienna','burnt sienna',[136,45,23],'882d17',8924439],
['nbs-iscc-r:burntumber.46','burntumber','burnt umber',[103,76,71],'674c47',6769735],
['nbs-iscc-r:cacaobrown.42','cacaobrown','cacao brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-r:cadetblue.178','cadetblue','cadet blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:cadetblue.182','cadetblue','cadet blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:cadetgray.185','cadetgray','cadet gray',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:cadmiumorange.48','cadmiumorange','cadmium orange',[243,132,0],'f38400',15959040],
['nbs-iscc-r:cadmiumorange.50','cadmiumorange','cadmium orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-r:cadmiumyellow.50','cadmiumyellow','cadmium yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-r:cadmiumyellow.68','cadmiumyellow','cadmium yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-r:calamineblue.171','calamineblue','calamine blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-r:calamineblue.172','calamineblue','calamine blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-r:callagreen.107','callagreen','calla green',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:callistegreen.117','callistegreen','calliste green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-r:cameobrown.43','cameobrown','cameo brown',[121,68,59],'79443b',7947323],
['nbs-iscc-r:cameobrown.46','cameobrown','cameo brown',[103,76,71],'674c47',6769735],
['nbs-iscc-r:cameopink.246','cameopink','cameo pink',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-r:cameopink.249','cameopink','cameo pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-r:capriblue.173','capriblue','capri blue ',[54,117,136],'367588',3569032],
['nbs-iscc-r:capucinebuff.70','capucinebuff','capucine buff ',[251,201,127],'fbc97f',16501119],
['nbs-iscc-r:capucinebuff.71','capucinebuff','capucine buff ',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:capucinebuff.73','capucinebuff','capucine buff ',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:capucineorange.53','capucineorange','capucine orange ',[217,144,88],'d99058',14258264],
['nbs-iscc-r:capucineyellow.68','capucineyellow','capucine yellow ',[234,162,33],'eaa221',15376929],
['nbs-iscc-r:carmine.11','carmine','carmine',[190,0,50],'be0032',12451890],
['nbs-iscc-r:carnelianred.35','carnelianred','carnelian red',[217,96,59],'d9603b',14245947],
['nbs-iscc-r:carobbrown.44','carobbrown','carob brown',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-r:carrotred.37','carrotred','carrot red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:cartridgebuff.89','cartridgebuff','cartridge buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-r:castorgray.155','castorgray','castor gray',[125,137,132],'7d8984',8227204],
['nbs-iscc-r:castorgray.265','castorgray','castor gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:cedargreen.120','cedargreen','cedar green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:cedargreen.125','cedargreen','cedar green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:celandinegreen.149','celandinegreen','celandine green',[141,163,153],'8da399',9282457],
['nbs-iscc-r:cendreblue.168','cendreblue','cendre blue',[35,158,186],'239eba',2334394],
['nbs-iscc-r:cendregreen.130','cendregreen','cendre green',[131,211,125],'83d37d',8639357],
['nbs-iscc-r:ceruleanblue.178','ceruleanblue','cerulean blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:chaeturablack.81','chaeturablack','chaetura black',[72,60,50],'483c32',4734002],
['nbs-iscc-r:chaeturadrab.64','chaeturadrab','chaetura drab',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:chalcedonyyellow.101','chalcedonyyellow','chalcedony yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:chamois.87','chamois','chamois',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:chapmansblue.182','chapmansblue','chapman\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:chartreuseyellow.101','chartreuseyellow','chartreuse yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:chatenaypink.5','chatenaypink','chatenay pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:chatenaypink.29','chatenaypink','chatenay pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:chessyliteblue.173','chessyliteblue','chessylite blue',[54,117,136],'367588',3569032],
['nbs-iscc-r:chessyliteblue.174','chessyliteblue','chessylite blue',[0,73,88],'004958',18776],
['nbs-iscc-r:chessyliteblue.182','chessyliteblue','chessylite blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:chessyliteblue.186','chessyliteblue','chessylite blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:chestnut.43','chestnut','chestnut',[121,68,59],'79443b',7947323],
['nbs-iscc-r:chestnutbrown.43','chestnutbrown','chestnut-brown',[121,68,59],'79443b',7947323],
['nbs-iscc-r:chestnutbrown.46','chestnutbrown','chestnut-brown',[103,76,71],'674c47',6769735],
['nbs-iscc-r:chicoryblue.199','chicoryblue','chicory blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:chicoryblue.210','chicoryblue','chicory blue',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:chinablue.182','chinablue','china blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:chineseviolet.223','chineseviolet','chinese violet',[134,96,142],'86608e',8806542],
['nbs-iscc-r:chocolate.46','chocolate','chocolate',[103,76,71],'674c47',6769735],
['nbs-iscc-r:chromiumgreen.120','chromiumgreen','chromium green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:chrysolitegreen.120','chrysolitegreen','chrysolite green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:chrysopraisegreen.135','chrysopraisegreen','chrysopraise green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:cinereous.190','cinereous','cinereous',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-r:cinereous.191','cinereous','cinereous',[129,135,139],'81878b',8488843],
['nbs-iscc-r:cinnamon.57','cinnamon','cinnamon',[166,123,91],'a67b5b',10910555],
['nbs-iscc-r:cinnamon.72','cinnamon','cinnamon',[190,138,61],'be8a3d',12487229],
['nbs-iscc-r:cinnamonbrown.58','cinnamonbrown','cinnamon-brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:cinnamonbuff.71','cinnamonbuff','cinnamon-buff',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:cinnamonbuff.76','cinnamonbuff','cinnamon-buff',[193,154,107],'c19a6b',12687979],
['nbs-iscc-r:cinnamonbuff.87','cinnamonbuff','cinnamon-buff',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:cinnamondrab.45','cinnamondrab','cinnamon-drab',[151,127,115],'977f73',9928563],
['nbs-iscc-r:cinnamondrab.60','cinnamondrab','cinnamon-drab',[149,128,112],'958070',9797744],
['nbs-iscc-r:cinnamonrufous.54','cinnamonrufous','cinnamon-rufous',[174,105,56],'ae6938',11430200],
['nbs-iscc-r:citrine.106','citrine','citrine',[134,126,54],'867e36',8814134],
['nbs-iscc-r:citrine.107','citrine','citrine',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:citrinedrab.106','citrinedrab','citrine-drab',[134,126,54],'867e36',8814134],
['nbs-iscc-r:citrongreen.102','citrongreen','citron green',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:citrongreen.105','citrongreen','citron green',[185,181,125],'b9b57d',12170621],
['nbs-iscc-r:citronyellow.98','citronyellow','citron yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-r:citronyellow.99','citronyellow','citron yellow',[190,183,46],'beb72e',12498734],
['nbs-iscc-r:citronyellow.101','citronyellow','citron yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:citronyellow.102','citronyellow','citron yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:civettegreen.136','civettegreen','civette green',[103,146,103],'679267',6787687],
['nbs-iscc-r:claretbrown.43','claretbrown','claret brown',[121,68,59],'79443b',7947323],
['nbs-iscc-r:claycolor.74','claycolor','clay color',[153,101,21],'996515',10052885],
['nbs-iscc-r:claycolor.77','claycolor','clay color',[130,102,68],'826644',8545860],
['nbs-iscc-r:claycolor.94','claycolor','clay color',[150,113,23],'967117',9859351],
['nbs-iscc-r:clearcadetblue.177','clearcadetblue','clear cadet blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-r:clearcadetblue.178','clearcadetblue','clear cadet blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:cleardullgreenyellow.116','cleardullgreenyellow','clear dull green-yellow',[189,218,87],'bdda57',12442199],
['nbs-iscc-r:cleardullgreenyellow.117','cleardullgreenyellow','clear dull green-yellow',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-r:cleardullgreenyellow.119','cleardullgreenyellow','clear dull green-yellow',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:cleardullgreenyellow.120','cleardullgreenyellow','clear dull green-yellow',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:clearfluoritegreen.135','clearfluoritegreen','clear fluorite green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:cleargreenbluegray.185','cleargreenbluegray','clear green-blue gray',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:cleargreenbluegray.191','cleargreenbluegray','clear green-blue gray',[129,135,139],'81878b',8488843],
['nbs-iscc-r:clearpaynesgray.186','clearpaynesgray','clear payne\'s gray ',[83,104,120],'536878',5466232],
['nbs-iscc-r:clearpaynesgray.191','clearpaynesgray','clear payne\'s gray ',[129,135,139],'81878b',8488843],
['nbs-iscc-r:clearwindsorblue.199','clearwindsorblue','clear windsor blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:clearyellowgreen.116','clearyellowgreen','clear yellow-green',[189,218,87],'bdda57',12442199],
['nbs-iscc-r:clovebrown.81','clovebrown','clove brown',[72,60,50],'483c32',4734002],
['nbs-iscc-r:cobaltgreen.144','cobaltgreen','cobalt green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-r:colonialbuff.86','colonialbuff','colonial buff',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:columbiablue.181','columbiablue','columbia blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:columbiablue.182','columbiablue','columbia blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:commelinablue.194','commelinablue','commelina blue',[48,38,122],'30267a',3155578],
['nbs-iscc-r:congopink.26','congopink','congo pink',[248,131,121],'f88379',16286585],
['nbs-iscc-r:congopink.29','congopink','congo pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:coralpink.26','coralpink','coral pink',[248,131,121],'f88379',16286585],
['nbs-iscc-r:coralred.37','coralred','coral red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:corinthianpink.5','corinthianpink','corinthian pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:corinthianpurple.259','corinthianpurple','corinthian purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:corinthianred.19','corinthianred','corinthian red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:cornflowerblue.194','cornflowerblue','cornflower blue',[48,38,122],'30267a',3155578],
['nbs-iscc-r:corydalisgreen.119','corydalisgreen','corydalis green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:corydalisgreen.121','corydalisgreen','corydalis green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:cossackgreen.125','cossackgreen','cossack green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:cossackgreen.127','cossackgreen','cossack green',[81,87,68],'515744',5330756],
['nbs-iscc-r:cossegreen.117','cossegreen','cosse green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-r:cotingapurple.219','cotingapurple','cotinga purple',[96,47,107],'602f6b',6303595],
['nbs-iscc-r:cotingapurple.223','cotingapurple','cotinga purple',[134,96,142],'86608e',8806542],
['nbs-iscc-r:courgegreen.120','courgegreen','courge green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:courtgray.148','courtgray','court gray',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:courtgrey.148','courtgrey','court grey ',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:creambuff.86','creambuff','cream buff',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:creambuff.87','creambuff','cream buff',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:creamcolor.86','creamcolor','cream color',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:cressgreen.120','cressgreen','cress green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:cressgreen.125','cressgreen','cress green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:cyanineblue.200','cyanineblue','cyanine blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:dahliacarmine.259','dahliacarmine','dahlia carmine',[103,49,71],'673147',6762823],
['nbs-iscc-r:dahliapurple.259','dahliapurple','dahlia purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:daphnepink.248','daphnepink','daphne pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:daphnepink.251','daphnepink','daphne pink',[193,126,145],'c17e91',12680849],
['nbs-iscc-r:daphnered.258','daphnered','daphne red',[168,81,110],'a8516e',11030894],
['nbs-iscc-r:darkamericangreen.137','darkamericangreen','dark american green',[53,94,59],'355e3b',3497531],
['nbs-iscc-r:darkamericangreen.150','darkamericangreen','dark american green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:darkamericangreen.151','darkamericangreen','dark american green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:darkanilineblue.187','darkanilineblue','dark aniline blue',[54,69,79],'36454f',3556687],
['nbs-iscc-r:darkanilineblue.229','darkanilineblue','dark aniline blue',[80,64,77],'50404d',5259341],
['nbs-iscc-r:darkanthraceneviolet.224','darkanthraceneviolet','dark anthracene violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:darkanthraceneviolet.229','darkanthraceneviolet','dark anthracene violet',[80,64,77],'50404d',5259341],
['nbs-iscc-r:darkbluishglaucous.144','darkbluishglaucous','dark bluish glaucous',[106,171,142],'6aab8e',6990734],
['nbs-iscc-r:darkbluishglaucous.149','darkbluishglaucous','dark bluish glaucous',[141,163,153],'8da399',9282457],
['nbs-iscc-r:darkbluishgraygreen.150','darkbluishgraygreen','dark bluish gray-green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:darkbluishgraygreen.151','darkbluishgraygreen','dark bluish gray-green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:darkbluishgraygreen.164','darkbluishgraygreen','dark bluish gray-green',[49,120,115],'317873',3242099],
['nbs-iscc-r:darkbluishgraygreen.165','darkbluishgraygreen','dark bluish gray-green',[0,75,73],'004b49',19273],
['nbs-iscc-r:darkbluishviolet.211','darkbluishviolet','dark bluish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:darkbluishviolet.212','darkbluishviolet','dark bluish violet',[47,33,64],'2f2140',3088704],
['nbs-iscc-r:darkbluishviolet.215','darkbluishviolet','dark bluish violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:darkcadetblue.182','darkcadetblue','dark cadet blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:darkcadetblue.204','darkcadetblue','dark cadet blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:darkchessyliteblue.174','darkchessyliteblue','dark chessylite blue',[0,73,88],'004958',18776],
['nbs-iscc-r:darkchessyliteblue.182','darkchessyliteblue','dark chessylite blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:darkchessyliteblue.183','darkchessyliteblue','dark chessylite blue',[0,48,78],'00304e',12366],
['nbs-iscc-r:darkchessyliteblue.186','darkchessyliteblue','dark chessylite blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:darkcinnabargreen.164','darkcinnabargreen','dark cinnabar green',[49,120,115],'317873',3242099],
['nbs-iscc-r:darkcitrine.107','darkcitrine','dark citrine',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:darkcorinthianpurple.259','darkcorinthianpurple','dark corinthian purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:darkcressgreen.125','darkcressgreen','dark cress green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:darkdelftblue.183','darkdelftblue','dark delft blue',[0,48,78],'00304e',12366],
['nbs-iscc-r:darkdelftblue.187','darkdelftblue','dark delft blue',[54,69,79],'36454f',3556687],
['nbs-iscc-r:darkdivablue.196','darkdivablue','dark diva blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:darkdivablue.200','darkdivablue','dark diva blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:darkdullbluishviolet.211','darkdullbluishviolet','dark dull bluish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:darkdullbluishviolet.215','darkdullbluishviolet','dark dull bluish violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:darkdullbluishviolet.215','darkdullbluishviolet','dark dull bluish violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:darkdullbluishviolet.224','darkdullbluishviolet','dark dull bluish violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:darkdullvioletblue.204','darkdullvioletblue','dark dull violet-blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:darkdullvioletblue.215','darkdullvioletblue','dark dull violet-blue',[85,76,105],'554c69',5590121],
['nbs-iscc-r:darkdullvioletblue.215','darkdullvioletblue','dark dull violet-blue',[85,76,105],'554c69',5590121],
['nbs-iscc-r:darkdullyellowgreen.125','darkdullyellowgreen','dark dull yellow-green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:darkdullyellowgreen.127','darkdullyellowgreen','dark dull yellow-green',[81,87,68],'515744',5330756],
['nbs-iscc-r:darkglaucousgray.150','darkglaucousgray','dark glaucous-gray',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:darkgrayishbluegreen.156','darkgrayishbluegreen','dark grayish blue-green',[78,87,85],'4e5755',5134165],
['nbs-iscc-r:darkgrayishbluegreen.266','darkgrayishbluegreen','dark grayish blue-green',[85,85,85],'555555',5592405],
['nbs-iscc-r:darkgrayishblueviolet.215','darkgrayishblueviolet','dark grayish blue-violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:darkgrayishbrown.19','darkgrayishbrown','dark grayish brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:darkgrayishbrown.23','darkgrayishbrown','dark grayish brown',[92,80,79],'5c504f',6049871],
['nbs-iscc-r:darkgrayishlavender.214','darkgrayishlavender','dark grayish lavender',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:darkgrayisholive.113','darkgrayisholive','dark grayish olive',[87,85,76],'57554c',5723468],
['nbs-iscc-r:darkgreen.137','darkgreen','dark green',[53,94,59],'355e3b',3497531],
['nbs-iscc-r:darkgreen.150','darkgreen','dark green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:darkgreen.151','darkgreen','dark green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:darkgreenbluegray.186','darkgreenbluegray','dark green-blue gray',[83,104,120],'536878',5466232],
['nbs-iscc-r:darkgreenblueslate.183','darkgreenblueslate','dark green-blue slate',[0,48,78],'00304e',12366],
['nbs-iscc-r:darkgreenblueslate.187','darkgreenblueslate','dark green-blue slate',[54,69,79],'36454f',3556687],
['nbs-iscc-r:darkgreenishglaucous.135','darkgreenishglaucous','dark greenish glaucous',[147,197,146],'93c592',9684370],
['nbs-iscc-r:darkgreenishglaucous.136','darkgreenishglaucous','dark greenish glaucous',[103,146,103],'679267',6787687],
['nbs-iscc-r:darkgreenisholive.107','darkgreenisholive','dark greenish olive',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:darkgreenisholive.110','darkgreenisholive','dark greenish olive',[91,88,66],'5b5842',5986370],
['nbs-iscc-r:darkgullgray.266','darkgullgray','dark gull gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:darkheliotropegray.228','darkheliotropegray','dark heliotrope gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:darkheliotropeslate.229','darkheliotropeslate','dark heliotrope slate',[80,64,77],'50404d',5259341],
['nbs-iscc-r:darkheliotropeslate.234','darkheliotropeslate','dark heliotrope slate',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:darkhyssopviolet.224','darkhyssopviolet','dark hyssop violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:darkhyssopviolet.228','darkhyssopviolet','dark hyssop violet',[121,104,120],'796878',7956600],
['nbs-iscc-r:darkindianred.19','darkindianred','dark indian red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:darkindianred.20','darkindianred','dark indian red',[84,61,63],'543d3f',5520703],
['nbs-iscc-r:darkivygreen.127','darkivygreen','dark ivy green',[81,87,68],'515744',5330756],
['nbs-iscc-r:darklavender.222','darklavender','dark lavender',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:darklividbrown.19','darklividbrown','dark livid brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:darklividpurple.229','darklividpurple','dark livid purple',[80,64,77],'50404d',5259341],
['nbs-iscc-r:darklividpurple.259','darklividpurple','dark livid purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:darkmadderblue.186','darkmadderblue','dark madder blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:darkmadderblue.204','darkmadderblue','dark madder blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:darkmadderviolet.224','darkmadderviolet','dark madder violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:darkmadderviolet.229','darkmadderviolet','dark madder violet',[80,64,77],'50404d',5259341],
['nbs-iscc-r:darkmaroonpurple.242','darkmaroonpurple','dark maroon purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:darkmediciblue.192','darkmediciblue','dark medici blue',[81,88,94],'51585e',5331038],
['nbs-iscc-r:darkmineralred.19','darkmineralred','dark mineral red ',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:darkmineralred.20','darkmineralred','dark mineral red ',[84,61,63],'543d3f',5520703],
['nbs-iscc-r:darkmousegray.64','darkmousegray','dark mouse gray ',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:darkmousegray.266','darkmousegray','dark mouse gray ',[85,85,85],'555555',5592405],
['nbs-iscc-r:darknaphthaleneviolet.229','darknaphthaleneviolet','dark naphthalene violet ',[80,64,77],'50404d',5259341],
['nbs-iscc-r:darknaphthaleneviolet.242','darknaphthaleneviolet','dark naphthalene violet ',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:darkneutralgray.266','darkneutralgray','dark neutral gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:darknigrosinviolet.224','darknigrosinviolet','dark nigrosin violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:darkolive.110','darkolive','dark olive',[91,88,66],'5b5842',5986370],
['nbs-iscc-r:darkolivebuff.91','darkolivebuff','dark olive-buff',[161,143,96],'a18f60',10588000],
['nbs-iscc-r:darkolivegray.110','darkolivegray','dark olive-gray',[91,88,66],'5b5842',5986370],
['nbs-iscc-r:darkolivegray.113','darkolivegray','dark olive-gray',[87,85,76],'57554c',5723468],
['nbs-iscc-r:darkorientblue.186','darkorientblue','dark orient blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:darkpaynesgray.187','darkpaynesgray','dark payne\'s gray',[54,69,79],'36454f',3556687],
['nbs-iscc-r:darkpaynesgray.192','darkpaynesgray','dark payne\'s gray',[81,88,94],'51585e',5331038],
['nbs-iscc-r:darkperillapurple.259','darkperillapurple','dark perilla purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:darkplumbagoblue.214','darkplumbagoblue','dark plumbago blue',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:darkplumbagoblue.227','darkplumbagoblue','dark plumbago blue',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:darkplumbagogray.228','darkplumbagogray','dark plumbago gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:darkplumbagogray.233','darkplumbagogray','dark plumbago gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:darkplumbagogray.234','darkplumbagogray','dark plumbago gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:darkplumbagoslate.234','darkplumbagoslate','dark plumbago slate',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:darkplumbeous.192','darkplumbeous','dark plumbeous',[81,88,94],'51585e',5331038],
['nbs-iscc-r:darkporcelaingreen.150','darkporcelaingreen','dark porcelain green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:darkpurpledrab.228','darkpurpledrab','dark purple-drab',[121,104,120],'796878',7956600],
['nbs-iscc-r:darkpurplishgray.234','darkpurplishgray','dark purplish gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:darkpurplishgray.266','darkpurplishgray','dark purplish gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:darkquakerdrab.234','darkquakerdrab','dark quaker drab',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:darkrussiangreen.150','darkrussiangreen','dark russian green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:darkrussiangreen.151','darkrussiangreen','dark russian green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:darkslatepurple.242','darkslatepurple','dark slate-purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:darkslateviolet.234','darkslateviolet','dark slate-violet ',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:darkslateviolet.228','darkslateviolet','dark slate-violet ',[121,104,120],'796878',7956600],
['nbs-iscc-r:darksoftblueviolet.200','darksoftblueviolet','dark soft blue-violet',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:darksoftblueviolet.211','darksoftblueviolet','dark soft blue-violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:darksoftbluishviolet.211','darksoftbluishviolet','dark soft bluish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:darksulphategreen.164','darksulphategreen','dark sulphate green',[49,120,115],'317873',3242099],
['nbs-iscc-r:darkterreverte.150','darkterreverte','dark terre verte',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:darktyrianblue.186','darktyrianblue','dark tyrian blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:darktyrianblue.204','darktyrianblue','dark tyrian blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:darkvarleysgray.234','darkvarleysgray','dark varley\'s gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:darkvinaceous.19','darkvinaceous','dark vinaceous',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:darkvinaceousbrown.19','darkvinaceousbrown','dark vinaceous-brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:darkvinaceousdrab.19','darkvinaceousdrab','dark vinaceous-drab',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:darkvinaceousdrab.23','darkvinaceousdrab','dark vinaceous-drab',[92,80,79],'5c504f',6049871],
['nbs-iscc-r:darkvinaceousgray.228','darkvinaceousgray','dark vinaceous-gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:darkvinaceouspurple.259','darkvinaceouspurple','dark vinaceous-purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:darkviolet.211','darkviolet','dark violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:darkvioletgray.234','darkvioletgray','dark violet-gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:darkvioletgray.266','darkvioletgray','dark violet-gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:darkvioletslate.186','darkvioletslate','dark violet-slate',[83,104,120],'536878',5466232],
['nbs-iscc-r:darkviridiangreen.145','darkviridiangreen','dark viridian green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:darkyellowishgreen.137','darkyellowishgreen','dark yellowish green',[53,94,59],'355e3b',3497531],
['nbs-iscc-r:darkyvetteviolet.229','darkyvetteviolet','dark yvette violet',[80,64,77],'50404d',5259341],
['nbs-iscc-r:darkzincgreen.145','darkzincgreen','dark zinc green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:dauphinsviolet.211','dauphinsviolet','dauphin\'s violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:dawngray.190','dawngray','dawn gray',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-r:dawngray.264','dawngray','dawn gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-r:deepanilinelilac.177','deepanilinelilac','deep aniline lilac',[73,151,208],'4997d0',4822992],
['nbs-iscc-r:deepblueviolet.194','deepblueviolet','deep blue-violet',[48,38,122],'30267a',3155578],
['nbs-iscc-r:deepblueviolet.205','deepblueviolet','deep blue-violet',[144,101,202],'9065ca',9463242],
['nbs-iscc-r:deepbluishglaucous.162','deepbluishglaucous','deep bluish glaucous',[150,222,209],'96ded1',9887441],
['nbs-iscc-r:deepbluishgraygreen.150','deepbluishgraygreen','deep bluish gray-green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:deepbluishgraygreen.164','deepbluishgraygreen','deep bluish gray-green',[49,120,115],'317873',3242099],
['nbs-iscc-r:deepbrownishdrab.61','deepbrownishdrab','deep brownish drab',[99,81,71],'635147',6508871],
['nbs-iscc-r:deepbrownishvinaceous.19','deepbrownishvinaceous','deep brownish vinaceous',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:deepcadetblue.182','deepcadetblue','deep cadet blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:deepchicoryblue.206','deepchicoryblue','deep chicory blue',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:deepchrome.68','deepchrome','deep chrome',[234,162,33],'eaa221',15376929],
['nbs-iscc-r:deepchrysolitegreen.120','deepchrysolitegreen','deep chrysolite green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:deepcolonialbuff.87','deepcolonialbuff','deep colonial buff',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:deepcorinthianred.19','deepcorinthianred','deep corinthian red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:deepdelftblue.186','deepdelftblue','deep delft blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:deepdullbluishviolet.207','deepdullbluishviolet','deep dull bluish violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:deepdullbluishviolet.211','deepdullbluishviolet','deep dull bluish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:deepdullbluishviolet.203','deepdullbluishviolet','deep dull bluish violet',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:deepdullbluishviolet.204','deepdullbluishviolet','deep dull bluish violet',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:deepdullbluishviolet.214','deepdullbluishviolet','deep dull bluish violet',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:deepdullbluishviolet.215','deepdullbluishviolet','deep dull bluish violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:deepdullbluishviolet.211','deepdullbluishviolet','deep dull bluish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:deepdulllavender.227','deepdulllavender','deep dull lavender',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:deepdullviolaceousblue.200','deepdullviolaceousblue','deep dull violaceous blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:deepdullvioletblue.211','deepdullvioletblue','deep dull violet-blue',[96,78,129],'604e81',6311553],
['nbs-iscc-r:deepdutchblue.186','deepdutchblue','deep dutch blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:deepdutchblue.203','deepdutchblue','deep dutch blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:deepglaucousgray.191','deepglaucousgray','deep glaucous-gray',[129,135,139],'81878b',8488843],
['nbs-iscc-r:deepglaucousgreen.144','deepglaucousgreen','deep glaucous-green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-r:deepgrapegreen.120','deepgrapegreen','deep grape green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:deepgrapegreen.122','deepgrapegreen','deep grape green',[143,151,121],'8f9779',9410425],
['nbs-iscc-r:deepgrayishbluegreen.150','deepgrayishbluegreen','deep grayish blue-green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:deepgrayishlavender.214','deepgrayishlavender','deep grayish lavender ',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:deepgrayishlavender.227','deepgrayishlavender','deep grayish lavender ',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:deepgrayisholive.113','deepgrayisholive','deep grayish olive',[87,85,76],'57554c',5723468],
['nbs-iscc-r:deepgreenbluegray.186','deepgreenbluegray','deep green-blue gray',[83,104,120],'536878',5466232],
['nbs-iscc-r:deepgreenishglaucous.143','deepgreenishglaucous','deep greenish glaucous',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-r:deepgullgray.265','deepgullgray','deep gull gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:deepheliotropegray.228','deepheliotropegray','deep heliotrope gray ',[121,104,120],'796878',7956600],
['nbs-iscc-r:deephyssopviolet.223','deephyssopviolet','deep hyssop violet',[134,96,142],'86608e',8806542],
['nbs-iscc-r:deeplavender.210','deeplavender','deep lavender',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:deeplavenderblue.195','deeplavenderblue','deep lavender-blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:deeplichengreen.135','deeplichengreen','deep lichen green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:deeplividbrown.19','deeplividbrown','deep livid brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:deeplividpurple.259','deeplividpurple','deep livid purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:deepmadderblue.204','deepmadderblue','deep madder blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:deepmalachitegreen.136','deepmalachitegreen','deep malachite green',[103,146,103],'679267',6787687],
['nbs-iscc-r:deepmediciblue.191','deepmediciblue','deep medici blue',[129,135,139],'81878b',8488843],
['nbs-iscc-r:deepmousegray.64','deepmousegray','deep mouse gray ',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:deepmousegray.265','deepmousegray','deep mouse gray ',[132,132,130],'848482',8684674],
['nbs-iscc-r:deepmousegray.266','deepmousegray','deep mouse gray ',[85,85,85],'555555',5592405],
['nbs-iscc-r:deepneutralgray.266','deepneutralgray','deep neutral gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:deepolive.107','deepolive','deep olive',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:deepolive.110','deepolive','deep olive',[91,88,66],'5b5842',5986370],
['nbs-iscc-r:deepolivebuff.90','deepolivebuff','deep olive-buff',[194,178,128],'c2b280',12759680],
['nbs-iscc-r:deepolivegray.112','deepolivegray','deep olive-gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-r:deeporientblue.186','deeporientblue','deep orient blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:deeppaynesgray.186','deeppaynesgray','deep payne\'s gray',[83,104,120],'536878',5466232],
['nbs-iscc-r:deepplumbagoblue.227','deepplumbagoblue','deep plumbago blue',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:deepplumbagogray.233','deepplumbagogray','deep plumbago gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:deepplumbeous.186','deepplumbeous','deep plumbeous',[83,104,120],'536878',5466232],
['nbs-iscc-r:deepplumbeous.191','deepplumbeous','deep plumbeous',[129,135,139],'81878b',8488843],
['nbs-iscc-r:deeppurplishgray.234','deeppurplishgray','deep purplish gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:deeppurplishvinaceous.262','deeppurplishvinaceous','deep purplish vinaceous',[145,95,109],'915f6d',9527149],
['nbs-iscc-r:deepquakerdrab.234','deepquakerdrab','deep quaker drab',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:deeprosepink.247','deeprosepink','deep rose pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-r:deepseafoamgreen.119','deepseafoamgreen','deep sea-foam green ',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:deepslateblue.186','deepslateblue','deep slate-blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:deepslategreen.156','deepslategreen','deep slate-green',[78,87,85],'4e5755',5134165],
['nbs-iscc-r:deepslateolive.156','deepslateolive','deep slate-olive',[78,87,85],'4e5755',5134165],
['nbs-iscc-r:deepslateviolet.228','deepslateviolet','deep slate-violet',[121,104,120],'796878',7956600],
['nbs-iscc-r:deepslatybrown.229','deepslatybrown','deep slaty brown',[80,64,77],'50404d',5259341],
['nbs-iscc-r:deepsoftblueviolet.200','deepsoftblueviolet','deep soft blue-violet',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:deepsoftblueviolet.211','deepsoftblueviolet','deep soft blue-violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:deepsoftbluishviolet.207','deepsoftbluishviolet','deep soft bluish violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:deepturtlegreen.131','deepturtlegreen','deep turtle green',[68,148,74],'44944a',4494410],
['nbs-iscc-r:deepturtlegreen.136','deepturtlegreen','deep turtle green',[103,146,103],'679267',6787687],
['nbs-iscc-r:deepvarleysgray.228','deepvarleysgray','deep varley\'s gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:deepvarleysgray.234','deepvarleysgray','deep varley\'s gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:deepvinaceous.6','deepvinaceous','deep vinaceous',[192,128,129],'c08081',12615809],
['nbs-iscc-r:deepvinaceousgray.228','deepvinaceousgray','deep vinaceous-gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:deepvinaceouslavender.244','deepvinaceouslavender','deep vinaceous-lavender',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-r:deepvinaceouslavender.253','deepvinaceouslavender','deep vinaceous-lavender',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-r:deepvioletgray.233','deepvioletgray','deep violet-gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:deepvioletgray.234','deepvioletgray','deep violet-gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:deepvioletgray.265','deepvioletgray','deep violet-gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:deepvioletgray.266','deepvioletgray','deep violet-gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:deepvioletplumbeous.204','deepvioletplumbeous','deep violet-plumbeous ',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:deepwedgewoodblue.195','deepwedgewoodblue','deep wedgewood blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:delftblue.186','delftblue','delft blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:diaminazoblue.215','diaminazoblue','diamin-azo blue',[85,76,105],'554c69',5590121],
['nbs-iscc-r:diaminazoblue.229','diaminazoblue','diamin-azo blue',[80,64,77],'50404d',5259341],
['nbs-iscc-r:diaminebrown.46','diaminebrown','diamine brown',[103,76,71],'674c47',6769735],
['nbs-iscc-r:diaminegreen.145','diaminegreen','diamine green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:diaminegreen.146','diaminegreen','diamine green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-r:divablue.195','divablue','diva blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:divablue.196','divablue','diva blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:drab.76','drab','drab',[193,154,107],'c19a6b',12687979],
['nbs-iscc-r:drab.77','drab','drab',[130,102,68],'826644',8545860],
['nbs-iscc-r:drab.79','drab','drab',[174,155,130],'ae9b82',11443074],
['nbs-iscc-r:drab.80','drab','drab',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-r:drabgray.79','drabgray','drab-gray',[174,155,130],'ae9b82',11443074],
['nbs-iscc-r:drabgray.93','drabgray','drab-gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-r:dragonsbloodred.38','dragonsbloodred','dragons-blood red',[158,71,50],'9e4732',10372914],
['nbs-iscc-r:dresdenbrown.77','dresdenbrown','dresden brown',[130,102,68],'826644',8545860],
['nbs-iscc-r:duckgreen.151','duckgreen','duck green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:dullblackishgreen.151','dullblackishgreen','dull blackish green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:dullbluegreenblack.187','dullbluegreenblack','dull blue-green black',[54,69,79],'36454f',3556687],
['nbs-iscc-r:dullbluegreenblack.188','dullbluegreenblack','dull blue-green black',[32,40,48],'202830',2107440],
['nbs-iscc-r:dullbluegreenblack.193','dullbluegreenblack','dull blue-green black',[32,36,40],'202428',2106408],
['nbs-iscc-r:dullblueviolet.196','dullblueviolet','dull blue-violet',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:dullblueviolet.206','dullblueviolet','dull blue-violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:dullblueviolet.207','dullblueviolet','dull blue-violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:dullblueviolet.211','dullblueviolet','dull blue-violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:dullbluishviolet.206','dullbluishviolet','dull bluish violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:dullbluishviolet.207','dullbluishviolet','dull bluish violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:dullbluishviolet.210','dullbluishviolet','dull bluish violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:dullbluishviolet.211','dullbluishviolet','dull bluish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:dullbluishviolet.207','dullbluishviolet','dull bluish violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:dullbluishviolet.211','dullbluishviolet','dull bluish violet',[96,78,129],'604e81',6311553],
['nbs-iscc-r:dullcitrine.106','dullcitrine','dull citrine',[134,126,54],'867e36',8814134],
['nbs-iscc-r:dullcitrine.107','dullcitrine','dull citrine',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:dulldarkpurple.237','dulldarkpurple','dull dark purple',[158,79,136],'9e4f88',10375048],
['nbs-iscc-r:dulldarkpurple.238','dulldarkpurple','dull dark purple',[112,41,99],'702963',7350627],
['nbs-iscc-r:dulldarkpurple.241','dulldarkpurple','dull dark purple',[145,92,131],'915c83',9526403],
['nbs-iscc-r:dullduskypurple.229','dullduskypurple','dull dusky purple',[80,64,77],'50404d',5259341],
['nbs-iscc-r:dullduskypurple.242','dullduskypurple','dull dusky purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:dullgreenishblack.156','dullgreenishblack','dull greenish black ',[78,87,85],'4e5755',5134165],
['nbs-iscc-r:dullgreenishblack.266','dullgreenishblack','dull greenish black ',[85,85,85],'555555',5592405],
['nbs-iscc-r:dullgreenishblack.156','dullgreenishblack','dull greenish black ',[78,87,85],'4e5755',5134165],
['nbs-iscc-r:dullgreenishblack.266','dullgreenishblack','dull greenish black ',[85,85,85],'555555',5592405],
['nbs-iscc-r:dullgreenyellow.117','dullgreenyellow','dull green-yellow',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-r:dullindianpurple.262','dullindianpurple','dull indian purple',[145,95,109],'915f6d',9527149],
['nbs-iscc-r:dulllavender.253','dulllavender','dull lavender',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-r:dullmagentapurple.237','dullmagentapurple','dull magenta purple',[158,79,136],'9e4f88',10375048],
['nbs-iscc-r:dullopalinegreen.148','dullopalinegreen','dull opaline green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:dullpurplishblack.234','dullpurplishblack','dull purplish black',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:dullviolaceousblue.196','dullviolaceousblue','dull violaceous blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:dullvioletblack.234','dullvioletblack','dull violet-black ',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:dullvioletblack.187','dullvioletblack','dull violet-black ',[54,69,79],'36454f',3556687],
['nbs-iscc-r:dullvioletblack.192','dullvioletblack','dull violet-black ',[81,88,94],'51585e',5331038],
['nbs-iscc-r:dullvioletblack.229','dullvioletblack','dull violet-black ',[80,64,77],'50404d',5259341],
['nbs-iscc-r:dullvioletblack.234','dullvioletblack','dull violet-black ',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:dullvioletblack.266','dullvioletblack','dull violet-black ',[85,85,85],'555555',5592405],
['nbs-iscc-r:dullvioletblack.267','dullvioletblack','dull violet-black ',[34,34,34],'222222',2236962],
['nbs-iscc-r:dullvioletblue.196','dullvioletblue','dull violet-blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:dullvioletblue.211','dullvioletblue','dull violet-blue',[96,78,129],'604e81',6311553],
['nbs-iscc-r:duskyauriculapurple.242','duskyauriculapurple','dusky auricula purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:duskyblue.204','duskyblue','dusky blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:duskybluegreen.151','duskybluegreen','dusky blue-green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:duskyblueviolet.215','duskyblueviolet','dusky blue-violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:duskyblueviolet.212','duskyblueviolet','dusky blue-violet',[47,33,64],'2f2140',3088704],
['nbs-iscc-r:duskyblueviolet.229','duskyblueviolet','dusky blue-violet',[80,64,77],'50404d',5259341],
['nbs-iscc-r:duskybluishgreen.156','duskybluishgreen','dusky bluish green',[78,87,85],'4e5755',5134165],
['nbs-iscc-r:duskybrown.229','duskybrown','dusky brown ',[80,64,77],'50404d',5259341],
['nbs-iscc-r:duskybrown.234','duskybrown','dusky brown ',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:duskydrab.64','duskydrab','dusky drab',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:duskydullbluishgreen.151','duskydullbluishgreen','dusky dull bluish green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:duskydullgreen.151','duskydullgreen','dusky dull green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:duskydullgreen.156','duskydullgreen','dusky dull green',[78,87,85],'4e5755',5134165],
['nbs-iscc-r:duskydullviolet.224','duskydullviolet','dusky dull violet ',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:duskydullviolet.223','duskydullviolet','dusky dull violet ',[134,96,142],'86608e',8806542],
['nbs-iscc-r:duskydullviolet.224','duskydullviolet','dusky dull violet ',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:duskydullviolet.228','duskydullviolet','dusky dull violet ',[121,104,120],'796878',7956600],
['nbs-iscc-r:duskydullvioletblue.215','duskydullvioletblue','dusky dull violet-blue ',[85,76,105],'554c69',5590121],
['nbs-iscc-r:duskygreen.150','duskygreen','dusky green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:duskygreen.151','duskygreen','dusky green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:duskygreenblue.165','duskygreenblue','dusky green-blue ',[0,75,73],'004b49',19273],
['nbs-iscc-r:duskygreenblue.174','duskygreenblue','dusky green-blue ',[0,73,88],'004958',18776],
['nbs-iscc-r:duskygreenblue.186','duskygreenblue','dusky green-blue ',[83,104,120],'536878',5466232],
['nbs-iscc-r:duskygreenblue.186','duskygreenblue','dusky green-blue ',[83,104,120],'536878',5466232],
['nbs-iscc-r:duskygreenblue.187','duskygreenblue','dusky green-blue ',[54,69,79],'36454f',3556687],
['nbs-iscc-r:duskygreengray.266','duskygreengray','dusky green-gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:duskygreenishblue.179','duskygreenishblue','dusky greenish blue',[0,65,106],'00416a',16746],
['nbs-iscc-r:duskygreenishblue.182','duskygreenishblue','dusky greenish blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:duskygreenishblue.183','duskygreenishblue','dusky greenish blue',[0,48,78],'00304e',12366],
['nbs-iscc-r:duskyneutralgray.266','duskyneutralgray','dusky neutral gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:duskyolivegreen.127','duskyolivegreen','dusky olive-green',[81,87,68],'515744',5330756],
['nbs-iscc-r:duskyorientblue.186','duskyorientblue','dusky orient blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:duskypurplishgray.229','duskypurplishgray','dusky purplish gray',[80,64,77],'50404d',5259341],
['nbs-iscc-r:duskypurplishgray.234','duskypurplishgray','dusky purplish gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:duskypurplishgray.266','duskypurplishgray','dusky purplish gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:duskypurplishgray.267','duskypurplishgray','dusky purplish gray',[34,34,34],'222222',2236962],
['nbs-iscc-r:duskyslateblue.187','duskyslateblue','dusky slate-blue',[54,69,79],'36454f',3556687],
['nbs-iscc-r:duskyslateviolet.229','duskyslateviolet','dusky slate-violet',[80,64,77],'50404d',5259341],
['nbs-iscc-r:duskyslateviolet.234','duskyslateviolet','dusky slate-violet',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:duskyviolet.229','duskyviolet','dusky violet',[80,64,77],'50404d',5259341],
['nbs-iscc-r:duskyvioletblue.204','duskyvioletblue','dusky violet-blue ',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:duskyvioletblue.215','duskyvioletblue','dusky violet-blue ',[85,76,105],'554c69',5590121],
['nbs-iscc-r:duskyvioletblue.187','duskyvioletblue','dusky violet-blue ',[54,69,79],'36454f',3556687],
['nbs-iscc-r:duskyyellowishgreen.127','duskyyellowishgreen','dusky yellowish green',[81,87,68],'515744',5330756],
['nbs-iscc-r:dutchblue.185','dutchblue','dutch blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:dutchblue.203','dutchblue','dutch blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:ecrudrab.33','ecrudrab','ecru-drab',[194,172,153],'c2ac99',12758169],
['nbs-iscc-r:ecruolive.88','ecruolive','ecru-olive',[171,145,68],'ab9144',11243844],
['nbs-iscc-r:ecruolive.91','ecruolive','ecru-olive',[161,143,96],'a18f60',10588000],
['nbs-iscc-r:elmgreen.125','elmgreen','elm green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:elmgreen.127','elmgreen','elm green',[81,87,68],'515744',5330756],
['nbs-iscc-r:emeraldgreen.130','emeraldgreen','emerald green',[131,211,125],'83d37d',8639357],
['nbs-iscc-r:empiregreen.150','empiregreen','empire green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:empiregreen.151','empiregreen','empire green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:empireyellow.83','empireyellow','empire yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-r:endiveblue.199','endiveblue','endive blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:endiveblue.203','endiveblue','endive blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:englishred.38','englishred','english red',[158,71,50],'9e4732',10372914],
['nbs-iscc-r:eosinepink.3','eosinepink','eosine pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-r:ethylgreen.160','ethylgreen','ethyl green',[0,122,116],'007a74',31348],
['nbs-iscc-r:ethylgreen.164','ethylgreen','ethyl green',[49,120,115],'317873',3242099],
['nbs-iscc-r:etonblue.182','etonblue','eton blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:etruscanred.19','etruscanred','etruscan red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:eugeniared.15','eugeniared','eugenia red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-r:eupatoriumpurple.240','eupatoriumpurple','eupatorium purple',[183,132,167],'b784a7',12027047],
['nbs-iscc-r:eupatoriumpurple.241','eupatoriumpurple','eupatorium purple',[145,92,131],'915c83',9526403],
['nbs-iscc-r:fawncolor.45','fawncolor','fawn color',[151,127,115],'977f73',9928563],
['nbs-iscc-r:fawncolor.57','fawncolor','fawn color',[166,123,91],'a67b5b',10910555],
['nbs-iscc-r:fawncolor.60','fawncolor','fawn color',[149,128,112],'958070',9797744],
['nbs-iscc-r:ferruginous.37','ferruginous','ferruginous',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:ferruginous.38','ferruginous','ferruginous',[158,71,50],'9e4732',10372914],
['nbs-iscc-r:flamescarlet.34','flamescarlet','flame scarlet ',[226,88,34],'e25822',14833698],
['nbs-iscc-r:flaxflowerblue.195','flaxflowerblue','flax-flower blue ',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:fleshcolor.5','fleshcolor','flesh color',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:fleshochre.53','fleshochre','flesh-ochre ',[217,144,88],'d99058',14258264],
['nbs-iscc-r:fleshpink.28','fleshpink','flesh pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:fleshpink.29','fleshpink','flesh pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:fluoritegreen.136','fluoritegreen','fluorite green',[103,146,103],'679267',6787687],
['nbs-iscc-r:fluoriteviolet.224','fluoriteviolet','fluorite violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:forestgreen.120','forestgreen','forest green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:forestgreen.125','forestgreen','forest green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:forgetmenotblue.195','forgetmenotblue','forget-me-not blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:frenchgray.185','frenchgray','french gray',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:frenchgray.190','frenchgray','french gray',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-r:frenchgreen.145','frenchgreen','french green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:fuscous.64','fuscous','fuscous',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:fuscousblack.64','fuscousblack','fuscous-black',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:fuscousblack.266','fuscousblack','fuscous-black',[85,85,85],'555555',5592405],
['nbs-iscc-r:garnetbrown.13','garnetbrown','garnet brown',[132,27,45],'841b2d',8657709],
['nbs-iscc-r:gendarmeblue.182','gendarmeblue','gendarme blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:gentianblue.196','gentianblue','gentian blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:geraniumpink.3','geraniumpink','geranium pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-r:geraniumpink.27','geraniumpink','geranium pink',[230,103,97],'e66761',15099745],
['nbs-iscc-r:glassgreen.119','glassgreen','glass green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:glaucous.121','glaucous','glaucous',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:glaucousblue.172','glaucousblue','glaucous-blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-r:glaucousgray.190','glaucousgray','glaucous-gray',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-r:glaucousgreen.149','glaucousgreen','glaucous-green',[141,163,153],'8da399',9282457],
['nbs-iscc-r:gnaphaliumgreen.148','gnaphaliumgreen','gnaphalium green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:gnaphaliumgreen.149','gnaphaliumgreen','gnaphalium green',[141,163,153],'8da399',9282457],
['nbs-iscc-r:grassgreen.120','grassgreen','grass green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:grayishbluegreen.150','grayishbluegreen','grayish blue-green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:grayishblueviolet.196','grayishblueviolet','grayish blue-violet ',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:grayishblueviolet.200','grayishblueviolet','grayish blue-violet ',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:grayishblueviolet.207','grayishblueviolet','grayish blue-violet ',[96,78,151],'604e97',6311575],
['nbs-iscc-r:grayishblueviolet.211','grayishblueviolet','grayish blue-violet ',[96,78,129],'604e81',6311553],
['nbs-iscc-r:grayishblueviolet.199','grayishblueviolet','grayish blue-violet ',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:grayishlavender.227','grayishlavender','grayish lavender',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:grayisholive.109','grayisholive','grayish olive',[140,135,103],'8c8767',9209703],
['nbs-iscc-r:grayishviolaceousblue.199','grayishviolaceousblue','grayish violaceous blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:grayishvioletblue.210','grayishvioletblue','grayish violet-blue',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:grayishvioletblue.211','grayishvioletblue','grayish violet-blue',[96,78,129],'604e81',6311553],
['nbs-iscc-r:greenblueslate.186','greenblueslate','green-blue slate',[83,104,120],'536878',5466232],
['nbs-iscc-r:greenishglaucous.148','greenishglaucous','greenish glaucous',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:greenishglaucousblue.163','greenishglaucousblue','greenish glaucous-blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:greenishslateblack.151','greenishslateblack','greenish slate-black',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:greenishslateblack.156','greenishslateblack','greenish slate-black',[78,87,85],'4e5755',5134165],
['nbs-iscc-r:greenishslateblack.266','greenishslateblack','greenish slate-black',[85,85,85],'555555',5592405],
['nbs-iscc-r:greenishslateblack.267','greenishslateblack','greenish slate-black',[34,34,34],'222222',2236962],
['nbs-iscc-r:greenishyellow.99','greenishyellow','greenish yellow',[190,183,46],'beb72e',12498734],
['nbs-iscc-r:greenyellow.98','greenyellow','green-yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-r:grenadine.35','grenadine','grenadine',[217,96,59],'d9603b',14245947],
['nbs-iscc-r:grenadinepink.26','grenadinepink','grenadine pink',[248,131,121],'f88379',16286585],
['nbs-iscc-r:grenadinered.34','grenadinered','grenadine red ',[226,88,34],'e25822',14833698],
['nbs-iscc-r:guineagreen.160','guineagreen','guinea green',[0,122,116],'007a74',31348],
['nbs-iscc-r:gullgray.265','gullgray','gull gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:haematitered.46','haematitered','haematite red',[103,76,71],'674c47',6769735],
['nbs-iscc-r:haematoxylinviolet.223','haematoxylinviolet','haematoxylin violet',[134,96,142],'86608e',8806542],
['nbs-iscc-r:hairbrown.64','hairbrown','hair brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-r:hathigray.154','hathigray','hathi gray',[178,190,181],'b2beb5',11714229],
['nbs-iscc-r:hathigray.155','hathigray','hathi gray',[125,137,132],'7d8984',8227204],
['nbs-iscc-r:hathigray.264','hathigray','hathi gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-r:hathigray.265','hathigray','hathi gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:haysblue.196','haysblue','hay\'s blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:haysbrown.19','haysbrown','hay\'s brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:haysbrown.46','haysbrown','hay\'s brown',[103,76,71],'674c47',6769735],
['nbs-iscc-r:haysgreen.136','haysgreen','hay\'s green',[103,146,103],'679267',6787687],
['nbs-iscc-r:haysgreen.137','haysgreen','hay\'s green',[53,94,59],'355e3b',3497531],
['nbs-iscc-r:hayslilac.222','hayslilac','hay\'s lilac',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:haysmaroon.20','haysmaroon','hay\'s maroon',[84,61,63],'543d3f',5520703],
['nbs-iscc-r:haysrusset.43','haysrusset','hay\'s russet',[121,68,59],'79443b',7947323],
['nbs-iscc-r:hazel.55','hazel','hazel',[128,70,27],'80461b',8406555],
['nbs-iscc-r:heliotropegray.227','heliotropegray','heliotrope gray',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:heliotropegray.228','heliotropegray','heliotrope gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:heliotropeslate.228','heliotropeslate','heliotrope slate',[121,104,120],'796878',7956600],
['nbs-iscc-r:helleborered.258','helleborered','hellebore red',[168,81,110],'a8516e',11030894],
['nbs-iscc-r:helvetiablue.196','helvetiablue','helvetia blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:hermosapink.2','hermosapink','hermosa pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-r:hessianbrown.46','hessianbrown','hessian brown',[103,76,71],'674c47',6769735],
['nbs-iscc-r:hessianbrown.47','hessianbrown','hessian brown',[67,48,46],'43302e',4403246],
['nbs-iscc-r:honeyyellow.87','honeyyellow','honey yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:honeyyellow.88','honeyyellow','honey yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-r:hortenseblue.182','hortenseblue','hortense blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:hortenseviolet.217','hortenseviolet','hortense violet',[211,153,230],'d399e6',13867494],
['nbs-iscc-r:hyacinthblue.197','hyacinthblue','hyacinth blue',[39,36,88],'272458',2565208],
['nbs-iscc-r:hyacinthblue.211','hyacinthblue','hyacinth blue',[96,78,129],'604e81',6311553],
['nbs-iscc-r:hyacinthviolet.219','hyacinthviolet','hyacinth violet',[96,47,107],'602f6b',6303595],
['nbs-iscc-r:hydrangeapink.28','hydrangeapink','hydrangea pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:hydrangeapink.29','hydrangeapink','hydrangea pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:hydrangeared.19','hydrangeared','hydrangea red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:hyssopviolet.223','hyssopviolet','hyssop violet',[134,96,142],'86608e',8806542],
['nbs-iscc-r:indianlake.258','indianlake','indian lake',[168,81,110],'a8516e',11030894],
['nbs-iscc-r:indianlake.262','indianlake','indian lake',[145,95,109],'915f6d',9527149],
['nbs-iscc-r:indianpurple.229','indianpurple','indian purple',[80,64,77],'50404d',5259341],
['nbs-iscc-r:indianpurple.259','indianpurple','indian purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:indianred.19','indianred','indian red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:indigoblue.183','indigoblue','indigo blue',[0,48,78],'00304e',12366],
['nbs-iscc-r:indigoblue.186','indigoblue','indigo blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:indigoblue.187','indigoblue','indigo blue',[54,69,79],'36454f',3556687],
['nbs-iscc-r:indigoblue.204','indigoblue','indigo blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:indulinblue.204','indulinblue','indulin blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:invisiblegreen.151','invisiblegreen','invisible green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-r:invisiblegreen.165','invisiblegreen','invisible green',[0,75,73],'004b49',19273],
['nbs-iscc-r:irongray.113','irongray','iron gray',[87,85,76],'57554c',5723468],
['nbs-iscc-r:isabellacolor.91','isabellacolor','isabella color',[161,143,96],'a18f60',10588000],
['nbs-iscc-r:italianblue.169','italianblue','italian blue',[0,119,145],'007791',30609],
['nbs-iscc-r:ivoryyellow.89','ivoryyellow','ivory yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-r:ivygreen.107','ivygreen','ivy green',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:ivygreen.110','ivygreen','ivy green',[91,88,66],'5b5842',5986370],
['nbs-iscc-r:jadegreen.125','jadegreen','jade green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:jadegreen.127','jadegreen','jade green',[81,87,68],'515744',5330756],
['nbs-iscc-r:japanrose.29','japanrose','japan rose',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:jaspergreen.145','jaspergreen','jasper green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:jasperpink.3','jasperpink','jasper pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-r:jasperpink.26','jasperpink','jasper pink',[248,131,121],'f88379',16286585],
['nbs-iscc-r:jasperpink.27','jasperpink','jasper pink',[230,103,97],'e66761',15099745],
['nbs-iscc-r:jasperred.15','jasperred','jasper red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-r:javelgreen.102','javelgreen','javel green',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:jayblue.182','jayblue','jay blue ',[67,107,149],'436b95',4418453],
['nbs-iscc-r:jayblue.199','jayblue','jay blue ',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:jouvenceblue.164','jouvenceblue','jouvence blue',[49,120,115],'317873',3242099],
['nbs-iscc-r:jouvenceblue.173','jouvenceblue','jouvence blue',[54,117,136],'367588',3569032],
['nbs-iscc-r:kaiserbrown.55','kaiserbrown','kaiser brown',[128,70,27],'80461b',8406555],
['nbs-iscc-r:kildaregreen.120','kildaregreen','kildare green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:killarneygreen.136','killarneygreen','killarney green ',[103,146,103],'679267',6787687],
['nbs-iscc-r:kingsblue.181','kingsblue','king\'s blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:kronbergsgreen.106','kronbergsgreen','kronberg\'s green',[134,126,54],'867e36',8814134],
['nbs-iscc-r:kronbergsgreen.107','kronbergsgreen','kronberg\'s green',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:laeliapink.240','laeliapink','laelia pink',[183,132,167],'b784a7',12027047],
['nbs-iscc-r:laeliapink.248','laeliapink','laelia pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:lafrancepink.1','lafrancepink','la france pink',[255,181,186],'ffb5ba',16758202],
['nbs-iscc-r:lavender.209','lavender','lavender',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-r:lavender.213','lavender','lavender',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-r:lavenderblue.195','lavenderblue','lavender-blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:lavenderblue.199','lavenderblue','lavender-blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:lavendergray.202','lavendergray','lavender-gray',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-r:lavendergray.203','lavendergray','lavender-gray',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:lavendergray.213','lavendergray','lavender-gray',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-r:lavendergray.214','lavendergray','lavender-gray',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:lavenderviolet.206','lavenderviolet','lavender-violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:leafgreen.127','leafgreen','leaf green',[81,87,68],'515744',5330756],
['nbs-iscc-r:leitchsblue.178','leitchsblue','leitch\'s blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:lemonchrome.84','lemonchrome','lemon chrome',[212,175,55],'d4af37',13938487],
['nbs-iscc-r:lemonyellow.98','lemonyellow','lemon yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-r:lemonyellow.99','lemonyellow','lemon yellow',[190,183,46],'beb72e',12498734],
['nbs-iscc-r:lettucegreen.120','lettucegreen','lettuce green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:lichengreen.148','lichengreen','lichen green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:lightaliceblue.181','lightaliceblue','light alice blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:lightaliceblue.185','lightaliceblue','light alice blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:lightamparoblue.177','lightamparoblue','light amparo blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-r:lightamparopurple.217','lightamparopurple','light amparo purple',[211,153,230],'d399e6',13867494],
['nbs-iscc-r:lightbicegreen.120','lightbicegreen','light bice green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:lightbluegreen.140','lightbluegreen','light blue-green',[62,180,137],'3eb489',4109449],
['nbs-iscc-r:lightbluegreen.144','lightbluegreen','light blue-green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-r:lightblueviolet.194','lightblueviolet','light blue-violet',[48,38,122],'30267a',3155578],
['nbs-iscc-r:lightbluishviolet.195','lightbluishviolet','light bluish violet',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:lightbluishviolet.196','lightbluishviolet','light bluish violet',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:lightbluishviolet.206','lightbluishviolet','light bluish violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:lightbrownishdrab.60','lightbrownishdrab','light brownish drab',[149,128,112],'958070',9797744],
['nbs-iscc-r:lightbrownisholive.94','lightbrownisholive','light brownish olive',[150,113,23],'967117',9859351],
['nbs-iscc-r:lightbrownishvinaceous.8','lightbrownishvinaceous','light brownish vinaceous',[196,174,173],'c4aead',12889773],
['nbs-iscc-r:lightbuff.73','lightbuff','light buff',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:lightbuff.89','lightbuff','light buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-r:lightcadetblue.177','lightcadetblue','light cadet blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-r:lightcadmium.82','lightcadmium','light cadmium',[243,195,0],'f3c300',15975168],
['nbs-iscc-r:lightcampanulablue.195','lightcampanulablue','light campanula blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:lightcelandinegreen.154','lightcelandinegreen','light celandine green',[178,190,181],'b2beb5',11714229],
['nbs-iscc-r:lightcelandinegreen.155','lightcelandinegreen','light celandine green',[125,137,132],'7d8984',8227204],
['nbs-iscc-r:lightcendregreen.130','lightcendregreen','light cendre green',[131,211,125],'83d37d',8639357],
['nbs-iscc-r:lightcendregreen.135','lightcendregreen','light cendre green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:lightceruleanblue.181','lightceruleanblue','light cerulean blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:lightchalcedonyyellow.101','lightchalcedonyyellow','light chalcedony yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:lightchicoryblue.210','lightchicoryblue','light chicory blue',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:lightcinnamondrab.45','lightcinnamondrab','light cinnamon-drab',[151,127,115],'977f73',9928563],
['nbs-iscc-r:lightcinnamondrab.60','lightcinnamondrab','light cinnamon-drab',[149,128,112],'958070',9797744],
['nbs-iscc-r:lightcolumbiablue.181','lightcolumbiablue','light columbia blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:lightcongopink.28','lightcongopink','light congo pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:lightcongopink.29','lightcongopink','light congo pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:lightcoralred.37','lightcoralred','light coral red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:lightcorinthianred.6','lightcorinthianred','light corinthian red',[192,128,129],'c08081',12615809],
['nbs-iscc-r:lightcressgreen.120','lightcressgreen','light cress green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:lightdanubegreen.145','lightdanubegreen','light danube green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:lightdrab.79','lightdrab','light drab',[174,155,130],'ae9b82',11443074],
['nbs-iscc-r:lightdullbluishviolet.210','lightdullbluishviolet','light dull bluish violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:lightdullglaucousblue.172','lightdullglaucousblue','light dull glaucous-blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-r:lightdullglaucousblue.185','lightdullglaucousblue','light dull glaucous-blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:lightdullgreenyellow.119','lightdullgreenyellow','light dull green-yellow',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:lightelmgreen.120','lightelmgreen','light elm green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:lightfluoritegreen.119','lightfluoritegreen','light fluorite green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:lightforgetmenotblue.181','lightforgetmenotblue','light forget-me-not blue ',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:lightglaucousblue.171','lightglaucousblue','light glaucous-blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-r:lightgrapegreen.120','lightgrapegreen','light grape green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:lightgrayishblueviolet.181','lightgrayishblueviolet','light grayish blue-violet',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:lightgrayishblueviolet.199','lightgrayishblueviolet','light grayish blue-violet',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:lightgrayisholive.109','lightgrayisholive','light grayish olive',[140,135,103],'8c8767',9209703],
['nbs-iscc-r:lightgrayisholive.112','lightgrayisholive','light grayish olive',[138,135,118],'8a8776',9078646],
['nbs-iscc-r:lightgrayishvinaceous.32','lightgrayishvinaceous','light grayish vinaceous',[199,173,163],'c7ada3',13086115],
['nbs-iscc-r:lightgrayishvioletblue.195','lightgrayishvioletblue','light grayish violet-blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:lightgreenishyellow.98','lightgreenishyellow','light greenish yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-r:lightgreenishyellow.99','lightgreenishyellow','light greenish yellow',[190,183,46],'beb72e',12498734],
['nbs-iscc-r:lightgreenyellow.101','lightgreenyellow','light green-yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:lightgullgray.264','lightgullgray','light gull gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-r:lightheliotropegray.227','lightheliotropegray','light heliotrope gray',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:lighthelleboregreen.120','lighthelleboregreen','light hellebore green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:lighthelleboregreen.122','lighthelleboregreen','light hellebore green',[143,151,121],'8f9779',9410425],
['nbs-iscc-r:lighthortenseviolet.217','lighthortenseviolet','light hortense violet',[211,153,230],'d399e6',13867494],
['nbs-iscc-r:lighthyssopviolet.210','lighthyssopviolet','light hyssop violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:lightjasperred.3','lightjasperred','light jasper red',[228,113,122],'e4717a',14971258],
['nbs-iscc-r:lightjasperred.15','lightjasperred','light jasper red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-r:lightkingsblue.184','lightkingsblue','light king\'s blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:lightkingsblue.185','lightkingsblue','light king\'s blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:lightlavenderblue.199','lightlavenderblue','light lavender-blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:lightlavenderviolet.210','lightlavenderviolet','light lavender-violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:lightlobeliaviolet.222','lightlobeliaviolet','light lobelia violet',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:lightlumieregreen.119','lightlumieregreen','light lumiere green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:lightmallowpurple.248','lightmallowpurple','light mallow purple',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:lightmauve.210','lightmauve','light mauve',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:lightmediciblue.186','lightmediciblue','light medici blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:lightmethylblue.177','lightmethylblue','light methyl blue ',[73,151,208],'4997d0',4822992],
['nbs-iscc-r:lightmethylblue.178','lightmethylblue','light methyl blue ',[0,103,165],'0067a5',26533],
['nbs-iscc-r:lightmineralgray.154','lightmineralgray','light mineral gray ',[178,190,181],'b2beb5',11714229],
['nbs-iscc-r:lightmousegray.63','lightmousegray','light mouse gray ',[142,130,121],'8e8279',9339513],
['nbs-iscc-r:lightneropalinblue.185','lightneropalinblue','light neropalin blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:lightneutralgray.265','lightneutralgray','light neutral gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:lightniagaragreen.163','lightniagaragreen','light niagara green',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:lightochraceousbuff.71','lightochraceousbuff','light ochraceous-buff',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:lightochraceoussalmon.73','lightochraceoussalmon','light ochraceous-salmon',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:lightolivegray.93','lightolivegray','light olive-gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-r:lightorangeyellow.71','lightorangeyellow','light orange-yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:lightorangeyellow.84','lightorangeyellow','light orange-yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-r:lightorientalgreen.135','lightorientalgreen','light oriental green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:lightparisgreen.135','lightparisgreen','light paris green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:lightpaynesgray.185','lightpaynesgray','light payne\'s gray',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:lightpaynesgray.191','lightpaynesgray','light payne\'s gray',[129,135,139],'81878b',8488843],
['nbs-iscc-r:lightperillapurple.241','lightperillapurple','light perilla purple',[145,92,131],'915c83',9526403],
['nbs-iscc-r:lightperillapurple.245','lightperillapurple','light perilla purple',[131,100,121],'836479',8610937],
['nbs-iscc-r:lightphloxpurple.248','lightphloxpurple','light phlox purple',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:lightpinkishcinnamon.28','lightpinkishcinnamon','light pinkish cinnamon',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:lightpinkishcinnamon.29','lightpinkishcinnamon','light pinkish cinnamon',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:lightpinkishlilac.249','lightpinkishlilac','light pinkish lilac',[239,187,204],'efbbcc',15711180],
['nbs-iscc-r:lightplumbagogray.233','lightplumbagogray','light plumbago gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:lightporcelaingreen.163','lightporcelaingreen','light porcelain green',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:lightporcelaingreen.164','lightporcelaingreen','light porcelain green',[49,120,115],'317873',3242099],
['nbs-iscc-r:lightpurpledrab.228','lightpurpledrab','light purple-drab',[121,104,120],'796878',7956600],
['nbs-iscc-r:lightpurplishgray.233','lightpurplishgray','light purplish gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:lightpurplishgray.265','lightpurplishgray','light purplish gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:lightpurplishvinaceous.5','lightpurplishvinaceous','light purplish vinaceous',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:lightquakerdrab.233','lightquakerdrab','light quaker drab ',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:lightrosolanepurple.248','lightrosolanepurple','light rosolane purple',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:lightrussetvinaceous.42','lightrussetvinaceous','light russet-vinaceous',[168,124,109],'a87c6d',11041901],
['nbs-iscc-r:lightsalmonorange.53','lightsalmonorange','light salmon-orange',[217,144,88],'d99058',14258264],
['nbs-iscc-r:lightsealbrown.23','lightsealbrown','light seal brown',[92,80,79],'5c504f',6049871],
['nbs-iscc-r:lightskyblue.185','lightskyblue','light sky blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:lightsoftblueviolet.195','lightsoftblueviolet','light soft blue-violet',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:lightsoftblueviolet.206','lightsoftblueviolet','light soft blue-violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:lightsquillblue.181','lightsquillblue','light squill blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:lightsulphategreen.163','lightsulphategreen','light sulphate green',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:lightterreverte.164','lightterreverte','light terre verte',[49,120,115],'317873',3242099],
['nbs-iscc-r:lightturtlegreen.119','lightturtlegreen','light turtle green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:lighttyrianblue.186','lighttyrianblue','light tyrian blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:lighttyrianblue.203','lighttyrianblue','light tyrian blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:lighttyrianblue.204','lighttyrianblue','light tyrian blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:lightvarleysgray.227','lightvarleysgray','light varley\'s gray',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:lightvinaceouscinnamon.73','lightvinaceouscinnamon','light vinaceous-cinnamon',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:lightvinaceousdrab.19','lightvinaceousdrab','light vinaceous-drab',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:lightvinaceousfawn.32','lightvinaceousfawn','light vinaceous-fawn',[199,173,163],'c7ada3',13086115],
['nbs-iscc-r:lightvinaceousfawn.33','lightvinaceousfawn','light vinaceous-fawn',[194,172,153],'c2ac99',12758169],
['nbs-iscc-r:lightvinaceousgray.227','lightvinaceousgray','light vinaceous-gray',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:lightvinaceousgray.232','lightvinaceousgray','light vinaceous-gray',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-r:lightvinaceousgray.233','lightvinaceousgray','light vinaceous-gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:lightvinaceousgray.253','lightvinaceousgray','light vinaceous-gray',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-r:lightvinaceouslilac.240','lightvinaceouslilac','light vinaceous-lilac',[183,132,167],'b784a7',12027047],
['nbs-iscc-r:lightvinaceouslilac.244','lightvinaceouslilac','light vinaceous-lilac',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-r:lightvinaceouslilac.250','lightvinaceouslilac','light vinaceous-lilac',[213,151,174],'d597ae',13997998],
['nbs-iscc-r:lightvinaceouslilac.253','lightvinaceouslilac','light vinaceous-lilac',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-r:lightvinaceouspurple.245','lightvinaceouspurple','light vinaceous-purple',[131,100,121],'836479',8610937],
['nbs-iscc-r:lightviolet.195','lightviolet','light violet',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:lightviolet.206','lightviolet','light violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:lightvioletblue.196','lightvioletblue','light violet-blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:lightvioletgray.233','lightvioletgray','light violet-gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:lightvioletgray.265','lightvioletgray','light violet-gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:lightvioletplumbeous.185','lightvioletplumbeous','light violet-plumbeous ',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:lightvioletplumbeous.186','lightvioletplumbeous','light violet-plumbeous ',[83,104,120],'536878',5466232],
['nbs-iscc-r:lightvioletplumbeous.203','lightvioletplumbeous','light violet-plumbeous ',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:lightviridinegreen.119','lightviridinegreen','light viridine green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:lightviridineyellow.101','lightviridineyellow','light viridine yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:lightwindsorblue.199','lightwindsorblue','light windsor blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:lightwistariablue.199','lightwistariablue','light wistaria blue ',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:lightwistariablue.210','lightwistariablue','light wistaria blue ',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:lightwistariaviolet.210','lightwistariaviolet','light wistaria violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:lightyellowgreen.116','lightyellowgreen','light yellow-green',[189,218,87],'bdda57',12442199],
['nbs-iscc-r:lightyellowgreen.119','lightyellowgreen','light yellow-green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:lightyellowisholive.103','lightyellowisholive','light yellowish olive',[152,148,62],'98943e',9999422],
['nbs-iscc-r:lilac.222','lilac','lilac',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:lilac.227','lilac','lilac',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:lilacgray.232','lilacgray','lilac gray',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-r:lilygreen.155','lilygreen','lily green',[125,137,132],'7d8984',8227204],
['nbs-iscc-r:limegreen.102','limegreen','lime green',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:limegreen.103','limegreen','lime green',[152,148,62],'98943e',9999422],
['nbs-iscc-r:limegreen.106','limegreen','lime green',[134,126,54],'867e36',8814134],
['nbs-iscc-r:lincolngreen.127','lincolngreen','lincoln green',[81,87,68],'515744',5330756],
['nbs-iscc-r:liseranpurple.237','liseranpurple','liseran purple',[158,79,136],'9e4f88',10375048],
['nbs-iscc-r:liseranpurple.240','liseranpurple','liseran purple',[183,132,167],'b784a7',12027047],
['nbs-iscc-r:liseranpurple.241','liseranpurple','liseran purple',[145,92,131],'915c83',9526403],
['nbs-iscc-r:liseranpurple.248','liseranpurple','liseran purple',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:lithopurple.218','lithopurple','litho purple',[135,86,146],'875692',8869522],
['nbs-iscc-r:lithopurple.219','lithopurple','litho purple',[96,47,107],'602f6b',6303595],
['nbs-iscc-r:lithopurple.223','lithopurple','litho purple',[134,96,142],'86608e',8806542],
['nbs-iscc-r:liverbrown.43','liverbrown','liver brown',[121,68,59],'79443b',7947323],
['nbs-iscc-r:lividbrown.19','lividbrown','livid brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:lividpink.4','lividpink','livid pink',[249,204,202],'f9ccca',16370890],
['nbs-iscc-r:lividpink.5','lividpink','livid pink',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:lividpink.7','lividpink','livid pink',[234,216,215],'ead8d7',15390935],
['nbs-iscc-r:lividpink.8','lividpink','livid pink',[196,174,173],'c4aead',12889773],
['nbs-iscc-r:lividpurple.241','lividpurple','livid purple',[145,92,131],'915c83',9526403],
['nbs-iscc-r:lividviolet.223','lividviolet','livid violet',[134,96,142],'86608e',8806542],
['nbs-iscc-r:lividviolet.228','lividviolet','livid violet',[121,104,120],'796878',7956600],
['nbs-iscc-r:lobeliaviolet.222','lobeliaviolet','lobelia violet',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:lumiereblue.163','lumiereblue','lumiere blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:lumiereblue.172','lumiereblue','lumiere blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-r:lumieregreen.119','lumieregreen','lumiere green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:lumieregreen.120','lumieregreen','lumiere green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:lyonsblue.178','lyonsblue','lyons blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:madderblue.214','madderblue','madder blue',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:madderblue.228','madderblue','madder blue',[121,104,120],'796878',7956600],
['nbs-iscc-r:madderbrown.19','madderbrown','madder brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:madderviolet.224','madderviolet','madder violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:magenta.237','magenta','magenta',[158,79,136],'9e4f88',10375048],
['nbs-iscc-r:mahoganyred.43','mahoganyred','mahogany red',[121,68,59],'79443b',7947323],
['nbs-iscc-r:maizeyellow.86','maizeyellow','maize yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:malachitegreen.135','malachitegreen','malachite green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:mallowpink.247','mallowpink','mallow pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-r:mallowpurple.236','mallowpurple','mallow purple',[135,0,116],'870074',8847476],
['nbs-iscc-r:mallowpurple.248','mallowpurple','mallow purple',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:manganeseviolet.218','manganeseviolet','manganese violet',[135,86,146],'875692',8869522],
['nbs-iscc-r:margueriteyellow.89','margueriteyellow','marguerite yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-r:marineblue.182','marineblue','marine blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:maroon.44','maroon','maroon',[62,29,30],'3e1d1e',4070686],
['nbs-iscc-r:marsbrown.58','marsbrown','mars brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:marsorange.37','marsorange','mars orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:marsorange.38','marsorange','mars orange',[158,71,50],'9e4732',10372914],
['nbs-iscc-r:marsviolet.229','marsviolet','mars violet',[80,64,77],'50404d',5259341],
['nbs-iscc-r:marsyellow.69','marsyellow','mars yellow',[201,133,0],'c98500',13206784],
['nbs-iscc-r:marsyellow.72','marsyellow','mars yellow',[190,138,61],'be8a3d',12487229],
['nbs-iscc-r:martiusyellow.101','martiusyellow','martius yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:massicotyellow.86','massicotyellow','massicot yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:massicotyellow.89','massicotyellow','massicot yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-r:mathewsblue.178','mathewsblue','mathew\'s blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:mathewspurple.218','mathewspurple','mathew\'s purple',[135,86,146],'875692',8869522],
['nbs-iscc-r:mathewspurple.223','mathewspurple','mathew\'s purple',[134,96,142],'86608e',8806542],
['nbs-iscc-r:mauve.206','mauve','mauve',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:mauvette.249','mauvette','mauvette',[239,187,204],'efbbcc',15711180],
['nbs-iscc-r:mazarineblue.177','mazarineblue','mazarine blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-r:mazarineblue.181','mazarineblue','mazarine blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:meadowgreen.136','meadowgreen','meadow green',[103,146,103],'679267',6787687],
['nbs-iscc-r:medalbronze.95','medalbronze','medal bronze',[108,84,30],'6c541e',7099422],
['nbs-iscc-r:mediciblue.191','mediciblue','medici blue',[129,135,139],'81878b',8488843],
['nbs-iscc-r:methylblue.176','methylblue','methyl blue ',[0,161,194],'00a1c2',41410],
['nbs-iscc-r:methylgreen.160','methylgreen','methyl green ',[0,122,116],'007a74',31348],
['nbs-iscc-r:methylgreen.164','methylgreen','methyl green ',[49,120,115],'317873',3242099],
['nbs-iscc-r:microclinegreen.162','microclinegreen','microcline green ',[150,222,209],'96ded1',9887441],
['nbs-iscc-r:mignonettegreen.106','mignonettegreen','mignonette green ',[134,126,54],'867e36',8814134],
['nbs-iscc-r:mikadobrown.57','mikadobrown','mikado brown ',[166,123,91],'a67b5b',10910555],
['nbs-iscc-r:mikadoorange.50','mikadoorange','mikado orange ',[237,135,45],'ed872d',15566637],
['nbs-iscc-r:mineralgray.122','mineralgray','mineral gray ',[143,151,121],'8f9779',9410425],
['nbs-iscc-r:mineralgreen.117','mineralgreen','mineral green ',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-r:mineralred.19','mineralred','mineral red ',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:montpelliergreen.144','montpelliergreen','montpellier green ',[106,171,142],'6aab8e',6990734],
['nbs-iscc-r:montpelliergreen.145','montpelliergreen','montpellier green ',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:moroccored.43','moroccored','morocco red ',[121,68,59],'79443b',7947323],
['nbs-iscc-r:motmotblue.173','motmotblue','motmot blue ',[54,117,136],'367588',3569032],
['nbs-iscc-r:motmotgreen.131','motmotgreen','motmot green ',[68,148,74],'44944a',4494410],
['nbs-iscc-r:motmotgreen.136','motmotgreen','motmot green ',[103,146,103],'679267',6787687],
['nbs-iscc-r:mousegray.63','mousegray','mouse gray ',[142,130,121],'8e8279',9339513],
['nbs-iscc-r:mulberrypurple.219','mulberrypurple','mulberry purple ',[96,47,107],'602f6b',6303595],
['nbs-iscc-r:mulberrypurple.224','mulberrypurple','mulberry purple ',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:mummybrown.78','mummybrown','mummy brown ',[75,54,33],'4b3621',4929057],
['nbs-iscc-r:munichlake.11','munichlake','munich lake ',[190,0,50],'be0032',12451890],
['nbs-iscc-r:munichlake.12','munichlake','munich lake ',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-r:mustardyellow.84','mustardyellow','mustard yellow ',[212,175,55],'d4af37',13938487],
['nbs-iscc-r:myrtlegreen.165','myrtlegreen','myrtle green ',[0,75,73],'004b49',19273],
['nbs-iscc-r:mythogreen.120','mythogreen','mytho green ',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:mythogreen.122','mythogreen','mytho green ',[143,151,121],'8f9779',9410425],
['nbs-iscc-r:naphthaleneviolet.242','naphthaleneviolet','naphthalene violet ',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:naphthaleneyellow.101','naphthaleneyellow','naphthalene yellow ',[234,230,121],'eae679',15394425],
['nbs-iscc-r:naphthaleneyellow.104','naphthaleneyellow','naphthalene yellow ',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-r:naplesyellow.86','naplesyellow','naples yellow ',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:natalbrown.61','natalbrown','natal brown',[99,81,71],'635147',6508871],
['nbs-iscc-r:navyblue.200','navyblue','navy blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:navyblue.204','navyblue','navy blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:neropalinblue.181','neropalinblue','neropalin blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:neutralgray.265','neutralgray','neutral gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:neutralred.259','neutralred','neutral red',[103,49,71],'673147',6762823],
['nbs-iscc-r:neutralred.262','neutralred','neutral red',[145,95,109],'915f6d',9527149],
['nbs-iscc-r:neuvidergreen.135','neuvidergreen','neuvider green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:nevagreen.116','nevagreen','neva green',[189,218,87],'bdda57',12442199],
['nbs-iscc-r:niagaragreen.149','niagaragreen','niagara green',[141,163,153],'8da399',9282457],
['nbs-iscc-r:niagaragreen.163','niagaragreen','niagara green',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:nickelgreen.145','nickelgreen','nickel green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:nickelgreen.150','nickelgreen','nickel green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:nightgreen.115','nightgreen','night green',[141,182,0],'8db600',9287168],
['nbs-iscc-r:nigrosinblue.204','nigrosinblue','nigrosin blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:nigrosinviolet.224','nigrosinviolet','nigrosin violet ',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:nileblue.163','nileblue','nile blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:nopalred.12','nopalred','nopal red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-r:ocherred.19','ocherred','ocher red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:ochraceousbuff.28','ochraceousbuff','ochraceous-buff',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:ochraceousbuff.29','ochraceousbuff','ochraceous-buff',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:ochraceousorange.68','ochraceousorange','ochraceous-orange',[234,162,33],'eaa221',15376929],
['nbs-iscc-r:ochraceousorange.69','ochraceousorange','ochraceous-orange',[201,133,0],'c98500',13206784],
['nbs-iscc-r:ochraceoussalmon.53','ochraceoussalmon','ochraceous-salmon',[217,144,88],'d99058',14258264],
['nbs-iscc-r:ochraceoustawny.72','ochraceoustawny','ochraceous-tawny',[190,138,61],'be8a3d',12487229],
['nbs-iscc-r:ochraceoustawny.74','ochraceoustawny','ochraceous-tawny',[153,101,21],'996515',10052885],
['nbs-iscc-r:oilgreen.120','oilgreen','oil green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:oldburgundy.21','oldburgundy','old burgundy',[46,29,33],'2e1d21',3022113],
['nbs-iscc-r:oldgold.88','oldgold','old gold',[171,145,68],'ab9144',11243844],
['nbs-iscc-r:oldgold.94','oldgold','old gold',[150,113,23],'967117',9859351],
['nbs-iscc-r:oldrose.15','oldrose','old rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-r:olive.107','olive','olive',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:olive.110','olive','olive',[91,88,66],'5b5842',5986370],
['nbs-iscc-r:olivebrown.80','olivebrown','olive-brown ',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-r:olivebuff.89','olivebuff','olive-buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-r:olivebuff.90','olivebuff','olive-buff',[194,178,128],'c2b280',12759680],
['nbs-iscc-r:olivecitrine.107','olivecitrine','olive-citrine',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:olivegray.109','olivegray','olive-gray ',[140,135,103],'8c8767',9209703],
['nbs-iscc-r:olivegray.112','olivegray','olive-gray ',[138,135,118],'8a8776',9078646],
['nbs-iscc-r:olivegreen.107','olivegreen','olive green',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:olivelake.91','olivelake','olive lake',[161,143,96],'a18f60',10588000],
['nbs-iscc-r:olivelake.106','olivelake','olive lake',[134,126,54],'867e36',8814134],
['nbs-iscc-r:oliveocher.87','oliveocher','olive-ocher',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:oliveocher.88','oliveocher','olive-ocher',[171,145,68],'ab9144',11243844],
['nbs-iscc-r:oliveyellow.102','oliveyellow','olive-yellow ',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:olivine.135','olivine','olivine',[147,197,146],'93c592',9684370],
['nbs-iscc-r:olympicblue.178','olympicblue','olympic blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:onionskinpink.29','onionskinpink','onion-skin pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:onionskinpink.53','onionskinpink','onion-skin pink',[217,144,88],'d99058',14258264],
['nbs-iscc-r:ontarioviolet.210','ontarioviolet','ontario violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:opalinegreen.119','opalinegreen','opaline green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:opalinegreen.121','opalinegreen','opaline green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:orange.50','orange','orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-r:orangebuff.71','orangebuff','orange-buff ',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:orangechrome.48','orangechrome','orange chrome',[243,132,0],'f38400',15959040],
['nbs-iscc-r:orangecinnamon.53','orangecinnamon','orange-cinnamon',[217,144,88],'d99058',14258264],
['nbs-iscc-r:orangecitrine.94','orangecitrine','orange-citrine',[150,113,23],'967117',9859351],
['nbs-iscc-r:orangepink.49','orangepink','orange-pink',[253,148,63],'fd943f',16618559],
['nbs-iscc-r:orangepink.52','orangepink','orange-pink',[250,181,127],'fab57f',16430463],
['nbs-iscc-r:orangerufous.51','orangerufous','orange-rufous ',[190,101,22],'be6516',12477718],
['nbs-iscc-r:orangevinaceous.3','orangevinaceous','orange-vinaceous ',[228,113,122],'e4717a',14971258],
['nbs-iscc-r:orangevinaceous.26','orangevinaceous','orange-vinaceous ',[248,131,121],'f88379',16286585],
['nbs-iscc-r:orientalgreen.136','orientalgreen','oriental green',[103,146,103],'679267',6787687],
['nbs-iscc-r:orientblue.182','orientblue','orient blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:orientblue.186','orientblue','orient blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:orientpink.26','orientpink','orient pink',[248,131,121],'f88379',16286585],
['nbs-iscc-r:ouralgreen.134','ouralgreen','oural green',[182,229,175],'b6e5af',11986351],
['nbs-iscc-r:ouralgreen.135','ouralgreen','oural green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:oxbloodred.13','oxbloodred','ox-blood red ',[132,27,45],'841b2d',8657709],
['nbs-iscc-r:oxideblue.178','oxideblue','oxide blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:oxideblue.182','oxideblue','oxide blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:paleamaranthpink.247','paleamaranthpink','pale amaranth pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-r:paleamparoblue.184','paleamparoblue','pale amparo blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:paleamparoblue.185','paleamparoblue','pale amparo blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:paleamparopurple.222','paleamparopurple','pale amparo purple',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:paleanilinelilac.180','paleanilinelilac','pale aniline lilac',[161,202,241],'a1caf1',10603249],
['nbs-iscc-r:paleanilinelilac.181','paleanilinelilac','pale aniline lilac',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:paleblue.171','paleblue','pale blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-r:paleblue.184','paleblue','pale blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:palebluegreen.148','palebluegreen','pale blue-green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:paleblueviolet.195','paleblueviolet','pale blue-violet',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:palebluishlavender.213','palebluishlavender','pale bluish lavender ',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-r:palebluishlavender.226','palebluishlavender','pale bluish lavender ',[214,202,221],'d6cadd',14076637],
['nbs-iscc-r:palebluishviolet.195','palebluishviolet','pale bluish violet',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:palebrownishdrab.10','palebrownishdrab','pale brownish drab',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-r:palebrownishvinaceous.7','palebrownishvinaceous','pale brownish vinaceous',[234,216,215],'ead8d7',15390935],
['nbs-iscc-r:palebrownishvinaceous.8','palebrownishvinaceous','pale brownish vinaceous',[196,174,173],'c4aead',12889773],
['nbs-iscc-r:palecadetblue.181','palecadetblue','pale cadet blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:palecadetblue.185','palecadetblue','pale cadet blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:palecadetblue.199','palecadetblue','pale cadet blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:palecadetblue.203','palecadetblue','pale cadet blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:palecampanulablue.198','palecampanulablue','pale campanula blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-r:palecampanulablue.199','palecampanulablue','pale campanula blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:palecendregreen.119','palecendregreen','pale cendre green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:palecendregreen.121','palecendregreen','pale cendre green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:paleceruleanblue.180','paleceruleanblue','pale cerulean blue',[161,202,241],'a1caf1',10603249],
['nbs-iscc-r:paleceruleanblue.181','paleceruleanblue','pale cerulean blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:palechalcedonyyellow.104','palechalcedonyyellow','pale chalcedony yellow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-r:palecinnamonpink.28','palecinnamonpink','pale cinnamon-pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:palecinnamonpink.29','palecinnamonpink','pale cinnamon-pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:palecinnamonpink.31','palecinnamonpink','pale cinnamon-pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:palecinnamonpink.33','palecinnamonpink','pale cinnamon-pink',[194,172,153],'c2ac99',12758169],
['nbs-iscc-r:palecongopink.28','palecongopink','pale congo pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:palecongopink.29','palecongopink','pale congo pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:palecongopink.31','palecongopink','pale congo pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:palecongopink.32','palecongopink','pale congo pink',[199,173,163],'c7ada3',13086115],
['nbs-iscc-r:paledrabgray.263','paledrabgray','pale drab-gray',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-r:paledrabgray.264','paledrabgray','pale drab-gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-r:paledullglaucousblue.184','paledullglaucousblue','pale dull glaucous-blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:paledullglaucousblue.185','paledullglaucousblue','pale dull glaucous-blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:paledullgreenyellow.119','paledullgreenyellow','pale dull green-yellow',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:paleecrudrab.10','paleecrudrab','pale ecru-drab',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-r:palefleshcolor.28','palefleshcolor','pale flesh color',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:palefleshcolor.29','palefleshcolor','pale flesh color',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:palefluoritegreen.148','palefluoritegreen','pale fluorite green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:paleglassgreen.119','paleglassgreen','pale glass green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:paleglassgreen.121','paleglassgreen','pale glass green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:paleglaucousblue.171','paleglaucousblue','pale glaucous-blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-r:paleglaucousblue.184','paleglaucousblue','pale glaucous-blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:paleglaucousgreen.148','paleglaucousgreen','pale glaucous-green ',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:palegrayishblue.184','palegrayishblue','pale grayish blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:palegrayishblue.202','palegrayishblue','pale grayish blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-r:palegrayishblueviolet.202','palegrayishblueviolet','pale grayish blue-violet',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-r:palegrayishvinaceous.10','palegrayishvinaceous','pale grayish vinaceous',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-r:palegrayishvinaceous.31','palegrayishvinaceous','pale grayish vinaceous',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:palegrayishvinaceous.32','palegrayishvinaceous','pale grayish vinaceous',[199,173,163],'c7ada3',13086115],
['nbs-iscc-r:palegrayishvioletblue.199','palegrayishvioletblue','pale grayish violet-blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:palegreenbluegray.185','palegreenbluegray','pale green-blue gray',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:palegreenishyellow.101','palegreenishyellow','pale greenish yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:palegreenishyellow.102','palegreenishyellow','pale greenish yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:palegreenyellow.101','palegreenyellow','pale green-yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:palegreenyellow.104','palegreenyellow','pale green-yellow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-r:palegullgray.264','palegullgray','pale gull gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-r:palehortenseviolet.221','palehortenseviolet','pale hortense violet',[213,186,219],'d5badb',14007003],
['nbs-iscc-r:palehortenseviolet.222','palehortenseviolet','pale hortense violet',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:palekingsblue.213','palekingsblue','pale king\'s blue',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-r:palelaeliapink.249','palelaeliapink','pale laelia pink ',[239,187,204],'efbbcc',15711180],
['nbs-iscc-r:palelaeliapink.250','palelaeliapink','pale laelia pink ',[213,151,174],'d597ae',13997998],
['nbs-iscc-r:palelavenderviolet.222','palelavenderviolet','pale lavender-violet',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:palelavenderviolet.227','palelavenderviolet','pale lavender-violet',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:palelemonyellow.98','palelemonyellow','pale lemon yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-r:palelilac.252','palelilac','pale lilac',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-r:palelobeliaviolet.226','palelobeliaviolet','pale lobelia violet',[214,202,221],'d6cadd',14076637],
['nbs-iscc-r:palelobeliaviolet.227','palelobeliaviolet','pale lobelia violet',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:palelumieregreen.119','palelumieregreen','pale lumiere green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:palemauve.226','palemauve','pale mauve',[214,202,221],'d6cadd',14076637],
['nbs-iscc-r:palemazarineblue.184','palemazarineblue','pale mazarine blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:palemazarineblue.185','palemazarineblue','pale mazarine blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:palemazarineblue.202','palemazarineblue','pale mazarine blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-r:palemazarineblue.203','palemazarineblue','pale mazarine blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:palemediciblue.185','palemediciblue','pale medici blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:palemediciblue.190','palemediciblue','pale medici blue',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-r:palemediciblue.191','palemediciblue','pale medici blue',[129,135,139],'81878b',8488843],
['nbs-iscc-r:palemethylblue.181','palemethylblue','pale methyl blue ',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:palemousegray.63','palemousegray','pale mouse gray ',[142,130,121],'8e8279',9339513],
['nbs-iscc-r:palemousegray.93','palemousegray','pale mouse gray ',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-r:paleneropalinblue.184','paleneropalinblue','pale neropalin blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:paleneutralgray.265','paleneutralgray','pale neutral gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:paleniagaragreen.148','paleniagaragreen','pale niagara green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:palenileblue.162','palenileblue','pale nile blue',[150,222,209],'96ded1',9887441],
['nbs-iscc-r:paleochraceousbuff.28','paleochraceousbuff','pale ochraceous-buff',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:paleochraceoussalmon.73','paleochraceoussalmon','pale ochraceous-salmon',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:paleochraceoussalmon.89','paleochraceoussalmon','pale ochraceous-salmon',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-r:paleolivebuff.89','paleolivebuff','pale olive-buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-r:paleolivegray.92','paleolivegray','pale olive-gray',[240,234,214],'f0ead6',15788758],
['nbs-iscc-r:paleolivegray.93','paleolivegray','pale olive-gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-r:paleolivine.148','paleolivine','pale olivine',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-r:paleorangeyellow.70','paleorangeyellow','pale orange-yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-r:paleorangeyellow.71','paleorangeyellow','pale orange-yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:paleorangeyellow.83','paleorangeyellow','pale orange-yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-r:paleorangeyellow.84','paleorangeyellow','pale orange-yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-r:paleorangeyellow.86','paleorangeyellow','pale orange-yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:paleorangeyellow.87','paleorangeyellow','pale orange-yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:palepaynesgray.185','palepaynesgray','pale payne\'s gray',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:palepersianlilac.250','palepersianlilac','pale persian lilac',[213,151,174],'d597ae',13997998],
['nbs-iscc-r:palepinkishbuff.73','palepinkishbuff','pale pinkish buff',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:palepinkishcinnamon.73','palepinkishcinnamon','pale pinkish cinnamon',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:palepurpledrab.253','palepurpledrab','pale purple-drab',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-r:palepurplishgray.233','palepurplishgray','pale purplish gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:palepurplishvinaceous.4','palepurplishvinaceous','pale purplish vinaceous',[249,204,202],'f9ccca',16370890],
['nbs-iscc-r:palepurplishvinaceous.5','palepurplishvinaceous','pale purplish vinaceous',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:palequakerdrab.232','palequakerdrab','pale quaker drab',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-r:palequakerdrab.233','palequakerdrab','pale quaker drab',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:palerhodonitepink.249','palerhodonitepink','pale rhodonite pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-r:palerosepurple.222','palerosepurple','pale rose-purple ',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:palerosolanepurple.248','palerosolanepurple','pale rosolane purple',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:palerussianblue.184','palerussianblue','pale russian blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:palesalmoncolor.73','palesalmoncolor','pale salmon color',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:palesmokegray.93','palesmokegray','pale smoke gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-r:palesoftblueviolet.199','palesoftblueviolet','pale soft blue-violet',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:palesoftblueviolet.210','palesoftblueviolet','pale soft blue-violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:palesulphategreen.163','palesulphategreen','pale sulphate green',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:paletibergreen.119','paletibergreen','pale tiber green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:paleturquoisegreen.162','paleturquoisegreen','pale turquoise green',[150,222,209],'96ded1',9887441],
['nbs-iscc-r:paleturtlegreen.119','paleturtlegreen','pale turtle green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:paleturtlegreen.121','paleturtlegreen','pale turtle green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:palevarleysgray.214','palevarleysgray','pale varley\'s gray ',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:palevarleysgray.227','palevarleysgray','pale varley\'s gray ',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:paleverbenaviolet.209','paleverbenaviolet','pale verbena violet',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-r:paleveronesegreen.119','paleveronesegreen','pale veronese green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:paleveronesegreen.121','paleveronesegreen','pale veronese green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:palevinaceous.5','palevinaceous','pale vinaceous',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:palevinaceousdrab.8','palevinaceousdrab','pale vinaceous-drab',[196,174,173],'c4aead',12889773],
['nbs-iscc-r:palevinaceousdrab.10','palevinaceousdrab','pale vinaceous-drab',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-r:palevinaceousdrab.18','palevinaceousdrab','pale vinaceous-drab',[173,136,132],'ad8884',11372676],
['nbs-iscc-r:palevinaceousdrab.22','palevinaceousdrab','pale vinaceous-drab',[143,129,127],'8f817f',9404799],
['nbs-iscc-r:palevinaceousfawn.10','palevinaceousfawn','pale vinaceous-fawn',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-r:palevinaceousfawn.31','palevinaceousfawn','pale vinaceous-fawn',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:palevinaceousfawn.32','palevinaceousfawn','pale vinaceous-fawn',[199,173,163],'c7ada3',13086115],
['nbs-iscc-r:palevinaceousfawn.33','palevinaceousfawn','pale vinaceous-fawn',[194,172,153],'c2ac99',12758169],
['nbs-iscc-r:palevinaceouslilac.249','palevinaceouslilac','pale vinaceous-lilac',[239,187,204],'efbbcc',15711180],
['nbs-iscc-r:palevinaceouslilac.252','palevinaceouslilac','pale vinaceous-lilac',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-r:palevinaceouspink.31','palevinaceouspink','pale vinaceous-pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:palevinaceouspink.32','palevinaceouspink','pale vinaceous-pink',[199,173,163],'c7ada3',13086115],
['nbs-iscc-r:paleviolet.199','paleviolet','pale violet',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:paleviolet.210','paleviolet','pale violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:palevioletblue.177','palevioletblue','pale violet-blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-r:palevioletgray.233','palevioletgray','pale violet-gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:palevioletgray.265','palevioletgray','pale violet-gray',[132,132,130],'848482',8684674],
['nbs-iscc-r:palevioletplumbeous.185','palevioletplumbeous','pale violet-plumbeous ',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:palevioletplumbeous.203','palevioletplumbeous','pale violet-plumbeous ',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:paleviridineyellow.101','paleviridineyellow','pale viridine yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:paleviridineyellow.104','paleviridineyellow','pale viridine yellow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-r:palewindsorblue.181','palewindsorblue','pale windsor blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:palewindsorblue.199','palewindsorblue','pale windsor blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:palewistariablue.209','palewistariablue','pale wistaria blue',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-r:palewistariablue.210','palewistariablue','pale wistaria blue',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:palewistariaviolet.210','palewistariaviolet','pale wistaria violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:palewistariaviolet.214','palewistariaviolet','pale wistaria violet',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:paleyellowgreen.119','paleyellowgreen','pale yellow-green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:paleyelloworange.28','paleyelloworange','pale yellow-orange',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:pallidblueviolet.198','pallidblueviolet','pallid blue-violet',[179,188,226],'b3bce2',11779298],
['nbs-iscc-r:pallidblueviolet.199','pallidblueviolet','pallid blue-violet',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:pallidbluishviolet.198','pallidbluishviolet','pallid bluish violet',[179,188,226],'b3bce2',11779298],
['nbs-iscc-r:pallidbluishviolet.199','pallidbluishviolet','pallid bluish violet',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:pallidbluishviolet.209','pallidbluishviolet','pallid bluish violet',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-r:pallidbluishviolet.210','pallidbluishviolet','pallid bluish violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:pallidbrownishdrab.10','pallidbrownishdrab','pallid brownish drab',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-r:pallidgrayishvioletblue.199','pallidgrayishvioletblue','pallid grayish violet-blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:pallidgrayishvioletblue.203','pallidgrayishvioletblue','pallid grayish violet-blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:pallidmethylblue.180','pallidmethylblue','pallid methyl blue ',[161,202,241],'a1caf1',10603249],
['nbs-iscc-r:pallidmousegray.10','pallidmousegray','pallid mouse gray ',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-r:pallidmousegray.264','pallidmousegray','pallid mouse gray ',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-r:pallidneutralgray.264','pallidneutralgray','pallid neutral gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-r:pallidpurpledrab.232','pallidpurpledrab','pallid purple-drab',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-r:pallidpurpledrab.253','pallidpurpledrab','pallid purple-drab',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-r:pallidpurplishgray.232','pallidpurplishgray','pallid purplish gray ',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-r:pallidquakerdrab.232','pallidquakerdrab','pallid quaker drab',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-r:pallidsoftblueviolet.198','pallidsoftblueviolet','pallid soft blue-violet ',[179,188,226],'b3bce2',11779298],
['nbs-iscc-r:pallidsoftblueviolet.199','pallidsoftblueviolet','pallid soft blue-violet ',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:pallidsoftblueviolet.209','pallidsoftblueviolet','pallid soft blue-violet ',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-r:pallidsoftblueviolet.210','pallidsoftblueviolet','pallid soft blue-violet ',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:pallidvinaceousdrab.232','pallidvinaceousdrab','pallid vinaceous-drab',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-r:pallidvinaceousdrab.252','pallidvinaceousdrab','pallid vinaceous-drab',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-r:pallidviolet.198','pallidviolet','pallid violet',[179,188,226],'b3bce2',11779298],
['nbs-iscc-r:pallidviolet.199','pallidviolet','pallid violet',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:pallidviolet.202','pallidviolet','pallid violet',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-r:pallidviolet.203','pallidviolet','pallid violet',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:pallidviolet.209','pallidviolet','pallid violet',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-r:pallidviolet.210','pallidviolet','pallid violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:pallidviolet.213','pallidviolet','pallid violet',[196,195,221],'c4c3dd',12895197],
['nbs-iscc-r:pallidviolet.214','pallidviolet','pallid violet',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:pallidvioletblue.198','pallidvioletblue','pallid violet-blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-r:pallidvioletblue.199','pallidvioletblue','pallid violet-blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:pansypurple.259','pansypurple','pansy purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:pansyviolet.218','pansyviolet','pansy violet',[135,86,146],'875692',8869522],
['nbs-iscc-r:parisblue.178','parisblue','paris blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:parisblue.179','parisblue','paris blue',[0,65,106],'00416a',16746],
['nbs-iscc-r:parisgreen.135','parisgreen','paris green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:parrotgreen.120','parrotgreen','parrot green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:parulablue.185','parulablue','parula blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:parulablue.186','parulablue','parula blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:patentblue.174','patentblue','patent blue',[0,73,88],'004958',18776],
['nbs-iscc-r:paynesgray.186','paynesgray','payne\'s gray',[83,104,120],'536878',5466232],
['nbs-iscc-r:peachred.37','peachred','peach red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:peacockblue.169','peacockblue','peacock blue',[0,119,145],'007791',30609],
['nbs-iscc-r:peacockgreen.120','peacockgreen','peacock green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:peagreen.155','peagreen','pea green',[125,137,132],'7d8984',8227204],
['nbs-iscc-r:pearlblue.202','pearlblue','pearl blue',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-r:pearlblue.203','pearlblue','pearl blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:pearlgray.264','pearlgray','pearl gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-r:pecanbrown.57','pecanbrown','pecan brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-r:perillapurple.259','perillapurple','perilla purple',[103,49,71],'673147',6762823],
['nbs-iscc-r:persianblue.184','persianblue','persian blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:persianblue.185','persianblue','persian blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:persianlilac.251','persianlilac','persian lilac',[193,126,145],'c17e91',12680849],
['nbs-iscc-r:petuniaviolet.219','petuniaviolet','petunia violet',[96,47,107],'602f6b',6303595],
['nbs-iscc-r:phenylblue.194','phenylblue','phenyl blue',[48,38,122],'30267a',3155578],
['nbs-iscc-r:phloxpink.222','phloxpink','phlox pink',[182,149,192],'b695c0',11965888],
['nbs-iscc-r:phloxpurple.237','phloxpurple','phlox purple',[158,79,136],'9e4f88',10375048],
['nbs-iscc-r:picricyellow.98','picricyellow','picric yellow',[233,228,80],'e9e450',15328336],
['nbs-iscc-r:pinardyellow.83','pinardyellow','pinard yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-r:pinardyellow.86','pinardyellow','pinard yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:pinkishbuff.28','pinkishbuff','pinkish buff',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:pinkishbuff.29','pinkishbuff','pinkish buff',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:pinkishcinnamon.71','pinkishcinnamon','pinkish cinnamon',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:pinkishcinnamon.76','pinkishcinnamon','pinkish cinnamon',[193,154,107],'c19a6b',12687979],
['nbs-iscc-r:pinkishvinaceous.29','pinkishvinaceous','pinkish vinaceous',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:pistachiogreen.136','pistachiogreen','pistachio green',[103,146,103],'679267',6787687],
['nbs-iscc-r:pleromaviolet.206','pleromaviolet','pleroma violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:pleromaviolet.207','pleromaviolet','pleroma violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:plumbagoblue.214','plumbagoblue','plumbago blue',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:plumbagoblue.227','plumbagoblue','plumbago blue',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:plumbagogray.233','plumbagogray','plumbago gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:plumbeous.185','plumbeous','plumbeous',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:plumbeous.191','plumbeous','plumbeous',[129,135,139],'81878b',8488843],
['nbs-iscc-r:plumbeousblack.187','plumbeousblack','plumbeous black ',[54,69,79],'36454f',3556687],
['nbs-iscc-r:plumbeousblack.267','plumbeousblack','plumbeous black ',[34,34,34],'222222',2236962],
['nbs-iscc-r:plumpurple.212','plumpurple','plum purple',[47,33,64],'2f2140',3088704],
['nbs-iscc-r:poisgreen.122','poisgreen','pois green',[143,151,121],'8f9779',9410425],
['nbs-iscc-r:pompeianred.15','pompeianred','pompeian red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-r:porcelainblue.172','porcelainblue','porcelain blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-r:porcelaingreen.164','porcelaingreen','porcelain green',[49,120,115],'317873',3242099],
['nbs-iscc-r:primroseyellow.101','primroseyellow','primrose yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:primulineyellow.84','primulineyellow','primuline yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-r:proutsbrown.58','proutsbrown','prout\'s brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:prunepurple.224','prunepurple','prune purple',[86,60,92],'563c5c',5651548],
['nbs-iscc-r:prussianblue.178','prussianblue','prussian blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:prussianblue.182','prussianblue','prussian blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:prussiangreen.165','prussiangreen','prussian green',[0,75,73],'004b49',19273],
['nbs-iscc-r:prussianred.19','prussianred','prussian red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:puritangray.191','puritangray','puritan gray',[129,135,139],'81878b',8488843],
['nbs-iscc-r:purple.236','purple','purple',[135,0,116],'870074',8847476],
['nbs-iscc-r:purpledrab.228','purpledrab','purple-drab',[121,104,120],'796878',7956600],
['nbs-iscc-r:purplishgray.228','purplishgray','purplish gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:purplishgray.234','purplishgray','purplish gray',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:purplishlilac.240','purplishlilac','purplish lilac',[183,132,167],'b784a7',12027047],
['nbs-iscc-r:purplishlilac.250','purplishlilac','purplish lilac',[213,151,174],'d597ae',13997998],
['nbs-iscc-r:purplishvinaceous.18','purplishvinaceous','purplish vinaceous',[173,136,132],'ad8884',11372676],
['nbs-iscc-r:pyriteyellow.103','pyriteyellow','pyrite yellow',[152,148,62],'98943e',9999422],
['nbs-iscc-r:quakerdrab.233','quakerdrab','quaker drab',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:quakerdrab.265','quakerdrab','quaker drab',[132,132,130],'848482',8684674],
['nbs-iscc-r:rainettegreen.120','rainettegreen','rainette green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:raisinblack.229','raisinblack','raisin black',[80,64,77],'50404d',5259341],
['nbs-iscc-r:raisinpurple.242','raisinpurple','raisin purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-r:ramierblue.214','ramierblue','ramier blue',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:ramierblue.215','ramierblue','ramier blue',[85,76,105],'554c69',5590121],
['nbs-iscc-r:ramierblue.228','ramierblue','ramier blue',[121,104,120],'796878',7956600],
['nbs-iscc-r:rawsienna.72','rawsienna','raw sienna',[190,138,61],'be8a3d',12487229],
['nbs-iscc-r:rawsienna.74','rawsienna','raw sienna',[153,101,21],'996515',10052885],
['nbs-iscc-r:reedyellow.102','reedyellow','reed yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:rejanegreen.135','rejanegreen','rejane green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:rejanegreen.136','rejanegreen','rejane green',[103,146,103],'679267',6787687],
['nbs-iscc-r:rhodaminepurple.254','rhodaminepurple','rhodamine purple',[206,70,118],'ce4676',13518454],
['nbs-iscc-r:rhodonitepink.251','rhodonitepink','rhodonite pink',[193,126,145],'c17e91',12680849],
['nbs-iscc-r:rinnemannsgreen.120','rinnemannsgreen','rinnemann\'s green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:rivagegreen.119','rivagegreen','rivage green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:rivagegreen.120','rivagegreen','rivage green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:rocellinpurple.248','rocellinpurple','rocellin purple',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:rocellinpurple.251','rocellinpurple','rocellin purple',[193,126,145],'c17e91',12680849],
['nbs-iscc-r:romangreen.107','romangreen','roman green',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:roodsblue.176','roodsblue','rood\'s blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-r:roodsbrown.45','roodsbrown','rood\'s brown',[151,127,115],'977f73',9928563],
['nbs-iscc-r:roodsbrown.57','roodsbrown','rood\'s brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-r:roodsbrown.58','roodsbrown','rood\'s brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:roodslavender.227','roodslavender','rood\'s lavender',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:roodsviolet.238','roodsviolet','rood\'s violet',[112,41,99],'702963',7350627],
['nbs-iscc-r:rosecolor.248','rosecolor','rose color',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:rosecolor.254','rosecolor','rose color',[206,70,118],'ce4676',13518454],
['nbs-iscc-r:rosedoree.27','rosedoree','rose doree ',[230,103,97],'e66761',15099745],
['nbs-iscc-r:rosepink.249','rosepink','rose pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-r:rosepurple.217','rosepurple','rose-purple ',[211,153,230],'d399e6',13867494],
['nbs-iscc-r:rosered.11','rosered','rose red',[190,0,50],'be0032',12451890],
['nbs-iscc-r:roslynblue.197','roslynblue','roslyn blue',[39,36,88],'272458',2565208],
['nbs-iscc-r:roslynblue.200','roslynblue','roslyn blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:roslynblue.211','roslynblue','roslyn blue',[96,78,129],'604e81',6311553],
['nbs-iscc-r:rosolanepink.246','rosolanepink','rosolane pink',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-r:rosolanepink.249','rosolanepink','rosolane pink',[239,187,204],'efbbcc',15711180],
['nbs-iscc-r:rosolanepurple.255','rosolanepurple','rosolane purple',[179,68,108],'b3446c',11748460],
['nbs-iscc-r:royalpurple.211','royalpurple','royal purple',[96,78,129],'604e81',6311553],
['nbs-iscc-r:rufous.37','rufous','rufous',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:russet.58','russet','russet',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:russetvinaceous.19','russetvinaceous','russet-vinaceous',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:russetvinaceous.42','russetvinaceous','russet-vinaceous',[168,124,109],'a87c6d',11041901],
['nbs-iscc-r:russianblue.184','russianblue','russian blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:russianblue.185','russianblue','russian blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-r:russiangreen.150','russiangreen','russian green',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:saccardosolive.94','saccardosolive','saccardo\'s olive',[150,113,23],'967117',9859351],
['nbs-iscc-r:saccardosolive.95','saccardosolive','saccardo\'s olive',[108,84,30],'6c541e',7099422],
['nbs-iscc-r:saccardosslate.192','saccardosslate','saccardo\'s slate',[81,88,94],'51585e',5331038],
['nbs-iscc-r:saccardosumber.80','saccardosumber','saccardo\'s umber',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-r:saccardosumber.95','saccardosumber','saccardo\'s umber',[108,84,30],'6c541e',7099422],
['nbs-iscc-r:saccardosviolet.218','saccardosviolet','saccardo\'s violet',[135,86,146],'875692',8869522],
['nbs-iscc-r:saccardosviolet.223','saccardosviolet','saccardo\'s violet',[134,96,142],'86608e',8806542],
['nbs-iscc-r:safranopink.26','safranopink','safrano pink',[248,131,121],'f88379',16286585],
['nbs-iscc-r:sagegreen.149','sagegreen','sage green',[141,163,153],'8da399',9282457],
['nbs-iscc-r:sailorblue.196','sailorblue','sailor blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:salmonbuff.71','salmonbuff','salmon-buff ',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:salmonbuff.73','salmonbuff','salmon-buff ',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:salmoncolor.29','salmoncolor','salmon color',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:salmoncolor.52','salmoncolor','salmon color',[250,181,127],'fab57f',16430463],
['nbs-iscc-r:salmoncolor.53','salmoncolor','salmon color',[217,144,88],'d99058',14258264],
['nbs-iscc-r:salmonorange.50','salmonorange','salmon-orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-r:salviablue.194','salviablue','salvia blue',[48,38,122],'30267a',3155578],
['nbs-iscc-r:sanfordsbrown.54','sanfordsbrown','sanford\'s brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-r:sanfordsbrown.55','sanfordsbrown','sanford\'s brown',[128,70,27],'80461b',8406555],
['nbs-iscc-r:sayalbrown.74','sayalbrown','sayal brown',[153,101,21],'996515',10052885],
['nbs-iscc-r:sayalbrown.77','sayalbrown','sayal brown',[130,102,68],'826644',8545860],
['nbs-iscc-r:scarlet.35','scarlet','scarlet',[217,96,59],'d9603b',14245947],
['nbs-iscc-r:scarletred.11','scarletred','scarlet-red ',[190,0,50],'be0032',12451890],
['nbs-iscc-r:scheelesgreen.117','scheelesgreen','scheele\'s green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-r:scheelesgreen.120','scheelesgreen','scheele\'s green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:schoenfeldspurple.256','schoenfeldspurple','schoenfeld\'s purple',[120,24,74],'78184a',7870538],
['nbs-iscc-r:seafoamgreen.104','seafoamgreen','sea-foam green ',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-r:seafoamyellow.101','seafoamyellow','sea-foam yellow ',[234,230,121],'eae679',15394425],
['nbs-iscc-r:seafoamyellow.104','seafoamyellow','sea-foam yellow ',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-r:seagreen.164','seagreen','sea green',[49,120,115],'317873',3242099],
['nbs-iscc-r:sealbrown.23','sealbrown','seal brown',[92,80,79],'5c504f',6049871],
['nbs-iscc-r:sealbrown.46','sealbrown','seal brown',[103,76,71],'674c47',6769735],
['nbs-iscc-r:seashellpink.31','seashellpink','seashell pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:seashellpink.33','seashellpink','seashell pink',[194,172,153],'c2ac99',12758169],
['nbs-iscc-r:seashellpink.73','seashellpink','seashell pink',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:sepia.81','sepia','sepia',[72,60,50],'483c32',4734002],
['nbs-iscc-r:sepia.95','sepia','sepia',[108,84,30],'6c541e',7099422],
['nbs-iscc-r:serpentinegreen.106','serpentinegreen','serpentine green',[134,126,54],'867e36',8814134],
['nbs-iscc-r:shamrockgreen.136','shamrockgreen','shamrock green',[103,146,103],'679267',6787687],
['nbs-iscc-r:shellpink.31','shellpink','shell pink',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:shellpink.32','shellpink','shell pink',[199,173,163],'c7ada3',13086115],
['nbs-iscc-r:shrimppink.28','shrimppink','shrimp pink',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:shrimppink.29','shrimppink','shrimp pink',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:skobeloffgreen.160','skobeloffgreen','skobeloff green',[0,122,116],'007a74',31348],
['nbs-iscc-r:skyblue.181','skyblue','sky blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:skygray.184','skygray','sky gray',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-r:slateblack.267','slateblack','slate-black',[34,34,34],'222222',2236962],
['nbs-iscc-r:slateblue.204','slateblue','slate-blue ',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:slatecolor.266','slatecolor','slate color',[85,85,85],'555555',5592405],
['nbs-iscc-r:slategray.266','slategray','slate-gray',[85,85,85],'555555',5592405],
['nbs-iscc-r:slateolive.155','slateolive','slate-olive',[125,137,132],'7d8984',8227204],
['nbs-iscc-r:slatepurple.228','slatepurple','slate-purple',[121,104,120],'796878',7956600],
['nbs-iscc-r:slatepurple.245','slatepurple','slate-purple',[131,100,121],'836479',8610937],
['nbs-iscc-r:slateviolet.229','slateviolet','slate-violet ',[80,64,77],'50404d',5259341],
['nbs-iscc-r:slateviolet.234','slateviolet','slate-violet ',[93,85,91],'5d555b',6116699],
['nbs-iscc-r:slateviolet.228','slateviolet','slate-violet ',[121,104,120],'796878',7956600],
['nbs-iscc-r:smaltblue.194','smaltblue','smalt blue',[48,38,122],'30267a',3155578],
['nbs-iscc-r:smokegray.90','smokegray','smoke gray',[194,178,128],'c2b280',12759680],
['nbs-iscc-r:smokegray.93','smokegray','smoke gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-r:snuffbrown.77','snuffbrown','snuff brown',[130,102,68],'826644',8545860],
['nbs-iscc-r:snuffbrown.80','snuffbrown','snuff brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-r:softblueviolet.206','softblueviolet','soft blue-violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:softbluishviolet.207','softbluishviolet','soft bluish violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:sootyblack.266','sootyblack','sooty black',[85,85,85],'555555',5592405],
['nbs-iscc-r:sorghumbrown.46','sorghumbrown','sorghum brown',[103,76,71],'674c47',6769735],
['nbs-iscc-r:sorrentogreen.164','sorrentogreen','sorrento green',[49,120,115],'317873',3242099],
['nbs-iscc-r:spectrumblue.176','spectrumblue','spectrum blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-r:spectrumred.11','spectrumred','spectrum red',[190,0,50],'be0032',12451890],
['nbs-iscc-r:spectrumviolet.207','spectrumviolet','spectrum violet',[96,78,151],'604e97',6311575],
['nbs-iscc-r:spinachgreen.120','spinachgreen','spinach green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:spinelpink.255','spinelpink','spinel pink',[179,68,108],'b3446c',11748460],
['nbs-iscc-r:spinelred.255','spinelred','spinel red',[179,68,108],'b3446c',11748460],
['nbs-iscc-r:squillblue.181','squillblue','squill blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:stonegreen.136','stonegreen','stone green',[103,146,103],'679267',6787687],
['nbs-iscc-r:stormgray.155','stormgray','storm gray',[125,137,132],'7d8984',8227204],
['nbs-iscc-r:strawberrypink.37','strawberrypink','strawberry pink',[203,109,81],'cb6d51',13331793],
['nbs-iscc-r:strawyellow.86','strawyellow','straw yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-r:strontianyellow.99','strontianyellow','strontian yellow ',[190,183,46],'beb72e',12498734],
['nbs-iscc-r:sudanbrown.55','sudanbrown','sudan brown',[128,70,27],'80461b',8406555],
['nbs-iscc-r:sudanbrown.57','sudanbrown','sudan brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-r:sudanbrown.74','sudanbrown','sudan brown',[153,101,21],'996515',10052885],
['nbs-iscc-r:sulphategreen.163','sulphategreen','sulphate green',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:sulphategreen.164','sulphategreen','sulphate green',[49,120,115],'317873',3242099],
['nbs-iscc-r:sulphineyellow.88','sulphineyellow','sulphine yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-r:sulphuryellow.101','sulphuryellow','sulphur yellow',[234,230,121],'eae679',15394425],
['nbs-iscc-r:sulphuryellow.104','sulphuryellow','sulphur yellow',[235,232,164],'ebe8a4',15460516],
['nbs-iscc-r:taupebrown.229','taupebrown','taupe brown',[80,64,77],'50404d',5259341],
['nbs-iscc-r:tawny.54','tawny','tawny',[174,105,56],'ae6938',11430200],
['nbs-iscc-r:tawnyolive.77','tawnyolive','tawny-olive',[130,102,68],'826644',8545860],
['nbs-iscc-r:tawnyolive.94','tawnyolive','tawny-olive',[150,113,23],'967117',9859351],
['nbs-iscc-r:teagreen.122','teagreen','tea green',[143,151,121],'8f9779',9410425],
['nbs-iscc-r:terracotta.39','terracotta','terra cotta',[180,116,94],'b4745e',11826270],
['nbs-iscc-r:terreverte.150','terreverte','terre verte',[94,113,106],'5e716a',6189418],
['nbs-iscc-r:testaceous.39','testaceous','testaceous',[180,116,94],'b4745e',11826270],
['nbs-iscc-r:testaceous.42','testaceous','testaceous',[168,124,109],'a87c6d',11041901],
['nbs-iscc-r:thulitepink.247','thulitepink','thulite pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-r:tibergreen.135','tibergreen','tiber green',[147,197,146],'93c592',9684370],
['nbs-iscc-r:tilleulbuff.31','tilleulbuff','tilleul-buff',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:tourmalinepink.237','tourmalinepink','tourmaline pink',[158,79,136],'9e4f88',10375048],
['nbs-iscc-r:tourmalinepink.248','tourmalinepink','tourmaline pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-r:turquoisegreen.163','turquoisegreen','turquoise green',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:turtlegreen.120','turtlegreen','turtle green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:tyrianblue.186','tyrianblue','tyrian blue',[83,104,120],'536878',5466232],
['nbs-iscc-r:tyrianblue.204','tyrianblue','tyrian blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-r:tyrianpink.237','tyrianpink','tyrian pink',[158,79,136],'9e4f88',10375048],
['nbs-iscc-r:tyrianrose.254','tyrianrose','tyrian rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-r:tyrolitegreen.163','tyrolitegreen','tyrolite green',[102,173,164],'66ada4',6729124],
['nbs-iscc-r:ultramarineash.178','ultramarineash','ultramarine ash',[0,103,165],'0067a5',26533],
['nbs-iscc-r:ultramarineblue.176','ultramarineblue','ultramarine blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-r:uraniablue.212','uraniablue','urania blue',[47,33,64],'2f2140',3088704],
['nbs-iscc-r:uraniablue.215','uraniablue','urania blue',[85,76,105],'554c69',5590121],
['nbs-iscc-r:uraniablue.229','uraniablue','urania blue',[80,64,77],'50404d',5259341],
['nbs-iscc-r:vanderpoelsblue.178','vanderpoelsblue','vanderpoel\'s blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:vanderpoelsblue.182','vanderpoelsblue','vanderpoel\'s blue',[67,107,149],'436b95',4418453],
['nbs-iscc-r:vanderpoelsgreen.116','vanderpoelsgreen','vanderpoel\'s green',[189,218,87],'bdda57',12442199],
['nbs-iscc-r:vanderpoelsgreen.117','vanderpoelsgreen','vanderpoel\'s green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-r:vanderpoelsviolet.210','vanderpoelsviolet','vanderpoel\'s violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-r:vandykebrown.58','vandykebrown','vandyke brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:vandykebrown.61','vandykebrown','vandyke brown',[99,81,71],'635147',6508871],
['nbs-iscc-r:vandykered.19','vandykered','vandyke red',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:variscitegreen.143','variscitegreen','variscite green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-r:varleysgray.228','varleysgray','varley\'s gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:varleysgreen.137','varleysgreen','varley\'s green',[53,94,59],'355e3b',3497531],
['nbs-iscc-r:venetianblue.178','venetianblue','venetian blue',[0,103,165],'0067a5',26533],
['nbs-iscc-r:venetianpink.26','venetianpink','venetian pink',[248,131,121],'f88379',16286585],
['nbs-iscc-r:venicegreen.159','venicegreen','venice green',[0,166,147],'00a693',42643],
['nbs-iscc-r:verbenaviolet.214','verbenaviolet','verbena violet',[150,144,171],'9690ab',9867435],
['nbs-iscc-r:verdigrisgreen.144','verdigrisgreen','verdigris green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-r:vernoniapurple.262','vernoniapurple','vernonia purple',[145,95,109],'915f6d',9527149],
['nbs-iscc-r:veronabrown.58','veronabrown','verona brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-r:veronesegreen.119','veronesegreen','veronese green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-r:veronesegreen.120','veronesegreen','veronese green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:vetivergreen.120','vetivergreen','vetiver green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-r:vetivergreen.122','vetivergreen','vetiver green',[143,151,121],'8f9779',9410425],
['nbs-iscc-r:victorialake.16','victorialake','victoria lake',[114,47,55],'722f37',7483191],
['nbs-iscc-r:victorialake.17','victorialake','victoria lake',[63,23,40],'3f1728',4134696],
['nbs-iscc-r:vinaceous.2','vinaceous','vinaceous',[234,147,153],'ea9399',15373209],
['nbs-iscc-r:vinaceous.3','vinaceous','vinaceous',[228,113,122],'e4717a',14971258],
['nbs-iscc-r:vinaceous.5','vinaceous','vinaceous',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:vinaceous.6','vinaceous','vinaceous',[192,128,129],'c08081',12615809],
['nbs-iscc-r:vinaceousbrown.19','vinaceousbrown','vinaceous-brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:vinaceousbuff.28','vinaceousbuff','vinaceous-buff',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-r:vinaceousbuff.29','vinaceousbuff','vinaceous-buff',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:vinaceousbuff.31','vinaceousbuff','vinaceous-buff',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-r:vinaceousbuff.33','vinaceousbuff','vinaceous-buff',[194,172,153],'c2ac99',12758169],
['nbs-iscc-r:vinaceouscinnamon.29','vinaceouscinnamon','vinaceous-cinnamon',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:vinaceouscinnamon.76','vinaceouscinnamon','vinaceous-cinnamon',[193,154,107],'c19a6b',12687979],
['nbs-iscc-r:vinaceousdrab.19','vinaceousdrab','vinaceous-drab',[144,93,93],'905d5d',9461085],
['nbs-iscc-r:vinaceousfawn.29','vinaceousfawn','vinaceous-fawn',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-r:vinaceousfawn.32','vinaceousfawn','vinaceous-fawn',[199,173,163],'c7ada3',13086115],
['nbs-iscc-r:vinaceousgray.227','vinaceousgray','vinaceous-gray',[170,152,169],'aa98a9',11180201],
['nbs-iscc-r:vinaceousgray.228','vinaceousgray','vinaceous-gray',[121,104,120],'796878',7956600],
['nbs-iscc-r:vinaceouslavender.5','vinaceouslavender','vinaceous-lavender',[222,165,164],'dea5a4',14591396],
['nbs-iscc-r:vinaceouslilac.251','vinaceouslilac','vinaceous-lilac',[193,126,145],'c17e91',12680849],
['nbs-iscc-r:vinaceouslilac.262','vinaceouslilac','vinaceous-lilac',[145,95,109],'915f6d',9527149],
['nbs-iscc-r:vinaceouspink.39','vinaceouspink','vinaceous-pink',[180,116,94],'b4745e',11826270],
['nbs-iscc-r:vinaceouspink.42','vinaceouspink','vinaceous-pink',[168,124,109],'a87c6d',11041901],
['nbs-iscc-r:vinaceouspurple.258','vinaceouspurple','vinaceous-purple ',[168,81,110],'a8516e',11030894],
['nbs-iscc-r:vinaceouspurple.262','vinaceouspurple','vinaceous-purple ',[145,95,109],'915f6d',9527149],
['nbs-iscc-r:vinaceouspurple.245','vinaceouspurple','vinaceous-purple ',[131,100,121],'836479',8610937],
['nbs-iscc-r:vinaceousrufous.38','vinaceousrufous','vinaceous-rufous',[158,71,50],'9e4732',10372914],
['nbs-iscc-r:vinaceousrusset.42','vinaceousrusset','vinaceous-russet',[168,124,109],'a87c6d',11041901],
['nbs-iscc-r:vinaceousrusset.43','vinaceousrusset','vinaceous-russet',[121,68,59],'79443b',7947323],
['nbs-iscc-r:vinaceousslate.228','vinaceousslate','vinaceous-slate',[121,104,120],'796878',7956600],
['nbs-iscc-r:vinaceoustawny.39','vinaceoustawny','vinaceous-tawny',[180,116,94],'b4745e',11826270],
['nbs-iscc-r:violetcarmine.259','violetcarmine','violet carmine ',[103,49,71],'673147',6762823],
['nbs-iscc-r:violetgray.233','violetgray','violet-gray',[139,133,137],'8b8589',9143689],
['nbs-iscc-r:violetplumbeous.203','violetplumbeous','violet-plumbeous',[140,146,172],'8c92ac',9212588],
['nbs-iscc-r:violetpurple.216','violetpurple','violet-purple ',[154,78,174],'9a4eae',10112686],
['nbs-iscc-r:violetslate.186','violetslate','violet-slate',[83,104,120],'536878',5466232],
['nbs-iscc-r:violetultramarine.196','violetultramarine','violet ultramarine',[84,90,167],'545aa7',5528231],
['nbs-iscc-r:violetultramarine.207','violetultramarine','violet ultramarine',[96,78,151],'604e97',6311575],
['nbs-iscc-r:viridiangreen.140','viridiangreen','viridian green',[62,180,137],'3eb489',4109449],
['nbs-iscc-r:viridiangreen.141','viridiangreen','viridian green',[0,121,89],'007959',31065],
['nbs-iscc-r:viridinegreen.116','viridinegreen','viridine green',[189,218,87],'bdda57',12442199],
['nbs-iscc-r:viridineyellow.99','viridineyellow','viridine yellow',[190,183,46],'beb72e',12498734],
['nbs-iscc-r:viridineyellow.102','viridineyellow','viridine yellow',[185,180,89],'b9b459',12170329],
['nbs-iscc-r:vividgreen.140','vividgreen','vivid green',[62,180,137],'3eb489',4109449],
['nbs-iscc-r:wallgreen.164','wallgreen','wall green',[49,120,115],'317873',3242099],
['nbs-iscc-r:walnutbrown.43','walnutbrown','walnut brown',[121,68,59],'79443b',7947323],
['nbs-iscc-r:walnutbrown.46','walnutbrown','walnut brown',[103,76,71],'674c47',6769735],
['nbs-iscc-r:warblergreen.106','warblergreen','warbler green',[134,126,54],'867e36',8814134],
['nbs-iscc-r:warmblackishbrown.20','warmblackishbrown','warm blackish brown ',[84,61,63],'543d3f',5520703],
['nbs-iscc-r:warmblackishbrown.23','warmblackishbrown','warm blackish brown ',[92,80,79],'5c504f',6049871],
['nbs-iscc-r:warmbuff.71','warmbuff','warm buff ',[227,168,87],'e3a857',14919767],
['nbs-iscc-r:warmbuff.73','warmbuff','warm buff ',[250,214,165],'fad6a5',16438949],
['nbs-iscc-r:warmbuff.87','warmbuff','warm buff ',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-r:warmsepia.61','warmsepia','warm sepia ',[99,81,71],'635147',6508871],
['nbs-iscc-r:watergreen.121','watergreen','water green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:waxyellow.84','waxyellow','wax yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-r:wedgewoodblue.180','wedgewoodblue','wedgewood blue',[161,202,241],'a1caf1',10603249],
['nbs-iscc-r:wedgewoodblue.181','wedgewoodblue','wedgewood blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:wedgewoodblue.198','wedgewoodblue','wedgewood blue',[179,188,226],'b3bce2',11779298],
['nbs-iscc-r:wedgewoodblue.199','wedgewoodblue','wedgewood blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-r:white.263','white','white',[242,243,244],'f2f3f4',15922164],
['nbs-iscc-r:windsorblue.200','windsorblue','windsor blue',[78,81,128],'4e5180',5132672],
['nbs-iscc-r:wintergreen.136','wintergreen','winter green',[103,146,103],'679267',6787687],
['nbs-iscc-r:wistariablue.195','wistariablue','wistaria blue',[108,121,184],'6c79b8',7109048],
['nbs-iscc-r:wistariablue.206','wistariablue','wistaria blue',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:wistariaviolet.206','wistariaviolet','wistaria violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-r:woodbrown.76','woodbrown','wood brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-r:woodbrown.79','woodbrown','wood brown',[174,155,130],'ae9b82',11443074],
['nbs-iscc-r:xanthineorange.51','xanthineorange','xanthine orange',[190,101,22],'be6516',12477718],
['nbs-iscc-r:yaleblue.181','yaleblue','yale blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-r:yellowgreen.116','yellowgreen','yellow green',[189,218,87],'bdda57',12442199],
['nbs-iscc-r:yellowishcitrine.103','yellowishcitrine','yellowish citrine',[152,148,62],'98943e',9999422],
['nbs-iscc-r:yellowishglaucous.121','yellowishglaucous','yellowish glaucous',[218,223,183],'dadfb7',14344119],
['nbs-iscc-r:yellowishoilgreen.106','yellowishoilgreen','yellowish oil green',[134,126,54],'867e36',8814134],
['nbs-iscc-r:yellowisholive.106','yellowisholive','yellowish olive',[134,126,54],'867e36',8814134],
['nbs-iscc-r:yellowisholive.107','yellowisholive','yellowish olive',[102,93,30],'665d1e',6708510],
['nbs-iscc-r:yellowochre.72','yellowochre','yellow ochre',[190,138,61],'be8a3d',12487229],
['nbs-iscc-r:yewgreen.125','yewgreen','yew green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-r:yvetteviolet.215','yvetteviolet','yvette violet',[85,76,105],'554c69',5590121],
['nbs-iscc-r:zincgreen.145','zincgreen','zinc green',[59,120,97],'3b7861',3897441],
['nbs-iscc-r:zincorange.50','zincorange','zinc orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-r:zincorange.53','zincorange','zinc orange',[217,144,88],'d99058',14258264]
    ];
}

sub _description {
    return {
          'subtitle' => 'Color Standards and Color Nomenclature',
          'title' => 'NBS/ISCC R',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (R) Color Standards and Color Nomenclature

        Ridgway,
        Color Standards and Color Nomenclature 

    While using some modifiers, this primarily idiosyncratic dictionary was intended for biology and botany. It maps 1096 names to 1602 colors, using 214 of the 267 centroids.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#R]
'
        }

}

1;
