package Color::Library::Dictionary::NBS_ISCC::S;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::NBS_ISCC::S;

=pod

=head1 NAME

Color::Library::Dictionary::NBS_ISCC::S - (NBS/ISCC S) Postage-Stamp Color Names

=head1 DESCRIPTION


Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (S) Postage-Stamp Color Names

        Postage-Stamp Color Names,
        William H. Beck 

    This dictionary is a hybrid of combinatorial and idiosyncratic styles. 178 names map to 905 colors, using 223 of 267 centroids. Despite covering 84% of the centroids, averaging over 5 colors per name makes this dictionary uselessly unspecific.

L<http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#S>

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#8db600;width:4em;" /><td>apple green</td><td>applegreen</td><td>##8db600</td><td>141</td> <td>182</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>apple green</td><td>applegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>apple green</td><td>applegreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>bistre</td><td>bistre</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>bistre</td><td>bistre</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>bistre</td><td>bistre</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>bistre</td><td>bistre</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>bistre</td><td>bistre</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>bistre</td><td>bistre</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>bistre</td><td>bistre</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>bistre</td><td>bistre</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>bistre</td><td>bistre</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>bistre</td><td>bistre</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>bistre</td><td>bistre</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>bistre</td><td>bistre</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>bistre</td><td>bistre</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>bistre</td><td>bistre</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>bistre</td><td>bistre</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>bistre</td><td>bistre</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>bistre</td><td>bistre</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>bistre</td><td>bistre</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b459;width:4em;" /><td>bistre</td><td>bistre</td><td>##b9b459</td><td>185</td> <td>180</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>bistre</td><td>bistre</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>bistre</td><td>bistre</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>bistre brown</td><td>bistrebrown</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>bistre brown</td><td>bistrebrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>bistre brown</td><td>bistrebrown</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>bistre brown</td><td>bistrebrown</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>bistre brown</td><td>bistrebrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>bistre brown</td><td>bistrebrown</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>bistre brown</td><td>bistrebrown</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>black</td><td>black</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>black</td><td>black</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>black</td><td>black</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>black</td><td>black</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#222222;width:4em;" /><td>black</td><td>black</td><td>##222222</td><td>34</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>black brown</td><td>blackbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#3e322c;width:4em;" /><td>black brown</td><td>blackbrown</td><td>##3e322c</td><td>62</td> <td>50</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>black brown</td><td>blackbrown</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>black brown</td><td>blackbrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>black brown</td><td>blackbrown</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>black brown</td><td>blackbrown</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>black violet</td><td>blackviolet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>black violet</td><td>blackviolet</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>black violet</td><td>blackviolet</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#38152c;width:4em;" /><td>black violet</td><td>blackviolet</td><td>##38152c</td><td>56</td> <td>21</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>blue</td><td>blue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>blue</td><td>blue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>blue</td><td>blue</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>blue</td><td>blue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>blue</td><td>blue</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#9cd1dc;width:4em;" /><td>blue</td><td>blue</td><td>##9cd1dc</td><td>156</td> <td>209</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>blue</td><td>blue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>blue</td><td>blue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>blue</td><td>blue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>blue</td><td>blue</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>blue</td><td>blue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>blue</td><td>blue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>blue</td><td>blue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>blue</td><td>blue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>blue</td><td>blue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>blue</td><td>blue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>blue</td><td>blue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>blue black</td><td>blueblack</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>blue black</td><td>blueblack</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>blue gray</td><td>bluegray</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>blue gray</td><td>bluegray</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#008882;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##008882</td><td>0</td> <td>136</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>blue green</td><td>bluegreen</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>blue violet</td><td>blueviolet</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>brick red</td><td>brickred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>brick red</td><td>brickred</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>bright blue</td><td>brightblue</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>bright blue</td><td>brightblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>bright blue</td><td>brightblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>bright blue</td><td>brightblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>bright blue green</td><td>brightbluegreen</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>bright blue green</td><td>brightbluegreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>bright blue green</td><td>brightbluegreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>bright green</td><td>brightgreen</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>bright green</td><td>brightgreen</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>bright green</td><td>brightgreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#00543d;width:4em;" /><td>bright green</td><td>brightgreen</td><td>##00543d</td><td>0</td> <td>84</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>bright red violet</td><td>brightredviolet</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>bright red violet</td><td>brightredviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>bright red violet</td><td>brightredviolet</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>bright red violet</td><td>brightredviolet</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>bright rose</td><td>brightrose</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>bright rose</td><td>brightrose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>bright rose</td><td>brightrose</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>bright rose violet</td><td>brightroseviolet</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>bright ultramarine</td><td>brightultramarine</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>bright ultramarine</td><td>brightultramarine</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>bright ultramarine</td><td>brightultramarine</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>bright ultramarine</td><td>brightultramarine</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>bright violet</td><td>brightviolet</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>bright violet</td><td>brightviolet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>bright violet</td><td>brightviolet</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>bright violet</td><td>brightviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>bright violet</td><td>brightviolet</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>bright violet</td><td>brightviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>bright yellow</td><td>brightyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>brown</td><td>brown</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>brown</td><td>brown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>brown</td><td>brown</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>brown</td><td>brown</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>brown</td><td>brown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>brown</td><td>brown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>brown</td><td>brown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>brown</td><td>brown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>brown</td><td>brown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>brown</td><td>brown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>brown</td><td>brown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>brown</td><td>brown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>brown</td><td>brown</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>brown</td><td>brown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>brown</td><td>brown</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>brown</td><td>brown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>brown</td><td>brown</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>brown</td><td>brown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>brown bistre</td><td>brownbistre</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>brown bistre</td><td>brownbistre</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>brown bistre</td><td>brownbistre</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>brown bistre</td><td>brownbistre</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>brown-black</td><td>brownblack</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>brown carmine</td><td>browncarmine</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#5c0923;width:4em;" /><td>brown carmine</td><td>browncarmine</td><td>##5c0923</td><td>92</td> <td>9</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>brown carmine</td><td>browncarmine</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>brown lake</td><td>brownlake</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>brown lake</td><td>brownlake</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>brown olive</td><td>brownolive</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>brown olive</td><td>brownolive</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>brown orange</td><td>brownorange</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>brown purple</td><td>brownpurple</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>brown red</td><td>brownred</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>brown red</td><td>brownred</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>brown red</td><td>brownred</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>brown red</td><td>brownred</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>brown violet</td><td>brownviolet</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>brown violet</td><td>brownviolet</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>buff</td><td>buff</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>buff</td><td>buff</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>buff</td><td>buff</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>buff</td><td>buff</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>buff</td><td>buff</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>buff</td><td>buff</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>buff</td><td>buff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>buff</td><td>buff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>buff</td><td>buff</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>buff</td><td>buff</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>buff</td><td>buff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>buff</td><td>buff</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>buff</td><td>buff</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>burnt orange</td><td>burntorange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>burnt orange</td><td>burntorange</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>burnt orange</td><td>burntorange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>burnt orange</td><td>burntorange</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb5ba;width:4em;" /><td>carmine</td><td>carmine</td><td>##ffb5ba</td><td>255</td> <td>181</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>carmine</td><td>carmine</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>carmine</td><td>carmine</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>carmine</td><td>carmine</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carmine</td><td>carmine</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>carmine</td><td>carmine</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>carmine</td><td>carmine</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>carmine</td><td>carmine</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>carmine</td><td>carmine</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>carmine</td><td>carmine</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>carmine</td><td>carmine</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>carmine</td><td>carmine</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>carmine</td><td>carmine</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carmine lake</td><td>carminelake</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>carmine lake</td><td>carminelake</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>carmine lake</td><td>carminelake</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>carmine lake</td><td>carminelake</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>carmine lake</td><td>carminelake</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb5ba;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##ffb5ba</td><td>255</td> <td>181</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>carmine rose</td><td>carminerose</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>cerise</td><td>cerise</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>cerise</td><td>cerise</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>chalky blue</td><td>chalkyblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>chestnut brown</td><td>chestnutbrown</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>chocolate</td><td>chocolate</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>chocolate</td><td>chocolate</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>chocolate</td><td>chocolate</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#56070c;width:4em;" /><td>chocolate</td><td>chocolate</td><td>##56070c</td><td>86</td> <td>7</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>chocolate</td><td>chocolate</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>claret</td><td>claret</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>claret</td><td>claret</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>claret brown</td><td>claretbrown</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>claret brown</td><td>claretbrown</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>claret brown</td><td>claretbrown</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>crimson</td><td>crimson</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>crimson</td><td>crimson</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#00304e;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##00304e</td><td>0</td> <td>48</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#1c352d;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##1c352d</td><td>28</td> <td>53</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>dark blue green</td><td>darkbluegreen</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#5c504f;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##5c504f</td><td>92</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#5b504f;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##5b504f</td><td>91</td> <td>80</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>dark brown</td><td>darkbrown</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>dark carmine</td><td>darkcarmine</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>dark carmine</td><td>darkcarmine</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>dark gray</td><td>darkgray</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#00622d;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##00622d</td><td>0</td> <td>98</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#00543d;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##00543d</td><td>0</td> <td>84</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>dark ochre</td><td>darkochre</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>dark olive</td><td>darkolive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>dark olive</td><td>darkolive</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>dark olive</td><td>darkolive</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>dark olive green</td><td>darkolivegreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>dark red brown</td><td>darkredbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>dark rose</td><td>darkrose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#1b4d3e;width:4em;" /><td>dark slate green</td><td>darkslategreen</td><td>##1b4d3e</td><td>27</td> <td>77</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#1c352d;width:4em;" /><td>dark slate green</td><td>darkslategreen</td><td>##1c352d</td><td>28</td> <td>53</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dark slate green</td><td>darkslategreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#1a2421;width:4em;" /><td>dark slate green</td><td>darkslategreen</td><td>##1a2421</td><td>26</td> <td>36</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#563c5c;width:4em;" /><td>dark violet</td><td>darkviolet</td><td>##563c5c</td><td>86</td> <td>60</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>dark violet</td><td>darkviolet</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dark violet</td><td>darkviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>dark violet</td><td>darkviolet</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>dark violet</td><td>darkviolet</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>dark violet brown</td><td>darkvioletbrown</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#291e29;width:4em;" /><td>dark violet brown</td><td>darkvioletbrown</td><td>##291e29</td><td>41</td> <td>30</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dark violet brown</td><td>darkvioletbrown</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#38152c;width:4em;" /><td>dark violet brown</td><td>darkvioletbrown</td><td>##38152c</td><td>56</td> <td>21</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>deep bistre</td><td>deepbistre</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>deep blue</td><td>deepblue</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>deep blue</td><td>deepblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>deep blue</td><td>deepblue</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>deep blue</td><td>deepblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>deep blue</td><td>deepblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>deep blue</td><td>deepblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>deep blue</td><td>deepblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>deep blue</td><td>deepblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>deep brown</td><td>deepbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>deep brown</td><td>deepbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>deep brown</td><td>deepbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>deep claret</td><td>deepclaret</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#00622d;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##00622d</td><td>0</td> <td>98</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#003118;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##003118</td><td>0</td> <td>49</td> <td>24</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#00543d;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##00543d</td><td>0</td> <td>84</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>deep green</td><td>deepgreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>deep lake</td><td>deeplake</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>deep magenta</td><td>deepmagenta</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>deep olive green</td><td>deepolivegreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>deep orange</td><td>deeporange</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>deep orange</td><td>deeporange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>deep plum</td><td>deepplum</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>deep ultramarine</td><td>deepultramarine</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>deep ultramarine</td><td>deepultramarine</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>deep ultramarine</td><td>deepultramarine</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>deep violet</td><td>deepviolet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>deep violet</td><td>deepviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>deep violet</td><td>deepviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>deep violet</td><td>deepviolet</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>dull blue</td><td>dullblue</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>dull buff</td><td>dullbuff</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>dull buff</td><td>dullbuff</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>dull buff</td><td>dullbuff</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>dull buff</td><td>dullbuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>dull buff</td><td>dullbuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>dull green</td><td>dullgreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>dull lilac</td><td>dulllilac</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>dull lilac</td><td>dulllilac</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>dull lilac</td><td>dulllilac</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>dull orange</td><td>dullorange</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>dull red</td><td>dullred</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>dull rose</td><td>dullrose</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>dull rose</td><td>dullrose</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>dull rose</td><td>dullrose</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>dull vermilion</td><td>dullvermilion</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>dull violet</td><td>dullviolet</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>dull yellow</td><td>dullyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>dull yellow</td><td>dullyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>emerald</td><td>emerald</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>emerald</td><td>emerald</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>emerald</td><td>emerald</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#00622d;width:4em;" /><td>emerald</td><td>emerald</td><td>##00622d</td><td>0</td> <td>98</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>emerald</td><td>emerald</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>emerald</td><td>emerald</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>emerald</td><td>emerald</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>fawn</td><td>fawn</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>fawn</td><td>fawn</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>gray</td><td>gray</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>gray</td><td>gray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>gray</td><td>gray</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>gray</td><td>gray</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>gray</td><td>gray</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>gray</td><td>gray</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#e9e9ed;width:4em;" /><td>gray</td><td>gray</td><td>##e9e9ed</td><td>233</td> <td>233</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>gray</td><td>gray</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>gray</td><td>gray</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>gray</td><td>gray</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gray</td><td>gray</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>gray bistre</td><td>graybistre</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>gray bistre</td><td>graybistre</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>gray bistre</td><td>graybistre</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>gray black</td><td>grayblack</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>gray black</td><td>grayblack</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>gray black</td><td>grayblack</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>gray black</td><td>grayblack</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#848482;width:4em;" /><td>gray black</td><td>grayblack</td><td>##848482</td><td>132</td> <td>132</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>gray blue</td><td>grayblue</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>gray blue</td><td>grayblue</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#b4bcc0;width:4em;" /><td>gray blue</td><td>grayblue</td><td>##b4bcc0</td><td>180</td> <td>188</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>gray blue</td><td>grayblue</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>gray blue</td><td>grayblue</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>gray blue</td><td>grayblue</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>gray brown</td><td>graybrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>gray brown</td><td>graybrown</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>gray brown</td><td>graybrown</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>gray brown</td><td>graybrown</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>gray green</td><td>graygreen</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>gray green</td><td>graygreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>gray green</td><td>graygreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>gray green</td><td>graygreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>gray green</td><td>graygreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>gray green</td><td>graygreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>gray green</td><td>graygreen</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>gray lilac</td><td>graylilac</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>gray lilac</td><td>graylilac</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>gray lilac</td><td>graylilac</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>gray lilac</td><td>graylilac</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>gray lilac</td><td>graylilac</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>gray violet</td><td>grayviolet</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>green</td><td>green</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>green</td><td>green</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>green</td><td>green</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>green</td><td>green</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>green</td><td>green</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#00622d;width:4em;" /><td>green</td><td>green</td><td>##00622d</td><td>0</td> <td>98</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>green</td><td>green</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>green</td><td>green</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>green</td><td>green</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>green</td><td>green</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>green</td><td>green</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#00543d;width:4em;" /><td>green</td><td>green</td><td>##00543d</td><td>0</td> <td>84</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>green</td><td>green</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>green</td><td>green</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>green</td><td>green</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#c7e6d7;width:4em;" /><td>green</td><td>green</td><td>##c7e6d7</td><td>199</td> <td>230</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>green</td><td>green</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>green</td><td>green</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#b2beb5;width:4em;" /><td>green</td><td>green</td><td>##b2beb5</td><td>178</td> <td>190</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>green</td><td>green</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>green</td><td>green</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>green</td><td>green</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>greenish black</td><td>greenishblack</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>greenish blue</td><td>greenishblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>henna brown </td><td>hennabrown</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>indigo</td><td>indigo</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>indigo</td><td>indigo</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>lake</td><td>lake</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>lake</td><td>lake</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>lake</td><td>lake</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>lake</td><td>lake</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>lake</td><td>lake</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>lemon</td><td>lemon</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>lemon</td><td>lemon</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>lemon</td><td>lemon</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>lemon</td><td>lemon</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd300;width:4em;" /><td>lemon</td><td>lemon</td><td>##dcd300</td><td>220</td> <td>211</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#9b9400;width:4em;" /><td>lemon yellow</td><td>lemonyellow</td><td>##9b9400</td><td>155</td> <td>148</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#96ded1;width:4em;" /><td>light blue</td><td>lightblue</td><td>##96ded1</td><td>150</td> <td>222</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#66ada4;width:4em;" /><td>light blue</td><td>lightblue</td><td>##66ada4</td><td>102</td> <td>173</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>light blue</td><td>lightblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#239eba;width:4em;" /><td>light blue</td><td>lightblue</td><td>##239eba</td><td>35</td> <td>158</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>light blue</td><td>lightblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#367588;width:4em;" /><td>light blue</td><td>lightblue</td><td>##367588</td><td>54</td> <td>117</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>light blue</td><td>lightblue</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>light blue</td><td>lightblue</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd4e6;width:4em;" /><td>light blue</td><td>lightblue</td><td>##bcd4e6</td><td>188</td> <td>212</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>light brown</td><td>lightbrown</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>light green</td><td>lightgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>light green</td><td>lightgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>light green</td><td>lightgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>light olive green</td><td>lightolivegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>light olive green</td><td>lightolivegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>light olive green</td><td>lightolivegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>light red brown</td><td>lightredbrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>lilac</td><td>lilac</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#dcd0ff;width:4em;" /><td>lilac</td><td>lilac</td><td>##dcd0ff</td><td>220</td> <td>208</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>lilac</td><td>lilac</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#d5badb;width:4em;" /><td>lilac</td><td>lilac</td><td>##d5badb</td><td>213</td> <td>186</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>lilac</td><td>lilac</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>lilac</td><td>lilac</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>lilac</td><td>lilac</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e3e5;width:4em;" /><td>lilac</td><td>lilac</td><td>##e8e3e5</td><td>232</td> <td>227</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>lilac</td><td>lilac</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8589;width:4em;" /><td>lilac</td><td>lilac</td><td>##8b8589</td><td>139</td> <td>133</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>lilac</td><td>lilac</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>lilac</td><td>lilac</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>lilac</td><td>lilac</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>lilac</td><td>lilac</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>lilac</td><td>lilac</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>lilac</td><td>lilac</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#c1b6b3;width:4em;" /><td>lilac brown</td><td>lilacbrown</td><td>##c1b6b3</td><td>193</td> <td>182</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>lilac brown</td><td>lilacbrown</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>lilac brown</td><td>lilacbrown</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>lilac gray</td><td>lilacgray</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>lilac rose</td><td>lilacrose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>lilac rose</td><td>lilacrose</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>lilac rose</td><td>lilacrose</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>lilac rose</td><td>lilacrose</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>lilac rose</td><td>lilacrose</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>lilac rose</td><td>lilacrose</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#9065ca;width:4em;" /><td>magenta</td><td>magenta</td><td>##9065ca</td><td>144</td> <td>101</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>magenta</td><td>magenta</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>magenta</td><td>magenta</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>magenta</td><td>magenta</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>magenta</td><td>magenta</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>magenta</td><td>magenta</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>magenta</td><td>magenta</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>magenta</td><td>magenta</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>maroon</td><td>maroon</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>maroon</td><td>maroon</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>mauve</td><td>mauve</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>milky blue </td><td>milkyblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>myrtle green </td><td>myrtlegreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#004b49;width:4em;" /><td>myrtle green </td><td>myrtlegreen</td><td>##004b49</td><td>0</td> <td>75</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>ochre</td><td>ochre</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>ochre</td><td>ochre</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>ochre</td><td>ochre</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>ochre</td><td>ochre</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>ochre</td><td>ochre</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>ochre</td><td>ochre</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>ochre</td><td>ochre</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>ochre</td><td>ochre</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>ochre</td><td>ochre</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>ochre</td><td>ochre</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>ochre</td><td>ochre</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>olive</td><td>olive</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive</td><td>olive</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>olive</td><td>olive</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#c98500;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##c98500</td><td>201</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#967117;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##967117</td><td>150</td> <td>113</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#b9b8b5;width:4em;" /><td>olive bistre</td><td>olivebistre</td><td>##b9b8b5</td><td>185</td> <td>184</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive black</td><td>oliveblack</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>olive black</td><td>oliveblack</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#4b3621;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##4b3621</td><td>75</td> <td>54</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#7e6d5a;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##7e6d5a</td><td>126</td> <td>109</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#483c32;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##483c32</td><td>72</td> <td>60</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>olive brown</td><td>olivebrown</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>olive gray</td><td>olivegray</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#a18f60;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##a18f60</td><td>161</td> <td>143</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#9b9400;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##9b9400</td><td>155</td> <td>148</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#665d1e;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##665d1e</td><td>102</td> <td>93</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#5b5842;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##5b5842</td><td>91</td> <td>88</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#57554c;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##57554c</td><td>87</td> <td>85</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8f9779;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##8f9779</td><td>143</td> <td>151</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#404f00;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##404f00</td><td>64</td> <td>79</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#515744;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##515744</td><td>81</td> <td>87</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#5e716a;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##5e716a</td><td>94</td> <td>113</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>olive green</td><td>olivegreen</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb8a5;width:4em;" /><td>olive yellow</td><td>oliveyellow</td><td>##bfb8a5</td><td>191</td> <td>184</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>orange</td><td>orange</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>orange</td><td>orange</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>orange</td><td>orange</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>orange</td><td>orange</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>orange</td><td>orange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>orange</td><td>orange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>orange</td><td>orange</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>orange</td><td>orange</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fd943f;width:4em;" /><td>orange</td><td>orange</td><td>##fd943f</td><td>253</td> <td>148</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange</td><td>orange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>orange</td><td>orange</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>orange</td><td>orange</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>orange</td><td>orange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>orange</td><td>orange</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>orange</td><td>orange</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>orange</td><td>orange</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#c98500;width:4em;" /><td>orange</td><td>orange</td><td>##c98500</td><td>201</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>orange</td><td>orange</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>orange</td><td>orange</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>orange</td><td>orange</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>orange</td><td>orange</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>orange</td><td>orange</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>orange</td><td>orange</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>orange</td><td>orange</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>orange</td><td>orange</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>orange</td><td>orange</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>orange</td><td>orange</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#b4745e;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##b4745e</td><td>180</td> <td>116</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#882d17;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##882d17</td><td>136</td> <td>45</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#958070;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##958070</td><td>149</td> <td>128</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#ae9b82;width:4em;" /><td>orange brown</td><td>orangebrown</td><td>##ae9b82</td><td>174</td> <td>155</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>orange buff</td><td>orangebuff</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>orange red</td><td>orangered</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>orange red</td><td>orangered</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>orange red</td><td>orangered</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>orange vermilion</td><td>orangevermilion</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>orange vermilion</td><td>orangevermilion</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fd943f;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##fd943f</td><td>253</td> <td>148</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#c98500;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##c98500</td><td>201</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>orange yellow</td><td>orangeyellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>pale blue</td><td>paleblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#bfb9bd;width:4em;" /><td>pale blue</td><td>paleblue</td><td>##bfb9bd</td><td>191</td> <td>185</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>pale brown</td><td>palebrown</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>pale brown</td><td>palebrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#dadfb7;width:4em;" /><td>pale gray green</td><td>palegraygreen</td><td>##dadfb7</td><td>218</td> <td>223</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale green</td><td>palegreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>pale green</td><td>palegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>pale green</td><td>palegreen</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>pale lilac</td><td>palelilac</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>pale olive green</td><td>paleolivegreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#bdda57;width:4em;" /><td>pale yellow-green</td><td>paleyellowgreen</td><td>##bdda57</td><td>189</td> <td>218</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#c9dc89;width:4em;" /><td>pale yellow-green</td><td>paleyellowgreen</td><td>##c9dc89</td><td>201</td> <td>220</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>pale yellow-green</td><td>paleyellowgreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#007791;width:4em;" /><td>peacock blue</td><td>peacockblue</td><td>##007791</td><td>0</td> <td>119</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>pink</td><td>pink</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>pink</td><td>pink</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>pink</td><td>pink</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc8d6;width:4em;" /><td>pink</td><td>pink</td><td>##ffc8d6</td><td>255</td> <td>200</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>pink</td><td>pink</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>pink</td><td>pink</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>pink</td><td>pink</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#870074;width:4em;" /><td>plum</td><td>plum</td><td>##870074</td><td>135</td> <td>0</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>plum</td><td>plum</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>plum</td><td>plum</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>prussian blue</td><td>prussianblue</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#004958;width:4em;" /><td>prussian blue</td><td>prussianblue</td><td>##004958</td><td>0</td> <td>73</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#007a74;width:4em;" /><td>prussian green</td><td>prussiangreen</td><td>##007a74</td><td>0</td> <td>122</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#00443f;width:4em;" /><td>prussian green</td><td>prussiangreen</td><td>##00443f</td><td>0</td> <td>68</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>prussian green</td><td>prussiangreen</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8495;width:4em;" /><td>prussian green</td><td>prussiangreen</td><td>##2e8495</td><td>46</td> <td>132</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#272458;width:4em;" /><td>purple</td><td>purple</td><td>##272458</td><td>39</td> <td>36</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>purple</td><td>purple</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#604e97;width:4em;" /><td>purple</td><td>purple</td><td>##604e97</td><td>96</td> <td>78</td> <td>151</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>purple</td><td>purple</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#554c69;width:4em;" /><td>purple</td><td>purple</td><td>##554c69</td><td>85</td> <td>76</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>purple</td><td>purple</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>purple</td><td>purple</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>purple</td><td>purple</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>purple</td><td>purple</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>purple</td><td>purple</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#5d3954;width:4em;" /><td>purple</td><td>purple</td><td>##5d3954</td><td>93</td> <td>57</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>purple</td><td>purple</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>purple brown</td><td>purplebrown</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>purplish bistre</td><td>purplishbistre</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>red</td><td>red</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>red</td><td>red</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>red</td><td>red</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>red</td><td>red</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>red</td><td>red</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>red</td><td>red</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>red</td><td>red</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>red</td><td>red</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>red</td><td>red</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>red</td><td>red</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>red</td><td>red</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>red</td><td>red</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>red brown</td><td>redbrown</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>red brown</td><td>redbrown</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>red brown</td><td>redbrown</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>red brown</td><td>redbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#8f817f;width:4em;" /><td>red brown</td><td>redbrown</td><td>##8f817f</td><td>143</td> <td>129</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>red brown</td><td>redbrown</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>red brown</td><td>redbrown</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>red brown</td><td>redbrown</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>red brown</td><td>redbrown</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>red brown</td><td>redbrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#79443b;width:4em;" /><td>red brown</td><td>redbrown</td><td>##79443b</td><td>121</td> <td>68</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#be6516;width:4em;" /><td>red brown</td><td>redbrown</td><td>##be6516</td><td>190</td> <td>101</td> <td>22</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>red brown</td><td>redbrown</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>red brown</td><td>redbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>red brown</td><td>redbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#6f4e37;width:4em;" /><td>red brown</td><td>redbrown</td><td>##6f4e37</td><td>111</td> <td>78</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>red brown</td><td>redbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#826644;width:4em;" /><td>red brown</td><td>redbrown</td><td>##826644</td><td>130</td> <td>102</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#6c541e;width:4em;" /><td>red brown</td><td>redbrown</td><td>##6c541e</td><td>108</td> <td>84</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#674c47;width:4em;" /><td>reddish brown</td><td>reddishbrown</td><td>##674c47</td><td>103</td> <td>76</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#c4aead;width:4em;" /><td>red lilac</td><td>redlilac</td><td>##c4aead</td><td>196</td> <td>174</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>red lilac</td><td>redlilac</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>red lilac</td><td>redlilac</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>red orange</td><td>redorange</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>red orange</td><td>redorange</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>red orange</td><td>redorange</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>red orange</td><td>redorange</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>red orange</td><td>redorange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>red purple</td><td>redpurple</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>red purple</td><td>redpurple</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#9a4eae;width:4em;" /><td>red violet</td><td>redviolet</td><td>##9a4eae</td><td>154</td> <td>78</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>red violet</td><td>redviolet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#602f6b;width:4em;" /><td>red violet</td><td>redviolet</td><td>##602f6b</td><td>96</td> <td>47</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>red violet</td><td>redviolet</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>red violet</td><td>redviolet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>red violet</td><td>redviolet</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>red violet</td><td>redviolet</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>red violet</td><td>redviolet</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>red violet</td><td>redviolet</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>red violet</td><td>redviolet</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>red violet</td><td>redviolet</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>red violet</td><td>redviolet</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>red violet</td><td>redviolet</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb5ba;width:4em;" /><td>rose</td><td>rose</td><td>##ffb5ba</td><td>255</td> <td>181</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>rose</td><td>rose</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rose</td><td>rose</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>rose</td><td>rose</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>rose</td><td>rose</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>rose</td><td>rose</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>rose</td><td>rose</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>rose</td><td>rose</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rose</td><td>rose</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>rose</td><td>rose</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb7a5;width:4em;" /><td>rose</td><td>rose</td><td>##ffb7a5</td><td>255</td> <td>183</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>rose</td><td>rose</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>rose</td><td>rose</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>rose</td><td>rose</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>rose</td><td>rose</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>rose</td><td>rose</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#ecd5c5;width:4em;" /><td>rose</td><td>rose</td><td>##ecd5c5</td><td>236</td> <td>213</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#c7ada3;width:4em;" /><td>rose</td><td>rose</td><td>##c7ada3</td><td>199</td> <td>173</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>rose</td><td>rose</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>rose</td><td>rose</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e68fac;width:4em;" /><td>rose</td><td>rose</td><td>##e68fac</td><td>230</td> <td>143</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#de6fa1;width:4em;" /><td>rose</td><td>rose</td><td>##de6fa1</td><td>222</td> <td>111</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#efbbcc;width:4em;" /><td>rose</td><td>rose</td><td>##efbbcc</td><td>239</td> <td>187</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>rose</td><td>rose</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>rose</td><td>rose</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rose</td><td>rose</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>rose</td><td>rose</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>rose</td><td>rose</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>rose</td><td>rose</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>rose brown</td><td>rosebrown</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#841b2d;width:4em;" /><td>rose brown</td><td>rosebrown</td><td>##841b2d</td><td>132</td> <td>27</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#5c0923;width:4em;" /><td>rose brown</td><td>rosebrown</td><td>##5c0923</td><td>92</td> <td>9</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>rose brown</td><td>rosebrown</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#54133b;width:4em;" /><td>rose brown</td><td>rosebrown</td><td>##54133b</td><td>84</td> <td>19</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rose carmine</td><td>rosecarmine</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rose carmine</td><td>rosecarmine</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#b3446c;width:4em;" /><td>rose carmine</td><td>rosecarmine</td><td>##b3446c</td><td>179</td> <td>68</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>rose carmine</td><td>rosecarmine</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#dea5a4;width:4em;" /><td>rose lake</td><td>roselake</td><td>##dea5a4</td><td>222</td> <td>165</td> <td>164</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>rose lake</td><td>roselake</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>rose lake</td><td>roselake</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>rose lilac</td><td>roselilac</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>rose lilac</td><td>roselilac</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>rose lilac</td><td>roselilac</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#c17e91;width:4em;" /><td>rose lilac</td><td>roselilac</td><td>##c17e91</td><td>193</td> <td>126</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>rose lilac</td><td>roselilac</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#915f6d;width:4em;" /><td>rose lilac</td><td>roselilac</td><td>##915f6d</td><td>145</td> <td>95</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#ce4676;width:4em;" /><td>rose pink</td><td>rosepink</td><td>##ce4676</td><td>206</td> <td>70</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>rose red</td><td>rosered</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>rose red</td><td>rosered</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>rose red</td><td>rosered</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4f88;width:4em;" /><td>rose violet</td><td>roseviolet</td><td>##9e4f88</td><td>158</td> <td>79</td> <td>136</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>rose violet</td><td>roseviolet</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#915c83;width:4em;" /><td>rose violet</td><td>roseviolet</td><td>##915c83</td><td>145</td> <td>92</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#78184a;width:4em;" /><td>rose violet</td><td>roseviolet</td><td>##78184a</td><td>120</td> <td>24</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#a8516e;width:4em;" /><td>rose violet</td><td>roseviolet</td><td>##a8516e</td><td>168</td> <td>81</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>royal blue</td><td>royalblue</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>salmon</td><td>salmon</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>salmon</td><td>salmon</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>salmon</td><td>salmon</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#ea9399;width:4em;" /><td>salmon rose</td><td>salmonrose</td><td>##ea9399</td><td>234</td> <td>147</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#f9ccca;width:4em;" /><td>salmon rose</td><td>salmonrose</td><td>##f9ccca</td><td>249</td> <td>204</td> <td>202</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>salmon rose</td><td>salmonrose</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>salmon rose</td><td>salmonrose</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>salmon rose</td><td>salmonrose</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#e4717a;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##e4717a</td><td>228</td> <td>113</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#be0032;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##be0032</td><td>190</td> <td>0</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#e25822;width:4em;" /><td>scarlet</td><td>scarlet</td><td>##e25822</td><td>226</td> <td>88</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#8e8279;width:4em;" /><td>sepia</td><td>sepia</td><td>##8e8279</td><td>142</td> <td>130</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#8da399;width:4em;" /><td>slate</td><td>slate</td><td>##8da399</td><td>141</td> <td>163</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>slate</td><td>slate</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>slate</td><td>slate</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5755;width:4em;" /><td>slate</td><td>slate</td><td>##4e5755</td><td>78</td> <td>87</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#36454f;width:4em;" /><td>slate</td><td>slate</td><td>##36454f</td><td>54</td> <td>69</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#202830;width:4em;" /><td>slate</td><td>slate</td><td>##202830</td><td>32</td> <td>40</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#81878b;width:4em;" /><td>slate</td><td>slate</td><td>##81878b</td><td>129</td> <td>135</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#51585e;width:4em;" /><td>slate</td><td>slate</td><td>##51585e</td><td>81</td> <td>88</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#252440;width:4em;" /><td>slate</td><td>slate</td><td>##252440</td><td>37</td> <td>36</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>slate</td><td>slate</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#555555;width:4em;" /><td>slate</td><td>slate</td><td>##555555</td><td>85</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#317873;width:4em;" /><td>slate blue</td><td>slateblue</td><td>##317873</td><td>49</td> <td>120</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>slate blue</td><td>slateblue</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8767;width:4em;" /><td>slate green </td><td>slategreen</td><td>##8c8767</td><td>140</td> <td>135</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8776;width:4em;" /><td>slate green </td><td>slategreen</td><td>##8a8776</td><td>138</td> <td>135</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#404f00;width:4em;" /><td>slate green </td><td>slategreen</td><td>##404f00</td><td>64</td> <td>79</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#4a5d23;width:4em;" /><td>slate green </td><td>slategreen</td><td>##4a5d23</td><td>74</td> <td>93</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>slate green </td><td>slategreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#3a4b47;width:4em;" /><td>slate green </td><td>slategreen</td><td>##3a4b47</td><td>58</td> <td>75</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#7d8984;width:4em;" /><td>slate green </td><td>slategreen</td><td>##7d8984</td><td>125</td> <td>137</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>straw</td><td>straw</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#66aabc;width:4em;" /><td>turquoise blue</td><td>turquoiseblue</td><td>##66aabc</td><td>102</td> <td>170</td> <td>188</td>
</tr> <tr><td style="border:1px solid #666; background:#008882;width:4em;" /><td>turquoise green</td><td>turquoisegreen</td><td>##008882</td><td>0</td> <td>136</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#00a693;width:4em;" /><td>turquoise green</td><td>turquoisegreen</td><td>##00a693</td><td>0</td> <td>166</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#00a1c2;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##00a1c2</td><td>0</td> <td>161</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#4997d0;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##4997d0</td><td>73</td> <td>151</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#0067a5;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##0067a5</td><td>0</td> <td>103</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#00416a;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##00416a</td><td>0</td> <td>65</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#70a3cc;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##70a3cc</td><td>112</td> <td>163</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#436b95;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##436b95</td><td>67</td> <td>107</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#91a3b0;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##91a3b0</td><td>145</td> <td>163</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#536878;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##536878</td><td>83</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#30267a;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##30267a</td><td>48</td> <td>38</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#6c79b8;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##6c79b8</td><td>108</td> <td>121</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#b3bce2;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##b3bce2</td><td>179</td> <td>188</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8791bf;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##8791bf</td><td>135</td> <td>145</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#c0c8e1;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##c0c8e1</td><td>192</td> <td>200</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#8c92ac;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##8c92ac</td><td>140</td> <td>146</td> <td>172</td>
</tr> <tr><td style="border:1px solid #666; background:#4c516d;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##4c516d</td><td>76</td> <td>81</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>ultramarine</td><td>ultramarine</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#635147;width:4em;" /><td>umber brown</td><td>umberbrown</td><td>##635147</td><td>99</td> <td>81</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#c08081;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##c08081</td><td>192</td> <td>128</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#bc3f4a;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##bc3f4a</td><td>188</td> <td>63</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#ab4e52;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##ab4e52</td><td>171</td> <td>78</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#ad8884;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##ad8884</td><td>173</td> <td>136</td> <td>132</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#f88379;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##f88379</td><td>248</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#e66761;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##e66761</td><td>230</td> <td>103</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#c48379;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##c48379</td><td>196</td> <td>131</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d9603b;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##d9603b</td><td>217</td> <td>96</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#aa381e;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##aa381e</td><td>170</td> <td>56</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#cb6d51;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##cb6d51</td><td>203</td> <td>109</td> <td>81</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>vermilion</td><td>vermilion</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#722f37;width:4em;" /><td>violet</td><td>violet</td><td>##722f37</td><td>114</td> <td>47</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#4e5180;width:4em;" /><td>violet</td><td>violet</td><td>##4e5180</td><td>78</td> <td>81</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#7e73b8;width:4em;" /><td>violet</td><td>violet</td><td>##7e73b8</td><td>126</td> <td>115</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#8c82b6;width:4em;" /><td>violet</td><td>violet</td><td>##8c82b6</td><td>140</td> <td>130</td> <td>182</td>
</tr> <tr><td style="border:1px solid #666; background:#604e81;width:4em;" /><td>violet</td><td>violet</td><td>##604e81</td><td>96</td> <td>78</td> <td>129</td>
</tr> <tr><td style="border:1px solid #666; background:#9690ab;width:4em;" /><td>violet</td><td>violet</td><td>##9690ab</td><td>150</td> <td>144</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#d399e6;width:4em;" /><td>violet</td><td>violet</td><td>##d399e6</td><td>211</td> <td>153</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#875692;width:4em;" /><td>violet</td><td>violet</td><td>##875692</td><td>135</td> <td>86</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#b695c0;width:4em;" /><td>violet</td><td>violet</td><td>##b695c0</td><td>182</td> <td>149</td> <td>192</td>
</tr> <tr><td style="border:1px solid #666; background:#86608e;width:4em;" /><td>violet</td><td>violet</td><td>##86608e</td><td>134</td> <td>96</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#d6cadd;width:4em;" /><td>violet</td><td>violet</td><td>##d6cadd</td><td>214</td> <td>202</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#aa98a9;width:4em;" /><td>violet</td><td>violet</td><td>##aa98a9</td><td>170</td> <td>152</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>violet</td><td>violet</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#50404d;width:4em;" /><td>violet</td><td>violet</td><td>##50404d</td><td>80</td> <td>64</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#702963;width:4em;" /><td>violet</td><td>violet</td><td>##702963</td><td>112</td> <td>41</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#b784a7;width:4em;" /><td>violet</td><td>violet</td><td>##b784a7</td><td>183</td> <td>132</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#aa8a9e;width:4em;" /><td>violet</td><td>violet</td><td>##aa8a9e</td><td>170</td> <td>138</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#836479;width:4em;" /><td>violet</td><td>violet</td><td>##836479</td><td>131</td> <td>100</td> <td>121</td>
</tr> <tr><td style="border:1px solid #666; background:#d597ae;width:4em;" /><td>violet</td><td>violet</td><td>##d597ae</td><td>213</td> <td>151</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#e8ccd7;width:4em;" /><td>violet</td><td>violet</td><td>##e8ccd7</td><td>232</td> <td>204</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#c3a6b1;width:4em;" /><td>violet</td><td>violet</td><td>##c3a6b1</td><td>195</td> <td>166</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#af868e;width:4em;" /><td>violet</td><td>violet</td><td>##af868e</td><td>175</td> <td>134</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#543d3f;width:4em;" /><td>violet black</td><td>violetblack</td><td>##543d3f</td><td>84</td> <td>61</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#5d555b;width:4em;" /><td>violet black</td><td>violetblack</td><td>##5d555b</td><td>93</td> <td>85</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#545aa7;width:4em;" /><td>violet blue</td><td>violetblue</td><td>##545aa7</td><td>84</td> <td>90</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#905d5d;width:4em;" /><td>violet brown</td><td>violetbrown</td><td>##905d5d</td><td>144</td> <td>93</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#796878;width:4em;" /><td>violet brown</td><td>violetbrown</td><td>##796878</td><td>121</td> <td>104</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#673147;width:4em;" /><td>violet brown</td><td>violetbrown</td><td>##673147</td><td>103</td> <td>49</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#f4c2c2;width:4em;" /><td>yellow</td><td>yellow</td><td>##f4c2c2</td><td>244</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>yellow</td><td>yellow</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#f38400;width:4em;" /><td>yellow</td><td>yellow</td><td>##f38400</td><td>243</td> <td>132</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fd943f;width:4em;" /><td>yellow</td><td>yellow</td><td>##fd943f</td><td>253</td> <td>148</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>yellow</td><td>yellow</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#fab57f;width:4em;" /><td>yellow</td><td>yellow</td><td>##fab57f</td><td>250</td> <td>181</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>yellow</td><td>yellow</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>yellow</td><td>yellow</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#f6a600;width:4em;" /><td>yellow</td><td>yellow</td><td>##f6a600</td><td>246</td> <td>166</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc14f;width:4em;" /><td>yellow</td><td>yellow</td><td>##ffc14f</td><td>255</td> <td>193</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#eaa221;width:4em;" /><td>yellow</td><td>yellow</td><td>##eaa221</td><td>234</td> <td>162</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#c98500;width:4em;" /><td>yellow</td><td>yellow</td><td>##c98500</td><td>201</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fbc97f;width:4em;" /><td>yellow</td><td>yellow</td><td>##fbc97f</td><td>251</td> <td>201</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow</td><td>yellow</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>yellow</td><td>yellow</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>yellow</td><td>yellow</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>yellow</td><td>yellow</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#f3c300;width:4em;" /><td>yellow</td><td>yellow</td><td>##f3c300</td><td>243</td> <td>195</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fada5e;width:4em;" /><td>yellow</td><td>yellow</td><td>##fada5e</td><td>250</td> <td>218</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#d4af37;width:4em;" /><td>yellow</td><td>yellow</td><td>##d4af37</td><td>212</td> <td>175</td> <td>55</td>
</tr> <tr><td style="border:1px solid #666; background:#af8d13;width:4em;" /><td>yellow</td><td>yellow</td><td>##af8d13</td><td>175</td> <td>141</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#f8de7e;width:4em;" /><td>yellow</td><td>yellow</td><td>##f8de7e</td><td>248</td> <td>222</td> <td>126</td>
</tr> <tr><td style="border:1px solid #666; background:#c9ae5d;width:4em;" /><td>yellow</td><td>yellow</td><td>##c9ae5d</td><td>201</td> <td>174</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ab9144;width:4em;" /><td>yellow</td><td>yellow</td><td>##ab9144</td><td>171</td> <td>145</td> <td>68</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>yellow</td><td>yellow</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>yellow</td><td>yellow</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ead6;width:4em;" /><td>yellow</td><td>yellow</td><td>##f0ead6</td><td>240</td> <td>234</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#c2ac99;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##c2ac99</td><td>194</td> <td>172</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#9e4732;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##9e4732</td><td>158</td> <td>71</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#a87c6d;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##a87c6d</td><td>168</td> <td>124</td> <td>109</td>
</tr> <tr><td style="border:1px solid #666; background:#977f73;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##977f73</td><td>151</td> <td>127</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#ae6938;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##ae6938</td><td>174</td> <td>105</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#80461b;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##80461b</td><td>128</td> <td>70</td> <td>27</td>
</tr> <tr><td style="border:1px solid #666; background:#a67b5b;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##a67b5b</td><td>166</td> <td>123</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#be8a3d;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##be8a3d</td><td>190</td> <td>138</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#996515;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##996515</td><td>153</td> <td>101</td> <td>21</td>
</tr> <tr><td style="border:1px solid #666; background:#867e36;width:4em;" /><td>yellow brown</td><td>yellowbrown</td><td>##867e36</td><td>134</td> <td>126</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#d9a6a9;width:4em;" /><td>yellow buff</td><td>yellowbuff</td><td>##d9a6a9</td><td>217</td> <td>166</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>yellow buff</td><td>yellowbuff</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr> <tr><td style="border:1px solid #666; background:#e3a857;width:4em;" /><td>yellow buff</td><td>yellowbuff</td><td>##e3a857</td><td>227</td> <td>168</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fad6a5;width:4em;" /><td>yellow buff</td><td>yellowbuff</td><td>##fad6a5</td><td>250</td> <td>214</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#c19a6b;width:4em;" /><td>yellow buff</td><td>yellowbuff</td><td>##c19a6b</td><td>193</td> <td>154</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#f3e5ab;width:4em;" /><td>yellow buff</td><td>yellowbuff</td><td>##f3e5ab</td><td>243</td> <td>229</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#c2b280;width:4em;" /><td>yellow buff</td><td>yellowbuff</td><td>##c2b280</td><td>194</td> <td>178</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#7e9f2e;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##7e9f2e</td><td>126</td> <td>159</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#8a9a5b;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##8a9a5b</td><td>138</td> <td>154</td> <td>91</td>
</tr> <tr><td style="border:1px solid #666; background:#27a64c;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##27a64c</td><td>39</td> <td>166</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#83d37d;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##83d37d</td><td>131</td> <td>211</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#44944a;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##44944a</td><td>68</td> <td>148</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#00622d;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##00622d</td><td>0</td> <td>98</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#b6e5af;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##b6e5af</td><td>182</td> <td>229</td> <td>175</td>
</tr> <tr><td style="border:1px solid #666; background:#93c592;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##93c592</td><td>147</td> <td>197</td> <td>146</td>
</tr> <tr><td style="border:1px solid #666; background:#679267;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##679267</td><td>103</td> <td>146</td> <td>103</td>
</tr> <tr><td style="border:1px solid #666; background:#355e3b;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##355e3b</td><td>53</td> <td>94</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#008856;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##008856</td><td>0</td> <td>136</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#3eb489;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##3eb489</td><td>62</td> <td>180</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#007959;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##007959</td><td>0</td> <td>121</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#8ed1b2;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##8ed1b2</td><td>142</td> <td>209</td> <td>178</td>
</tr> <tr><td style="border:1px solid #666; background:#6aab8e;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##6aab8e</td><td>106</td> <td>171</td> <td>142</td>
</tr> <tr><td style="border:1px solid #666; background:#3b7861;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##3b7861</td><td>59</td> <td>120</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#ed872d;width:4em;" /><td>yellow orange</td><td>yelloworange</td><td>##ed872d</td><td>237</td> <td>135</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#d99058;width:4em;" /><td>yellow orange</td><td>yelloworange</td><td>##d99058</td><td>217</td> <td>144</td> <td>88</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item apple green        applegreen        #8db600

=item apple green        applegreen        #7e9f2e

=item apple green        applegreen        #44944a

=item bistre             bistre            #a67b5b

=item bistre             bistre            #8e8279

=item bistre             bistre            #e3a857

=item bistre             bistre            #be8a3d

=item bistre             bistre            #996515

=item bistre             bistre            #c19a6b

=item bistre             bistre            #826644

=item bistre             bistre            #ae9b82

=item bistre             bistre            #7e6d5a

=item bistre             bistre            #af8d13

=item bistre             bistre            #c9ae5d

=item bistre             bistre            #ab9144

=item bistre             bistre            #f3e5ab

=item bistre             bistre            #c2b280

=item bistre             bistre            #a18f60

=item bistre             bistre            #bfb8a5

=item bistre             bistre            #967117

=item bistre             bistre            #6c541e

=item bistre             bistre            #b9b459

=item bistre             bistre            #8c8767

=item bistre             bistre            #8a8776

=item bistre brown       bistrebrown       #d9a6a9

=item bistre brown       bistrebrown       #a67b5b

=item bistre brown       bistrebrown       #8e8279

=item bistre brown       bistrebrown       #c19a6b

=item bistre brown       bistrebrown       #826644

=item bistre brown       bistrebrown       #967117

=item bistre brown       bistrebrown       #867e36

=item black              black             #57554c

=item black              black             #b9b8b5

=item black              black             #848482

=item black              black             #555555

=item black              black             #222222

=item black brown        blackbrown        #635147

=item black brown        blackbrown        #3e322c

=item black brown        blackbrown        #8e8279

=item black brown        blackbrown        #5b504f

=item black brown        blackbrown        #5b5842

=item black brown        blackbrown        #57554c

=item black violet       blackviolet       #50404d

=item black violet       blackviolet       #291e29

=item black violet       blackviolet       #673147

=item black violet       blackviolet       #38152c

=item blue               blue              #66ada4

=item blue               blue              #317873

=item blue               blue              #239eba

=item blue               blue              #007791

=item blue               blue              #2e8495

=item blue               blue              #9cd1dc

=item blue               blue              #66aabc

=item blue               blue              #367588

=item blue               blue              #004958

=item blue               blue              #4997d0

=item blue               blue              #0067a5

=item blue               blue              #00416a

=item blue               blue              #70a3cc

=item blue               blue              #436b95

=item blue               blue              #00304e

=item blue               blue              #bcd4e6

=item blue               blue              #536878

=item blue black         blueblack         #81878b

=item blue black         blueblack         #51585e

=item blue gray          bluegray          #b2beb5

=item blue gray          bluegray          #81878b

=item blue green         bluegreen         #3eb489

=item blue green         bluegreen         #007959

=item blue green         bluegreen         #8ed1b2

=item blue green         bluegreen         #6aab8e

=item blue green         bluegreen         #3b7861

=item blue green         bluegreen         #008882

=item blue green         bluegreen         #00a693

=item blue green         bluegreen         #007a74

=item blue green         bluegreen         #66ada4

=item blue green         bluegreen         #317873

=item blue green         bluegreen         #367588

=item blue violet        blueviolet        #8791bf

=item brick red          brickred          #905d5d

=item brick red          brickred          #674c47

=item bright blue        brightblue        #007a74

=item bright blue        brightblue        #007791

=item bright blue        brightblue        #0067a5

=item bright blue        brightblue        #436b95

=item bright blue green  brightbluegreen   #008856

=item bright blue green  brightbluegreen   #3eb489

=item bright blue green  brightbluegreen   #007959

=item bright green       brightgreen       #27a64c

=item bright green       brightgreen       #008856

=item bright green       brightgreen       #007959

=item bright green       brightgreen       #00543d

=item bright red violet  brightredviolet   #9a4eae

=item bright red violet  brightredviolet   #875692

=item bright red violet  brightredviolet   #870074

=item bright red violet  brightredviolet   #9e4f88

=item bright rose        brightrose        #de6fa1

=item bright rose        brightrose        #ce4676

=item bright rose        brightrose        #915f6d

=item bright rose violet brightroseviolet  #de6fa1

=item bright ultramarine brightultramarine #00a1c2

=item bright ultramarine brightultramarine #0067a5

=item bright ultramarine brightultramarine #30267a

=item bright ultramarine brightultramarine #545aa7

=item bright violet      brightviolet      #9065ca

=item bright violet      brightviolet      #604e81

=item bright violet      brightviolet      #9a4eae

=item bright violet      brightviolet      #875692

=item bright violet      brightviolet      #b695c0

=item bright violet      brightviolet      #86608e

=item bright yellow      brightyellow      #ffc14f

=item bright yellow      brightyellow      #eaa221

=item bright yellow      brightyellow      #fbc97f

=item bright yellow      brightyellow      #e3a857

=item bright yellow      brightyellow      #fada5e

=item bright yellow      brightyellow      #d4af37

=item bright yellow      brightyellow      #f8de7e

=item bright yellow      brightyellow      #c9ae5d

=item brown              brown             #c1b6b3

=item brown              brown             #905d5d

=item brown              brown             #5c504f

=item brown              brown             #cb6d51

=item brown              brown             #a87c6d

=item brown              brown             #79443b

=item brown              brown             #977f73

=item brown              brown             #674c47

=item brown              brown             #ae6938

=item brown              brown             #80461b

=item brown              brown             #a67b5b

=item brown              brown             #6f4e37

=item brown              brown             #958070

=item brown              brown             #635147

=item brown              brown             #8e8279

=item brown              brown             #5b504f

=item brown              brown             #ae9b82

=item brown              brown             #7e6d5a

=item brown bistre       brownbistre       #c19a6b

=item brown bistre       brownbistre       #ae9b82

=item brown bistre       brownbistre       #c9ae5d

=item brown bistre       brownbistre       #967117

=item brown-black        brownblack        #5b504f

=item brown carmine      browncarmine      #bc3f4a

=item brown carmine      browncarmine      #5c0923

=item brown carmine      browncarmine      #722f37

=item brown lake         brownlake         #ab4e52

=item brown lake         brownlake         #905d5d

=item brown olive        brownolive        #996515

=item brown olive        brownolive        #967117

=item brown orange       brownorange       #d9a6a9

=item brown orange       brownorange       #cb6d51

=item brown orange       brownorange       #b4745e

=item brown orange       brownorange       #ed872d

=item brown orange       brownorange       #be6516

=item brown orange       brownorange       #d99058

=item brown orange       brownorange       #ae6938

=item brown orange       brownorange       #a67b5b

=item brown orange       brownorange       #eaa221

=item brown orange       brownorange       #e3a857

=item brown orange       brownorange       #c19a6b

=item brown orange       brownorange       #c9ae5d

=item brown purple       brownpurple       #796878

=item brown red          brownred          #be0032

=item brown red          brownred          #ad8884

=item brown red          brownred          #905d5d

=item brown red          brownred          #674c47

=item brown violet       brownviolet       #673147

=item brown violet       brownviolet       #915f6d

=item buff               buff              #f4c2c2

=item buff               buff              #d9a6a9

=item buff               buff              #ecd5c5

=item buff               buff              #c2ac99

=item buff               buff              #fab57f

=item buff               buff              #d99058

=item buff               buff              #e3a857

=item buff               buff              #fad6a5

=item buff               buff              #c19a6b

=item buff               buff              #ae9b82

=item buff               buff              #f3e5ab

=item buff               buff              #f0ead6

=item buff               buff              #bfb8a5

=item burnt orange       burntorange       #d9603b

=item burnt orange       burntorange       #be6516

=item burnt orange       burntorange       #d99058

=item burnt orange       burntorange       #ae6938

=item carmine            carmine           #ffb5ba

=item carmine            carmine           #ea9399

=item carmine            carmine           #e4717a

=item carmine            carmine           #c08081

=item carmine            carmine           #be0032

=item carmine            carmine           #bc3f4a

=item carmine            carmine           #841b2d

=item carmine            carmine           #ab4e52

=item carmine            carmine           #905d5d

=item carmine            carmine           #ce4676

=item carmine            carmine           #b3446c

=item carmine            carmine           #78184a

=item carmine            carmine           #a8516e

=item carmine lake       carminelake       #be0032

=item carmine lake       carminelake       #bc3f4a

=item carmine lake       carminelake       #ab4e52

=item carmine lake       carminelake       #b3446c

=item carmine lake       carminelake       #a8516e

=item carmine rose       carminerose       #ffb5ba

=item carmine rose       carminerose       #ea9399

=item carmine rose       carminerose       #e4717a

=item carmine rose       carminerose       #be0032

=item carmine rose       carminerose       #bc3f4a

=item carmine rose       carminerose       #ab4e52

=item carmine rose       carminerose       #905d5d

=item carmine rose       carminerose       #e66761

=item carmine rose       carminerose       #de6fa1

=item carmine rose       carminerose       #b3446c

=item carmine rose       carminerose       #a8516e

=item cerise             cerise            #ce4676

=item cerise             cerise            #78184a

=item chalky blue        chalkyblue        #91a3b0

=item chestnut brown     chestnutbrown     #9e4732

=item chocolate          chocolate         #905d5d

=item chocolate          chocolate         #8f817f

=item chocolate          chocolate         #5c504f

=item chocolate          chocolate         #56070c

=item chocolate          chocolate         #674c47

=item claret             claret            #c17e91

=item claret             claret            #915f6d

=item claret brown       claretbrown       #841b2d

=item claret brown       claretbrown       #722f37

=item claret brown       claretbrown       #796878

=item crimson            crimson           #be0032

=item crimson            crimson           #bc3f4a

=item dark blue          darkblue          #2e8495

=item dark blue          darkblue          #367588

=item dark blue          darkblue          #004958

=item dark blue          darkblue          #0067a5

=item dark blue          darkblue          #00416a

=item dark blue          darkblue          #436b95

=item dark blue          darkblue          #00304e

=item dark blue          darkblue          #536878

=item dark blue          darkblue          #36454f

=item dark blue          darkblue          #202830

=item dark blue          darkblue          #272458

=item dark blue          darkblue          #8791bf

=item dark blue green    darkbluegreen     #007959

=item dark blue green    darkbluegreen     #1b4d3e

=item dark blue green    darkbluegreen     #1c352d

=item dark blue green    darkbluegreen     #3a4b47

=item dark blue green    darkbluegreen     #1a2421

=item dark blue green    darkbluegreen     #007a74

=item dark blue green    darkbluegreen     #66ada4

=item dark blue green    darkbluegreen     #317873

=item dark blue green    darkbluegreen     #367588

=item dark brown         darkbrown         #543d3f

=item dark brown         darkbrown         #8f817f

=item dark brown         darkbrown         #5c504f

=item dark brown         darkbrown         #79443b

=item dark brown         darkbrown         #977f73

=item dark brown         darkbrown         #6f4e37

=item dark brown         darkbrown         #635147

=item dark brown         darkbrown         #8e8279

=item dark brown         darkbrown         #5b504f

=item dark brown         darkbrown         #7e6d5a

=item dark brown         darkbrown         #bfb8a5

=item dark carmine       darkcarmine       #be0032

=item dark carmine       darkcarmine       #ab4e52

=item dark gray          darkgray          #51585e

=item dark green         darkgreen         #00622d

=item dark green         darkgreen         #355e3b

=item dark green         darkgreen         #007959

=item dark green         darkgreen         #00543d

=item dark green         darkgreen         #3b7861

=item dark green         darkgreen         #1b4d3e

=item dark green         darkgreen         #5e716a

=item dark green         darkgreen         #3a4b47

=item dark green         darkgreen         #7d8984

=item dark green         darkgreen         #317873

=item dark ochre         darkochre         #967117

=item dark olive         darkolive         #5b5842

=item dark olive         darkolive         #57554c

=item dark olive         darkolive         #515744

=item dark olive green   darkolivegreen    #4a5d23

=item dark red brown     darkredbrown      #674c47

=item dark rose          darkrose          #ab4e52

=item dark slate green   darkslategreen    #1b4d3e

=item dark slate green   darkslategreen    #1c352d

=item dark slate green   darkslategreen    #3a4b47

=item dark slate green   darkslategreen    #1a2421

=item dark violet        darkviolet        #563c5c

=item dark violet        darkviolet        #aa98a9

=item dark violet        darkviolet        #796878

=item dark violet        darkviolet        #8b8589

=item dark violet        darkviolet        #915f6d

=item dark violet brown  darkvioletbrown   #50404d

=item dark violet brown  darkvioletbrown   #291e29

=item dark violet brown  darkvioletbrown   #673147

=item dark violet brown  darkvioletbrown   #38152c

=item deep bistre        deepbistre        #967117

=item deep blue          deepblue          #2e8495

=item deep blue          deepblue          #367588

=item deep blue          deepblue          #00a1c2

=item deep blue          deepblue          #0067a5

=item deep blue          deepblue          #00416a

=item deep blue          deepblue          #70a3cc

=item deep blue          deepblue          #436b95

=item deep blue          deepblue          #536878

=item deep brown         deepbrown         #79443b

=item deep brown         deepbrown         #80461b

=item deep brown         deepbrown         #6f4e37

=item deep claret        deepclaret        #722f37

=item deep green         deepgreen         #7e9f2e

=item deep green         deepgreen         #8a9a5b

=item deep green         deepgreen         #27a64c

=item deep green         deepgreen         #83d37d

=item deep green         deepgreen         #44944a

=item deep green         deepgreen         #00622d

=item deep green         deepgreen         #003118

=item deep green         deepgreen         #93c592

=item deep green         deepgreen         #007959

=item deep green         deepgreen         #00543d

=item deep green         deepgreen         #3b7861

=item deep green         deepgreen         #7d8984

=item deep green         deepgreen         #007a74

=item deep green         deepgreen         #66ada4

=item deep green         deepgreen         #317873

=item deep green         deepgreen         #004b49

=item deep lake          deeplake          #673147

=item deep magenta       deepmagenta       #ce4676

=item deep olive green   deepolivegreen    #4a5d23

=item deep orange        deeporange        #f88379

=item deep orange        deeporange        #d99058

=item deep plum          deepplum          #a8516e

=item deep ultramarine   deepultramarine   #00a1c2

=item deep ultramarine   deepultramarine   #436b95

=item deep ultramarine   deepultramarine   #30267a

=item deep violet        deepviolet        #7e73b8

=item deep violet        deepviolet        #875692

=item deep violet        deepviolet        #86608e

=item deep violet        deepviolet        #702963

=item dull blue          dullblue          #0067a5

=item dull blue          dullblue          #00416a

=item dull blue          dullblue          #70a3cc

=item dull blue          dullblue          #436b95

=item dull blue          dullblue          #536878

=item dull blue          dullblue          #51585e

=item dull blue          dullblue          #4c516d

=item dull buff          dullbuff          #ecd5c5

=item dull buff          dullbuff          #c7ada3

=item dull buff          dullbuff          #fbc97f

=item dull buff          dullbuff          #e3a857

=item dull buff          dullbuff          #fad6a5

=item dull green         dullgreen         #515744

=item dull green         dullgreen         #93c592

=item dull green         dullgreen         #355e3b

=item dull green         dullgreen         #6aab8e

=item dull green         dullgreen         #3b7861

=item dull green         dullgreen         #3a4b47

=item dull green         dullgreen         #66ada4

=item dull lilac         dulllilac         #604e81

=item dull lilac         dulllilac         #aa98a9

=item dull lilac         dulllilac         #915f6d

=item dull orange        dullorange        #c1b6b3

=item dull red           dullred           #d9603b

=item dull rose          dullrose          #ea9399

=item dull rose          dullrose          #ad8884

=item dull rose          dullrose          #d597ae

=item dull vermilion     dullvermilion     #cb6d51

=item dull violet        dullviolet        #796878

=item dull violet        dullviolet        #836479

=item dull violet        dullviolet        #673147

=item dull violet        dullviolet        #af868e

=item dull violet        dullviolet        #915f6d

=item dull yellow        dullyellow        #fbc97f

=item dull yellow        dullyellow        #e3a857

=item emerald            emerald           #27a64c

=item emerald            emerald           #83d37d

=item emerald            emerald           #44944a

=item emerald            emerald           #00622d

=item emerald            emerald           #008856

=item emerald            emerald           #3eb489

=item emerald            emerald           #6aab8e

=item fawn               fawn              #d9a6a9

=item fawn               fawn              #79443b

=item gray               gray              #bfb8a5

=item gray               gray              #8a8776

=item gray               gray              #8da399

=item gray               gray              #b2beb5

=item gray               gray              #7d8984

=item gray               gray              #4e5755

=item gray               gray              #e9e9ed

=item gray               gray              #51585e

=item gray               gray              #bfb9bd

=item gray               gray              #b9b8b5

=item gray               gray              #848482

=item gray bistre        graybistre        #c19a6b

=item gray bistre        graybistre        #ae9b82

=item gray bistre        graybistre        #967117

=item gray black         grayblack         #8e8279

=item gray black         grayblack         #8a8776

=item gray black         grayblack         #57554c

=item gray black         grayblack         #7d8984

=item gray black         grayblack         #848482

=item gray blue          grayblue          #436b95

=item gray blue          grayblue          #91a3b0

=item gray blue          grayblue          #b4bcc0

=item gray blue          grayblue          #8c92ac

=item gray blue          grayblue          #9690ab

=item gray blue          grayblue          #bfb9bd

=item gray brown         graybrown         #977f73

=item gray brown         graybrown         #8e8279

=item gray brown         graybrown         #967117

=item gray brown         graybrown         #8a8776

=item gray green         graygreen         #8a8776

=item gray green         graygreen         #8a9a5b

=item gray green         graygreen         #8f9779

=item gray green         graygreen         #679267

=item gray green         graygreen         #6aab8e

=item gray green         graygreen         #3b7861

=item gray green         graygreen         #66ada4

=item gray lilac         graylilac         #8f817f

=item gray lilac         graylilac         #8e8279

=item gray lilac         graylilac         #d6cadd

=item gray lilac         graylilac         #bfb9bd

=item gray lilac         graylilac         #efbbcc

=item gray violet        grayviolet        #8b8589

=item green              green             #7e9f2e

=item green              green             #8a9a5b

=item green              green             #27a64c

=item green              green             #83d37d

=item green              green             #44944a

=item green              green             #00622d

=item green              green             #93c592

=item green              green             #679267

=item green              green             #008856

=item green              green             #3eb489

=item green              green             #007959

=item green              green             #00543d

=item green              green             #8ed1b2

=item green              green             #6aab8e

=item green              green             #3b7861

=item green              green             #c7e6d7

=item green              green             #8da399

=item green              green             #5e716a

=item green              green             #b2beb5

=item green              green             #00a693

=item green              green             #66ada4

=item green              green             #317873

=item greenish black     greenishblack     #8da399

=item greenish blue      greenishblue      #317873

=item greenish blue      greenishblue      #007791

=item greenish blue      greenishblue      #367588

=item henna brown        hennabrown        #841b2d

=item indigo             indigo            #00416a

=item indigo             indigo            #4c516d

=item lake               lake              #ab4e52

=item lake               lake              #722f37

=item lake               lake              #905d5d

=item lake               lake              #b4745e

=item lake               lake              #a8516e

=item lemon              lemon             #f3c300

=item lemon              lemon             #fada5e

=item lemon              lemon             #d4af37

=item lemon              lemon             #af8d13

=item lemon              lemon             #dcd300

=item lemon yellow       lemonyellow       #af8d13

=item lemon yellow       lemonyellow       #9b9400

=item light blue         lightblue         #96ded1

=item light blue         lightblue         #66ada4

=item light blue         lightblue         #317873

=item light blue         lightblue         #239eba

=item light blue         lightblue         #66aabc

=item light blue         lightblue         #367588

=item light blue         lightblue         #0067a5

=item light blue         lightblue         #70a3cc

=item light blue         lightblue         #bcd4e6

=item light brown        lightbrown        #c7ada3

=item light green        lightgreen        #44944a

=item light green        lightgreen        #93c592

=item light green        lightgreen        #3eb489

=item light olive green  lightolivegreen   #867e36

=item light olive green  lightolivegreen   #7e9f2e

=item light olive green  lightolivegreen   #c9dc89

=item light red brown    lightredbrown     #a87c6d

=item lilac              lilac             #c1b6b3

=item lilac              lilac             #dcd0ff

=item lilac              lilac             #8c82b6

=item lilac              lilac             #d5badb

=item lilac              lilac             #d6cadd

=item lilac              lilac             #aa98a9

=item lilac              lilac             #796878

=item lilac              lilac             #e8e3e5

=item lilac              lilac             #bfb9bd

=item lilac              lilac             #8b8589

=item lilac              lilac             #915c83

=item lilac              lilac             #aa8a9e

=item lilac              lilac             #e8ccd7

=item lilac              lilac             #c3a6b1

=item lilac              lilac             #af868e

=item lilac              lilac             #915f6d

=item lilac brown        lilacbrown        #c1b6b3

=item lilac brown        lilacbrown        #8f817f

=item lilac brown        lilacbrown        #8e8279

=item lilac gray         lilacgray         #bfb9bd

=item lilac rose         lilacrose         #e4717a

=item lilac rose         lilacrose         #ad8884

=item lilac rose         lilacrose         #9e4f88

=item lilac rose         lilacrose         #de6fa1

=item lilac rose         lilacrose         #efbbcc

=item lilac rose         lilacrose         #a8516e

=item magenta            magenta           #9065ca

=item magenta            magenta           #875692

=item magenta            magenta           #9e4f88

=item magenta            magenta           #5d3954

=item magenta            magenta           #b3446c

=item magenta            magenta           #a8516e

=item magenta            magenta           #673147

=item magenta            magenta           #915f6d

=item maroon             maroon            #722f37

=item maroon             maroon            #673147

=item mauve              mauve             #915c83

=item milky blue         milkyblue         #66aabc

=item myrtle green       myrtlegreen       #317873

=item myrtle green       myrtlegreen       #004b49

=item ochre              ochre             #be6516

=item ochre              ochre             #d99058

=item ochre              ochre             #a67b5b

=item ochre              ochre             #ffc14f

=item ochre              ochre             #e3a857

=item ochre              ochre             #fad6a5

=item ochre              ochre             #996515

=item ochre              ochre             #fada5e

=item ochre              ochre             #d4af37

=item ochre              ochre             #f8de7e

=item ochre              ochre             #c9ae5d

=item olive              olive             #6c541e

=item olive              olive             #5b5842

=item olive              olive             #8f9779

=item olive bistre       olivebistre       #c98500

=item olive bistre       olivebistre       #be8a3d

=item olive bistre       olivebistre       #996515

=item olive bistre       olivebistre       #826644

=item olive bistre       olivebistre       #af8d13

=item olive bistre       olivebistre       #c9ae5d

=item olive bistre       olivebistre       #ab9144

=item olive bistre       olivebistre       #f3e5ab

=item olive bistre       olivebistre       #c2b280

=item olive bistre       olivebistre       #a18f60

=item olive bistre       olivebistre       #bfb8a5

=item olive bistre       olivebistre       #967117

=item olive bistre       olivebistre       #867e36

=item olive bistre       olivebistre       #8a8776

=item olive bistre       olivebistre       #8f9779

=item olive bistre       olivebistre       #b9b8b5

=item olive black        oliveblack        #5b5842

=item olive black        oliveblack        #57554c

=item olive brown        olivebrown        #6f4e37

=item olive brown        olivebrown        #8e8279

=item olive brown        olivebrown        #4b3621

=item olive brown        olivebrown        #7e6d5a

=item olive brown        olivebrown        #483c32

=item olive brown        olivebrown        #6c541e

=item olive brown        olivebrown        #5b5842

=item olive brown        olivebrown        #57554c

=item olive gray         olivegray         #665d1e

=item olive gray         olivegray         #8a8776

=item olive gray         olivegray         #57554c

=item olive gray         olivegray         #8f9779

=item olive gray         olivegray         #7d8984

=item olive gray         olivegray         #4e5755

=item olive green        olivegreen        #ab9144

=item olive green        olivegreen        #f3e5ab

=item olive green        olivegreen        #c2b280

=item olive green        olivegreen        #a18f60

=item olive green        olivegreen        #bfb8a5

=item olive green        olivegreen        #9b9400

=item olive green        olivegreen        #867e36

=item olive green        olivegreen        #665d1e

=item olive green        olivegreen        #8c8767

=item olive green        olivegreen        #5b5842

=item olive green        olivegreen        #8a8776

=item olive green        olivegreen        #57554c

=item olive green        olivegreen        #7e9f2e

=item olive green        olivegreen        #8a9a5b

=item olive green        olivegreen        #8f9779

=item olive green        olivegreen        #404f00

=item olive green        olivegreen        #4a5d23

=item olive green        olivegreen        #515744

=item olive green        olivegreen        #5e716a

=item olive green        olivegreen        #3a4b47

=item olive green        olivegreen        #7d8984

=item olive green        olivegreen        #4e5755

=item olive yellow       oliveyellow       #ecd5c5

=item olive yellow       oliveyellow       #c2ac99

=item olive yellow       oliveyellow       #fad6a5

=item olive yellow       oliveyellow       #f8de7e

=item olive yellow       oliveyellow       #c9ae5d

=item olive yellow       oliveyellow       #f3e5ab

=item olive yellow       oliveyellow       #bfb8a5

=item orange             orange            #ffb7a5

=item orange             orange            #f88379

=item orange             orange            #f4c2c2

=item orange             orange            #d9a6a9

=item orange             orange            #e25822

=item orange             orange            #d9603b

=item orange             orange            #cb6d51

=item orange             orange            #f38400

=item orange             orange            #fd943f

=item orange             orange            #ed872d

=item orange             orange            #be6516

=item orange             orange            #fab57f

=item orange             orange            #d99058

=item orange             orange            #f6a600

=item orange             orange            #ffc14f

=item orange             orange            #eaa221

=item orange             orange            #c98500

=item orange             orange            #fbc97f

=item orange             orange            #e3a857

=item orange             orange            #be8a3d

=item orange             orange            #fad6a5

=item orange             orange            #c19a6b

=item orange             orange            #fada5e

=item orange             orange            #d4af37

=item orange             orange            #f8de7e

=item orange             orange            #c9ae5d

=item orange             orange            #f3e5ab

=item orange brown       orangebrown       #722f37

=item orange brown       orangebrown       #cb6d51

=item orange brown       orangebrown       #b4745e

=item orange brown       orangebrown       #882d17

=item orange brown       orangebrown       #be6516

=item orange brown       orangebrown       #d99058

=item orange brown       orangebrown       #ae6938

=item orange brown       orangebrown       #80461b

=item orange brown       orangebrown       #a67b5b

=item orange brown       orangebrown       #6f4e37

=item orange brown       orangebrown       #958070

=item orange brown       orangebrown       #ae9b82

=item orange buff        orangebuff        #d9a6a9

=item orange red         orangered         #c08081

=item orange red         orangered         #d9603b

=item orange red         orangered         #cb6d51

=item orange vermilion   orangevermilion   #cb6d51

=item orange vermilion   orangevermilion   #be6516

=item orange yellow      orangeyellow      #f38400

=item orange yellow      orangeyellow      #fd943f

=item orange yellow      orangeyellow      #ed872d

=item orange yellow      orangeyellow      #fab57f

=item orange yellow      orangeyellow      #ffc14f

=item orange yellow      orangeyellow      #eaa221

=item orange yellow      orangeyellow      #c98500

=item orange yellow      orangeyellow      #fbc97f

=item orange yellow      orangeyellow      #e3a857

=item pale blue          paleblue          #536878

=item pale blue          paleblue          #bfb9bd

=item pale brown         palebrown         #d99058

=item pale brown         palebrown         #a67b5b

=item pale gray green    palegraygreen     #dadfb7

=item pale green         palegreen         #c9dc89

=item pale green         palegreen         #8a9a5b

=item pale green         palegreen         #8ed1b2

=item pale lilac         palelilac         #e8ccd7

=item pale olive green   paleolivegreen    #8a9a5b

=item pale yellow-green  paleyellowgreen   #bdda57

=item pale yellow-green  paleyellowgreen   #c9dc89

=item pale yellow-green  paleyellowgreen   #83d37d

=item peacock blue       peacockblue       #007791

=item pink               pink              #ea9399

=item pink               pink              #e4717a

=item pink               pink              #f88379

=item pink               pink              #ffc8d6

=item pink               pink              #e68fac

=item pink               pink              #de6fa1

=item pink               pink              #a8516e

=item plum               plum              #870074

=item plum               plum              #702963

=item plum               plum              #78184a

=item prussian blue      prussianblue      #2e8495

=item prussian blue      prussianblue      #004958

=item prussian green     prussiangreen     #007a74

=item prussian green     prussiangreen     #00443f

=item prussian green     prussiangreen     #317873

=item prussian green     prussiangreen     #2e8495

=item purple             purple            #272458

=item purple             purple            #4e5180

=item purple             purple            #604e97

=item purple             purple            #604e81

=item purple             purple            #554c69

=item purple             purple            #9a4eae

=item purple             purple            #875692

=item purple             purple            #602f6b

=item purple             purple            #86608e

=item purple             purple            #915c83

=item purple             purple            #5d3954

=item purple             purple            #836479

=item purple brown       purplebrown       #796878

=item purplish bistre    purplishbistre    #c2ac99

=item red                red               #e4717a

=item red                red               #dea5a4

=item red                red               #c4aead

=item red                red               #bc3f4a

=item red                red               #905d5d

=item red                red               #f88379

=item red                red               #e66761

=item red                red               #f4c2c2

=item red                red               #d9a6a9

=item red                red               #d9603b

=item red                red               #aa381e

=item red                red               #cb6d51

=item red brown          redbrown          #c4aead

=item red brown          redbrown          #722f37

=item red brown          redbrown          #ad8884

=item red brown          redbrown          #905d5d

=item red brown          redbrown          #8f817f

=item red brown          redbrown          #ecd5c5

=item red brown          redbrown          #c7ada3

=item red brown          redbrown          #cb6d51

=item red brown          redbrown          #9e4732

=item red brown          redbrown          #a87c6d

=item red brown          redbrown          #79443b

=item red brown          redbrown          #be6516

=item red brown          redbrown          #d99058

=item red brown          redbrown          #ae6938

=item red brown          redbrown          #a67b5b

=item red brown          redbrown          #6f4e37

=item red brown          redbrown          #996515

=item red brown          redbrown          #826644

=item red brown          redbrown          #6c541e

=item reddish brown      reddishbrown      #674c47

=item red lilac          redlilac          #c4aead

=item red lilac          redlilac          #a8516e

=item red lilac          redlilac          #915f6d

=item red orange         redorange         #be0032

=item red orange         redorange         #ffb7a5

=item red orange         redorange         #e25822

=item red orange         redorange         #d9603b

=item red orange         redorange         #ed872d

=item red purple         redpurple         #702963

=item red purple         redpurple         #673147

=item red violet         redviolet         #9a4eae

=item red violet         redviolet         #875692

=item red violet         redviolet         #602f6b

=item red violet         redviolet         #b695c0

=item red violet         redviolet         #86608e

=item red violet         redviolet         #9e4f88

=item red violet         redviolet         #702963

=item red violet         redviolet         #b784a7

=item red violet         redviolet         #915c83

=item red violet         redviolet         #efbbcc

=item red violet         redviolet         #d597ae

=item red violet         redviolet         #c3a6b1

=item red violet         redviolet         #915f6d

=item rose               rose              #ffb5ba

=item rose               rose              #ea9399

=item rose               rose              #e4717a

=item rose               rose              #f9ccca

=item rose               rose              #dea5a4

=item rose               rose              #c08081

=item rose               rose              #bc3f4a

=item rose               rose              #841b2d

=item rose               rose              #ab4e52

=item rose               rose              #905d5d

=item rose               rose              #ffb7a5

=item rose               rose              #f88379

=item rose               rose              #e66761

=item rose               rose              #f4c2c2

=item rose               rose              #d9a6a9

=item rose               rose              #c48379

=item rose               rose              #ecd5c5

=item rose               rose              #c7ada3

=item rose               rose              #cb6d51

=item rose               rose              #aa98a9

=item rose               rose              #e68fac

=item rose               rose              #de6fa1

=item rose               rose              #efbbcc

=item rose               rose              #d597ae

=item rose               rose              #c17e91

=item rose               rose              #ce4676

=item rose               rose              #b3446c

=item rose               rose              #a8516e

=item rose               rose              #915f6d

=item rose brown         rosebrown         #be0032

=item rose brown         rosebrown         #841b2d

=item rose brown         rosebrown         #5c0923

=item rose brown         rosebrown         #78184a

=item rose brown         rosebrown         #54133b

=item rose carmine       rosecarmine       #e4717a

=item rose carmine       rosecarmine       #ce4676

=item rose carmine       rosecarmine       #b3446c

=item rose carmine       rosecarmine       #a8516e

=item rose lake          roselake          #dea5a4

=item rose lake          roselake          #673147

=item rose lake          roselake          #915f6d

=item rose lilac         roselilac         #9e4f88

=item rose lilac         roselilac         #b784a7

=item rose lilac         roselilac         #d597ae

=item rose lilac         roselilac         #c17e91

=item rose lilac         roselilac         #a8516e

=item rose lilac         roselilac         #915f6d

=item rose pink          rosepink          #ce4676

=item rose red           rosered           #e4717a

=item rose red           rosered           #ab4e52

=item rose red           rosered           #722f37

=item rose violet        roseviolet        #9e4f88

=item rose violet        roseviolet        #702963

=item rose violet        roseviolet        #915c83

=item rose violet        roseviolet        #78184a

=item rose violet        roseviolet        #a8516e

=item royal blue         royalblue         #00416a

=item salmon             salmon            #f88379

=item salmon             salmon            #f4c2c2

=item salmon             salmon            #d9a6a9

=item salmon rose        salmonrose        #ea9399

=item salmon rose        salmonrose        #f9ccca

=item salmon rose        salmonrose        #f88379

=item salmon rose        salmonrose        #f4c2c2

=item salmon rose        salmonrose        #d9a6a9

=item scarlet            scarlet           #e4717a

=item scarlet            scarlet           #be0032

=item scarlet            scarlet           #bc3f4a

=item scarlet            scarlet           #ab4e52

=item scarlet            scarlet           #e25822

=item sepia              sepia             #8e8279

=item slate              slate             #8da399

=item slate              slate             #3a4b47

=item slate              slate             #7d8984

=item slate              slate             #4e5755

=item slate              slate             #36454f

=item slate              slate             #202830

=item slate              slate             #81878b

=item slate              slate             #51585e

=item slate              slate             #252440

=item slate              slate             #4c516d

=item slate              slate             #555555

=item slate blue         slateblue         #317873

=item slate blue         slateblue         #536878

=item slate green        slategreen        #8c8767

=item slate green        slategreen        #8a8776

=item slate green        slategreen        #404f00

=item slate green        slategreen        #4a5d23

=item slate green        slategreen        #3b7861

=item slate green        slategreen        #3a4b47

=item slate green        slategreen        #7d8984

=item straw              straw             #c9ae5d

=item turquoise blue     turquoiseblue     #66aabc

=item turquoise green    turquoisegreen    #008882

=item turquoise green    turquoisegreen    #00a693

=item ultramarine        ultramarine       #00a1c2

=item ultramarine        ultramarine       #4997d0

=item ultramarine        ultramarine       #0067a5

=item ultramarine        ultramarine       #00416a

=item ultramarine        ultramarine       #70a3cc

=item ultramarine        ultramarine       #436b95

=item ultramarine        ultramarine       #91a3b0

=item ultramarine        ultramarine       #536878

=item ultramarine        ultramarine       #30267a

=item ultramarine        ultramarine       #6c79b8

=item ultramarine        ultramarine       #545aa7

=item ultramarine        ultramarine       #b3bce2

=item ultramarine        ultramarine       #8791bf

=item ultramarine        ultramarine       #4e5180

=item ultramarine        ultramarine       #c0c8e1

=item ultramarine        ultramarine       #8c92ac

=item ultramarine        ultramarine       #4c516d

=item ultramarine        ultramarine       #8c82b6

=item umber brown        umberbrown        #635147

=item vermilion          vermilion         #c08081

=item vermilion          vermilion         #bc3f4a

=item vermilion          vermilion         #ab4e52

=item vermilion          vermilion         #ad8884

=item vermilion          vermilion         #905d5d

=item vermilion          vermilion         #f88379

=item vermilion          vermilion         #e66761

=item vermilion          vermilion         #c48379

=item vermilion          vermilion         #d9603b

=item vermilion          vermilion         #aa381e

=item vermilion          vermilion         #cb6d51

=item vermilion          vermilion         #9e4732

=item violet             violet            #722f37

=item violet             violet            #4e5180

=item violet             violet            #7e73b8

=item violet             violet            #8c82b6

=item violet             violet            #604e81

=item violet             violet            #9690ab

=item violet             violet            #d399e6

=item violet             violet            #875692

=item violet             violet            #b695c0

=item violet             violet            #86608e

=item violet             violet            #d6cadd

=item violet             violet            #aa98a9

=item violet             violet            #796878

=item violet             violet            #50404d

=item violet             violet            #702963

=item violet             violet            #b784a7

=item violet             violet            #aa8a9e

=item violet             violet            #836479

=item violet             violet            #d597ae

=item violet             violet            #e8ccd7

=item violet             violet            #c3a6b1

=item violet             violet            #af868e

=item violet black       violetblack       #543d3f

=item violet black       violetblack       #5d555b

=item violet blue        violetblue        #545aa7

=item violet brown       violetbrown       #905d5d

=item violet brown       violetbrown       #796878

=item violet brown       violetbrown       #673147

=item yellow             yellow            #f4c2c2

=item yellow             yellow            #d9a6a9

=item yellow             yellow            #f38400

=item yellow             yellow            #fd943f

=item yellow             yellow            #ed872d

=item yellow             yellow            #fab57f

=item yellow             yellow            #d99058

=item yellow             yellow            #a67b5b

=item yellow             yellow            #f6a600

=item yellow             yellow            #ffc14f

=item yellow             yellow            #eaa221

=item yellow             yellow            #c98500

=item yellow             yellow            #fbc97f

=item yellow             yellow            #e3a857

=item yellow             yellow            #be8a3d

=item yellow             yellow            #fad6a5

=item yellow             yellow            #c19a6b

=item yellow             yellow            #f3c300

=item yellow             yellow            #fada5e

=item yellow             yellow            #d4af37

=item yellow             yellow            #af8d13

=item yellow             yellow            #f8de7e

=item yellow             yellow            #c9ae5d

=item yellow             yellow            #ab9144

=item yellow             yellow            #f3e5ab

=item yellow             yellow            #c2b280

=item yellow             yellow            #f0ead6

=item yellow brown       yellowbrown       #c2ac99

=item yellow brown       yellowbrown       #9e4732

=item yellow brown       yellowbrown       #a87c6d

=item yellow brown       yellowbrown       #977f73

=item yellow brown       yellowbrown       #d99058

=item yellow brown       yellowbrown       #ae6938

=item yellow brown       yellowbrown       #80461b

=item yellow brown       yellowbrown       #a67b5b

=item yellow brown       yellowbrown       #be8a3d

=item yellow brown       yellowbrown       #996515

=item yellow brown       yellowbrown       #867e36

=item yellow buff        yellowbuff        #d9a6a9

=item yellow buff        yellowbuff        #d99058

=item yellow buff        yellowbuff        #e3a857

=item yellow buff        yellowbuff        #fad6a5

=item yellow buff        yellowbuff        #c19a6b

=item yellow buff        yellowbuff        #f3e5ab

=item yellow buff        yellowbuff        #c2b280

=item yellow green       yellowgreen       #7e9f2e

=item yellow green       yellowgreen       #8a9a5b

=item yellow green       yellowgreen       #27a64c

=item yellow green       yellowgreen       #83d37d

=item yellow green       yellowgreen       #44944a

=item yellow green       yellowgreen       #00622d

=item yellow green       yellowgreen       #b6e5af

=item yellow green       yellowgreen       #93c592

=item yellow green       yellowgreen       #679267

=item yellow green       yellowgreen       #355e3b

=item yellow green       yellowgreen       #008856

=item yellow green       yellowgreen       #3eb489

=item yellow green       yellowgreen       #007959

=item yellow green       yellowgreen       #8ed1b2

=item yellow green       yellowgreen       #6aab8e

=item yellow green       yellowgreen       #3b7861

=item yellow orange      yelloworange      #ed872d

=item yellow orange      yelloworange      #d99058


=back

=end :man

=cut

sub _load_color_list() {
    return [
['nbs-iscc-s:applegreen.115','applegreen','apple green',[141,182,0],'8db600',9287168],
['nbs-iscc-s:applegreen.117','applegreen','apple green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-s:applegreen.131','applegreen','apple green',[68,148,74],'44944a',4494410],
['nbs-iscc-s:bistre.57','bistre','bistre',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:bistre.63','bistre','bistre',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:bistre.71','bistre','bistre',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:bistre.72','bistre','bistre',[190,138,61],'be8a3d',12487229],
['nbs-iscc-s:bistre.74','bistre','bistre',[153,101,21],'996515',10052885],
['nbs-iscc-s:bistre.76','bistre','bistre',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:bistre.77','bistre','bistre',[130,102,68],'826644',8545860],
['nbs-iscc-s:bistre.79','bistre','bistre',[174,155,130],'ae9b82',11443074],
['nbs-iscc-s:bistre.80','bistre','bistre',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-s:bistre.85','bistre','bistre',[175,141,19],'af8d13',11504915],
['nbs-iscc-s:bistre.87','bistre','bistre',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:bistre.88','bistre','bistre',[171,145,68],'ab9144',11243844],
['nbs-iscc-s:bistre.89','bistre','bistre',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-s:bistre.90','bistre','bistre',[194,178,128],'c2b280',12759680],
['nbs-iscc-s:bistre.91','bistre','bistre',[161,143,96],'a18f60',10588000],
['nbs-iscc-s:bistre.93','bistre','bistre',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-s:bistre.94','bistre','bistre',[150,113,23],'967117',9859351],
['nbs-iscc-s:bistre.95','bistre','bistre',[108,84,30],'6c541e',7099422],
['nbs-iscc-s:bistre.102','bistre','bistre',[185,180,89],'b9b459',12170329],
['nbs-iscc-s:bistre.109','bistre','bistre',[140,135,103],'8c8767',9209703],
['nbs-iscc-s:bistre.112','bistre','bistre',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:bistrebrown.29','bistrebrown','bistre brown',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:bistrebrown.57','bistrebrown','bistre brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:bistrebrown.63','bistrebrown','bistre brown',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:bistrebrown.76','bistrebrown','bistre brown',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:bistrebrown.77','bistrebrown','bistre brown',[130,102,68],'826644',8545860],
['nbs-iscc-s:bistrebrown.94','bistrebrown','bistre brown',[150,113,23],'967117',9859351],
['nbs-iscc-s:bistrebrown.106','bistrebrown','bistre brown',[134,126,54],'867e36',8814134],
['nbs-iscc-s:black.113','black','black',[87,85,76],'57554c',5723468],
['nbs-iscc-s:black.264','black','black',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-s:black.265','black','black',[132,132,130],'848482',8684674],
['nbs-iscc-s:black.266','black','black',[85,85,85],'555555',5592405],
['nbs-iscc-s:black.267','black','black',[34,34,34],'222222',2236962],
['nbs-iscc-s:blackbrown.61','blackbrown','black brown',[99,81,71],'635147',6508871],
['nbs-iscc-s:blackbrown.62','blackbrown','black brown',[62,50,44],'3e322c',4076076],
['nbs-iscc-s:blackbrown.63','blackbrown','black brown',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:blackbrown.64','blackbrown','black brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-s:blackbrown.110','blackbrown','black brown',[91,88,66],'5b5842',5986370],
['nbs-iscc-s:blackbrown.113','blackbrown','black brown',[87,85,76],'57554c',5723468],
['nbs-iscc-s:blackviolet.229','blackviolet','black violet',[80,64,77],'50404d',5259341],
['nbs-iscc-s:blackviolet.230','blackviolet','black violet',[41,30,41],'291e29',2694697],
['nbs-iscc-s:blackviolet.259','blackviolet','black violet',[103,49,71],'673147',6762823],
['nbs-iscc-s:blackviolet.260','blackviolet','black violet',[56,21,44],'38152c',3675436],
['nbs-iscc-s:blue.163','blue','blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-s:blue.164','blue','blue',[49,120,115],'317873',3242099],
['nbs-iscc-s:blue.168','blue','blue',[35,158,186],'239eba',2334394],
['nbs-iscc-s:blue.169','blue','blue',[0,119,145],'007791',30609],
['nbs-iscc-s:blue.170','blue','blue',[46,132,149],'2e8495',3048597],
['nbs-iscc-s:blue.171','blue','blue',[156,209,220],'9cd1dc',10277340],
['nbs-iscc-s:blue.172','blue','blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-s:blue.173','blue','blue',[54,117,136],'367588',3569032],
['nbs-iscc-s:blue.174','blue','blue',[0,73,88],'004958',18776],
['nbs-iscc-s:blue.177','blue','blue',[73,151,208],'4997d0',4822992],
['nbs-iscc-s:blue.178','blue','blue',[0,103,165],'0067a5',26533],
['nbs-iscc-s:blue.179','blue','blue',[0,65,106],'00416a',16746],
['nbs-iscc-s:blue.181','blue','blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-s:blue.182','blue','blue',[67,107,149],'436b95',4418453],
['nbs-iscc-s:blue.183','blue','blue',[0,48,78],'00304e',12366],
['nbs-iscc-s:blue.184','blue','blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-s:blue.186','blue','blue',[83,104,120],'536878',5466232],
['nbs-iscc-s:blueblack.191','blueblack','blue black',[129,135,139],'81878b',8488843],
['nbs-iscc-s:blueblack.192','blueblack','blue black',[81,88,94],'51585e',5331038],
['nbs-iscc-s:bluegray.154','bluegray','blue gray',[178,190,181],'b2beb5',11714229],
['nbs-iscc-s:bluegray.191','bluegray','blue gray',[129,135,139],'81878b',8488843],
['nbs-iscc-s:bluegreen.140','bluegreen','blue green',[62,180,137],'3eb489',4109449],
['nbs-iscc-s:bluegreen.141','bluegreen','blue green',[0,121,89],'007959',31065],
['nbs-iscc-s:bluegreen.143','bluegreen','blue green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-s:bluegreen.144','bluegreen','blue green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-s:bluegreen.145','bluegreen','blue green',[59,120,97],'3b7861',3897441],
['nbs-iscc-s:bluegreen.158','bluegreen','blue green',[0,136,130],'008882',34946],
['nbs-iscc-s:bluegreen.159','bluegreen','blue green',[0,166,147],'00a693',42643],
['nbs-iscc-s:bluegreen.160','bluegreen','blue green',[0,122,116],'007a74',31348],
['nbs-iscc-s:bluegreen.163','bluegreen','blue green',[102,173,164],'66ada4',6729124],
['nbs-iscc-s:bluegreen.164','bluegreen','blue green',[49,120,115],'317873',3242099],
['nbs-iscc-s:bluegreen.173','bluegreen','blue green',[54,117,136],'367588',3569032],
['nbs-iscc-s:blueviolet.199','blueviolet','blue violet',[135,145,191],'8791bf',8884671],
['nbs-iscc-s:brickred.19','brickred','brick red',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:brickred.46','brickred','brick red',[103,76,71],'674c47',6769735],
['nbs-iscc-s:brightblue.160','brightblue','bright blue',[0,122,116],'007a74',31348],
['nbs-iscc-s:brightblue.169','brightblue','bright blue',[0,119,145],'007791',30609],
['nbs-iscc-s:brightblue.178','brightblue','bright blue',[0,103,165],'0067a5',26533],
['nbs-iscc-s:brightblue.182','brightblue','bright blue',[67,107,149],'436b95',4418453],
['nbs-iscc-s:brightbluegreen.139','brightbluegreen','bright blue green',[0,136,86],'008856',34902],
['nbs-iscc-s:brightbluegreen.140','brightbluegreen','bright blue green',[62,180,137],'3eb489',4109449],
['nbs-iscc-s:brightbluegreen.141','brightbluegreen','bright blue green',[0,121,89],'007959',31065],
['nbs-iscc-s:brightgreen.129','brightgreen','bright green',[39,166,76],'27a64c',2598476],
['nbs-iscc-s:brightgreen.139','brightgreen','bright green',[0,136,86],'008856',34902],
['nbs-iscc-s:brightgreen.141','brightgreen','bright green',[0,121,89],'007959',31065],
['nbs-iscc-s:brightgreen.142','brightgreen','bright green',[0,84,61],'00543d',21565],
['nbs-iscc-s:brightredviolet.216','brightredviolet','bright red violet',[154,78,174],'9a4eae',10112686],
['nbs-iscc-s:brightredviolet.218','brightredviolet','bright red violet',[135,86,146],'875692',8869522],
['nbs-iscc-s:brightredviolet.236','brightredviolet','bright red violet',[135,0,116],'870074',8847476],
['nbs-iscc-s:brightredviolet.237','brightredviolet','bright red violet',[158,79,136],'9e4f88',10375048],
['nbs-iscc-s:brightrose.248','brightrose','bright rose',[222,111,161],'de6fa1',14577569],
['nbs-iscc-s:brightrose.254','brightrose','bright rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-s:brightrose.262','brightrose','bright rose',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:brightroseviolet.248','brightroseviolet','bright rose violet',[222,111,161],'de6fa1',14577569],
['nbs-iscc-s:brightultramarine.176','brightultramarine','bright ultramarine',[0,161,194],'00a1c2',41410],
['nbs-iscc-s:brightultramarine.178','brightultramarine','bright ultramarine',[0,103,165],'0067a5',26533],
['nbs-iscc-s:brightultramarine.194','brightultramarine','bright ultramarine',[48,38,122],'30267a',3155578],
['nbs-iscc-s:brightultramarine.196','brightultramarine','bright ultramarine',[84,90,167],'545aa7',5528231],
['nbs-iscc-s:brightviolet.205','brightviolet','bright violet',[144,101,202],'9065ca',9463242],
['nbs-iscc-s:brightviolet.211','brightviolet','bright violet',[96,78,129],'604e81',6311553],
['nbs-iscc-s:brightviolet.216','brightviolet','bright violet',[154,78,174],'9a4eae',10112686],
['nbs-iscc-s:brightviolet.218','brightviolet','bright violet',[135,86,146],'875692',8869522],
['nbs-iscc-s:brightviolet.222','brightviolet','bright violet',[182,149,192],'b695c0',11965888],
['nbs-iscc-s:brightviolet.223','brightviolet','bright violet',[134,96,142],'86608e',8806542],
['nbs-iscc-s:brightyellow.67','brightyellow','bright yellow',[255,193,79],'ffc14f',16761167],
['nbs-iscc-s:brightyellow.68','brightyellow','bright yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-s:brightyellow.70','brightyellow','bright yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-s:brightyellow.71','brightyellow','bright yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:brightyellow.83','brightyellow','bright yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-s:brightyellow.84','brightyellow','bright yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-s:brightyellow.86','brightyellow','bright yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-s:brightyellow.87','brightyellow','bright yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:brown.10','brown','brown',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-s:brown.19','brown','brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:brown.23','brown','brown',[92,80,79],'5c504f',6049871],
['nbs-iscc-s:brown.37','brown','brown',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:brown.42','brown','brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-s:brown.43','brown','brown',[121,68,59],'79443b',7947323],
['nbs-iscc-s:brown.45','brown','brown',[151,127,115],'977f73',9928563],
['nbs-iscc-s:brown.46','brown','brown',[103,76,71],'674c47',6769735],
['nbs-iscc-s:brown.54','brown','brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-s:brown.55','brown','brown',[128,70,27],'80461b',8406555],
['nbs-iscc-s:brown.57','brown','brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:brown.58','brown','brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-s:brown.60','brown','brown',[149,128,112],'958070',9797744],
['nbs-iscc-s:brown.61','brown','brown',[99,81,71],'635147',6508871],
['nbs-iscc-s:brown.63','brown','brown',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:brown.64','brown','brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-s:brown.79','brown','brown',[174,155,130],'ae9b82',11443074],
['nbs-iscc-s:brown.80','brown','brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-s:brownbistre.76','brownbistre','brown bistre',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:brownbistre.79','brownbistre','brown bistre',[174,155,130],'ae9b82',11443074],
['nbs-iscc-s:brownbistre.87','brownbistre','brown bistre',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:brownbistre.94','brownbistre','brown bistre',[150,113,23],'967117',9859351],
['nbs-iscc-s:brownblack.64','brownblack','brown-black',[91,80,79],'5b504f',5984335],
['nbs-iscc-s:browncarmine.12','browncarmine','brown carmine',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:browncarmine.14','browncarmine','brown carmine',[92,9,35],'5c0923',6031651],
['nbs-iscc-s:browncarmine.16','browncarmine','brown carmine',[114,47,55],'722f37',7483191],
['nbs-iscc-s:brownlake.15','brownlake','brown lake',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:brownlake.19','brownlake','brown lake',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:brownolive.74','brownolive','brown olive',[153,101,21],'996515',10052885],
['nbs-iscc-s:brownolive.94','brownolive','brown olive',[150,113,23],'967117',9859351],
['nbs-iscc-s:brownorange.29','brownorange','brown orange',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:brownorange.37','brownorange','brown orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:brownorange.39','brownorange','brown orange',[180,116,94],'b4745e',11826270],
['nbs-iscc-s:brownorange.50','brownorange','brown orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-s:brownorange.51','brownorange','brown orange',[190,101,22],'be6516',12477718],
['nbs-iscc-s:brownorange.53','brownorange','brown orange',[217,144,88],'d99058',14258264],
['nbs-iscc-s:brownorange.54','brownorange','brown orange',[174,105,56],'ae6938',11430200],
['nbs-iscc-s:brownorange.57','brownorange','brown orange',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:brownorange.68','brownorange','brown orange',[234,162,33],'eaa221',15376929],
['nbs-iscc-s:brownorange.71','brownorange','brown orange',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:brownorange.76','brownorange','brown orange',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:brownorange.87','brownorange','brown orange',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:brownpurple.228','brownpurple','brown purple',[121,104,120],'796878',7956600],
['nbs-iscc-s:brownred.11','brownred','brown red',[190,0,50],'be0032',12451890],
['nbs-iscc-s:brownred.18','brownred','brown red',[173,136,132],'ad8884',11372676],
['nbs-iscc-s:brownred.19','brownred','brown red',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:brownred.46','brownred','brown red',[103,76,71],'674c47',6769735],
['nbs-iscc-s:brownviolet.259','brownviolet','brown violet',[103,49,71],'673147',6762823],
['nbs-iscc-s:brownviolet.262','brownviolet','brown violet',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:buff.28','buff','buff',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-s:buff.29','buff','buff',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:buff.31','buff','buff',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-s:buff.33','buff','buff',[194,172,153],'c2ac99',12758169],
['nbs-iscc-s:buff.52','buff','buff',[250,181,127],'fab57f',16430463],
['nbs-iscc-s:buff.53','buff','buff',[217,144,88],'d99058',14258264],
['nbs-iscc-s:buff.71','buff','buff',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:buff.73','buff','buff',[250,214,165],'fad6a5',16438949],
['nbs-iscc-s:buff.76','buff','buff',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:buff.79','buff','buff',[174,155,130],'ae9b82',11443074],
['nbs-iscc-s:buff.89','buff','buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-s:buff.92','buff','buff',[240,234,214],'f0ead6',15788758],
['nbs-iscc-s:buff.93','buff','buff',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-s:burntorange.35','burntorange','burnt orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-s:burntorange.51','burntorange','burnt orange',[190,101,22],'be6516',12477718],
['nbs-iscc-s:burntorange.53','burntorange','burnt orange',[217,144,88],'d99058',14258264],
['nbs-iscc-s:burntorange.54','burntorange','burnt orange',[174,105,56],'ae6938',11430200],
['nbs-iscc-s:carmine.1','carmine','carmine',[255,181,186],'ffb5ba',16758202],
['nbs-iscc-s:carmine.2','carmine','carmine',[234,147,153],'ea9399',15373209],
['nbs-iscc-s:carmine.3','carmine','carmine',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:carmine.6','carmine','carmine',[192,128,129],'c08081',12615809],
['nbs-iscc-s:carmine.11','carmine','carmine',[190,0,50],'be0032',12451890],
['nbs-iscc-s:carmine.12','carmine','carmine',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:carmine.13','carmine','carmine',[132,27,45],'841b2d',8657709],
['nbs-iscc-s:carmine.15','carmine','carmine',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:carmine.19','carmine','carmine',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:carmine.254','carmine','carmine',[206,70,118],'ce4676',13518454],
['nbs-iscc-s:carmine.255','carmine','carmine',[179,68,108],'b3446c',11748460],
['nbs-iscc-s:carmine.256','carmine','carmine',[120,24,74],'78184a',7870538],
['nbs-iscc-s:carmine.258','carmine','carmine',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:carminelake.11','carminelake','carmine lake',[190,0,50],'be0032',12451890],
['nbs-iscc-s:carminelake.12','carminelake','carmine lake',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:carminelake.15','carminelake','carmine lake',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:carminelake.255','carminelake','carmine lake',[179,68,108],'b3446c',11748460],
['nbs-iscc-s:carminelake.258','carminelake','carmine lake',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:carminerose.1','carminerose','carmine rose',[255,181,186],'ffb5ba',16758202],
['nbs-iscc-s:carminerose.2','carminerose','carmine rose',[234,147,153],'ea9399',15373209],
['nbs-iscc-s:carminerose.3','carminerose','carmine rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:carminerose.11','carminerose','carmine rose',[190,0,50],'be0032',12451890],
['nbs-iscc-s:carminerose.12','carminerose','carmine rose',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:carminerose.15','carminerose','carmine rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:carminerose.19','carminerose','carmine rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:carminerose.27','carminerose','carmine rose',[230,103,97],'e66761',15099745],
['nbs-iscc-s:carminerose.248','carminerose','carmine rose',[222,111,161],'de6fa1',14577569],
['nbs-iscc-s:carminerose.255','carminerose','carmine rose',[179,68,108],'b3446c',11748460],
['nbs-iscc-s:carminerose.258','carminerose','carmine rose',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:cerise.254','cerise','cerise',[206,70,118],'ce4676',13518454],
['nbs-iscc-s:cerise.256','cerise','cerise',[120,24,74],'78184a',7870538],
['nbs-iscc-s:chalkyblue.185','chalkyblue','chalky blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-s:chestnutbrown.38','chestnutbrown','chestnut brown',[158,71,50],'9e4732',10372914],
['nbs-iscc-s:chocolate.19','chocolate','chocolate',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:chocolate.22','chocolate','chocolate',[143,129,127],'8f817f',9404799],
['nbs-iscc-s:chocolate.23','chocolate','chocolate',[92,80,79],'5c504f',6049871],
['nbs-iscc-s:chocolate.41','chocolate','chocolate',[86,7,12],'56070c',5637900],
['nbs-iscc-s:chocolate.46','chocolate','chocolate',[103,76,71],'674c47',6769735],
['nbs-iscc-s:claret.251','claret','claret',[193,126,145],'c17e91',12680849],
['nbs-iscc-s:claret.262','claret','claret',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:claretbrown.13','claretbrown','claret brown',[132,27,45],'841b2d',8657709],
['nbs-iscc-s:claretbrown.16','claretbrown','claret brown',[114,47,55],'722f37',7483191],
['nbs-iscc-s:claretbrown.228','claretbrown','claret brown',[121,104,120],'796878',7956600],
['nbs-iscc-s:crimson.11','crimson','crimson',[190,0,50],'be0032',12451890],
['nbs-iscc-s:crimson.12','crimson','crimson',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:darkblue.170','darkblue','dark blue',[46,132,149],'2e8495',3048597],
['nbs-iscc-s:darkblue.173','darkblue','dark blue',[54,117,136],'367588',3569032],
['nbs-iscc-s:darkblue.174','darkblue','dark blue',[0,73,88],'004958',18776],
['nbs-iscc-s:darkblue.178','darkblue','dark blue',[0,103,165],'0067a5',26533],
['nbs-iscc-s:darkblue.179','darkblue','dark blue',[0,65,106],'00416a',16746],
['nbs-iscc-s:darkblue.182','darkblue','dark blue',[67,107,149],'436b95',4418453],
['nbs-iscc-s:darkblue.183','darkblue','dark blue',[0,48,78],'00304e',12366],
['nbs-iscc-s:darkblue.186','darkblue','dark blue',[83,104,120],'536878',5466232],
['nbs-iscc-s:darkblue.187','darkblue','dark blue',[54,69,79],'36454f',3556687],
['nbs-iscc-s:darkblue.188','darkblue','dark blue',[32,40,48],'202830',2107440],
['nbs-iscc-s:darkblue.197','darkblue','dark blue',[39,36,88],'272458',2565208],
['nbs-iscc-s:darkblue.199','darkblue','dark blue',[135,145,191],'8791bf',8884671],
['nbs-iscc-s:darkbluegreen.141','darkbluegreen','dark blue green',[0,121,89],'007959',31065],
['nbs-iscc-s:darkbluegreen.146','darkbluegreen','dark blue green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-s:darkbluegreen.147','darkbluegreen','dark blue green',[28,53,45],'1c352d',1848621],
['nbs-iscc-s:darkbluegreen.151','darkbluegreen','dark blue green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-s:darkbluegreen.152','darkbluegreen','dark blue green',[26,36,33],'1a2421',1713185],
['nbs-iscc-s:darkbluegreen.160','darkbluegreen','dark blue green',[0,122,116],'007a74',31348],
['nbs-iscc-s:darkbluegreen.163','darkbluegreen','dark blue green',[102,173,164],'66ada4',6729124],
['nbs-iscc-s:darkbluegreen.164','darkbluegreen','dark blue green',[49,120,115],'317873',3242099],
['nbs-iscc-s:darkbluegreen.173','darkbluegreen','dark blue green',[54,117,136],'367588',3569032],
['nbs-iscc-s:darkbrown.20','darkbrown','dark brown',[84,61,63],'543d3f',5520703],
['nbs-iscc-s:darkbrown.22','darkbrown','dark brown',[143,129,127],'8f817f',9404799],
['nbs-iscc-s:darkbrown.23','darkbrown','dark brown',[92,80,79],'5c504f',6049871],
['nbs-iscc-s:darkbrown.43','darkbrown','dark brown',[121,68,59],'79443b',7947323],
['nbs-iscc-s:darkbrown.45','darkbrown','dark brown',[151,127,115],'977f73',9928563],
['nbs-iscc-s:darkbrown.58','darkbrown','dark brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-s:darkbrown.61','darkbrown','dark brown',[99,81,71],'635147',6508871],
['nbs-iscc-s:darkbrown.63','darkbrown','dark brown',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:darkbrown.64','darkbrown','dark brown',[91,80,79],'5b504f',5984335],
['nbs-iscc-s:darkbrown.80','darkbrown','dark brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-s:darkbrown.93','darkbrown','dark brown',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-s:darkcarmine.11','darkcarmine','dark carmine',[190,0,50],'be0032',12451890],
['nbs-iscc-s:darkcarmine.15','darkcarmine','dark carmine',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:darkgray.192','darkgray','dark gray',[81,88,94],'51585e',5331038],
['nbs-iscc-s:darkgreen.132','darkgreen','dark green',[0,98,45],'00622d',25133],
['nbs-iscc-s:darkgreen.137','darkgreen','dark green',[53,94,59],'355e3b',3497531],
['nbs-iscc-s:darkgreen.141','darkgreen','dark green',[0,121,89],'007959',31065],
['nbs-iscc-s:darkgreen.142','darkgreen','dark green',[0,84,61],'00543d',21565],
['nbs-iscc-s:darkgreen.145','darkgreen','dark green',[59,120,97],'3b7861',3897441],
['nbs-iscc-s:darkgreen.146','darkgreen','dark green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-s:darkgreen.150','darkgreen','dark green',[94,113,106],'5e716a',6189418],
['nbs-iscc-s:darkgreen.151','darkgreen','dark green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-s:darkgreen.155','darkgreen','dark green',[125,137,132],'7d8984',8227204],
['nbs-iscc-s:darkgreen.164','darkgreen','dark green',[49,120,115],'317873',3242099],
['nbs-iscc-s:darkochre.94','darkochre','dark ochre',[150,113,23],'967117',9859351],
['nbs-iscc-s:darkolive.110','darkolive','dark olive',[91,88,66],'5b5842',5986370],
['nbs-iscc-s:darkolive.113','darkolive','dark olive',[87,85,76],'57554c',5723468],
['nbs-iscc-s:darkolive.127','darkolive','dark olive',[81,87,68],'515744',5330756],
['nbs-iscc-s:darkolivegreen.125','darkolivegreen','dark olive green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-s:darkredbrown.46','darkredbrown','dark red brown',[103,76,71],'674c47',6769735],
['nbs-iscc-s:darkrose.15','darkrose','dark rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:darkslategreen.146','darkslategreen','dark slate green',[27,77,62],'1b4d3e',1789246],
['nbs-iscc-s:darkslategreen.147','darkslategreen','dark slate green',[28,53,45],'1c352d',1848621],
['nbs-iscc-s:darkslategreen.151','darkslategreen','dark slate green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-s:darkslategreen.152','darkslategreen','dark slate green',[26,36,33],'1a2421',1713185],
['nbs-iscc-s:darkviolet.224','darkviolet','dark violet',[86,60,92],'563c5c',5651548],
['nbs-iscc-s:darkviolet.227','darkviolet','dark violet',[170,152,169],'aa98a9',11180201],
['nbs-iscc-s:darkviolet.228','darkviolet','dark violet',[121,104,120],'796878',7956600],
['nbs-iscc-s:darkviolet.233','darkviolet','dark violet',[139,133,137],'8b8589',9143689],
['nbs-iscc-s:darkviolet.262','darkviolet','dark violet',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:darkvioletbrown.229','darkvioletbrown','dark violet brown',[80,64,77],'50404d',5259341],
['nbs-iscc-s:darkvioletbrown.230','darkvioletbrown','dark violet brown',[41,30,41],'291e29',2694697],
['nbs-iscc-s:darkvioletbrown.259','darkvioletbrown','dark violet brown',[103,49,71],'673147',6762823],
['nbs-iscc-s:darkvioletbrown.260','darkvioletbrown','dark violet brown',[56,21,44],'38152c',3675436],
['nbs-iscc-s:deepbistre.94','deepbistre','deep bistre',[150,113,23],'967117',9859351],
['nbs-iscc-s:deepblue.170','deepblue','deep blue',[46,132,149],'2e8495',3048597],
['nbs-iscc-s:deepblue.173','deepblue','deep blue',[54,117,136],'367588',3569032],
['nbs-iscc-s:deepblue.176','deepblue','deep blue',[0,161,194],'00a1c2',41410],
['nbs-iscc-s:deepblue.178','deepblue','deep blue',[0,103,165],'0067a5',26533],
['nbs-iscc-s:deepblue.179','deepblue','deep blue',[0,65,106],'00416a',16746],
['nbs-iscc-s:deepblue.181','deepblue','deep blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-s:deepblue.182','deepblue','deep blue',[67,107,149],'436b95',4418453],
['nbs-iscc-s:deepblue.186','deepblue','deep blue',[83,104,120],'536878',5466232],
['nbs-iscc-s:deepbrown.43','deepbrown','deep brown',[121,68,59],'79443b',7947323],
['nbs-iscc-s:deepbrown.55','deepbrown','deep brown',[128,70,27],'80461b',8406555],
['nbs-iscc-s:deepbrown.58','deepbrown','deep brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-s:deepclaret.16','deepclaret','deep claret',[114,47,55],'722f37',7483191],
['nbs-iscc-s:deepgreen.117','deepgreen','deep green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-s:deepgreen.120','deepgreen','deep green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-s:deepgreen.129','deepgreen','deep green',[39,166,76],'27a64c',2598476],
['nbs-iscc-s:deepgreen.130','deepgreen','deep green',[131,211,125],'83d37d',8639357],
['nbs-iscc-s:deepgreen.131','deepgreen','deep green',[68,148,74],'44944a',4494410],
['nbs-iscc-s:deepgreen.132','deepgreen','deep green',[0,98,45],'00622d',25133],
['nbs-iscc-s:deepgreen.133','deepgreen','deep green',[0,49,24],'003118',12568],
['nbs-iscc-s:deepgreen.135','deepgreen','deep green',[147,197,146],'93c592',9684370],
['nbs-iscc-s:deepgreen.141','deepgreen','deep green',[0,121,89],'007959',31065],
['nbs-iscc-s:deepgreen.142','deepgreen','deep green',[0,84,61],'00543d',21565],
['nbs-iscc-s:deepgreen.145','deepgreen','deep green',[59,120,97],'3b7861',3897441],
['nbs-iscc-s:deepgreen.155','deepgreen','deep green',[125,137,132],'7d8984',8227204],
['nbs-iscc-s:deepgreen.160','deepgreen','deep green',[0,122,116],'007a74',31348],
['nbs-iscc-s:deepgreen.163','deepgreen','deep green',[102,173,164],'66ada4',6729124],
['nbs-iscc-s:deepgreen.164','deepgreen','deep green',[49,120,115],'317873',3242099],
['nbs-iscc-s:deepgreen.165','deepgreen','deep green',[0,75,73],'004b49',19273],
['nbs-iscc-s:deeplake.259','deeplake','deep lake',[103,49,71],'673147',6762823],
['nbs-iscc-s:deepmagenta.254','deepmagenta','deep magenta',[206,70,118],'ce4676',13518454],
['nbs-iscc-s:deepolivegreen.125','deepolivegreen','deep olive green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-s:deeporange.26','deeporange','deep orange',[248,131,121],'f88379',16286585],
['nbs-iscc-s:deeporange.53','deeporange','deep orange',[217,144,88],'d99058',14258264],
['nbs-iscc-s:deepplum.258','deepplum','deep plum',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:deepultramarine.176','deepultramarine','deep ultramarine',[0,161,194],'00a1c2',41410],
['nbs-iscc-s:deepultramarine.182','deepultramarine','deep ultramarine',[67,107,149],'436b95',4418453],
['nbs-iscc-s:deepultramarine.194','deepultramarine','deep ultramarine',[48,38,122],'30267a',3155578],
['nbs-iscc-s:deepviolet.206','deepviolet','deep violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-s:deepviolet.218','deepviolet','deep violet',[135,86,146],'875692',8869522],
['nbs-iscc-s:deepviolet.223','deepviolet','deep violet',[134,96,142],'86608e',8806542],
['nbs-iscc-s:deepviolet.238','deepviolet','deep violet',[112,41,99],'702963',7350627],
['nbs-iscc-s:dullblue.178','dullblue','dull blue',[0,103,165],'0067a5',26533],
['nbs-iscc-s:dullblue.179','dullblue','dull blue',[0,65,106],'00416a',16746],
['nbs-iscc-s:dullblue.181','dullblue','dull blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-s:dullblue.182','dullblue','dull blue',[67,107,149],'436b95',4418453],
['nbs-iscc-s:dullblue.186','dullblue','dull blue',[83,104,120],'536878',5466232],
['nbs-iscc-s:dullblue.192','dullblue','dull blue',[81,88,94],'51585e',5331038],
['nbs-iscc-s:dullblue.204','dullblue','dull blue',[76,81,109],'4c516d',5001581],
['nbs-iscc-s:dullbuff.31','dullbuff','dull buff',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-s:dullbuff.32','dullbuff','dull buff',[199,173,163],'c7ada3',13086115],
['nbs-iscc-s:dullbuff.70','dullbuff','dull buff',[251,201,127],'fbc97f',16501119],
['nbs-iscc-s:dullbuff.71','dullbuff','dull buff',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:dullbuff.73','dullbuff','dull buff',[250,214,165],'fad6a5',16438949],
['nbs-iscc-s:dullgreen.127','dullgreen','dull green',[81,87,68],'515744',5330756],
['nbs-iscc-s:dullgreen.135','dullgreen','dull green',[147,197,146],'93c592',9684370],
['nbs-iscc-s:dullgreen.137','dullgreen','dull green',[53,94,59],'355e3b',3497531],
['nbs-iscc-s:dullgreen.144','dullgreen','dull green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-s:dullgreen.145','dullgreen','dull green',[59,120,97],'3b7861',3897441],
['nbs-iscc-s:dullgreen.151','dullgreen','dull green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-s:dullgreen.163','dullgreen','dull green',[102,173,164],'66ada4',6729124],
['nbs-iscc-s:dulllilac.211','dulllilac','dull lilac',[96,78,129],'604e81',6311553],
['nbs-iscc-s:dulllilac.227','dulllilac','dull lilac',[170,152,169],'aa98a9',11180201],
['nbs-iscc-s:dulllilac.262','dulllilac','dull lilac',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:dullorange.10','dullorange','dull orange',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-s:dullred.35','dullred','dull red',[217,96,59],'d9603b',14245947],
['nbs-iscc-s:dullrose.2','dullrose','dull rose',[234,147,153],'ea9399',15373209],
['nbs-iscc-s:dullrose.18','dullrose','dull rose',[173,136,132],'ad8884',11372676],
['nbs-iscc-s:dullrose.250','dullrose','dull rose',[213,151,174],'d597ae',13997998],
['nbs-iscc-s:dullvermilion.37','dullvermilion','dull vermilion',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:dullviolet.228','dullviolet','dull violet',[121,104,120],'796878',7956600],
['nbs-iscc-s:dullviolet.245','dullviolet','dull violet',[131,100,121],'836479',8610937],
['nbs-iscc-s:dullviolet.259','dullviolet','dull violet',[103,49,71],'673147',6762823],
['nbs-iscc-s:dullviolet.261','dullviolet','dull violet',[175,134,142],'af868e',11503246],
['nbs-iscc-s:dullviolet.262','dullviolet','dull violet',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:dullyellow.70','dullyellow','dull yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-s:dullyellow.71','dullyellow','dull yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:emerald.129','emerald','emerald',[39,166,76],'27a64c',2598476],
['nbs-iscc-s:emerald.130','emerald','emerald',[131,211,125],'83d37d',8639357],
['nbs-iscc-s:emerald.131','emerald','emerald',[68,148,74],'44944a',4494410],
['nbs-iscc-s:emerald.132','emerald','emerald',[0,98,45],'00622d',25133],
['nbs-iscc-s:emerald.139','emerald','emerald',[0,136,86],'008856',34902],
['nbs-iscc-s:emerald.140','emerald','emerald',[62,180,137],'3eb489',4109449],
['nbs-iscc-s:emerald.144','emerald','emerald',[106,171,142],'6aab8e',6990734],
['nbs-iscc-s:fawn.29','fawn','fawn',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:fawn.43','fawn','fawn',[121,68,59],'79443b',7947323],
['nbs-iscc-s:gray.93','gray','gray',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-s:gray.112','gray','gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:gray.149','gray','gray',[141,163,153],'8da399',9282457],
['nbs-iscc-s:gray.154','gray','gray',[178,190,181],'b2beb5',11714229],
['nbs-iscc-s:gray.155','gray','gray',[125,137,132],'7d8984',8227204],
['nbs-iscc-s:gray.156','gray','gray',[78,87,85],'4e5755',5134165],
['nbs-iscc-s:gray.189','gray','gray',[233,233,237],'e9e9ed',15329773],
['nbs-iscc-s:gray.192','gray','gray',[81,88,94],'51585e',5331038],
['nbs-iscc-s:gray.232','gray','gray',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-s:gray.264','gray','gray',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-s:gray.265','gray','gray',[132,132,130],'848482',8684674],
['nbs-iscc-s:graybistre.76','graybistre','gray bistre',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:graybistre.79','graybistre','gray bistre',[174,155,130],'ae9b82',11443074],
['nbs-iscc-s:graybistre.94','graybistre','gray bistre',[150,113,23],'967117',9859351],
['nbs-iscc-s:grayblack.63','grayblack','gray black',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:grayblack.112','grayblack','gray black',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:grayblack.113','grayblack','gray black',[87,85,76],'57554c',5723468],
['nbs-iscc-s:grayblack.155','grayblack','gray black',[125,137,132],'7d8984',8227204],
['nbs-iscc-s:grayblack.265','grayblack','gray black',[132,132,130],'848482',8684674],
['nbs-iscc-s:grayblue.182','grayblue','gray blue',[67,107,149],'436b95',4418453],
['nbs-iscc-s:grayblue.185','grayblue','gray blue',[145,163,176],'91a3b0',9544624],
['nbs-iscc-s:grayblue.190','grayblue','gray blue',[180,188,192],'b4bcc0',11844800],
['nbs-iscc-s:grayblue.203','grayblue','gray blue',[140,146,172],'8c92ac',9212588],
['nbs-iscc-s:grayblue.214','grayblue','gray blue',[150,144,171],'9690ab',9867435],
['nbs-iscc-s:grayblue.232','grayblue','gray blue',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-s:graybrown.45','graybrown','gray brown',[151,127,115],'977f73',9928563],
['nbs-iscc-s:graybrown.63','graybrown','gray brown',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:graybrown.94','graybrown','gray brown',[150,113,23],'967117',9859351],
['nbs-iscc-s:graybrown.112','graybrown','gray brown',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:graygreen.112','graygreen','gray green',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:graygreen.120','graygreen','gray green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-s:graygreen.122','graygreen','gray green',[143,151,121],'8f9779',9410425],
['nbs-iscc-s:graygreen.136','graygreen','gray green',[103,146,103],'679267',6787687],
['nbs-iscc-s:graygreen.144','graygreen','gray green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-s:graygreen.145','graygreen','gray green',[59,120,97],'3b7861',3897441],
['nbs-iscc-s:graygreen.163','graygreen','gray green',[102,173,164],'66ada4',6729124],
['nbs-iscc-s:graylilac.22','graylilac','gray lilac',[143,129,127],'8f817f',9404799],
['nbs-iscc-s:graylilac.63','graylilac','gray lilac',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:graylilac.226','graylilac','gray lilac',[214,202,221],'d6cadd',14076637],
['nbs-iscc-s:graylilac.232','graylilac','gray lilac',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-s:graylilac.249','graylilac','gray lilac',[239,187,204],'efbbcc',15711180],
['nbs-iscc-s:grayviolet.233','grayviolet','gray violet',[139,133,137],'8b8589',9143689],
['nbs-iscc-s:green.117','green','green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-s:green.120','green','green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-s:green.129','green','green',[39,166,76],'27a64c',2598476],
['nbs-iscc-s:green.130','green','green',[131,211,125],'83d37d',8639357],
['nbs-iscc-s:green.131','green','green',[68,148,74],'44944a',4494410],
['nbs-iscc-s:green.132','green','green',[0,98,45],'00622d',25133],
['nbs-iscc-s:green.135','green','green',[147,197,146],'93c592',9684370],
['nbs-iscc-s:green.136','green','green',[103,146,103],'679267',6787687],
['nbs-iscc-s:green.139','green','green',[0,136,86],'008856',34902],
['nbs-iscc-s:green.140','green','green',[62,180,137],'3eb489',4109449],
['nbs-iscc-s:green.141','green','green',[0,121,89],'007959',31065],
['nbs-iscc-s:green.142','green','green',[0,84,61],'00543d',21565],
['nbs-iscc-s:green.143','green','green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-s:green.144','green','green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-s:green.145','green','green',[59,120,97],'3b7861',3897441],
['nbs-iscc-s:green.148','green','green',[199,230,215],'c7e6d7',13100759],
['nbs-iscc-s:green.149','green','green',[141,163,153],'8da399',9282457],
['nbs-iscc-s:green.150','green','green',[94,113,106],'5e716a',6189418],
['nbs-iscc-s:green.154','green','green',[178,190,181],'b2beb5',11714229],
['nbs-iscc-s:green.159','green','green',[0,166,147],'00a693',42643],
['nbs-iscc-s:green.163','green','green',[102,173,164],'66ada4',6729124],
['nbs-iscc-s:green.164','green','green',[49,120,115],'317873',3242099],
['nbs-iscc-s:greenishblack.149','greenishblack','greenish black',[141,163,153],'8da399',9282457],
['nbs-iscc-s:greenishblue.164','greenishblue','greenish blue',[49,120,115],'317873',3242099],
['nbs-iscc-s:greenishblue.169','greenishblue','greenish blue',[0,119,145],'007791',30609],
['nbs-iscc-s:greenishblue.173','greenishblue','greenish blue',[54,117,136],'367588',3569032],
['nbs-iscc-s:hennabrown.13','hennabrown','henna brown ',[132,27,45],'841b2d',8657709],
['nbs-iscc-s:indigo.179','indigo','indigo',[0,65,106],'00416a',16746],
['nbs-iscc-s:indigo.204','indigo','indigo',[76,81,109],'4c516d',5001581],
['nbs-iscc-s:lake.15','lake','lake',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:lake.16','lake','lake',[114,47,55],'722f37',7483191],
['nbs-iscc-s:lake.19','lake','lake',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:lake.39','lake','lake',[180,116,94],'b4745e',11826270],
['nbs-iscc-s:lake.258','lake','lake',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:lemon.82','lemon','lemon',[243,195,0],'f3c300',15975168],
['nbs-iscc-s:lemon.83','lemon','lemon',[250,218,94],'fada5e',16439902],
['nbs-iscc-s:lemon.84','lemon','lemon',[212,175,55],'d4af37',13938487],
['nbs-iscc-s:lemon.85','lemon','lemon',[175,141,19],'af8d13',11504915],
['nbs-iscc-s:lemon.97','lemon','lemon',[220,211,0],'dcd300',14471936],
['nbs-iscc-s:lemonyellow.85','lemonyellow','lemon yellow',[175,141,19],'af8d13',11504915],
['nbs-iscc-s:lemonyellow.100','lemonyellow','lemon yellow',[155,148,0],'9b9400',10195968],
['nbs-iscc-s:lightblue.162','lightblue','light blue',[150,222,209],'96ded1',9887441],
['nbs-iscc-s:lightblue.163','lightblue','light blue',[102,173,164],'66ada4',6729124],
['nbs-iscc-s:lightblue.164','lightblue','light blue',[49,120,115],'317873',3242099],
['nbs-iscc-s:lightblue.168','lightblue','light blue',[35,158,186],'239eba',2334394],
['nbs-iscc-s:lightblue.172','lightblue','light blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-s:lightblue.173','lightblue','light blue',[54,117,136],'367588',3569032],
['nbs-iscc-s:lightblue.178','lightblue','light blue',[0,103,165],'0067a5',26533],
['nbs-iscc-s:lightblue.181','lightblue','light blue',[112,163,204],'70a3cc',7381964],
['nbs-iscc-s:lightblue.184','lightblue','light blue',[188,212,230],'bcd4e6',12375270],
['nbs-iscc-s:lightbrown.32','lightbrown','light brown',[199,173,163],'c7ada3',13086115],
['nbs-iscc-s:lightgreen.131','lightgreen','light green',[68,148,74],'44944a',4494410],
['nbs-iscc-s:lightgreen.135','lightgreen','light green',[147,197,146],'93c592',9684370],
['nbs-iscc-s:lightgreen.140','lightgreen','light green',[62,180,137],'3eb489',4109449],
['nbs-iscc-s:lightolivegreen.106','lightolivegreen','light olive green',[134,126,54],'867e36',8814134],
['nbs-iscc-s:lightolivegreen.117','lightolivegreen','light olive green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-s:lightolivegreen.119','lightolivegreen','light olive green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-s:lightredbrown.42','lightredbrown','light red brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-s:lilac.10','lilac','lilac',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-s:lilac.209','lilac','lilac',[220,208,255],'dcd0ff',14471423],
['nbs-iscc-s:lilac.210','lilac','lilac',[140,130,182],'8c82b6',9208502],
['nbs-iscc-s:lilac.221','lilac','lilac',[213,186,219],'d5badb',14007003],
['nbs-iscc-s:lilac.226','lilac','lilac',[214,202,221],'d6cadd',14076637],
['nbs-iscc-s:lilac.227','lilac','lilac',[170,152,169],'aa98a9',11180201],
['nbs-iscc-s:lilac.228','lilac','lilac',[121,104,120],'796878',7956600],
['nbs-iscc-s:lilac.231','lilac','lilac',[232,227,229],'e8e3e5',15262693],
['nbs-iscc-s:lilac.232','lilac','lilac',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-s:lilac.233','lilac','lilac',[139,133,137],'8b8589',9143689],
['nbs-iscc-s:lilac.241','lilac','lilac',[145,92,131],'915c83',9526403],
['nbs-iscc-s:lilac.244','lilac','lilac',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-s:lilac.252','lilac','lilac',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-s:lilac.253','lilac','lilac',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-s:lilac.261','lilac','lilac',[175,134,142],'af868e',11503246],
['nbs-iscc-s:lilac.262','lilac','lilac',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:lilacbrown.10','lilacbrown','lilac brown',[193,182,179],'c1b6b3',12695219],
['nbs-iscc-s:lilacbrown.22','lilacbrown','lilac brown',[143,129,127],'8f817f',9404799],
['nbs-iscc-s:lilacbrown.63','lilacbrown','lilac brown',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:lilacgray.232','lilacgray','lilac gray',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-s:lilacrose.3','lilacrose','lilac rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:lilacrose.18','lilacrose','lilac rose',[173,136,132],'ad8884',11372676],
['nbs-iscc-s:lilacrose.237','lilacrose','lilac rose',[158,79,136],'9e4f88',10375048],
['nbs-iscc-s:lilacrose.248','lilacrose','lilac rose',[222,111,161],'de6fa1',14577569],
['nbs-iscc-s:lilacrose.249','lilacrose','lilac rose',[239,187,204],'efbbcc',15711180],
['nbs-iscc-s:lilacrose.258','lilacrose','lilac rose',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:magenta.205','magenta','magenta',[144,101,202],'9065ca',9463242],
['nbs-iscc-s:magenta.218','magenta','magenta',[135,86,146],'875692',8869522],
['nbs-iscc-s:magenta.237','magenta','magenta',[158,79,136],'9e4f88',10375048],
['nbs-iscc-s:magenta.242','magenta','magenta',[93,57,84],'5d3954',6109524],
['nbs-iscc-s:magenta.255','magenta','magenta',[179,68,108],'b3446c',11748460],
['nbs-iscc-s:magenta.258','magenta','magenta',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:magenta.259','magenta','magenta',[103,49,71],'673147',6762823],
['nbs-iscc-s:magenta.262','magenta','magenta',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:maroon.16','maroon','maroon',[114,47,55],'722f37',7483191],
['nbs-iscc-s:maroon.259','maroon','maroon',[103,49,71],'673147',6762823],
['nbs-iscc-s:mauve.241','mauve','mauve',[145,92,131],'915c83',9526403],
['nbs-iscc-s:milkyblue.172','milkyblue','milky blue ',[102,170,188],'66aabc',6728380],
['nbs-iscc-s:myrtlegreen.164','myrtlegreen','myrtle green ',[49,120,115],'317873',3242099],
['nbs-iscc-s:myrtlegreen.165','myrtlegreen','myrtle green ',[0,75,73],'004b49',19273],
['nbs-iscc-s:ochre.51','ochre','ochre',[190,101,22],'be6516',12477718],
['nbs-iscc-s:ochre.53','ochre','ochre',[217,144,88],'d99058',14258264],
['nbs-iscc-s:ochre.57','ochre','ochre',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:ochre.67','ochre','ochre',[255,193,79],'ffc14f',16761167],
['nbs-iscc-s:ochre.71','ochre','ochre',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:ochre.73','ochre','ochre',[250,214,165],'fad6a5',16438949],
['nbs-iscc-s:ochre.74','ochre','ochre',[153,101,21],'996515',10052885],
['nbs-iscc-s:ochre.83','ochre','ochre',[250,218,94],'fada5e',16439902],
['nbs-iscc-s:ochre.84','ochre','ochre',[212,175,55],'d4af37',13938487],
['nbs-iscc-s:ochre.86','ochre','ochre',[248,222,126],'f8de7e',16309886],
['nbs-iscc-s:ochre.87','ochre','ochre',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:olive.95','olive','olive',[108,84,30],'6c541e',7099422],
['nbs-iscc-s:olive.110','olive','olive',[91,88,66],'5b5842',5986370],
['nbs-iscc-s:olive.122','olive','olive',[143,151,121],'8f9779',9410425],
['nbs-iscc-s:olivebistre.69','olivebistre','olive bistre',[201,133,0],'c98500',13206784],
['nbs-iscc-s:olivebistre.72','olivebistre','olive bistre',[190,138,61],'be8a3d',12487229],
['nbs-iscc-s:olivebistre.74','olivebistre','olive bistre',[153,101,21],'996515',10052885],
['nbs-iscc-s:olivebistre.77','olivebistre','olive bistre',[130,102,68],'826644',8545860],
['nbs-iscc-s:olivebistre.85','olivebistre','olive bistre',[175,141,19],'af8d13',11504915],
['nbs-iscc-s:olivebistre.87','olivebistre','olive bistre',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:olivebistre.88','olivebistre','olive bistre',[171,145,68],'ab9144',11243844],
['nbs-iscc-s:olivebistre.89','olivebistre','olive bistre',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-s:olivebistre.90','olivebistre','olive bistre',[194,178,128],'c2b280',12759680],
['nbs-iscc-s:olivebistre.91','olivebistre','olive bistre',[161,143,96],'a18f60',10588000],
['nbs-iscc-s:olivebistre.93','olivebistre','olive bistre',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-s:olivebistre.94','olivebistre','olive bistre',[150,113,23],'967117',9859351],
['nbs-iscc-s:olivebistre.106','olivebistre','olive bistre',[134,126,54],'867e36',8814134],
['nbs-iscc-s:olivebistre.112','olivebistre','olive bistre',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:olivebistre.122','olivebistre','olive bistre',[143,151,121],'8f9779',9410425],
['nbs-iscc-s:olivebistre.264','olivebistre','olive bistre',[185,184,181],'b9b8b5',12171445],
['nbs-iscc-s:oliveblack.110','oliveblack','olive black',[91,88,66],'5b5842',5986370],
['nbs-iscc-s:oliveblack.113','oliveblack','olive black',[87,85,76],'57554c',5723468],
['nbs-iscc-s:olivebrown.58','olivebrown','olive brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-s:olivebrown.63','olivebrown','olive brown',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:olivebrown.78','olivebrown','olive brown',[75,54,33],'4b3621',4929057],
['nbs-iscc-s:olivebrown.80','olivebrown','olive brown',[126,109,90],'7e6d5a',8285530],
['nbs-iscc-s:olivebrown.81','olivebrown','olive brown',[72,60,50],'483c32',4734002],
['nbs-iscc-s:olivebrown.95','olivebrown','olive brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-s:olivebrown.110','olivebrown','olive brown',[91,88,66],'5b5842',5986370],
['nbs-iscc-s:olivebrown.113','olivebrown','olive brown',[87,85,76],'57554c',5723468],
['nbs-iscc-s:olivegray.107','olivegray','olive gray',[102,93,30],'665d1e',6708510],
['nbs-iscc-s:olivegray.112','olivegray','olive gray',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:olivegray.113','olivegray','olive gray',[87,85,76],'57554c',5723468],
['nbs-iscc-s:olivegray.122','olivegray','olive gray',[143,151,121],'8f9779',9410425],
['nbs-iscc-s:olivegray.155','olivegray','olive gray',[125,137,132],'7d8984',8227204],
['nbs-iscc-s:olivegray.156','olivegray','olive gray',[78,87,85],'4e5755',5134165],
['nbs-iscc-s:olivegreen.88','olivegreen','olive green',[171,145,68],'ab9144',11243844],
['nbs-iscc-s:olivegreen.89','olivegreen','olive green',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-s:olivegreen.90','olivegreen','olive green',[194,178,128],'c2b280',12759680],
['nbs-iscc-s:olivegreen.91','olivegreen','olive green',[161,143,96],'a18f60',10588000],
['nbs-iscc-s:olivegreen.93','olivegreen','olive green',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-s:olivegreen.100','olivegreen','olive green',[155,148,0],'9b9400',10195968],
['nbs-iscc-s:olivegreen.106','olivegreen','olive green',[134,126,54],'867e36',8814134],
['nbs-iscc-s:olivegreen.107','olivegreen','olive green',[102,93,30],'665d1e',6708510],
['nbs-iscc-s:olivegreen.109','olivegreen','olive green',[140,135,103],'8c8767',9209703],
['nbs-iscc-s:olivegreen.110','olivegreen','olive green',[91,88,66],'5b5842',5986370],
['nbs-iscc-s:olivegreen.112','olivegreen','olive green',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:olivegreen.113','olivegreen','olive green',[87,85,76],'57554c',5723468],
['nbs-iscc-s:olivegreen.117','olivegreen','olive green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-s:olivegreen.120','olivegreen','olive green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-s:olivegreen.122','olivegreen','olive green',[143,151,121],'8f9779',9410425],
['nbs-iscc-s:olivegreen.123','olivegreen','olive green',[64,79,0],'404f00',4214528],
['nbs-iscc-s:olivegreen.125','olivegreen','olive green',[74,93,35],'4a5d23',4873507],
['nbs-iscc-s:olivegreen.127','olivegreen','olive green',[81,87,68],'515744',5330756],
['nbs-iscc-s:olivegreen.150','olivegreen','olive green',[94,113,106],'5e716a',6189418],
['nbs-iscc-s:olivegreen.151','olivegreen','olive green',[58,75,71],'3a4b47',3820359],
['nbs-iscc-s:olivegreen.155','olivegreen','olive green',[125,137,132],'7d8984',8227204],
['nbs-iscc-s:olivegreen.156','olivegreen','olive green',[78,87,85],'4e5755',5134165],
['nbs-iscc-s:oliveyellow.31','oliveyellow','olive yellow',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-s:oliveyellow.33','oliveyellow','olive yellow',[194,172,153],'c2ac99',12758169],
['nbs-iscc-s:oliveyellow.73','oliveyellow','olive yellow',[250,214,165],'fad6a5',16438949],
['nbs-iscc-s:oliveyellow.86','oliveyellow','olive yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-s:oliveyellow.87','oliveyellow','olive yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:oliveyellow.89','oliveyellow','olive yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-s:oliveyellow.93','oliveyellow','olive yellow',[191,184,165],'bfb8a5',12564645],
['nbs-iscc-s:orange.25','orange','orange',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-s:orange.26','orange','orange',[248,131,121],'f88379',16286585],
['nbs-iscc-s:orange.28','orange','orange',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-s:orange.29','orange','orange',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:orange.34','orange','orange',[226,88,34],'e25822',14833698],
['nbs-iscc-s:orange.35','orange','orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-s:orange.37','orange','orange',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:orange.48','orange','orange',[243,132,0],'f38400',15959040],
['nbs-iscc-s:orange.49','orange','orange',[253,148,63],'fd943f',16618559],
['nbs-iscc-s:orange.50','orange','orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-s:orange.51','orange','orange',[190,101,22],'be6516',12477718],
['nbs-iscc-s:orange.52','orange','orange',[250,181,127],'fab57f',16430463],
['nbs-iscc-s:orange.53','orange','orange',[217,144,88],'d99058',14258264],
['nbs-iscc-s:orange.66','orange','orange',[246,166,0],'f6a600',16164352],
['nbs-iscc-s:orange.67','orange','orange',[255,193,79],'ffc14f',16761167],
['nbs-iscc-s:orange.68','orange','orange',[234,162,33],'eaa221',15376929],
['nbs-iscc-s:orange.69','orange','orange',[201,133,0],'c98500',13206784],
['nbs-iscc-s:orange.70','orange','orange',[251,201,127],'fbc97f',16501119],
['nbs-iscc-s:orange.71','orange','orange',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:orange.72','orange','orange',[190,138,61],'be8a3d',12487229],
['nbs-iscc-s:orange.73','orange','orange',[250,214,165],'fad6a5',16438949],
['nbs-iscc-s:orange.76','orange','orange',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:orange.83','orange','orange',[250,218,94],'fada5e',16439902],
['nbs-iscc-s:orange.84','orange','orange',[212,175,55],'d4af37',13938487],
['nbs-iscc-s:orange.86','orange','orange',[248,222,126],'f8de7e',16309886],
['nbs-iscc-s:orange.87','orange','orange',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:orange.89','orange','orange',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-s:orangebrown.16','orangebrown','orange brown',[114,47,55],'722f37',7483191],
['nbs-iscc-s:orangebrown.37','orangebrown','orange brown',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:orangebrown.39','orangebrown','orange brown',[180,116,94],'b4745e',11826270],
['nbs-iscc-s:orangebrown.40','orangebrown','orange brown',[136,45,23],'882d17',8924439],
['nbs-iscc-s:orangebrown.51','orangebrown','orange brown',[190,101,22],'be6516',12477718],
['nbs-iscc-s:orangebrown.53','orangebrown','orange brown',[217,144,88],'d99058',14258264],
['nbs-iscc-s:orangebrown.54','orangebrown','orange brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-s:orangebrown.55','orangebrown','orange brown',[128,70,27],'80461b',8406555],
['nbs-iscc-s:orangebrown.57','orangebrown','orange brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:orangebrown.58','orangebrown','orange brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-s:orangebrown.60','orangebrown','orange brown',[149,128,112],'958070',9797744],
['nbs-iscc-s:orangebrown.79','orangebrown','orange brown',[174,155,130],'ae9b82',11443074],
['nbs-iscc-s:orangebuff.29','orangebuff','orange buff',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:orangered.6','orangered','orange red',[192,128,129],'c08081',12615809],
['nbs-iscc-s:orangered.35','orangered','orange red',[217,96,59],'d9603b',14245947],
['nbs-iscc-s:orangered.37','orangered','orange red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:orangevermilion.37','orangevermilion','orange vermilion',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:orangevermilion.51','orangevermilion','orange vermilion',[190,101,22],'be6516',12477718],
['nbs-iscc-s:orangeyellow.48','orangeyellow','orange yellow',[243,132,0],'f38400',15959040],
['nbs-iscc-s:orangeyellow.49','orangeyellow','orange yellow',[253,148,63],'fd943f',16618559],
['nbs-iscc-s:orangeyellow.50','orangeyellow','orange yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-s:orangeyellow.52','orangeyellow','orange yellow',[250,181,127],'fab57f',16430463],
['nbs-iscc-s:orangeyellow.67','orangeyellow','orange yellow',[255,193,79],'ffc14f',16761167],
['nbs-iscc-s:orangeyellow.68','orangeyellow','orange yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-s:orangeyellow.69','orangeyellow','orange yellow',[201,133,0],'c98500',13206784],
['nbs-iscc-s:orangeyellow.70','orangeyellow','orange yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-s:orangeyellow.71','orangeyellow','orange yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:paleblue.186','paleblue','pale blue',[83,104,120],'536878',5466232],
['nbs-iscc-s:paleblue.232','paleblue','pale blue',[191,185,189],'bfb9bd',12564925],
['nbs-iscc-s:palebrown.53','palebrown','pale brown',[217,144,88],'d99058',14258264],
['nbs-iscc-s:palebrown.57','palebrown','pale brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:palegraygreen.121','palegraygreen','pale gray green',[218,223,183],'dadfb7',14344119],
['nbs-iscc-s:palegreen.119','palegreen','pale green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-s:palegreen.120','palegreen','pale green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-s:palegreen.143','palegreen','pale green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-s:palelilac.252','palelilac','pale lilac',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-s:paleolivegreen.120','paleolivegreen','pale olive green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-s:paleyellowgreen.116','paleyellowgreen','pale yellow-green',[189,218,87],'bdda57',12442199],
['nbs-iscc-s:paleyellowgreen.119','paleyellowgreen','pale yellow-green',[201,220,137],'c9dc89',13229193],
['nbs-iscc-s:paleyellowgreen.130','paleyellowgreen','pale yellow-green',[131,211,125],'83d37d',8639357],
['nbs-iscc-s:peacockblue.169','peacockblue','peacock blue',[0,119,145],'007791',30609],
['nbs-iscc-s:pink.2','pink','pink',[234,147,153],'ea9399',15373209],
['nbs-iscc-s:pink.3','pink','pink',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:pink.26','pink','pink',[248,131,121],'f88379',16286585],
['nbs-iscc-s:pink.246','pink','pink',[255,200,214],'ffc8d6',16763094],
['nbs-iscc-s:pink.247','pink','pink',[230,143,172],'e68fac',15110060],
['nbs-iscc-s:pink.248','pink','pink',[222,111,161],'de6fa1',14577569],
['nbs-iscc-s:pink.258','pink','pink',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:plum.236','plum','plum',[135,0,116],'870074',8847476],
['nbs-iscc-s:plum.238','plum','plum',[112,41,99],'702963',7350627],
['nbs-iscc-s:plum.256','plum','plum',[120,24,74],'78184a',7870538],
['nbs-iscc-s:prussianblue.170','prussianblue','prussian blue',[46,132,149],'2e8495',3048597],
['nbs-iscc-s:prussianblue.174','prussianblue','prussian blue',[0,73,88],'004958',18776],
['nbs-iscc-s:prussiangreen.160','prussiangreen','prussian green',[0,122,116],'007a74',31348],
['nbs-iscc-s:prussiangreen.161','prussiangreen','prussian green',[0,68,63],'00443f',17471],
['nbs-iscc-s:prussiangreen.164','prussiangreen','prussian green',[49,120,115],'317873',3242099],
['nbs-iscc-s:prussiangreen.170','prussiangreen','prussian green',[46,132,149],'2e8495',3048597],
['nbs-iscc-s:purple.197','purple','purple',[39,36,88],'272458',2565208],
['nbs-iscc-s:purple.200','purple','purple',[78,81,128],'4e5180',5132672],
['nbs-iscc-s:purple.207','purple','purple',[96,78,151],'604e97',6311575],
['nbs-iscc-s:purple.211','purple','purple',[96,78,129],'604e81',6311553],
['nbs-iscc-s:purple.215','purple','purple',[85,76,105],'554c69',5590121],
['nbs-iscc-s:purple.216','purple','purple',[154,78,174],'9a4eae',10112686],
['nbs-iscc-s:purple.218','purple','purple',[135,86,146],'875692',8869522],
['nbs-iscc-s:purple.219','purple','purple',[96,47,107],'602f6b',6303595],
['nbs-iscc-s:purple.223','purple','purple',[134,96,142],'86608e',8806542],
['nbs-iscc-s:purple.241','purple','purple',[145,92,131],'915c83',9526403],
['nbs-iscc-s:purple.242','purple','purple',[93,57,84],'5d3954',6109524],
['nbs-iscc-s:purple.245','purple','purple',[131,100,121],'836479',8610937],
['nbs-iscc-s:purplebrown.228','purplebrown','purple brown',[121,104,120],'796878',7956600],
['nbs-iscc-s:purplishbistre.33','purplishbistre','purplish bistre',[194,172,153],'c2ac99',12758169],
['nbs-iscc-s:red.3','red','red',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:red.5','red','red',[222,165,164],'dea5a4',14591396],
['nbs-iscc-s:red.8','red','red',[196,174,173],'c4aead',12889773],
['nbs-iscc-s:red.12','red','red',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:red.19','red','red',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:red.26','red','red',[248,131,121],'f88379',16286585],
['nbs-iscc-s:red.27','red','red',[230,103,97],'e66761',15099745],
['nbs-iscc-s:red.28','red','red',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-s:red.29','red','red',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:red.35','red','red',[217,96,59],'d9603b',14245947],
['nbs-iscc-s:red.36','red','red',[170,56,30],'aa381e',11155486],
['nbs-iscc-s:red.37','red','red',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:redbrown.8','redbrown','red brown',[196,174,173],'c4aead',12889773],
['nbs-iscc-s:redbrown.16','redbrown','red brown',[114,47,55],'722f37',7483191],
['nbs-iscc-s:redbrown.18','redbrown','red brown',[173,136,132],'ad8884',11372676],
['nbs-iscc-s:redbrown.19','redbrown','red brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:redbrown.22','redbrown','red brown',[143,129,127],'8f817f',9404799],
['nbs-iscc-s:redbrown.31','redbrown','red brown',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-s:redbrown.32','redbrown','red brown',[199,173,163],'c7ada3',13086115],
['nbs-iscc-s:redbrown.37','redbrown','red brown',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:redbrown.38','redbrown','red brown',[158,71,50],'9e4732',10372914],
['nbs-iscc-s:redbrown.42','redbrown','red brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-s:redbrown.43','redbrown','red brown',[121,68,59],'79443b',7947323],
['nbs-iscc-s:redbrown.51','redbrown','red brown',[190,101,22],'be6516',12477718],
['nbs-iscc-s:redbrown.53','redbrown','red brown',[217,144,88],'d99058',14258264],
['nbs-iscc-s:redbrown.54','redbrown','red brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-s:redbrown.57','redbrown','red brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:redbrown.58','redbrown','red brown',[111,78,55],'6f4e37',7294519],
['nbs-iscc-s:redbrown.74','redbrown','red brown',[153,101,21],'996515',10052885],
['nbs-iscc-s:redbrown.77','redbrown','red brown',[130,102,68],'826644',8545860],
['nbs-iscc-s:redbrown.95','redbrown','red brown',[108,84,30],'6c541e',7099422],
['nbs-iscc-s:reddishbrown.46','reddishbrown','reddish brown',[103,76,71],'674c47',6769735],
['nbs-iscc-s:redlilac.8','redlilac','red lilac',[196,174,173],'c4aead',12889773],
['nbs-iscc-s:redlilac.258','redlilac','red lilac',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:redlilac.262','redlilac','red lilac',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:redorange.11','redorange','red orange',[190,0,50],'be0032',12451890],
['nbs-iscc-s:redorange.25','redorange','red orange',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-s:redorange.34','redorange','red orange',[226,88,34],'e25822',14833698],
['nbs-iscc-s:redorange.35','redorange','red orange',[217,96,59],'d9603b',14245947],
['nbs-iscc-s:redorange.50','redorange','red orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-s:redpurple.238','redpurple','red purple',[112,41,99],'702963',7350627],
['nbs-iscc-s:redpurple.259','redpurple','red purple',[103,49,71],'673147',6762823],
['nbs-iscc-s:redviolet.216','redviolet','red violet',[154,78,174],'9a4eae',10112686],
['nbs-iscc-s:redviolet.218','redviolet','red violet',[135,86,146],'875692',8869522],
['nbs-iscc-s:redviolet.219','redviolet','red violet',[96,47,107],'602f6b',6303595],
['nbs-iscc-s:redviolet.222','redviolet','red violet',[182,149,192],'b695c0',11965888],
['nbs-iscc-s:redviolet.223','redviolet','red violet',[134,96,142],'86608e',8806542],
['nbs-iscc-s:redviolet.237','redviolet','red violet',[158,79,136],'9e4f88',10375048],
['nbs-iscc-s:redviolet.238','redviolet','red violet',[112,41,99],'702963',7350627],
['nbs-iscc-s:redviolet.240','redviolet','red violet',[183,132,167],'b784a7',12027047],
['nbs-iscc-s:redviolet.241','redviolet','red violet',[145,92,131],'915c83',9526403],
['nbs-iscc-s:redviolet.249','redviolet','red violet',[239,187,204],'efbbcc',15711180],
['nbs-iscc-s:redviolet.250','redviolet','red violet',[213,151,174],'d597ae',13997998],
['nbs-iscc-s:redviolet.253','redviolet','red violet',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-s:redviolet.262','redviolet','red violet',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:rose.1','rose','rose',[255,181,186],'ffb5ba',16758202],
['nbs-iscc-s:rose.2','rose','rose',[234,147,153],'ea9399',15373209],
['nbs-iscc-s:rose.3','rose','rose',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:rose.4','rose','rose',[249,204,202],'f9ccca',16370890],
['nbs-iscc-s:rose.5','rose','rose',[222,165,164],'dea5a4',14591396],
['nbs-iscc-s:rose.6','rose','rose',[192,128,129],'c08081',12615809],
['nbs-iscc-s:rose.12','rose','rose',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:rose.13','rose','rose',[132,27,45],'841b2d',8657709],
['nbs-iscc-s:rose.15','rose','rose',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:rose.19','rose','rose',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:rose.25','rose','rose',[255,183,165],'ffb7a5',16758693],
['nbs-iscc-s:rose.26','rose','rose',[248,131,121],'f88379',16286585],
['nbs-iscc-s:rose.27','rose','rose',[230,103,97],'e66761',15099745],
['nbs-iscc-s:rose.28','rose','rose',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-s:rose.29','rose','rose',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:rose.30','rose','rose',[196,131,121],'c48379',12878713],
['nbs-iscc-s:rose.31','rose','rose',[236,213,197],'ecd5c5',15521221],
['nbs-iscc-s:rose.32','rose','rose',[199,173,163],'c7ada3',13086115],
['nbs-iscc-s:rose.37','rose','rose',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:rose.227','rose','rose',[170,152,169],'aa98a9',11180201],
['nbs-iscc-s:rose.247','rose','rose',[230,143,172],'e68fac',15110060],
['nbs-iscc-s:rose.248','rose','rose',[222,111,161],'de6fa1',14577569],
['nbs-iscc-s:rose.249','rose','rose',[239,187,204],'efbbcc',15711180],
['nbs-iscc-s:rose.250','rose','rose',[213,151,174],'d597ae',13997998],
['nbs-iscc-s:rose.251','rose','rose',[193,126,145],'c17e91',12680849],
['nbs-iscc-s:rose.254','rose','rose',[206,70,118],'ce4676',13518454],
['nbs-iscc-s:rose.255','rose','rose',[179,68,108],'b3446c',11748460],
['nbs-iscc-s:rose.258','rose','rose',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:rose.262','rose','rose',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:rosebrown.11','rosebrown','rose brown',[190,0,50],'be0032',12451890],
['nbs-iscc-s:rosebrown.13','rosebrown','rose brown',[132,27,45],'841b2d',8657709],
['nbs-iscc-s:rosebrown.14','rosebrown','rose brown',[92,9,35],'5c0923',6031651],
['nbs-iscc-s:rosebrown.256','rosebrown','rose brown',[120,24,74],'78184a',7870538],
['nbs-iscc-s:rosebrown.257','rosebrown','rose brown',[84,19,59],'54133b',5509947],
['nbs-iscc-s:rosecarmine.3','rosecarmine','rose carmine',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:rosecarmine.254','rosecarmine','rose carmine',[206,70,118],'ce4676',13518454],
['nbs-iscc-s:rosecarmine.255','rosecarmine','rose carmine',[179,68,108],'b3446c',11748460],
['nbs-iscc-s:rosecarmine.258','rosecarmine','rose carmine',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:roselake.5','roselake','rose lake',[222,165,164],'dea5a4',14591396],
['nbs-iscc-s:roselake.259','roselake','rose lake',[103,49,71],'673147',6762823],
['nbs-iscc-s:roselake.262','roselake','rose lake',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:roselilac.237','roselilac','rose lilac',[158,79,136],'9e4f88',10375048],
['nbs-iscc-s:roselilac.240','roselilac','rose lilac',[183,132,167],'b784a7',12027047],
['nbs-iscc-s:roselilac.250','roselilac','rose lilac',[213,151,174],'d597ae',13997998],
['nbs-iscc-s:roselilac.251','roselilac','rose lilac',[193,126,145],'c17e91',12680849],
['nbs-iscc-s:roselilac.258','roselilac','rose lilac',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:roselilac.262','roselilac','rose lilac',[145,95,109],'915f6d',9527149],
['nbs-iscc-s:rosepink.254','rosepink','rose pink',[206,70,118],'ce4676',13518454],
['nbs-iscc-s:rosered.3','rosered','rose red',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:rosered.15','rosered','rose red',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:rosered.16','rosered','rose red',[114,47,55],'722f37',7483191],
['nbs-iscc-s:roseviolet.237','roseviolet','rose violet',[158,79,136],'9e4f88',10375048],
['nbs-iscc-s:roseviolet.238','roseviolet','rose violet',[112,41,99],'702963',7350627],
['nbs-iscc-s:roseviolet.241','roseviolet','rose violet',[145,92,131],'915c83',9526403],
['nbs-iscc-s:roseviolet.256','roseviolet','rose violet',[120,24,74],'78184a',7870538],
['nbs-iscc-s:roseviolet.258','roseviolet','rose violet',[168,81,110],'a8516e',11030894],
['nbs-iscc-s:royalblue.179','royalblue','royal blue',[0,65,106],'00416a',16746],
['nbs-iscc-s:salmon.26','salmon','salmon',[248,131,121],'f88379',16286585],
['nbs-iscc-s:salmon.28','salmon','salmon',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-s:salmon.29','salmon','salmon',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:salmonrose.2','salmonrose','salmon rose',[234,147,153],'ea9399',15373209],
['nbs-iscc-s:salmonrose.4','salmonrose','salmon rose',[249,204,202],'f9ccca',16370890],
['nbs-iscc-s:salmonrose.26','salmonrose','salmon rose',[248,131,121],'f88379',16286585],
['nbs-iscc-s:salmonrose.28','salmonrose','salmon rose',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-s:salmonrose.29','salmonrose','salmon rose',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:scarlet.3','scarlet','scarlet',[228,113,122],'e4717a',14971258],
['nbs-iscc-s:scarlet.11','scarlet','scarlet',[190,0,50],'be0032',12451890],
['nbs-iscc-s:scarlet.12','scarlet','scarlet',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:scarlet.15','scarlet','scarlet',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:scarlet.34','scarlet','scarlet',[226,88,34],'e25822',14833698],
['nbs-iscc-s:sepia.63','sepia','sepia',[142,130,121],'8e8279',9339513],
['nbs-iscc-s:slate.149','slate','slate',[141,163,153],'8da399',9282457],
['nbs-iscc-s:slate.151','slate','slate',[58,75,71],'3a4b47',3820359],
['nbs-iscc-s:slate.155','slate','slate',[125,137,132],'7d8984',8227204],
['nbs-iscc-s:slate.156','slate','slate',[78,87,85],'4e5755',5134165],
['nbs-iscc-s:slate.187','slate','slate',[54,69,79],'36454f',3556687],
['nbs-iscc-s:slate.188','slate','slate',[32,40,48],'202830',2107440],
['nbs-iscc-s:slate.191','slate','slate',[129,135,139],'81878b',8488843],
['nbs-iscc-s:slate.192','slate','slate',[81,88,94],'51585e',5331038],
['nbs-iscc-s:slate.201','slate','slate',[37,36,64],'252440',2434112],
['nbs-iscc-s:slate.204','slate','slate',[76,81,109],'4c516d',5001581],
['nbs-iscc-s:slate.266','slate','slate',[85,85,85],'555555',5592405],
['nbs-iscc-s:slateblue.164','slateblue','slate blue',[49,120,115],'317873',3242099],
['nbs-iscc-s:slateblue.186','slateblue','slate blue',[83,104,120],'536878',5466232],
['nbs-iscc-s:slategreen.109','slategreen','slate green ',[140,135,103],'8c8767',9209703],
['nbs-iscc-s:slategreen.112','slategreen','slate green ',[138,135,118],'8a8776',9078646],
['nbs-iscc-s:slategreen.123','slategreen','slate green ',[64,79,0],'404f00',4214528],
['nbs-iscc-s:slategreen.125','slategreen','slate green ',[74,93,35],'4a5d23',4873507],
['nbs-iscc-s:slategreen.145','slategreen','slate green ',[59,120,97],'3b7861',3897441],
['nbs-iscc-s:slategreen.151','slategreen','slate green ',[58,75,71],'3a4b47',3820359],
['nbs-iscc-s:slategreen.155','slategreen','slate green ',[125,137,132],'7d8984',8227204],
['nbs-iscc-s:straw.87','straw','straw',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:turquoiseblue.172','turquoiseblue','turquoise blue',[102,170,188],'66aabc',6728380],
['nbs-iscc-s:turquoisegreen.158','turquoisegreen','turquoise green',[0,136,130],'008882',34946],
['nbs-iscc-s:turquoisegreen.159','turquoisegreen','turquoise green',[0,166,147],'00a693',42643],
['nbs-iscc-s:ultramarine.176','ultramarine','ultramarine',[0,161,194],'00a1c2',41410],
['nbs-iscc-s:ultramarine.177','ultramarine','ultramarine',[73,151,208],'4997d0',4822992],
['nbs-iscc-s:ultramarine.178','ultramarine','ultramarine',[0,103,165],'0067a5',26533],
['nbs-iscc-s:ultramarine.179','ultramarine','ultramarine',[0,65,106],'00416a',16746],
['nbs-iscc-s:ultramarine.181','ultramarine','ultramarine',[112,163,204],'70a3cc',7381964],
['nbs-iscc-s:ultramarine.182','ultramarine','ultramarine',[67,107,149],'436b95',4418453],
['nbs-iscc-s:ultramarine.185','ultramarine','ultramarine',[145,163,176],'91a3b0',9544624],
['nbs-iscc-s:ultramarine.186','ultramarine','ultramarine',[83,104,120],'536878',5466232],
['nbs-iscc-s:ultramarine.194','ultramarine','ultramarine',[48,38,122],'30267a',3155578],
['nbs-iscc-s:ultramarine.195','ultramarine','ultramarine',[108,121,184],'6c79b8',7109048],
['nbs-iscc-s:ultramarine.196','ultramarine','ultramarine',[84,90,167],'545aa7',5528231],
['nbs-iscc-s:ultramarine.198','ultramarine','ultramarine',[179,188,226],'b3bce2',11779298],
['nbs-iscc-s:ultramarine.199','ultramarine','ultramarine',[135,145,191],'8791bf',8884671],
['nbs-iscc-s:ultramarine.200','ultramarine','ultramarine',[78,81,128],'4e5180',5132672],
['nbs-iscc-s:ultramarine.202','ultramarine','ultramarine',[192,200,225],'c0c8e1',12634337],
['nbs-iscc-s:ultramarine.203','ultramarine','ultramarine',[140,146,172],'8c92ac',9212588],
['nbs-iscc-s:ultramarine.204','ultramarine','ultramarine',[76,81,109],'4c516d',5001581],
['nbs-iscc-s:ultramarine.210','ultramarine','ultramarine',[140,130,182],'8c82b6',9208502],
['nbs-iscc-s:umberbrown.61','umberbrown','umber brown',[99,81,71],'635147',6508871],
['nbs-iscc-s:vermilion.6','vermilion','vermilion',[192,128,129],'c08081',12615809],
['nbs-iscc-s:vermilion.12','vermilion','vermilion',[188,63,74],'bc3f4a',12336970],
['nbs-iscc-s:vermilion.15','vermilion','vermilion',[171,78,82],'ab4e52',11226706],
['nbs-iscc-s:vermilion.18','vermilion','vermilion',[173,136,132],'ad8884',11372676],
['nbs-iscc-s:vermilion.19','vermilion','vermilion',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:vermilion.26','vermilion','vermilion',[248,131,121],'f88379',16286585],
['nbs-iscc-s:vermilion.27','vermilion','vermilion',[230,103,97],'e66761',15099745],
['nbs-iscc-s:vermilion.30','vermilion','vermilion',[196,131,121],'c48379',12878713],
['nbs-iscc-s:vermilion.35','vermilion','vermilion',[217,96,59],'d9603b',14245947],
['nbs-iscc-s:vermilion.36','vermilion','vermilion',[170,56,30],'aa381e',11155486],
['nbs-iscc-s:vermilion.37','vermilion','vermilion',[203,109,81],'cb6d51',13331793],
['nbs-iscc-s:vermilion.38','vermilion','vermilion',[158,71,50],'9e4732',10372914],
['nbs-iscc-s:violet.16','violet','violet',[114,47,55],'722f37',7483191],
['nbs-iscc-s:violet.200','violet','violet',[78,81,128],'4e5180',5132672],
['nbs-iscc-s:violet.206','violet','violet',[126,115,184],'7e73b8',8287160],
['nbs-iscc-s:violet.210','violet','violet',[140,130,182],'8c82b6',9208502],
['nbs-iscc-s:violet.211','violet','violet',[96,78,129],'604e81',6311553],
['nbs-iscc-s:violet.214','violet','violet',[150,144,171],'9690ab',9867435],
['nbs-iscc-s:violet.217','violet','violet',[211,153,230],'d399e6',13867494],
['nbs-iscc-s:violet.218','violet','violet',[135,86,146],'875692',8869522],
['nbs-iscc-s:violet.222','violet','violet',[182,149,192],'b695c0',11965888],
['nbs-iscc-s:violet.223','violet','violet',[134,96,142],'86608e',8806542],
['nbs-iscc-s:violet.226','violet','violet',[214,202,221],'d6cadd',14076637],
['nbs-iscc-s:violet.227','violet','violet',[170,152,169],'aa98a9',11180201],
['nbs-iscc-s:violet.228','violet','violet',[121,104,120],'796878',7956600],
['nbs-iscc-s:violet.229','violet','violet',[80,64,77],'50404d',5259341],
['nbs-iscc-s:violet.238','violet','violet',[112,41,99],'702963',7350627],
['nbs-iscc-s:violet.240','violet','violet',[183,132,167],'b784a7',12027047],
['nbs-iscc-s:violet.244','violet','violet',[170,138,158],'aa8a9e',11176606],
['nbs-iscc-s:violet.245','violet','violet',[131,100,121],'836479',8610937],
['nbs-iscc-s:violet.250','violet','violet',[213,151,174],'d597ae',13997998],
['nbs-iscc-s:violet.252','violet','violet',[232,204,215],'e8ccd7',15256791],
['nbs-iscc-s:violet.253','violet','violet',[195,166,177],'c3a6b1',12822193],
['nbs-iscc-s:violet.261','violet','violet',[175,134,142],'af868e',11503246],
['nbs-iscc-s:violetblack.20','violetblack','violet black',[84,61,63],'543d3f',5520703],
['nbs-iscc-s:violetblack.234','violetblack','violet black',[93,85,91],'5d555b',6116699],
['nbs-iscc-s:violetblue.196','violetblue','violet blue',[84,90,167],'545aa7',5528231],
['nbs-iscc-s:violetbrown.19','violetbrown','violet brown',[144,93,93],'905d5d',9461085],
['nbs-iscc-s:violetbrown.228','violetbrown','violet brown',[121,104,120],'796878',7956600],
['nbs-iscc-s:violetbrown.259','violetbrown','violet brown',[103,49,71],'673147',6762823],
['nbs-iscc-s:yellow.28','yellow','yellow',[244,194,194],'f4c2c2',16040642],
['nbs-iscc-s:yellow.29','yellow','yellow',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:yellow.48','yellow','yellow',[243,132,0],'f38400',15959040],
['nbs-iscc-s:yellow.49','yellow','yellow',[253,148,63],'fd943f',16618559],
['nbs-iscc-s:yellow.50','yellow','yellow',[237,135,45],'ed872d',15566637],
['nbs-iscc-s:yellow.52','yellow','yellow',[250,181,127],'fab57f',16430463],
['nbs-iscc-s:yellow.53','yellow','yellow',[217,144,88],'d99058',14258264],
['nbs-iscc-s:yellow.57','yellow','yellow',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:yellow.66','yellow','yellow',[246,166,0],'f6a600',16164352],
['nbs-iscc-s:yellow.67','yellow','yellow',[255,193,79],'ffc14f',16761167],
['nbs-iscc-s:yellow.68','yellow','yellow',[234,162,33],'eaa221',15376929],
['nbs-iscc-s:yellow.69','yellow','yellow',[201,133,0],'c98500',13206784],
['nbs-iscc-s:yellow.70','yellow','yellow',[251,201,127],'fbc97f',16501119],
['nbs-iscc-s:yellow.71','yellow','yellow',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:yellow.72','yellow','yellow',[190,138,61],'be8a3d',12487229],
['nbs-iscc-s:yellow.73','yellow','yellow',[250,214,165],'fad6a5',16438949],
['nbs-iscc-s:yellow.76','yellow','yellow',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:yellow.82','yellow','yellow',[243,195,0],'f3c300',15975168],
['nbs-iscc-s:yellow.83','yellow','yellow',[250,218,94],'fada5e',16439902],
['nbs-iscc-s:yellow.84','yellow','yellow',[212,175,55],'d4af37',13938487],
['nbs-iscc-s:yellow.85','yellow','yellow',[175,141,19],'af8d13',11504915],
['nbs-iscc-s:yellow.86','yellow','yellow',[248,222,126],'f8de7e',16309886],
['nbs-iscc-s:yellow.87','yellow','yellow',[201,174,93],'c9ae5d',13217373],
['nbs-iscc-s:yellow.88','yellow','yellow',[171,145,68],'ab9144',11243844],
['nbs-iscc-s:yellow.89','yellow','yellow',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-s:yellow.90','yellow','yellow',[194,178,128],'c2b280',12759680],
['nbs-iscc-s:yellow.92','yellow','yellow',[240,234,214],'f0ead6',15788758],
['nbs-iscc-s:yellowbrown.33','yellowbrown','yellow brown',[194,172,153],'c2ac99',12758169],
['nbs-iscc-s:yellowbrown.38','yellowbrown','yellow brown',[158,71,50],'9e4732',10372914],
['nbs-iscc-s:yellowbrown.42','yellowbrown','yellow brown',[168,124,109],'a87c6d',11041901],
['nbs-iscc-s:yellowbrown.45','yellowbrown','yellow brown',[151,127,115],'977f73',9928563],
['nbs-iscc-s:yellowbrown.53','yellowbrown','yellow brown',[217,144,88],'d99058',14258264],
['nbs-iscc-s:yellowbrown.54','yellowbrown','yellow brown',[174,105,56],'ae6938',11430200],
['nbs-iscc-s:yellowbrown.55','yellowbrown','yellow brown',[128,70,27],'80461b',8406555],
['nbs-iscc-s:yellowbrown.57','yellowbrown','yellow brown',[166,123,91],'a67b5b',10910555],
['nbs-iscc-s:yellowbrown.72','yellowbrown','yellow brown',[190,138,61],'be8a3d',12487229],
['nbs-iscc-s:yellowbrown.74','yellowbrown','yellow brown',[153,101,21],'996515',10052885],
['nbs-iscc-s:yellowbrown.106','yellowbrown','yellow brown',[134,126,54],'867e36',8814134],
['nbs-iscc-s:yellowbuff.29','yellowbuff','yellow buff',[217,166,169],'d9a6a9',14263977],
['nbs-iscc-s:yellowbuff.53','yellowbuff','yellow buff',[217,144,88],'d99058',14258264],
['nbs-iscc-s:yellowbuff.71','yellowbuff','yellow buff',[227,168,87],'e3a857',14919767],
['nbs-iscc-s:yellowbuff.73','yellowbuff','yellow buff',[250,214,165],'fad6a5',16438949],
['nbs-iscc-s:yellowbuff.76','yellowbuff','yellow buff',[193,154,107],'c19a6b',12687979],
['nbs-iscc-s:yellowbuff.89','yellowbuff','yellow buff',[243,229,171],'f3e5ab',15984043],
['nbs-iscc-s:yellowbuff.90','yellowbuff','yellow buff',[194,178,128],'c2b280',12759680],
['nbs-iscc-s:yellowgreen.117','yellowgreen','yellow green',[126,159,46],'7e9f2e',8298286],
['nbs-iscc-s:yellowgreen.120','yellowgreen','yellow green',[138,154,91],'8a9a5b',9083483],
['nbs-iscc-s:yellowgreen.129','yellowgreen','yellow green',[39,166,76],'27a64c',2598476],
['nbs-iscc-s:yellowgreen.130','yellowgreen','yellow green',[131,211,125],'83d37d',8639357],
['nbs-iscc-s:yellowgreen.131','yellowgreen','yellow green',[68,148,74],'44944a',4494410],
['nbs-iscc-s:yellowgreen.132','yellowgreen','yellow green',[0,98,45],'00622d',25133],
['nbs-iscc-s:yellowgreen.134','yellowgreen','yellow green',[182,229,175],'b6e5af',11986351],
['nbs-iscc-s:yellowgreen.135','yellowgreen','yellow green',[147,197,146],'93c592',9684370],
['nbs-iscc-s:yellowgreen.136','yellowgreen','yellow green',[103,146,103],'679267',6787687],
['nbs-iscc-s:yellowgreen.137','yellowgreen','yellow green',[53,94,59],'355e3b',3497531],
['nbs-iscc-s:yellowgreen.139','yellowgreen','yellow green',[0,136,86],'008856',34902],
['nbs-iscc-s:yellowgreen.140','yellowgreen','yellow green',[62,180,137],'3eb489',4109449],
['nbs-iscc-s:yellowgreen.141','yellowgreen','yellow green',[0,121,89],'007959',31065],
['nbs-iscc-s:yellowgreen.143','yellowgreen','yellow green',[142,209,178],'8ed1b2',9359794],
['nbs-iscc-s:yellowgreen.144','yellowgreen','yellow green',[106,171,142],'6aab8e',6990734],
['nbs-iscc-s:yellowgreen.145','yellowgreen','yellow green',[59,120,97],'3b7861',3897441],
['nbs-iscc-s:yelloworange.50','yelloworange','yellow orange',[237,135,45],'ed872d',15566637],
['nbs-iscc-s:yelloworange.53','yelloworange','yellow orange',[217,144,88],'d99058',14258264]
    ];
}

sub _description {
    return {
          'subtitle' => 'Postage-Stamp Color Names',
          'title' => 'NBS/ISCC S',
          'description' => 'Kenneth L. Kelly and Deanne B. Judd.
"Color: Universal Language and Dictionary of Names",
National Bureau of Standards,
Spec. Publ. 440, Dec. 1976, 189 pages.


Color Name Dictionary: (S) Postage-Stamp Color Names

        Postage-Stamp Color Names,
        William H. Beck 

    This dictionary is a hybrid of combinatorial and idiosyncratic styles. 178 names map to 905 colors, using 223 of 267 centroids. Despite covering 84% of the centroids, averaging over 5 colors per name makes this dictionary uselessly unspecific.

[http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries#S]
'
        }

}

1;
