package Color::Library::Dictionary::X11;

use strict;
use warnings;

use base qw/Color::Library::Dictionary/;

__PACKAGE__->_register_dictionary;

package Color::Library::Dictionary::X11;

=pod

=head1 NAME

Color::Library::Dictionary::X11 - (X11) Colors for the X11 Window System (rgb.txt)

=head1 DESCRIPTION


X11/rgb.txt (often /usr/X11R6/lib/X11/rgb.txt) from the X11 Window System distribution.

=begin :html

=head1 COLORS

<table>
<tr><td style="border:1px solid #666; background:#f0f8ff;width:4em;" /><td>aliceblue</td><td>aliceblue</td><td>##f0f8ff</td><td>240</td> <td>248</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#f0f8ff;width:4em;" /><td>alice blue</td><td>aliceblue</td><td>##f0f8ff</td><td>240</td> <td>248</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#faebd7;width:4em;" /><td>antiquewhite</td><td>antiquewhite</td><td>##faebd7</td><td>250</td> <td>235</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#faebd7;width:4em;" /><td>antique white</td><td>antiquewhite</td><td>##faebd7</td><td>250</td> <td>235</td> <td>215</td>
</tr> <tr><td style="border:1px solid #666; background:#ffefdb;width:4em;" /><td>antiquewhite1</td><td>antiquewhite1</td><td>##ffefdb</td><td>255</td> <td>239</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#eedfcc;width:4em;" /><td>antiquewhite2</td><td>antiquewhite2</td><td>##eedfcc</td><td>238</td> <td>223</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#cdc0b0;width:4em;" /><td>antiquewhite3</td><td>antiquewhite3</td><td>##cdc0b0</td><td>205</td> <td>192</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8378;width:4em;" /><td>antiquewhite4</td><td>antiquewhite4</td><td>##8b8378</td><td>139</td> <td>131</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#7fffd4;width:4em;" /><td>aquamarine</td><td>aquamarine</td><td>##7fffd4</td><td>127</td> <td>255</td> <td>212</td>
</tr> <tr><td style="border:1px solid #666; background:#7fffd4;width:4em;" /><td>aquamarine1</td><td>aquamarine1</td><td>##7fffd4</td><td>127</td> <td>255</td> <td>212</td>
</tr> <tr><td style="border:1px solid #666; background:#76eec6;width:4em;" /><td>aquamarine2</td><td>aquamarine2</td><td>##76eec6</td><td>118</td> <td>238</td> <td>198</td>
</tr> <tr><td style="border:1px solid #666; background:#66cdaa;width:4em;" /><td>aquamarine3</td><td>aquamarine3</td><td>##66cdaa</td><td>102</td> <td>205</td> <td>170</td>
</tr> <tr><td style="border:1px solid #666; background:#458b74;width:4em;" /><td>aquamarine4</td><td>aquamarine4</td><td>##458b74</td><td>69</td> <td>139</td> <td>116</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ffff;width:4em;" /><td>azure</td><td>azure</td><td>##f0ffff</td><td>240</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#f0ffff;width:4em;" /><td>azure1</td><td>azure1</td><td>##f0ffff</td><td>240</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#e0eeee;width:4em;" /><td>azure2</td><td>azure2</td><td>##e0eeee</td><td>224</td> <td>238</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#c1cdcd;width:4em;" /><td>azure3</td><td>azure3</td><td>##c1cdcd</td><td>193</td> <td>205</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#838b8b;width:4em;" /><td>azure4</td><td>azure4</td><td>##838b8b</td><td>131</td> <td>139</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#f5f5dc;width:4em;" /><td>beige</td><td>beige</td><td>##f5f5dc</td><td>245</td> <td>245</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#ffe4c4;width:4em;" /><td>bisque</td><td>bisque</td><td>##ffe4c4</td><td>255</td> <td>228</td> <td>196</td>
</tr> <tr><td style="border:1px solid #666; background:#ffe4c4;width:4em;" /><td>bisque1</td><td>bisque1</td><td>##ffe4c4</td><td>255</td> <td>228</td> <td>196</td>
</tr> <tr><td style="border:1px solid #666; background:#eed5b7;width:4em;" /><td>bisque2</td><td>bisque2</td><td>##eed5b7</td><td>238</td> <td>213</td> <td>183</td>
</tr> <tr><td style="border:1px solid #666; background:#cdb79e;width:4em;" /><td>bisque3</td><td>bisque3</td><td>##cdb79e</td><td>205</td> <td>183</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#8b7d6b;width:4em;" /><td>bisque4</td><td>bisque4</td><td>##8b7d6b</td><td>139</td> <td>125</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#000000;width:4em;" /><td>black</td><td>black</td><td>##000000</td><td>0</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ffebcd;width:4em;" /><td>blanched almond</td><td>blanchedalmond</td><td>##ffebcd</td><td>255</td> <td>235</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#ffebcd;width:4em;" /><td>blanchedalmond</td><td>blanchedalmond</td><td>##ffebcd</td><td>255</td> <td>235</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#0000ff;width:4em;" /><td>blue</td><td>blue</td><td>##0000ff</td><td>0</td> <td>0</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#0000ff;width:4em;" /><td>blue1</td><td>blue1</td><td>##0000ff</td><td>0</td> <td>0</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#0000ee;width:4em;" /><td>blue2</td><td>blue2</td><td>##0000ee</td><td>0</td> <td>0</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#0000cd;width:4em;" /><td>blue3</td><td>blue3</td><td>##0000cd</td><td>0</td> <td>0</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#00008b;width:4em;" /><td>blue4</td><td>blue4</td><td>##00008b</td><td>0</td> <td>0</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#8a2be2;width:4em;" /><td>blueviolet</td><td>blueviolet</td><td>##8a2be2</td><td>138</td> <td>43</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#8a2be2;width:4em;" /><td>blue violet</td><td>blueviolet</td><td>##8a2be2</td><td>138</td> <td>43</td> <td>226</td>
</tr> <tr><td style="border:1px solid #666; background:#a52a2a;width:4em;" /><td>brown</td><td>brown</td><td>##a52a2a</td><td>165</td> <td>42</td> <td>42</td>
</tr> <tr><td style="border:1px solid #666; background:#ff4040;width:4em;" /><td>brown1</td><td>brown1</td><td>##ff4040</td><td>255</td> <td>64</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#ee3b3b;width:4em;" /><td>brown2</td><td>brown2</td><td>##ee3b3b</td><td>238</td> <td>59</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#cd3333;width:4em;" /><td>brown3</td><td>brown3</td><td>##cd3333</td><td>205</td> <td>51</td> <td>51</td>
</tr> <tr><td style="border:1px solid #666; background:#8b2323;width:4em;" /><td>brown4</td><td>brown4</td><td>##8b2323</td><td>139</td> <td>35</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#deb887;width:4em;" /><td>burlywood</td><td>burlywood</td><td>##deb887</td><td>222</td> <td>184</td> <td>135</td>
</tr> <tr><td style="border:1px solid #666; background:#ffd39b;width:4em;" /><td>burlywood1</td><td>burlywood1</td><td>##ffd39b</td><td>255</td> <td>211</td> <td>155</td>
</tr> <tr><td style="border:1px solid #666; background:#eec591;width:4em;" /><td>burlywood2</td><td>burlywood2</td><td>##eec591</td><td>238</td> <td>197</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#cdaa7d;width:4em;" /><td>burlywood3</td><td>burlywood3</td><td>##cdaa7d</td><td>205</td> <td>170</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#8b7355;width:4em;" /><td>burlywood4</td><td>burlywood4</td><td>##8b7355</td><td>139</td> <td>115</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#5f9ea0;width:4em;" /><td>cadetblue</td><td>cadetblue</td><td>##5f9ea0</td><td>95</td> <td>158</td> <td>160</td>
</tr> <tr><td style="border:1px solid #666; background:#5f9ea0;width:4em;" /><td>cadet blue</td><td>cadetblue</td><td>##5f9ea0</td><td>95</td> <td>158</td> <td>160</td>
</tr> <tr><td style="border:1px solid #666; background:#98f5ff;width:4em;" /><td>cadetblue1</td><td>cadetblue1</td><td>##98f5ff</td><td>152</td> <td>245</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8ee5ee;width:4em;" /><td>cadetblue2</td><td>cadetblue2</td><td>##8ee5ee</td><td>142</td> <td>229</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#7ac5cd;width:4em;" /><td>cadetblue3</td><td>cadetblue3</td><td>##7ac5cd</td><td>122</td> <td>197</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#53868b;width:4em;" /><td>cadetblue4</td><td>cadetblue4</td><td>##53868b</td><td>83</td> <td>134</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#7fff00;width:4em;" /><td>chartreuse</td><td>chartreuse</td><td>##7fff00</td><td>127</td> <td>255</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#7fff00;width:4em;" /><td>chartreuse1</td><td>chartreuse1</td><td>##7fff00</td><td>127</td> <td>255</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#76ee00;width:4em;" /><td>chartreuse2</td><td>chartreuse2</td><td>##76ee00</td><td>118</td> <td>238</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#66cd00;width:4em;" /><td>chartreuse3</td><td>chartreuse3</td><td>##66cd00</td><td>102</td> <td>205</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#458b00;width:4em;" /><td>chartreuse4</td><td>chartreuse4</td><td>##458b00</td><td>69</td> <td>139</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#d2691e;width:4em;" /><td>chocolate</td><td>chocolate</td><td>##d2691e</td><td>210</td> <td>105</td> <td>30</td>
</tr> <tr><td style="border:1px solid #666; background:#ff7f24;width:4em;" /><td>chocolate1</td><td>chocolate1</td><td>##ff7f24</td><td>255</td> <td>127</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#ee7621;width:4em;" /><td>chocolate2</td><td>chocolate2</td><td>##ee7621</td><td>238</td> <td>118</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#cd661d;width:4em;" /><td>chocolate3</td><td>chocolate3</td><td>##cd661d</td><td>205</td> <td>102</td> <td>29</td>
</tr> <tr><td style="border:1px solid #666; background:#8b4513;width:4em;" /><td>chocolate4</td><td>chocolate4</td><td>##8b4513</td><td>139</td> <td>69</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#ff7f50;width:4em;" /><td>coral</td><td>coral</td><td>##ff7f50</td><td>255</td> <td>127</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#ff7256;width:4em;" /><td>coral1</td><td>coral1</td><td>##ff7256</td><td>255</td> <td>114</td> <td>86</td>
</tr> <tr><td style="border:1px solid #666; background:#ee6a50;width:4em;" /><td>coral2</td><td>coral2</td><td>##ee6a50</td><td>238</td> <td>106</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#cd5b45;width:4em;" /><td>coral3</td><td>coral3</td><td>##cd5b45</td><td>205</td> <td>91</td> <td>69</td>
</tr> <tr><td style="border:1px solid #666; background:#8b3e2f;width:4em;" /><td>coral4</td><td>coral4</td><td>##8b3e2f</td><td>139</td> <td>62</td> <td>47</td>
</tr> <tr><td style="border:1px solid #666; background:#6495ed;width:4em;" /><td>cornflower blue</td><td>cornflowerblue</td><td>##6495ed</td><td>100</td> <td>149</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#6495ed;width:4em;" /><td>cornflowerblue</td><td>cornflowerblue</td><td>##6495ed</td><td>100</td> <td>149</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#fff8dc;width:4em;" /><td>cornsilk</td><td>cornsilk</td><td>##fff8dc</td><td>255</td> <td>248</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#fff8dc;width:4em;" /><td>cornsilk1</td><td>cornsilk1</td><td>##fff8dc</td><td>255</td> <td>248</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#eee8cd;width:4em;" /><td>cornsilk2</td><td>cornsilk2</td><td>##eee8cd</td><td>238</td> <td>232</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#cdc8b1;width:4em;" /><td>cornsilk3</td><td>cornsilk3</td><td>##cdc8b1</td><td>205</td> <td>200</td> <td>177</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8878;width:4em;" /><td>cornsilk4</td><td>cornsilk4</td><td>##8b8878</td><td>139</td> <td>136</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#00ffff;width:4em;" /><td>cyan</td><td>cyan</td><td>##00ffff</td><td>0</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#00ffff;width:4em;" /><td>cyan1</td><td>cyan1</td><td>##00ffff</td><td>0</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#00eeee;width:4em;" /><td>cyan2</td><td>cyan2</td><td>##00eeee</td><td>0</td> <td>238</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#00cdcd;width:4em;" /><td>cyan3</td><td>cyan3</td><td>##00cdcd</td><td>0</td> <td>205</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#008b8b;width:4em;" /><td>cyan4</td><td>cyan4</td><td>##008b8b</td><td>0</td> <td>139</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#00008b;width:4em;" /><td>dark blue</td><td>darkblue</td><td>##00008b</td><td>0</td> <td>0</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#00008b;width:4em;" /><td>darkblue</td><td>darkblue</td><td>##00008b</td><td>0</td> <td>0</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#008b8b;width:4em;" /><td>darkcyan</td><td>darkcyan</td><td>##008b8b</td><td>0</td> <td>139</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#008b8b;width:4em;" /><td>dark cyan</td><td>darkcyan</td><td>##008b8b</td><td>0</td> <td>139</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#b8860b;width:4em;" /><td>darkgoldenrod</td><td>darkgoldenrod</td><td>##b8860b</td><td>184</td> <td>134</td> <td>11</td>
</tr> <tr><td style="border:1px solid #666; background:#b8860b;width:4em;" /><td>dark goldenrod</td><td>darkgoldenrod</td><td>##b8860b</td><td>184</td> <td>134</td> <td>11</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb90f;width:4em;" /><td>darkgoldenrod1</td><td>darkgoldenrod1</td><td>##ffb90f</td><td>255</td> <td>185</td> <td>15</td>
</tr> <tr><td style="border:1px solid #666; background:#eead0e;width:4em;" /><td>darkgoldenrod2</td><td>darkgoldenrod2</td><td>##eead0e</td><td>238</td> <td>173</td> <td>14</td>
</tr> <tr><td style="border:1px solid #666; background:#cd950c;width:4em;" /><td>darkgoldenrod3</td><td>darkgoldenrod3</td><td>##cd950c</td><td>205</td> <td>149</td> <td>12</td>
</tr> <tr><td style="border:1px solid #666; background:#8b6508;width:4em;" /><td>darkgoldenrod4</td><td>darkgoldenrod4</td><td>##8b6508</td><td>139</td> <td>101</td> <td>8</td>
</tr> <tr><td style="border:1px solid #666; background:#a9a9a9;width:4em;" /><td>dark gray</td><td>darkgray</td><td>##a9a9a9</td><td>169</td> <td>169</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a9a9a9;width:4em;" /><td>darkgray</td><td>darkgray</td><td>##a9a9a9</td><td>169</td> <td>169</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#006400;width:4em;" /><td>darkgreen</td><td>darkgreen</td><td>##006400</td><td>0</td> <td>100</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#006400;width:4em;" /><td>dark green</td><td>darkgreen</td><td>##006400</td><td>0</td> <td>100</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#a9a9a9;width:4em;" /><td>dark grey</td><td>darkgrey</td><td>##a9a9a9</td><td>169</td> <td>169</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#a9a9a9;width:4em;" /><td>darkgrey</td><td>darkgrey</td><td>##a9a9a9</td><td>169</td> <td>169</td> <td>169</td>
</tr> <tr><td style="border:1px solid #666; background:#bdb76b;width:4em;" /><td>dark khaki</td><td>darkkhaki</td><td>##bdb76b</td><td>189</td> <td>183</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#bdb76b;width:4em;" /><td>darkkhaki</td><td>darkkhaki</td><td>##bdb76b</td><td>189</td> <td>183</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#8b008b;width:4em;" /><td>dark magenta</td><td>darkmagenta</td><td>##8b008b</td><td>139</td> <td>0</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#8b008b;width:4em;" /><td>darkmagenta</td><td>darkmagenta</td><td>##8b008b</td><td>139</td> <td>0</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#556b2f;width:4em;" /><td>dark olive green</td><td>darkolivegreen</td><td>##556b2f</td><td>85</td> <td>107</td> <td>47</td>
</tr> <tr><td style="border:1px solid #666; background:#556b2f;width:4em;" /><td>darkolivegreen</td><td>darkolivegreen</td><td>##556b2f</td><td>85</td> <td>107</td> <td>47</td>
</tr> <tr><td style="border:1px solid #666; background:#caff70;width:4em;" /><td>darkolivegreen1</td><td>darkolivegreen1</td><td>##caff70</td><td>202</td> <td>255</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#bcee68;width:4em;" /><td>darkolivegreen2</td><td>darkolivegreen2</td><td>##bcee68</td><td>188</td> <td>238</td> <td>104</td>
</tr> <tr><td style="border:1px solid #666; background:#a2cd5a;width:4em;" /><td>darkolivegreen3</td><td>darkolivegreen3</td><td>##a2cd5a</td><td>162</td> <td>205</td> <td>90</td>
</tr> <tr><td style="border:1px solid #666; background:#6e8b3d;width:4em;" /><td>darkolivegreen4</td><td>darkolivegreen4</td><td>##6e8b3d</td><td>110</td> <td>139</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#ff8c00;width:4em;" /><td>dark orange</td><td>darkorange</td><td>##ff8c00</td><td>255</td> <td>140</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ff8c00;width:4em;" /><td>darkorange</td><td>darkorange</td><td>##ff8c00</td><td>255</td> <td>140</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ff7f00;width:4em;" /><td>darkorange1</td><td>darkorange1</td><td>##ff7f00</td><td>255</td> <td>127</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ee7600;width:4em;" /><td>darkorange2</td><td>darkorange2</td><td>##ee7600</td><td>238</td> <td>118</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#cd6600;width:4em;" /><td>darkorange3</td><td>darkorange3</td><td>##cd6600</td><td>205</td> <td>102</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8b4500;width:4em;" /><td>darkorange4</td><td>darkorange4</td><td>##8b4500</td><td>139</td> <td>69</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#9932cc;width:4em;" /><td>darkorchid</td><td>darkorchid</td><td>##9932cc</td><td>153</td> <td>50</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#9932cc;width:4em;" /><td>dark orchid</td><td>darkorchid</td><td>##9932cc</td><td>153</td> <td>50</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#bf3eff;width:4em;" /><td>darkorchid1</td><td>darkorchid1</td><td>##bf3eff</td><td>191</td> <td>62</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#b23aee;width:4em;" /><td>darkorchid2</td><td>darkorchid2</td><td>##b23aee</td><td>178</td> <td>58</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#9a32cd;width:4em;" /><td>darkorchid3</td><td>darkorchid3</td><td>##9a32cd</td><td>154</td> <td>50</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#68228b;width:4em;" /><td>darkorchid4</td><td>darkorchid4</td><td>##68228b</td><td>104</td> <td>34</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#8b0000;width:4em;" /><td>dark red</td><td>darkred</td><td>##8b0000</td><td>139</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8b0000;width:4em;" /><td>darkred</td><td>darkred</td><td>##8b0000</td><td>139</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#e9967a;width:4em;" /><td>dark salmon</td><td>darksalmon</td><td>##e9967a</td><td>233</td> <td>150</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#e9967a;width:4em;" /><td>darksalmon</td><td>darksalmon</td><td>##e9967a</td><td>233</td> <td>150</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#8fbc8f;width:4em;" /><td>dark sea green</td><td>darkseagreen</td><td>##8fbc8f</td><td>143</td> <td>188</td> <td>143</td>
</tr> <tr><td style="border:1px solid #666; background:#8fbc8f;width:4em;" /><td>darkseagreen</td><td>darkseagreen</td><td>##8fbc8f</td><td>143</td> <td>188</td> <td>143</td>
</tr> <tr><td style="border:1px solid #666; background:#c1ffc1;width:4em;" /><td>darkseagreen1</td><td>darkseagreen1</td><td>##c1ffc1</td><td>193</td> <td>255</td> <td>193</td>
</tr> <tr><td style="border:1px solid #666; background:#b4eeb4;width:4em;" /><td>darkseagreen2</td><td>darkseagreen2</td><td>##b4eeb4</td><td>180</td> <td>238</td> <td>180</td>
</tr> <tr><td style="border:1px solid #666; background:#9bcd9b;width:4em;" /><td>darkseagreen3</td><td>darkseagreen3</td><td>##9bcd9b</td><td>155</td> <td>205</td> <td>155</td>
</tr> <tr><td style="border:1px solid #666; background:#698b69;width:4em;" /><td>darkseagreen4</td><td>darkseagreen4</td><td>##698b69</td><td>105</td> <td>139</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#483d8b;width:4em;" /><td>dark slate blue</td><td>darkslateblue</td><td>##483d8b</td><td>72</td> <td>61</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#483d8b;width:4em;" /><td>darkslateblue</td><td>darkslateblue</td><td>##483d8b</td><td>72</td> <td>61</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#2f4f4f;width:4em;" /><td>dark slate gray</td><td>darkslategray</td><td>##2f4f4f</td><td>47</td> <td>79</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#2f4f4f;width:4em;" /><td>darkslategray</td><td>darkslategray</td><td>##2f4f4f</td><td>47</td> <td>79</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#97ffff;width:4em;" /><td>darkslategray1</td><td>darkslategray1</td><td>##97ffff</td><td>151</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8deeee;width:4em;" /><td>darkslategray2</td><td>darkslategray2</td><td>##8deeee</td><td>141</td> <td>238</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#79cdcd;width:4em;" /><td>darkslategray3</td><td>darkslategray3</td><td>##79cdcd</td><td>121</td> <td>205</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#528b8b;width:4em;" /><td>darkslategray4</td><td>darkslategray4</td><td>##528b8b</td><td>82</td> <td>139</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#2f4f4f;width:4em;" /><td>dark slate grey</td><td>darkslategrey</td><td>##2f4f4f</td><td>47</td> <td>79</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#2f4f4f;width:4em;" /><td>darkslategrey</td><td>darkslategrey</td><td>##2f4f4f</td><td>47</td> <td>79</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#97ffff;width:4em;" /><td>darkslategrey1</td><td>darkslategrey1</td><td>##97ffff</td><td>151</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8deeee;width:4em;" /><td>darkslategrey2</td><td>darkslategrey2</td><td>##8deeee</td><td>141</td> <td>238</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#79cdcd;width:4em;" /><td>darkslategrey3</td><td>darkslategrey3</td><td>##79cdcd</td><td>121</td> <td>205</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#528b8b;width:4em;" /><td>darkslategrey4</td><td>darkslategrey4</td><td>##528b8b</td><td>82</td> <td>139</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#00ced1;width:4em;" /><td>dark turquoise</td><td>darkturquoise</td><td>##00ced1</td><td>0</td> <td>206</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#00ced1;width:4em;" /><td>darkturquoise</td><td>darkturquoise</td><td>##00ced1</td><td>0</td> <td>206</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#9400d3;width:4em;" /><td>darkviolet</td><td>darkviolet</td><td>##9400d3</td><td>148</td> <td>0</td> <td>211</td>
</tr> <tr><td style="border:1px solid #666; background:#9400d3;width:4em;" /><td>dark violet</td><td>darkviolet</td><td>##9400d3</td><td>148</td> <td>0</td> <td>211</td>
</tr> <tr><td style="border:1px solid #666; background:#ff1493;width:4em;" /><td>deep pink</td><td>deeppink</td><td>##ff1493</td><td>255</td> <td>20</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#ff1493;width:4em;" /><td>deeppink</td><td>deeppink</td><td>##ff1493</td><td>255</td> <td>20</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#ff1493;width:4em;" /><td>deeppink1</td><td>deeppink1</td><td>##ff1493</td><td>255</td> <td>20</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#ee1289;width:4em;" /><td>deeppink2</td><td>deeppink2</td><td>##ee1289</td><td>238</td> <td>18</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#cd1076;width:4em;" /><td>deeppink3</td><td>deeppink3</td><td>##cd1076</td><td>205</td> <td>16</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#8b0a50;width:4em;" /><td>deeppink4</td><td>deeppink4</td><td>##8b0a50</td><td>139</td> <td>10</td> <td>80</td>
</tr> <tr><td style="border:1px solid #666; background:#00bfff;width:4em;" /><td>deepskyblue</td><td>deepskyblue</td><td>##00bfff</td><td>0</td> <td>191</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#00bfff;width:4em;" /><td>deep sky blue</td><td>deepskyblue</td><td>##00bfff</td><td>0</td> <td>191</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#00bfff;width:4em;" /><td>deepskyblue1</td><td>deepskyblue1</td><td>##00bfff</td><td>0</td> <td>191</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#00b2ee;width:4em;" /><td>deepskyblue2</td><td>deepskyblue2</td><td>##00b2ee</td><td>0</td> <td>178</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#009acd;width:4em;" /><td>deepskyblue3</td><td>deepskyblue3</td><td>##009acd</td><td>0</td> <td>154</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#00688b;width:4em;" /><td>deepskyblue4</td><td>deepskyblue4</td><td>##00688b</td><td>0</td> <td>104</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#696969;width:4em;" /><td>dimgray</td><td>dimgray</td><td>##696969</td><td>105</td> <td>105</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#696969;width:4em;" /><td>dim gray</td><td>dimgray</td><td>##696969</td><td>105</td> <td>105</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#696969;width:4em;" /><td>dim grey</td><td>dimgrey</td><td>##696969</td><td>105</td> <td>105</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#696969;width:4em;" /><td>dimgrey</td><td>dimgrey</td><td>##696969</td><td>105</td> <td>105</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#1e90ff;width:4em;" /><td>dodger blue</td><td>dodgerblue</td><td>##1e90ff</td><td>30</td> <td>144</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#1e90ff;width:4em;" /><td>dodgerblue</td><td>dodgerblue</td><td>##1e90ff</td><td>30</td> <td>144</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#1e90ff;width:4em;" /><td>dodgerblue1</td><td>dodgerblue1</td><td>##1e90ff</td><td>30</td> <td>144</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#1c86ee;width:4em;" /><td>dodgerblue2</td><td>dodgerblue2</td><td>##1c86ee</td><td>28</td> <td>134</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#1874cd;width:4em;" /><td>dodgerblue3</td><td>dodgerblue3</td><td>##1874cd</td><td>24</td> <td>116</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#104e8b;width:4em;" /><td>dodgerblue4</td><td>dodgerblue4</td><td>##104e8b</td><td>16</td> <td>78</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#b22222;width:4em;" /><td>firebrick</td><td>firebrick</td><td>##b22222</td><td>178</td> <td>34</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#ff3030;width:4em;" /><td>firebrick1</td><td>firebrick1</td><td>##ff3030</td><td>255</td> <td>48</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#ee2c2c;width:4em;" /><td>firebrick2</td><td>firebrick2</td><td>##ee2c2c</td><td>238</td> <td>44</td> <td>44</td>
</tr> <tr><td style="border:1px solid #666; background:#cd2626;width:4em;" /><td>firebrick3</td><td>firebrick3</td><td>##cd2626</td><td>205</td> <td>38</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#8b1a1a;width:4em;" /><td>firebrick4</td><td>firebrick4</td><td>##8b1a1a</td><td>139</td> <td>26</td> <td>26</td>
</tr> <tr><td style="border:1px solid #666; background:#fffaf0;width:4em;" /><td>floral white</td><td>floralwhite</td><td>##fffaf0</td><td>255</td> <td>250</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#fffaf0;width:4em;" /><td>floralwhite</td><td>floralwhite</td><td>##fffaf0</td><td>255</td> <td>250</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#228b22;width:4em;" /><td>forestgreen</td><td>forestgreen</td><td>##228b22</td><td>34</td> <td>139</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#228b22;width:4em;" /><td>forest green</td><td>forestgreen</td><td>##228b22</td><td>34</td> <td>139</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#dcdcdc;width:4em;" /><td>gainsboro</td><td>gainsboro</td><td>##dcdcdc</td><td>220</td> <td>220</td> <td>220</td>
</tr> <tr><td style="border:1px solid #666; background:#f8f8ff;width:4em;" /><td>ghostwhite</td><td>ghostwhite</td><td>##f8f8ff</td><td>248</td> <td>248</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#f8f8ff;width:4em;" /><td>ghost white</td><td>ghostwhite</td><td>##f8f8ff</td><td>248</td> <td>248</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#ffd700;width:4em;" /><td>gold</td><td>gold</td><td>##ffd700</td><td>255</td> <td>215</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ffd700;width:4em;" /><td>gold1</td><td>gold1</td><td>##ffd700</td><td>255</td> <td>215</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#eec900;width:4em;" /><td>gold2</td><td>gold2</td><td>##eec900</td><td>238</td> <td>201</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#cdad00;width:4em;" /><td>gold3</td><td>gold3</td><td>##cdad00</td><td>205</td> <td>173</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8b7500;width:4em;" /><td>gold4</td><td>gold4</td><td>##8b7500</td><td>139</td> <td>117</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#daa520;width:4em;" /><td>goldenrod</td><td>goldenrod</td><td>##daa520</td><td>218</td> <td>165</td> <td>32</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc125;width:4em;" /><td>goldenrod1</td><td>goldenrod1</td><td>##ffc125</td><td>255</td> <td>193</td> <td>37</td>
</tr> <tr><td style="border:1px solid #666; background:#eeb422;width:4em;" /><td>goldenrod2</td><td>goldenrod2</td><td>##eeb422</td><td>238</td> <td>180</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#cd9b1d;width:4em;" /><td>goldenrod3</td><td>goldenrod3</td><td>##cd9b1d</td><td>205</td> <td>155</td> <td>29</td>
</tr> <tr><td style="border:1px solid #666; background:#8b6914;width:4em;" /><td>goldenrod4</td><td>goldenrod4</td><td>##8b6914</td><td>139</td> <td>105</td> <td>20</td>
</tr> <tr><td style="border:1px solid #666; background:#bebebe;width:4em;" /><td>gray</td><td>gray</td><td>##bebebe</td><td>190</td> <td>190</td> <td>190</td>
</tr> <tr><td style="border:1px solid #666; background:#000000;width:4em;" /><td>gray0</td><td>gray0</td><td>##000000</td><td>0</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#030303;width:4em;" /><td>gray1</td><td>gray1</td><td>##030303</td><td>3</td> <td>3</td> <td>3</td>
</tr> <tr><td style="border:1px solid #666; background:#1a1a1a;width:4em;" /><td>gray10</td><td>gray10</td><td>##1a1a1a</td><td>26</td> <td>26</td> <td>26</td>
</tr> <tr><td style="border:1px solid #666; background:#ffffff;width:4em;" /><td>gray100</td><td>gray100</td><td>##ffffff</td><td>255</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#1c1c1c;width:4em;" /><td>gray11</td><td>gray11</td><td>##1c1c1c</td><td>28</td> <td>28</td> <td>28</td>
</tr> <tr><td style="border:1px solid #666; background:#1f1f1f;width:4em;" /><td>gray12</td><td>gray12</td><td>##1f1f1f</td><td>31</td> <td>31</td> <td>31</td>
</tr> <tr><td style="border:1px solid #666; background:#212121;width:4em;" /><td>gray13</td><td>gray13</td><td>##212121</td><td>33</td> <td>33</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#242424;width:4em;" /><td>gray14</td><td>gray14</td><td>##242424</td><td>36</td> <td>36</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#262626;width:4em;" /><td>gray15</td><td>gray15</td><td>##262626</td><td>38</td> <td>38</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#292929;width:4em;" /><td>gray16</td><td>gray16</td><td>##292929</td><td>41</td> <td>41</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#2b2b2b;width:4em;" /><td>gray17</td><td>gray17</td><td>##2b2b2b</td><td>43</td> <td>43</td> <td>43</td>
</tr> <tr><td style="border:1px solid #666; background:#2e2e2e;width:4em;" /><td>gray18</td><td>gray18</td><td>##2e2e2e</td><td>46</td> <td>46</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#303030;width:4em;" /><td>gray19</td><td>gray19</td><td>##303030</td><td>48</td> <td>48</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#050505;width:4em;" /><td>gray2</td><td>gray2</td><td>##050505</td><td>5</td> <td>5</td> <td>5</td>
</tr> <tr><td style="border:1px solid #666; background:#333333;width:4em;" /><td>gray20</td><td>gray20</td><td>##333333</td><td>51</td> <td>51</td> <td>51</td>
</tr> <tr><td style="border:1px solid #666; background:#363636;width:4em;" /><td>gray21</td><td>gray21</td><td>##363636</td><td>54</td> <td>54</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#383838;width:4em;" /><td>gray22</td><td>gray22</td><td>##383838</td><td>56</td> <td>56</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3b3b;width:4em;" /><td>gray23</td><td>gray23</td><td>##3b3b3b</td><td>59</td> <td>59</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3d3d3d;width:4em;" /><td>gray24</td><td>gray24</td><td>##3d3d3d</td><td>61</td> <td>61</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#404040;width:4em;" /><td>gray25</td><td>gray25</td><td>##404040</td><td>64</td> <td>64</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#424242;width:4em;" /><td>gray26</td><td>gray26</td><td>##424242</td><td>66</td> <td>66</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#454545;width:4em;" /><td>gray27</td><td>gray27</td><td>##454545</td><td>69</td> <td>69</td> <td>69</td>
</tr> <tr><td style="border:1px solid #666; background:#474747;width:4em;" /><td>gray28</td><td>gray28</td><td>##474747</td><td>71</td> <td>71</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4a4a4a;width:4em;" /><td>gray29</td><td>gray29</td><td>##4a4a4a</td><td>74</td> <td>74</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#080808;width:4em;" /><td>gray3</td><td>gray3</td><td>##080808</td><td>8</td> <td>8</td> <td>8</td>
</tr> <tr><td style="border:1px solid #666; background:#4d4d4d;width:4em;" /><td>gray30</td><td>gray30</td><td>##4d4d4d</td><td>77</td> <td>77</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#4f4f4f;width:4em;" /><td>gray31</td><td>gray31</td><td>##4f4f4f</td><td>79</td> <td>79</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#525252;width:4em;" /><td>gray32</td><td>gray32</td><td>##525252</td><td>82</td> <td>82</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#545454;width:4em;" /><td>gray33</td><td>gray33</td><td>##545454</td><td>84</td> <td>84</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#575757;width:4em;" /><td>gray34</td><td>gray34</td><td>##575757</td><td>87</td> <td>87</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#595959;width:4em;" /><td>gray35</td><td>gray35</td><td>##595959</td><td>89</td> <td>89</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#5c5c5c;width:4em;" /><td>gray36</td><td>gray36</td><td>##5c5c5c</td><td>92</td> <td>92</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#5e5e5e;width:4em;" /><td>gray37</td><td>gray37</td><td>##5e5e5e</td><td>94</td> <td>94</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#616161;width:4em;" /><td>gray38</td><td>gray38</td><td>##616161</td><td>97</td> <td>97</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#636363;width:4em;" /><td>gray39</td><td>gray39</td><td>##636363</td><td>99</td> <td>99</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#0a0a0a;width:4em;" /><td>gray4</td><td>gray4</td><td>##0a0a0a</td><td>10</td> <td>10</td> <td>10</td>
</tr> <tr><td style="border:1px solid #666; background:#666666;width:4em;" /><td>gray40</td><td>gray40</td><td>##666666</td><td>102</td> <td>102</td> <td>102</td>
</tr> <tr><td style="border:1px solid #666; background:#696969;width:4em;" /><td>gray41</td><td>gray41</td><td>##696969</td><td>105</td> <td>105</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#6b6b6b;width:4em;" /><td>gray42</td><td>gray42</td><td>##6b6b6b</td><td>107</td> <td>107</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#6e6e6e;width:4em;" /><td>gray43</td><td>gray43</td><td>##6e6e6e</td><td>110</td> <td>110</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#707070;width:4em;" /><td>gray44</td><td>gray44</td><td>##707070</td><td>112</td> <td>112</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#737373;width:4em;" /><td>gray45</td><td>gray45</td><td>##737373</td><td>115</td> <td>115</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#757575;width:4em;" /><td>gray46</td><td>gray46</td><td>##757575</td><td>117</td> <td>117</td> <td>117</td>
</tr> <tr><td style="border:1px solid #666; background:#787878;width:4em;" /><td>gray47</td><td>gray47</td><td>##787878</td><td>120</td> <td>120</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#7a7a7a;width:4em;" /><td>gray48</td><td>gray48</td><td>##7a7a7a</td><td>122</td> <td>122</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#7d7d7d;width:4em;" /><td>gray49</td><td>gray49</td><td>##7d7d7d</td><td>125</td> <td>125</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#0d0d0d;width:4em;" /><td>gray5</td><td>gray5</td><td>##0d0d0d</td><td>13</td> <td>13</td> <td>13</td>
</tr> <tr><td style="border:1px solid #666; background:#7f7f7f;width:4em;" /><td>gray50</td><td>gray50</td><td>##7f7f7f</td><td>127</td> <td>127</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#828282;width:4em;" /><td>gray51</td><td>gray51</td><td>##828282</td><td>130</td> <td>130</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#858585;width:4em;" /><td>gray52</td><td>gray52</td><td>##858585</td><td>133</td> <td>133</td> <td>133</td>
</tr> <tr><td style="border:1px solid #666; background:#878787;width:4em;" /><td>gray53</td><td>gray53</td><td>##878787</td><td>135</td> <td>135</td> <td>135</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8a8a;width:4em;" /><td>gray54</td><td>gray54</td><td>##8a8a8a</td><td>138</td> <td>138</td> <td>138</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8c8c;width:4em;" /><td>gray55</td><td>gray55</td><td>##8c8c8c</td><td>140</td> <td>140</td> <td>140</td>
</tr> <tr><td style="border:1px solid #666; background:#8f8f8f;width:4em;" /><td>gray56</td><td>gray56</td><td>##8f8f8f</td><td>143</td> <td>143</td> <td>143</td>
</tr> <tr><td style="border:1px solid #666; background:#919191;width:4em;" /><td>gray57</td><td>gray57</td><td>##919191</td><td>145</td> <td>145</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#949494;width:4em;" /><td>gray58</td><td>gray58</td><td>##949494</td><td>148</td> <td>148</td> <td>148</td>
</tr> <tr><td style="border:1px solid #666; background:#969696;width:4em;" /><td>gray59</td><td>gray59</td><td>##969696</td><td>150</td> <td>150</td> <td>150</td>
</tr> <tr><td style="border:1px solid #666; background:#0f0f0f;width:4em;" /><td>gray6</td><td>gray6</td><td>##0f0f0f</td><td>15</td> <td>15</td> <td>15</td>
</tr> <tr><td style="border:1px solid #666; background:#999999;width:4em;" /><td>gray60</td><td>gray60</td><td>##999999</td><td>153</td> <td>153</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#9c9c9c;width:4em;" /><td>gray61</td><td>gray61</td><td>##9c9c9c</td><td>156</td> <td>156</td> <td>156</td>
</tr> <tr><td style="border:1px solid #666; background:#9e9e9e;width:4em;" /><td>gray62</td><td>gray62</td><td>##9e9e9e</td><td>158</td> <td>158</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#a1a1a1;width:4em;" /><td>gray63</td><td>gray63</td><td>##a1a1a1</td><td>161</td> <td>161</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#a3a3a3;width:4em;" /><td>gray64</td><td>gray64</td><td>##a3a3a3</td><td>163</td> <td>163</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#a6a6a6;width:4em;" /><td>gray65</td><td>gray65</td><td>##a6a6a6</td><td>166</td> <td>166</td> <td>166</td>
</tr> <tr><td style="border:1px solid #666; background:#a8a8a8;width:4em;" /><td>gray66</td><td>gray66</td><td>##a8a8a8</td><td>168</td> <td>168</td> <td>168</td>
</tr> <tr><td style="border:1px solid #666; background:#ababab;width:4em;" /><td>gray67</td><td>gray67</td><td>##ababab</td><td>171</td> <td>171</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#adadad;width:4em;" /><td>gray68</td><td>gray68</td><td>##adadad</td><td>173</td> <td>173</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#b0b0b0;width:4em;" /><td>gray69</td><td>gray69</td><td>##b0b0b0</td><td>176</td> <td>176</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#121212;width:4em;" /><td>gray7</td><td>gray7</td><td>##121212</td><td>18</td> <td>18</td> <td>18</td>
</tr> <tr><td style="border:1px solid #666; background:#b3b3b3;width:4em;" /><td>gray70</td><td>gray70</td><td>##b3b3b3</td><td>179</td> <td>179</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#b5b5b5;width:4em;" /><td>gray71</td><td>gray71</td><td>##b5b5b5</td><td>181</td> <td>181</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b8b8b8;width:4em;" /><td>gray72</td><td>gray72</td><td>##b8b8b8</td><td>184</td> <td>184</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#bababa;width:4em;" /><td>gray73</td><td>gray73</td><td>##bababa</td><td>186</td> <td>186</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#bdbdbd;width:4em;" /><td>gray74</td><td>gray74</td><td>##bdbdbd</td><td>189</td> <td>189</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#bfbfbf;width:4em;" /><td>gray75</td><td>gray75</td><td>##bfbfbf</td><td>191</td> <td>191</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#c2c2c2;width:4em;" /><td>gray76</td><td>gray76</td><td>##c2c2c2</td><td>194</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c4c4;width:4em;" /><td>gray77</td><td>gray77</td><td>##c4c4c4</td><td>196</td> <td>196</td> <td>196</td>
</tr> <tr><td style="border:1px solid #666; background:#c7c7c7;width:4em;" /><td>gray78</td><td>gray78</td><td>##c7c7c7</td><td>199</td> <td>199</td> <td>199</td>
</tr> <tr><td style="border:1px solid #666; background:#c9c9c9;width:4em;" /><td>gray79</td><td>gray79</td><td>##c9c9c9</td><td>201</td> <td>201</td> <td>201</td>
</tr> <tr><td style="border:1px solid #666; background:#141414;width:4em;" /><td>gray8</td><td>gray8</td><td>##141414</td><td>20</td> <td>20</td> <td>20</td>
</tr> <tr><td style="border:1px solid #666; background:#cccccc;width:4em;" /><td>gray80</td><td>gray80</td><td>##cccccc</td><td>204</td> <td>204</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#cfcfcf;width:4em;" /><td>gray81</td><td>gray81</td><td>##cfcfcf</td><td>207</td> <td>207</td> <td>207</td>
</tr> <tr><td style="border:1px solid #666; background:#d1d1d1;width:4em;" /><td>gray82</td><td>gray82</td><td>##d1d1d1</td><td>209</td> <td>209</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#d4d4d4;width:4em;" /><td>gray83</td><td>gray83</td><td>##d4d4d4</td><td>212</td> <td>212</td> <td>212</td>
</tr> <tr><td style="border:1px solid #666; background:#d6d6d6;width:4em;" /><td>gray84</td><td>gray84</td><td>##d6d6d6</td><td>214</td> <td>214</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#d9d9d9;width:4em;" /><td>gray85</td><td>gray85</td><td>##d9d9d9</td><td>217</td> <td>217</td> <td>217</td>
</tr> <tr><td style="border:1px solid #666; background:#dbdbdb;width:4em;" /><td>gray86</td><td>gray86</td><td>##dbdbdb</td><td>219</td> <td>219</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#dedede;width:4em;" /><td>gray87</td><td>gray87</td><td>##dedede</td><td>222</td> <td>222</td> <td>222</td>
</tr> <tr><td style="border:1px solid #666; background:#e0e0e0;width:4em;" /><td>gray88</td><td>gray88</td><td>##e0e0e0</td><td>224</td> <td>224</td> <td>224</td>
</tr> <tr><td style="border:1px solid #666; background:#e3e3e3;width:4em;" /><td>gray89</td><td>gray89</td><td>##e3e3e3</td><td>227</td> <td>227</td> <td>227</td>
</tr> <tr><td style="border:1px solid #666; background:#171717;width:4em;" /><td>gray9</td><td>gray9</td><td>##171717</td><td>23</td> <td>23</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#e5e5e5;width:4em;" /><td>gray90</td><td>gray90</td><td>##e5e5e5</td><td>229</td> <td>229</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e8e8;width:4em;" /><td>gray91</td><td>gray91</td><td>##e8e8e8</td><td>232</td> <td>232</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#ebebeb;width:4em;" /><td>gray92</td><td>gray92</td><td>##ebebeb</td><td>235</td> <td>235</td> <td>235</td>
</tr> <tr><td style="border:1px solid #666; background:#ededed;width:4em;" /><td>gray93</td><td>gray93</td><td>##ededed</td><td>237</td> <td>237</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#f0f0f0;width:4em;" /><td>gray94</td><td>gray94</td><td>##f0f0f0</td><td>240</td> <td>240</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f2f2;width:4em;" /><td>gray95</td><td>gray95</td><td>##f2f2f2</td><td>242</td> <td>242</td> <td>242</td>
</tr> <tr><td style="border:1px solid #666; background:#f5f5f5;width:4em;" /><td>gray96</td><td>gray96</td><td>##f5f5f5</td><td>245</td> <td>245</td> <td>245</td>
</tr> <tr><td style="border:1px solid #666; background:#f7f7f7;width:4em;" /><td>gray97</td><td>gray97</td><td>##f7f7f7</td><td>247</td> <td>247</td> <td>247</td>
</tr> <tr><td style="border:1px solid #666; background:#fafafa;width:4em;" /><td>gray98</td><td>gray98</td><td>##fafafa</td><td>250</td> <td>250</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#fcfcfc;width:4em;" /><td>gray99</td><td>gray99</td><td>##fcfcfc</td><td>252</td> <td>252</td> <td>252</td>
</tr> <tr><td style="border:1px solid #666; background:#00ff00;width:4em;" /><td>green</td><td>green</td><td>##00ff00</td><td>0</td> <td>255</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#00ff00;width:4em;" /><td>green1</td><td>green1</td><td>##00ff00</td><td>0</td> <td>255</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#00ee00;width:4em;" /><td>green2</td><td>green2</td><td>##00ee00</td><td>0</td> <td>238</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#00cd00;width:4em;" /><td>green3</td><td>green3</td><td>##00cd00</td><td>0</td> <td>205</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#008b00;width:4em;" /><td>green4</td><td>green4</td><td>##008b00</td><td>0</td> <td>139</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#adff2f;width:4em;" /><td>green yellow</td><td>greenyellow</td><td>##adff2f</td><td>173</td> <td>255</td> <td>47</td>
</tr> <tr><td style="border:1px solid #666; background:#adff2f;width:4em;" /><td>greenyellow</td><td>greenyellow</td><td>##adff2f</td><td>173</td> <td>255</td> <td>47</td>
</tr> <tr><td style="border:1px solid #666; background:#bebebe;width:4em;" /><td>grey</td><td>grey</td><td>##bebebe</td><td>190</td> <td>190</td> <td>190</td>
</tr> <tr><td style="border:1px solid #666; background:#000000;width:4em;" /><td>grey0</td><td>grey0</td><td>##000000</td><td>0</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#030303;width:4em;" /><td>grey1</td><td>grey1</td><td>##030303</td><td>3</td> <td>3</td> <td>3</td>
</tr> <tr><td style="border:1px solid #666; background:#1a1a1a;width:4em;" /><td>grey10</td><td>grey10</td><td>##1a1a1a</td><td>26</td> <td>26</td> <td>26</td>
</tr> <tr><td style="border:1px solid #666; background:#ffffff;width:4em;" /><td>grey100</td><td>grey100</td><td>##ffffff</td><td>255</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#1c1c1c;width:4em;" /><td>grey11</td><td>grey11</td><td>##1c1c1c</td><td>28</td> <td>28</td> <td>28</td>
</tr> <tr><td style="border:1px solid #666; background:#1f1f1f;width:4em;" /><td>grey12</td><td>grey12</td><td>##1f1f1f</td><td>31</td> <td>31</td> <td>31</td>
</tr> <tr><td style="border:1px solid #666; background:#212121;width:4em;" /><td>grey13</td><td>grey13</td><td>##212121</td><td>33</td> <td>33</td> <td>33</td>
</tr> <tr><td style="border:1px solid #666; background:#242424;width:4em;" /><td>grey14</td><td>grey14</td><td>##242424</td><td>36</td> <td>36</td> <td>36</td>
</tr> <tr><td style="border:1px solid #666; background:#262626;width:4em;" /><td>grey15</td><td>grey15</td><td>##262626</td><td>38</td> <td>38</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#292929;width:4em;" /><td>grey16</td><td>grey16</td><td>##292929</td><td>41</td> <td>41</td> <td>41</td>
</tr> <tr><td style="border:1px solid #666; background:#2b2b2b;width:4em;" /><td>grey17</td><td>grey17</td><td>##2b2b2b</td><td>43</td> <td>43</td> <td>43</td>
</tr> <tr><td style="border:1px solid #666; background:#2e2e2e;width:4em;" /><td>grey18</td><td>grey18</td><td>##2e2e2e</td><td>46</td> <td>46</td> <td>46</td>
</tr> <tr><td style="border:1px solid #666; background:#303030;width:4em;" /><td>grey19</td><td>grey19</td><td>##303030</td><td>48</td> <td>48</td> <td>48</td>
</tr> <tr><td style="border:1px solid #666; background:#050505;width:4em;" /><td>grey2</td><td>grey2</td><td>##050505</td><td>5</td> <td>5</td> <td>5</td>
</tr> <tr><td style="border:1px solid #666; background:#333333;width:4em;" /><td>grey20</td><td>grey20</td><td>##333333</td><td>51</td> <td>51</td> <td>51</td>
</tr> <tr><td style="border:1px solid #666; background:#363636;width:4em;" /><td>grey21</td><td>grey21</td><td>##363636</td><td>54</td> <td>54</td> <td>54</td>
</tr> <tr><td style="border:1px solid #666; background:#383838;width:4em;" /><td>grey22</td><td>grey22</td><td>##383838</td><td>56</td> <td>56</td> <td>56</td>
</tr> <tr><td style="border:1px solid #666; background:#3b3b3b;width:4em;" /><td>grey23</td><td>grey23</td><td>##3b3b3b</td><td>59</td> <td>59</td> <td>59</td>
</tr> <tr><td style="border:1px solid #666; background:#3d3d3d;width:4em;" /><td>grey24</td><td>grey24</td><td>##3d3d3d</td><td>61</td> <td>61</td> <td>61</td>
</tr> <tr><td style="border:1px solid #666; background:#404040;width:4em;" /><td>grey25</td><td>grey25</td><td>##404040</td><td>64</td> <td>64</td> <td>64</td>
</tr> <tr><td style="border:1px solid #666; background:#424242;width:4em;" /><td>grey26</td><td>grey26</td><td>##424242</td><td>66</td> <td>66</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#454545;width:4em;" /><td>grey27</td><td>grey27</td><td>##454545</td><td>69</td> <td>69</td> <td>69</td>
</tr> <tr><td style="border:1px solid #666; background:#474747;width:4em;" /><td>grey28</td><td>grey28</td><td>##474747</td><td>71</td> <td>71</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#4a4a4a;width:4em;" /><td>grey29</td><td>grey29</td><td>##4a4a4a</td><td>74</td> <td>74</td> <td>74</td>
</tr> <tr><td style="border:1px solid #666; background:#080808;width:4em;" /><td>grey3</td><td>grey3</td><td>##080808</td><td>8</td> <td>8</td> <td>8</td>
</tr> <tr><td style="border:1px solid #666; background:#4d4d4d;width:4em;" /><td>grey30</td><td>grey30</td><td>##4d4d4d</td><td>77</td> <td>77</td> <td>77</td>
</tr> <tr><td style="border:1px solid #666; background:#4f4f4f;width:4em;" /><td>grey31</td><td>grey31</td><td>##4f4f4f</td><td>79</td> <td>79</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#525252;width:4em;" /><td>grey32</td><td>grey32</td><td>##525252</td><td>82</td> <td>82</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#545454;width:4em;" /><td>grey33</td><td>grey33</td><td>##545454</td><td>84</td> <td>84</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#575757;width:4em;" /><td>grey34</td><td>grey34</td><td>##575757</td><td>87</td> <td>87</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#595959;width:4em;" /><td>grey35</td><td>grey35</td><td>##595959</td><td>89</td> <td>89</td> <td>89</td>
</tr> <tr><td style="border:1px solid #666; background:#5c5c5c;width:4em;" /><td>grey36</td><td>grey36</td><td>##5c5c5c</td><td>92</td> <td>92</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#5e5e5e;width:4em;" /><td>grey37</td><td>grey37</td><td>##5e5e5e</td><td>94</td> <td>94</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#616161;width:4em;" /><td>grey38</td><td>grey38</td><td>##616161</td><td>97</td> <td>97</td> <td>97</td>
</tr> <tr><td style="border:1px solid #666; background:#636363;width:4em;" /><td>grey39</td><td>grey39</td><td>##636363</td><td>99</td> <td>99</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#0a0a0a;width:4em;" /><td>grey4</td><td>grey4</td><td>##0a0a0a</td><td>10</td> <td>10</td> <td>10</td>
</tr> <tr><td style="border:1px solid #666; background:#666666;width:4em;" /><td>grey40</td><td>grey40</td><td>##666666</td><td>102</td> <td>102</td> <td>102</td>
</tr> <tr><td style="border:1px solid #666; background:#696969;width:4em;" /><td>grey41</td><td>grey41</td><td>##696969</td><td>105</td> <td>105</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#6b6b6b;width:4em;" /><td>grey42</td><td>grey42</td><td>##6b6b6b</td><td>107</td> <td>107</td> <td>107</td>
</tr> <tr><td style="border:1px solid #666; background:#6e6e6e;width:4em;" /><td>grey43</td><td>grey43</td><td>##6e6e6e</td><td>110</td> <td>110</td> <td>110</td>
</tr> <tr><td style="border:1px solid #666; background:#707070;width:4em;" /><td>grey44</td><td>grey44</td><td>##707070</td><td>112</td> <td>112</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#737373;width:4em;" /><td>grey45</td><td>grey45</td><td>##737373</td><td>115</td> <td>115</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#757575;width:4em;" /><td>grey46</td><td>grey46</td><td>##757575</td><td>117</td> <td>117</td> <td>117</td>
</tr> <tr><td style="border:1px solid #666; background:#787878;width:4em;" /><td>grey47</td><td>grey47</td><td>##787878</td><td>120</td> <td>120</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#7a7a7a;width:4em;" /><td>grey48</td><td>grey48</td><td>##7a7a7a</td><td>122</td> <td>122</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#7d7d7d;width:4em;" /><td>grey49</td><td>grey49</td><td>##7d7d7d</td><td>125</td> <td>125</td> <td>125</td>
</tr> <tr><td style="border:1px solid #666; background:#0d0d0d;width:4em;" /><td>grey5</td><td>grey5</td><td>##0d0d0d</td><td>13</td> <td>13</td> <td>13</td>
</tr> <tr><td style="border:1px solid #666; background:#7f7f7f;width:4em;" /><td>grey50</td><td>grey50</td><td>##7f7f7f</td><td>127</td> <td>127</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#828282;width:4em;" /><td>grey51</td><td>grey51</td><td>##828282</td><td>130</td> <td>130</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#858585;width:4em;" /><td>grey52</td><td>grey52</td><td>##858585</td><td>133</td> <td>133</td> <td>133</td>
</tr> <tr><td style="border:1px solid #666; background:#878787;width:4em;" /><td>grey53</td><td>grey53</td><td>##878787</td><td>135</td> <td>135</td> <td>135</td>
</tr> <tr><td style="border:1px solid #666; background:#8a8a8a;width:4em;" /><td>grey54</td><td>grey54</td><td>##8a8a8a</td><td>138</td> <td>138</td> <td>138</td>
</tr> <tr><td style="border:1px solid #666; background:#8c8c8c;width:4em;" /><td>grey55</td><td>grey55</td><td>##8c8c8c</td><td>140</td> <td>140</td> <td>140</td>
</tr> <tr><td style="border:1px solid #666; background:#8f8f8f;width:4em;" /><td>grey56</td><td>grey56</td><td>##8f8f8f</td><td>143</td> <td>143</td> <td>143</td>
</tr> <tr><td style="border:1px solid #666; background:#919191;width:4em;" /><td>grey57</td><td>grey57</td><td>##919191</td><td>145</td> <td>145</td> <td>145</td>
</tr> <tr><td style="border:1px solid #666; background:#949494;width:4em;" /><td>grey58</td><td>grey58</td><td>##949494</td><td>148</td> <td>148</td> <td>148</td>
</tr> <tr><td style="border:1px solid #666; background:#969696;width:4em;" /><td>grey59</td><td>grey59</td><td>##969696</td><td>150</td> <td>150</td> <td>150</td>
</tr> <tr><td style="border:1px solid #666; background:#0f0f0f;width:4em;" /><td>grey6</td><td>grey6</td><td>##0f0f0f</td><td>15</td> <td>15</td> <td>15</td>
</tr> <tr><td style="border:1px solid #666; background:#999999;width:4em;" /><td>grey60</td><td>grey60</td><td>##999999</td><td>153</td> <td>153</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#9c9c9c;width:4em;" /><td>grey61</td><td>grey61</td><td>##9c9c9c</td><td>156</td> <td>156</td> <td>156</td>
</tr> <tr><td style="border:1px solid #666; background:#9e9e9e;width:4em;" /><td>grey62</td><td>grey62</td><td>##9e9e9e</td><td>158</td> <td>158</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#a1a1a1;width:4em;" /><td>grey63</td><td>grey63</td><td>##a1a1a1</td><td>161</td> <td>161</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#a3a3a3;width:4em;" /><td>grey64</td><td>grey64</td><td>##a3a3a3</td><td>163</td> <td>163</td> <td>163</td>
</tr> <tr><td style="border:1px solid #666; background:#a6a6a6;width:4em;" /><td>grey65</td><td>grey65</td><td>##a6a6a6</td><td>166</td> <td>166</td> <td>166</td>
</tr> <tr><td style="border:1px solid #666; background:#a8a8a8;width:4em;" /><td>grey66</td><td>grey66</td><td>##a8a8a8</td><td>168</td> <td>168</td> <td>168</td>
</tr> <tr><td style="border:1px solid #666; background:#ababab;width:4em;" /><td>grey67</td><td>grey67</td><td>##ababab</td><td>171</td> <td>171</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#adadad;width:4em;" /><td>grey68</td><td>grey68</td><td>##adadad</td><td>173</td> <td>173</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#b0b0b0;width:4em;" /><td>grey69</td><td>grey69</td><td>##b0b0b0</td><td>176</td> <td>176</td> <td>176</td>
</tr> <tr><td style="border:1px solid #666; background:#121212;width:4em;" /><td>grey7</td><td>grey7</td><td>##121212</td><td>18</td> <td>18</td> <td>18</td>
</tr> <tr><td style="border:1px solid #666; background:#b3b3b3;width:4em;" /><td>grey70</td><td>grey70</td><td>##b3b3b3</td><td>179</td> <td>179</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#b5b5b5;width:4em;" /><td>grey71</td><td>grey71</td><td>##b5b5b5</td><td>181</td> <td>181</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#b8b8b8;width:4em;" /><td>grey72</td><td>grey72</td><td>##b8b8b8</td><td>184</td> <td>184</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#bababa;width:4em;" /><td>grey73</td><td>grey73</td><td>##bababa</td><td>186</td> <td>186</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#bdbdbd;width:4em;" /><td>grey74</td><td>grey74</td><td>##bdbdbd</td><td>189</td> <td>189</td> <td>189</td>
</tr> <tr><td style="border:1px solid #666; background:#bfbfbf;width:4em;" /><td>grey75</td><td>grey75</td><td>##bfbfbf</td><td>191</td> <td>191</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#c2c2c2;width:4em;" /><td>grey76</td><td>grey76</td><td>##c2c2c2</td><td>194</td> <td>194</td> <td>194</td>
</tr> <tr><td style="border:1px solid #666; background:#c4c4c4;width:4em;" /><td>grey77</td><td>grey77</td><td>##c4c4c4</td><td>196</td> <td>196</td> <td>196</td>
</tr> <tr><td style="border:1px solid #666; background:#c7c7c7;width:4em;" /><td>grey78</td><td>grey78</td><td>##c7c7c7</td><td>199</td> <td>199</td> <td>199</td>
</tr> <tr><td style="border:1px solid #666; background:#c9c9c9;width:4em;" /><td>grey79</td><td>grey79</td><td>##c9c9c9</td><td>201</td> <td>201</td> <td>201</td>
</tr> <tr><td style="border:1px solid #666; background:#141414;width:4em;" /><td>grey8</td><td>grey8</td><td>##141414</td><td>20</td> <td>20</td> <td>20</td>
</tr> <tr><td style="border:1px solid #666; background:#cccccc;width:4em;" /><td>grey80</td><td>grey80</td><td>##cccccc</td><td>204</td> <td>204</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#cfcfcf;width:4em;" /><td>grey81</td><td>grey81</td><td>##cfcfcf</td><td>207</td> <td>207</td> <td>207</td>
</tr> <tr><td style="border:1px solid #666; background:#d1d1d1;width:4em;" /><td>grey82</td><td>grey82</td><td>##d1d1d1</td><td>209</td> <td>209</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#d4d4d4;width:4em;" /><td>grey83</td><td>grey83</td><td>##d4d4d4</td><td>212</td> <td>212</td> <td>212</td>
</tr> <tr><td style="border:1px solid #666; background:#d6d6d6;width:4em;" /><td>grey84</td><td>grey84</td><td>##d6d6d6</td><td>214</td> <td>214</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#d9d9d9;width:4em;" /><td>grey85</td><td>grey85</td><td>##d9d9d9</td><td>217</td> <td>217</td> <td>217</td>
</tr> <tr><td style="border:1px solid #666; background:#dbdbdb;width:4em;" /><td>grey86</td><td>grey86</td><td>##dbdbdb</td><td>219</td> <td>219</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#dedede;width:4em;" /><td>grey87</td><td>grey87</td><td>##dedede</td><td>222</td> <td>222</td> <td>222</td>
</tr> <tr><td style="border:1px solid #666; background:#e0e0e0;width:4em;" /><td>grey88</td><td>grey88</td><td>##e0e0e0</td><td>224</td> <td>224</td> <td>224</td>
</tr> <tr><td style="border:1px solid #666; background:#e3e3e3;width:4em;" /><td>grey89</td><td>grey89</td><td>##e3e3e3</td><td>227</td> <td>227</td> <td>227</td>
</tr> <tr><td style="border:1px solid #666; background:#171717;width:4em;" /><td>grey9</td><td>grey9</td><td>##171717</td><td>23</td> <td>23</td> <td>23</td>
</tr> <tr><td style="border:1px solid #666; background:#e5e5e5;width:4em;" /><td>grey90</td><td>grey90</td><td>##e5e5e5</td><td>229</td> <td>229</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#e8e8e8;width:4em;" /><td>grey91</td><td>grey91</td><td>##e8e8e8</td><td>232</td> <td>232</td> <td>232</td>
</tr> <tr><td style="border:1px solid #666; background:#ebebeb;width:4em;" /><td>grey92</td><td>grey92</td><td>##ebebeb</td><td>235</td> <td>235</td> <td>235</td>
</tr> <tr><td style="border:1px solid #666; background:#ededed;width:4em;" /><td>grey93</td><td>grey93</td><td>##ededed</td><td>237</td> <td>237</td> <td>237</td>
</tr> <tr><td style="border:1px solid #666; background:#f0f0f0;width:4em;" /><td>grey94</td><td>grey94</td><td>##f0f0f0</td><td>240</td> <td>240</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#f2f2f2;width:4em;" /><td>grey95</td><td>grey95</td><td>##f2f2f2</td><td>242</td> <td>242</td> <td>242</td>
</tr> <tr><td style="border:1px solid #666; background:#f5f5f5;width:4em;" /><td>grey96</td><td>grey96</td><td>##f5f5f5</td><td>245</td> <td>245</td> <td>245</td>
</tr> <tr><td style="border:1px solid #666; background:#f7f7f7;width:4em;" /><td>grey97</td><td>grey97</td><td>##f7f7f7</td><td>247</td> <td>247</td> <td>247</td>
</tr> <tr><td style="border:1px solid #666; background:#fafafa;width:4em;" /><td>grey98</td><td>grey98</td><td>##fafafa</td><td>250</td> <td>250</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#fcfcfc;width:4em;" /><td>grey99</td><td>grey99</td><td>##fcfcfc</td><td>252</td> <td>252</td> <td>252</td>
</tr> <tr><td style="border:1px solid #666; background:#f0fff0;width:4em;" /><td>honeydew</td><td>honeydew</td><td>##f0fff0</td><td>240</td> <td>255</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#f0fff0;width:4em;" /><td>honeydew1</td><td>honeydew1</td><td>##f0fff0</td><td>240</td> <td>255</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#e0eee0;width:4em;" /><td>honeydew2</td><td>honeydew2</td><td>##e0eee0</td><td>224</td> <td>238</td> <td>224</td>
</tr> <tr><td style="border:1px solid #666; background:#c1cdc1;width:4em;" /><td>honeydew3</td><td>honeydew3</td><td>##c1cdc1</td><td>193</td> <td>205</td> <td>193</td>
</tr> <tr><td style="border:1px solid #666; background:#838b83;width:4em;" /><td>honeydew4</td><td>honeydew4</td><td>##838b83</td><td>131</td> <td>139</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#ff69b4;width:4em;" /><td>hot pink</td><td>hotpink</td><td>##ff69b4</td><td>255</td> <td>105</td> <td>180</td>
</tr> <tr><td style="border:1px solid #666; background:#ff69b4;width:4em;" /><td>hotpink</td><td>hotpink</td><td>##ff69b4</td><td>255</td> <td>105</td> <td>180</td>
</tr> <tr><td style="border:1px solid #666; background:#ff6eb4;width:4em;" /><td>hotpink1</td><td>hotpink1</td><td>##ff6eb4</td><td>255</td> <td>110</td> <td>180</td>
</tr> <tr><td style="border:1px solid #666; background:#ee6aa7;width:4em;" /><td>hotpink2</td><td>hotpink2</td><td>##ee6aa7</td><td>238</td> <td>106</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#cd6090;width:4em;" /><td>hotpink3</td><td>hotpink3</td><td>##cd6090</td><td>205</td> <td>96</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#8b3a62;width:4em;" /><td>hotpink4</td><td>hotpink4</td><td>##8b3a62</td><td>139</td> <td>58</td> <td>98</td>
</tr> <tr><td style="border:1px solid #666; background:#cd5c5c;width:4em;" /><td>indianred</td><td>indianred</td><td>##cd5c5c</td><td>205</td> <td>92</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#cd5c5c;width:4em;" /><td>indian red</td><td>indianred</td><td>##cd5c5c</td><td>205</td> <td>92</td> <td>92</td>
</tr> <tr><td style="border:1px solid #666; background:#ff6a6a;width:4em;" /><td>indianred1</td><td>indianred1</td><td>##ff6a6a</td><td>255</td> <td>106</td> <td>106</td>
</tr> <tr><td style="border:1px solid #666; background:#ee6363;width:4em;" /><td>indianred2</td><td>indianred2</td><td>##ee6363</td><td>238</td> <td>99</td> <td>99</td>
</tr> <tr><td style="border:1px solid #666; background:#cd5555;width:4em;" /><td>indianred3</td><td>indianred3</td><td>##cd5555</td><td>205</td> <td>85</td> <td>85</td>
</tr> <tr><td style="border:1px solid #666; background:#8b3a3a;width:4em;" /><td>indianred4</td><td>indianred4</td><td>##8b3a3a</td><td>139</td> <td>58</td> <td>58</td>
</tr> <tr><td style="border:1px solid #666; background:#fffff0;width:4em;" /><td>ivory</td><td>ivory</td><td>##fffff0</td><td>255</td> <td>255</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#fffff0;width:4em;" /><td>ivory1</td><td>ivory1</td><td>##fffff0</td><td>255</td> <td>255</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#eeeee0;width:4em;" /><td>ivory2</td><td>ivory2</td><td>##eeeee0</td><td>238</td> <td>238</td> <td>224</td>
</tr> <tr><td style="border:1px solid #666; background:#cdcdc1;width:4em;" /><td>ivory3</td><td>ivory3</td><td>##cdcdc1</td><td>205</td> <td>205</td> <td>193</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8b83;width:4em;" /><td>ivory4</td><td>ivory4</td><td>##8b8b83</td><td>139</td> <td>139</td> <td>131</td>
</tr> <tr><td style="border:1px solid #666; background:#f0e68c;width:4em;" /><td>khaki</td><td>khaki</td><td>##f0e68c</td><td>240</td> <td>230</td> <td>140</td>
</tr> <tr><td style="border:1px solid #666; background:#fff68f;width:4em;" /><td>khaki1</td><td>khaki1</td><td>##fff68f</td><td>255</td> <td>246</td> <td>143</td>
</tr> <tr><td style="border:1px solid #666; background:#eee685;width:4em;" /><td>khaki2</td><td>khaki2</td><td>##eee685</td><td>238</td> <td>230</td> <td>133</td>
</tr> <tr><td style="border:1px solid #666; background:#cdc673;width:4em;" /><td>khaki3</td><td>khaki3</td><td>##cdc673</td><td>205</td> <td>198</td> <td>115</td>
</tr> <tr><td style="border:1px solid #666; background:#8b864e;width:4em;" /><td>khaki4</td><td>khaki4</td><td>##8b864e</td><td>139</td> <td>134</td> <td>78</td>
</tr> <tr><td style="border:1px solid #666; background:#e6e6fa;width:4em;" /><td>lavender</td><td>lavender</td><td>##e6e6fa</td><td>230</td> <td>230</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#fff0f5;width:4em;" /><td>lavenderblush</td><td>lavenderblush</td><td>##fff0f5</td><td>255</td> <td>240</td> <td>245</td>
</tr> <tr><td style="border:1px solid #666; background:#fff0f5;width:4em;" /><td>lavender blush</td><td>lavenderblush</td><td>##fff0f5</td><td>255</td> <td>240</td> <td>245</td>
</tr> <tr><td style="border:1px solid #666; background:#fff0f5;width:4em;" /><td>lavenderblush1</td><td>lavenderblush1</td><td>##fff0f5</td><td>255</td> <td>240</td> <td>245</td>
</tr> <tr><td style="border:1px solid #666; background:#eee0e5;width:4em;" /><td>lavenderblush2</td><td>lavenderblush2</td><td>##eee0e5</td><td>238</td> <td>224</td> <td>229</td>
</tr> <tr><td style="border:1px solid #666; background:#cdc1c5;width:4em;" /><td>lavenderblush3</td><td>lavenderblush3</td><td>##cdc1c5</td><td>205</td> <td>193</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8386;width:4em;" /><td>lavenderblush4</td><td>lavenderblush4</td><td>##8b8386</td><td>139</td> <td>131</td> <td>134</td>
</tr> <tr><td style="border:1px solid #666; background:#7cfc00;width:4em;" /><td>lawn green</td><td>lawngreen</td><td>##7cfc00</td><td>124</td> <td>252</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#7cfc00;width:4em;" /><td>lawngreen</td><td>lawngreen</td><td>##7cfc00</td><td>124</td> <td>252</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#fffacd;width:4em;" /><td>lemonchiffon</td><td>lemonchiffon</td><td>##fffacd</td><td>255</td> <td>250</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#fffacd;width:4em;" /><td>lemon chiffon</td><td>lemonchiffon</td><td>##fffacd</td><td>255</td> <td>250</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#fffacd;width:4em;" /><td>lemonchiffon1</td><td>lemonchiffon1</td><td>##fffacd</td><td>255</td> <td>250</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#eee9bf;width:4em;" /><td>lemonchiffon2</td><td>lemonchiffon2</td><td>##eee9bf</td><td>238</td> <td>233</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#cdc9a5;width:4em;" /><td>lemonchiffon3</td><td>lemonchiffon3</td><td>##cdc9a5</td><td>205</td> <td>201</td> <td>165</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8970;width:4em;" /><td>lemonchiffon4</td><td>lemonchiffon4</td><td>##8b8970</td><td>139</td> <td>137</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#add8e6;width:4em;" /><td>lightblue</td><td>lightblue</td><td>##add8e6</td><td>173</td> <td>216</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#add8e6;width:4em;" /><td>light blue</td><td>lightblue</td><td>##add8e6</td><td>173</td> <td>216</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#bfefff;width:4em;" /><td>lightblue1</td><td>lightblue1</td><td>##bfefff</td><td>191</td> <td>239</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#b2dfee;width:4em;" /><td>lightblue2</td><td>lightblue2</td><td>##b2dfee</td><td>178</td> <td>223</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#9ac0cd;width:4em;" /><td>lightblue3</td><td>lightblue3</td><td>##9ac0cd</td><td>154</td> <td>192</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#68838b;width:4em;" /><td>lightblue4</td><td>lightblue4</td><td>##68838b</td><td>104</td> <td>131</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#f08080;width:4em;" /><td>lightcoral</td><td>lightcoral</td><td>##f08080</td><td>240</td> <td>128</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#f08080;width:4em;" /><td>light coral</td><td>lightcoral</td><td>##f08080</td><td>240</td> <td>128</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#e0ffff;width:4em;" /><td>lightcyan</td><td>lightcyan</td><td>##e0ffff</td><td>224</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#e0ffff;width:4em;" /><td>light cyan</td><td>lightcyan</td><td>##e0ffff</td><td>224</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#e0ffff;width:4em;" /><td>lightcyan1</td><td>lightcyan1</td><td>##e0ffff</td><td>224</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#d1eeee;width:4em;" /><td>lightcyan2</td><td>lightcyan2</td><td>##d1eeee</td><td>209</td> <td>238</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#b4cdcd;width:4em;" /><td>lightcyan3</td><td>lightcyan3</td><td>##b4cdcd</td><td>180</td> <td>205</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#7a8b8b;width:4em;" /><td>lightcyan4</td><td>lightcyan4</td><td>##7a8b8b</td><td>122</td> <td>139</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#eedd82;width:4em;" /><td>lightgoldenrod</td><td>lightgoldenrod</td><td>##eedd82</td><td>238</td> <td>221</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#eedd82;width:4em;" /><td>light goldenrod</td><td>lightgoldenrod</td><td>##eedd82</td><td>238</td> <td>221</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#ffec8b;width:4em;" /><td>lightgoldenrod1</td><td>lightgoldenrod1</td><td>##ffec8b</td><td>255</td> <td>236</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#eedc82;width:4em;" /><td>lightgoldenrod2</td><td>lightgoldenrod2</td><td>##eedc82</td><td>238</td> <td>220</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#cdbe70;width:4em;" /><td>lightgoldenrod3</td><td>lightgoldenrod3</td><td>##cdbe70</td><td>205</td> <td>190</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#8b814c;width:4em;" /><td>lightgoldenrod4</td><td>lightgoldenrod4</td><td>##8b814c</td><td>139</td> <td>129</td> <td>76</td>
</tr> <tr><td style="border:1px solid #666; background:#fafad2;width:4em;" /><td>lightgoldenrodyellow</td><td>lightgoldenrodyellow</td><td>##fafad2</td><td>250</td> <td>250</td> <td>210</td>
</tr> <tr><td style="border:1px solid #666; background:#fafad2;width:4em;" /><td>light goldenrod yellow</td><td>lightgoldenrodyellow</td><td>##fafad2</td><td>250</td> <td>250</td> <td>210</td>
</tr> <tr><td style="border:1px solid #666; background:#d3d3d3;width:4em;" /><td>lightgray</td><td>lightgray</td><td>##d3d3d3</td><td>211</td> <td>211</td> <td>211</td>
</tr> <tr><td style="border:1px solid #666; background:#d3d3d3;width:4em;" /><td>light gray</td><td>lightgray</td><td>##d3d3d3</td><td>211</td> <td>211</td> <td>211</td>
</tr> <tr><td style="border:1px solid #666; background:#90ee90;width:4em;" /><td>light green</td><td>lightgreen</td><td>##90ee90</td><td>144</td> <td>238</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#90ee90;width:4em;" /><td>lightgreen</td><td>lightgreen</td><td>##90ee90</td><td>144</td> <td>238</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#d3d3d3;width:4em;" /><td>lightgrey</td><td>lightgrey</td><td>##d3d3d3</td><td>211</td> <td>211</td> <td>211</td>
</tr> <tr><td style="border:1px solid #666; background:#d3d3d3;width:4em;" /><td>light grey</td><td>lightgrey</td><td>##d3d3d3</td><td>211</td> <td>211</td> <td>211</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb6c1;width:4em;" /><td>lightpink</td><td>lightpink</td><td>##ffb6c1</td><td>255</td> <td>182</td> <td>193</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb6c1;width:4em;" /><td>light pink</td><td>lightpink</td><td>##ffb6c1</td><td>255</td> <td>182</td> <td>193</td>
</tr> <tr><td style="border:1px solid #666; background:#ffaeb9;width:4em;" /><td>lightpink1</td><td>lightpink1</td><td>##ffaeb9</td><td>255</td> <td>174</td> <td>185</td>
</tr> <tr><td style="border:1px solid #666; background:#eea2ad;width:4em;" /><td>lightpink2</td><td>lightpink2</td><td>##eea2ad</td><td>238</td> <td>162</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#cd8c95;width:4em;" /><td>lightpink3</td><td>lightpink3</td><td>##cd8c95</td><td>205</td> <td>140</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#8b5f65;width:4em;" /><td>lightpink4</td><td>lightpink4</td><td>##8b5f65</td><td>139</td> <td>95</td> <td>101</td>
</tr> <tr><td style="border:1px solid #666; background:#ffa07a;width:4em;" /><td>light salmon</td><td>lightsalmon</td><td>##ffa07a</td><td>255</td> <td>160</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ffa07a;width:4em;" /><td>lightsalmon</td><td>lightsalmon</td><td>##ffa07a</td><td>255</td> <td>160</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ffa07a;width:4em;" /><td>lightsalmon1</td><td>lightsalmon1</td><td>##ffa07a</td><td>255</td> <td>160</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#ee9572;width:4em;" /><td>lightsalmon2</td><td>lightsalmon2</td><td>##ee9572</td><td>238</td> <td>149</td> <td>114</td>
</tr> <tr><td style="border:1px solid #666; background:#cd8162;width:4em;" /><td>lightsalmon3</td><td>lightsalmon3</td><td>##cd8162</td><td>205</td> <td>129</td> <td>98</td>
</tr> <tr><td style="border:1px solid #666; background:#8b5742;width:4em;" /><td>lightsalmon4</td><td>lightsalmon4</td><td>##8b5742</td><td>139</td> <td>87</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#20b2aa;width:4em;" /><td>light sea green</td><td>lightseagreen</td><td>##20b2aa</td><td>32</td> <td>178</td> <td>170</td>
</tr> <tr><td style="border:1px solid #666; background:#20b2aa;width:4em;" /><td>lightseagreen</td><td>lightseagreen</td><td>##20b2aa</td><td>32</td> <td>178</td> <td>170</td>
</tr> <tr><td style="border:1px solid #666; background:#87cefa;width:4em;" /><td>light sky blue</td><td>lightskyblue</td><td>##87cefa</td><td>135</td> <td>206</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#87cefa;width:4em;" /><td>lightskyblue</td><td>lightskyblue</td><td>##87cefa</td><td>135</td> <td>206</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#b0e2ff;width:4em;" /><td>lightskyblue1</td><td>lightskyblue1</td><td>##b0e2ff</td><td>176</td> <td>226</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#a4d3ee;width:4em;" /><td>lightskyblue2</td><td>lightskyblue2</td><td>##a4d3ee</td><td>164</td> <td>211</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#8db6cd;width:4em;" /><td>lightskyblue3</td><td>lightskyblue3</td><td>##8db6cd</td><td>141</td> <td>182</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#607b8b;width:4em;" /><td>lightskyblue4</td><td>lightskyblue4</td><td>##607b8b</td><td>96</td> <td>123</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#8470ff;width:4em;" /><td>light slate blue</td><td>lightslateblue</td><td>##8470ff</td><td>132</td> <td>112</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#8470ff;width:4em;" /><td>lightslateblue</td><td>lightslateblue</td><td>##8470ff</td><td>132</td> <td>112</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#778899;width:4em;" /><td>light slate gray</td><td>lightslategray</td><td>##778899</td><td>119</td> <td>136</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#778899;width:4em;" /><td>lightslategray</td><td>lightslategray</td><td>##778899</td><td>119</td> <td>136</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#778899;width:4em;" /><td>light slate grey</td><td>lightslategrey</td><td>##778899</td><td>119</td> <td>136</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#778899;width:4em;" /><td>lightslategrey</td><td>lightslategrey</td><td>##778899</td><td>119</td> <td>136</td> <td>153</td>
</tr> <tr><td style="border:1px solid #666; background:#b0c4de;width:4em;" /><td>lightsteelblue</td><td>lightsteelblue</td><td>##b0c4de</td><td>176</td> <td>196</td> <td>222</td>
</tr> <tr><td style="border:1px solid #666; background:#b0c4de;width:4em;" /><td>light steel blue</td><td>lightsteelblue</td><td>##b0c4de</td><td>176</td> <td>196</td> <td>222</td>
</tr> <tr><td style="border:1px solid #666; background:#cae1ff;width:4em;" /><td>lightsteelblue1</td><td>lightsteelblue1</td><td>##cae1ff</td><td>202</td> <td>225</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#bcd2ee;width:4em;" /><td>lightsteelblue2</td><td>lightsteelblue2</td><td>##bcd2ee</td><td>188</td> <td>210</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#a2b5cd;width:4em;" /><td>lightsteelblue3</td><td>lightsteelblue3</td><td>##a2b5cd</td><td>162</td> <td>181</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#6e7b8b;width:4em;" /><td>lightsteelblue4</td><td>lightsteelblue4</td><td>##6e7b8b</td><td>110</td> <td>123</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#ffffe0;width:4em;" /><td>lightyellow</td><td>lightyellow</td><td>##ffffe0</td><td>255</td> <td>255</td> <td>224</td>
</tr> <tr><td style="border:1px solid #666; background:#ffffe0;width:4em;" /><td>light yellow</td><td>lightyellow</td><td>##ffffe0</td><td>255</td> <td>255</td> <td>224</td>
</tr> <tr><td style="border:1px solid #666; background:#ffffe0;width:4em;" /><td>lightyellow1</td><td>lightyellow1</td><td>##ffffe0</td><td>255</td> <td>255</td> <td>224</td>
</tr> <tr><td style="border:1px solid #666; background:#eeeed1;width:4em;" /><td>lightyellow2</td><td>lightyellow2</td><td>##eeeed1</td><td>238</td> <td>238</td> <td>209</td>
</tr> <tr><td style="border:1px solid #666; background:#cdcdb4;width:4em;" /><td>lightyellow3</td><td>lightyellow3</td><td>##cdcdb4</td><td>205</td> <td>205</td> <td>180</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8b7a;width:4em;" /><td>lightyellow4</td><td>lightyellow4</td><td>##8b8b7a</td><td>139</td> <td>139</td> <td>122</td>
</tr> <tr><td style="border:1px solid #666; background:#32cd32;width:4em;" /><td>lime green</td><td>limegreen</td><td>##32cd32</td><td>50</td> <td>205</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#32cd32;width:4em;" /><td>limegreen</td><td>limegreen</td><td>##32cd32</td><td>50</td> <td>205</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#faf0e6;width:4em;" /><td>linen</td><td>linen</td><td>##faf0e6</td><td>250</td> <td>240</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#ff00ff;width:4em;" /><td>magenta</td><td>magenta</td><td>##ff00ff</td><td>255</td> <td>0</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#ff00ff;width:4em;" /><td>magenta1</td><td>magenta1</td><td>##ff00ff</td><td>255</td> <td>0</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#ee00ee;width:4em;" /><td>magenta2</td><td>magenta2</td><td>##ee00ee</td><td>238</td> <td>0</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#cd00cd;width:4em;" /><td>magenta3</td><td>magenta3</td><td>##cd00cd</td><td>205</td> <td>0</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#8b008b;width:4em;" /><td>magenta4</td><td>magenta4</td><td>##8b008b</td><td>139</td> <td>0</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#b03060;width:4em;" /><td>maroon</td><td>maroon</td><td>##b03060</td><td>176</td> <td>48</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#ff34b3;width:4em;" /><td>maroon1</td><td>maroon1</td><td>##ff34b3</td><td>255</td> <td>52</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#ee30a7;width:4em;" /><td>maroon2</td><td>maroon2</td><td>##ee30a7</td><td>238</td> <td>48</td> <td>167</td>
</tr> <tr><td style="border:1px solid #666; background:#cd2990;width:4em;" /><td>maroon3</td><td>maroon3</td><td>##cd2990</td><td>205</td> <td>41</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#8b1c62;width:4em;" /><td>maroon4</td><td>maroon4</td><td>##8b1c62</td><td>139</td> <td>28</td> <td>98</td>
</tr> <tr><td style="border:1px solid #666; background:#66cdaa;width:4em;" /><td>mediumaquamarine</td><td>mediumaquamarine</td><td>##66cdaa</td><td>102</td> <td>205</td> <td>170</td>
</tr> <tr><td style="border:1px solid #666; background:#66cdaa;width:4em;" /><td>medium aquamarine</td><td>mediumaquamarine</td><td>##66cdaa</td><td>102</td> <td>205</td> <td>170</td>
</tr> <tr><td style="border:1px solid #666; background:#0000cd;width:4em;" /><td>mediumblue</td><td>mediumblue</td><td>##0000cd</td><td>0</td> <td>0</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#0000cd;width:4em;" /><td>medium blue</td><td>mediumblue</td><td>##0000cd</td><td>0</td> <td>0</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#ba55d3;width:4em;" /><td>medium orchid</td><td>mediumorchid</td><td>##ba55d3</td><td>186</td> <td>85</td> <td>211</td>
</tr> <tr><td style="border:1px solid #666; background:#ba55d3;width:4em;" /><td>mediumorchid</td><td>mediumorchid</td><td>##ba55d3</td><td>186</td> <td>85</td> <td>211</td>
</tr> <tr><td style="border:1px solid #666; background:#e066ff;width:4em;" /><td>mediumorchid1</td><td>mediumorchid1</td><td>##e066ff</td><td>224</td> <td>102</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#d15fee;width:4em;" /><td>mediumorchid2</td><td>mediumorchid2</td><td>##d15fee</td><td>209</td> <td>95</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#b452cd;width:4em;" /><td>mediumorchid3</td><td>mediumorchid3</td><td>##b452cd</td><td>180</td> <td>82</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#7a378b;width:4em;" /><td>mediumorchid4</td><td>mediumorchid4</td><td>##7a378b</td><td>122</td> <td>55</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#9370db;width:4em;" /><td>medium purple</td><td>mediumpurple</td><td>##9370db</td><td>147</td> <td>112</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#9370db;width:4em;" /><td>mediumpurple</td><td>mediumpurple</td><td>##9370db</td><td>147</td> <td>112</td> <td>219</td>
</tr> <tr><td style="border:1px solid #666; background:#ab82ff;width:4em;" /><td>mediumpurple1</td><td>mediumpurple1</td><td>##ab82ff</td><td>171</td> <td>130</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#9f79ee;width:4em;" /><td>mediumpurple2</td><td>mediumpurple2</td><td>##9f79ee</td><td>159</td> <td>121</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#8968cd;width:4em;" /><td>mediumpurple3</td><td>mediumpurple3</td><td>##8968cd</td><td>137</td> <td>104</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#5d478b;width:4em;" /><td>mediumpurple4</td><td>mediumpurple4</td><td>##5d478b</td><td>93</td> <td>71</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#3cb371;width:4em;" /><td>medium sea green</td><td>mediumseagreen</td><td>##3cb371</td><td>60</td> <td>179</td> <td>113</td>
</tr> <tr><td style="border:1px solid #666; background:#3cb371;width:4em;" /><td>mediumseagreen</td><td>mediumseagreen</td><td>##3cb371</td><td>60</td> <td>179</td> <td>113</td>
</tr> <tr><td style="border:1px solid #666; background:#7b68ee;width:4em;" /><td>mediumslateblue</td><td>mediumslateblue</td><td>##7b68ee</td><td>123</td> <td>104</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#7b68ee;width:4em;" /><td>medium slate blue</td><td>mediumslateblue</td><td>##7b68ee</td><td>123</td> <td>104</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#00fa9a;width:4em;" /><td>mediumspringgreen</td><td>mediumspringgreen</td><td>##00fa9a</td><td>0</td> <td>250</td> <td>154</td>
</tr> <tr><td style="border:1px solid #666; background:#00fa9a;width:4em;" /><td>medium spring green</td><td>mediumspringgreen</td><td>##00fa9a</td><td>0</td> <td>250</td> <td>154</td>
</tr> <tr><td style="border:1px solid #666; background:#48d1cc;width:4em;" /><td>medium turquoise</td><td>mediumturquoise</td><td>##48d1cc</td><td>72</td> <td>209</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#48d1cc;width:4em;" /><td>mediumturquoise</td><td>mediumturquoise</td><td>##48d1cc</td><td>72</td> <td>209</td> <td>204</td>
</tr> <tr><td style="border:1px solid #666; background:#c71585;width:4em;" /><td>mediumvioletred</td><td>mediumvioletred</td><td>##c71585</td><td>199</td> <td>21</td> <td>133</td>
</tr> <tr><td style="border:1px solid #666; background:#c71585;width:4em;" /><td>medium violet red</td><td>mediumvioletred</td><td>##c71585</td><td>199</td> <td>21</td> <td>133</td>
</tr> <tr><td style="border:1px solid #666; background:#191970;width:4em;" /><td>midnight blue</td><td>midnightblue</td><td>##191970</td><td>25</td> <td>25</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#191970;width:4em;" /><td>midnightblue</td><td>midnightblue</td><td>##191970</td><td>25</td> <td>25</td> <td>112</td>
</tr> <tr><td style="border:1px solid #666; background:#f5fffa;width:4em;" /><td>mint cream</td><td>mintcream</td><td>##f5fffa</td><td>245</td> <td>255</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#f5fffa;width:4em;" /><td>mintcream</td><td>mintcream</td><td>##f5fffa</td><td>245</td> <td>255</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#ffe4e1;width:4em;" /><td>misty rose</td><td>mistyrose</td><td>##ffe4e1</td><td>255</td> <td>228</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#ffe4e1;width:4em;" /><td>mistyrose</td><td>mistyrose</td><td>##ffe4e1</td><td>255</td> <td>228</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#ffe4e1;width:4em;" /><td>mistyrose1</td><td>mistyrose1</td><td>##ffe4e1</td><td>255</td> <td>228</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#eed5d2;width:4em;" /><td>mistyrose2</td><td>mistyrose2</td><td>##eed5d2</td><td>238</td> <td>213</td> <td>210</td>
</tr> <tr><td style="border:1px solid #666; background:#cdb7b5;width:4em;" /><td>mistyrose3</td><td>mistyrose3</td><td>##cdb7b5</td><td>205</td> <td>183</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#8b7d7b;width:4em;" /><td>mistyrose4</td><td>mistyrose4</td><td>##8b7d7b</td><td>139</td> <td>125</td> <td>123</td>
</tr> <tr><td style="border:1px solid #666; background:#ffe4b5;width:4em;" /><td>moccasin</td><td>moccasin</td><td>##ffe4b5</td><td>255</td> <td>228</td> <td>181</td>
</tr> <tr><td style="border:1px solid #666; background:#ffdead;width:4em;" /><td>navajowhite</td><td>navajowhite</td><td>##ffdead</td><td>255</td> <td>222</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#ffdead;width:4em;" /><td>navajo white</td><td>navajowhite</td><td>##ffdead</td><td>255</td> <td>222</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#ffdead;width:4em;" /><td>navajowhite1</td><td>navajowhite1</td><td>##ffdead</td><td>255</td> <td>222</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#eecfa1;width:4em;" /><td>navajowhite2</td><td>navajowhite2</td><td>##eecfa1</td><td>238</td> <td>207</td> <td>161</td>
</tr> <tr><td style="border:1px solid #666; background:#cdb38b;width:4em;" /><td>navajowhite3</td><td>navajowhite3</td><td>##cdb38b</td><td>205</td> <td>179</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#8b795e;width:4em;" /><td>navajowhite4</td><td>navajowhite4</td><td>##8b795e</td><td>139</td> <td>121</td> <td>94</td>
</tr> <tr><td style="border:1px solid #666; background:#000080;width:4em;" /><td>navy</td><td>navy</td><td>##000080</td><td>0</td> <td>0</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#000080;width:4em;" /><td>navyblue</td><td>navyblue</td><td>##000080</td><td>0</td> <td>0</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#000080;width:4em;" /><td>navy blue</td><td>navyblue</td><td>##000080</td><td>0</td> <td>0</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#fdf5e6;width:4em;" /><td>oldlace</td><td>oldlace</td><td>##fdf5e6</td><td>253</td> <td>245</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#fdf5e6;width:4em;" /><td>old lace</td><td>oldlace</td><td>##fdf5e6</td><td>253</td> <td>245</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#6b8e23;width:4em;" /><td>olivedrab</td><td>olivedrab</td><td>##6b8e23</td><td>107</td> <td>142</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#6b8e23;width:4em;" /><td>olive drab</td><td>olivedrab</td><td>##6b8e23</td><td>107</td> <td>142</td> <td>35</td>
</tr> <tr><td style="border:1px solid #666; background:#c0ff3e;width:4em;" /><td>olivedrab1</td><td>olivedrab1</td><td>##c0ff3e</td><td>192</td> <td>255</td> <td>62</td>
</tr> <tr><td style="border:1px solid #666; background:#b3ee3a;width:4em;" /><td>olivedrab2</td><td>olivedrab2</td><td>##b3ee3a</td><td>179</td> <td>238</td> <td>58</td>
</tr> <tr><td style="border:1px solid #666; background:#9acd32;width:4em;" /><td>olivedrab3</td><td>olivedrab3</td><td>##9acd32</td><td>154</td> <td>205</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#698b22;width:4em;" /><td>olivedrab4</td><td>olivedrab4</td><td>##698b22</td><td>105</td> <td>139</td> <td>34</td>
</tr> <tr><td style="border:1px solid #666; background:#ffa500;width:4em;" /><td>orange</td><td>orange</td><td>##ffa500</td><td>255</td> <td>165</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ffa500;width:4em;" /><td>orange1</td><td>orange1</td><td>##ffa500</td><td>255</td> <td>165</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ee9a00;width:4em;" /><td>orange2</td><td>orange2</td><td>##ee9a00</td><td>238</td> <td>154</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#cd8500;width:4em;" /><td>orange3</td><td>orange3</td><td>##cd8500</td><td>205</td> <td>133</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8b5a00;width:4em;" /><td>orange4</td><td>orange4</td><td>##8b5a00</td><td>139</td> <td>90</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ff4500;width:4em;" /><td>orange red</td><td>orangered</td><td>##ff4500</td><td>255</td> <td>69</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ff4500;width:4em;" /><td>orangered</td><td>orangered</td><td>##ff4500</td><td>255</td> <td>69</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ff4500;width:4em;" /><td>orangered1</td><td>orangered1</td><td>##ff4500</td><td>255</td> <td>69</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ee4000;width:4em;" /><td>orangered2</td><td>orangered2</td><td>##ee4000</td><td>238</td> <td>64</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#cd3700;width:4em;" /><td>orangered3</td><td>orangered3</td><td>##cd3700</td><td>205</td> <td>55</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8b2500;width:4em;" /><td>orangered4</td><td>orangered4</td><td>##8b2500</td><td>139</td> <td>37</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#da70d6;width:4em;" /><td>orchid</td><td>orchid</td><td>##da70d6</td><td>218</td> <td>112</td> <td>214</td>
</tr> <tr><td style="border:1px solid #666; background:#ff83fa;width:4em;" /><td>orchid1</td><td>orchid1</td><td>##ff83fa</td><td>255</td> <td>131</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#ee7ae9;width:4em;" /><td>orchid2</td><td>orchid2</td><td>##ee7ae9</td><td>238</td> <td>122</td> <td>233</td>
</tr> <tr><td style="border:1px solid #666; background:#cd69c9;width:4em;" /><td>orchid3</td><td>orchid3</td><td>##cd69c9</td><td>205</td> <td>105</td> <td>201</td>
</tr> <tr><td style="border:1px solid #666; background:#8b4789;width:4em;" /><td>orchid4</td><td>orchid4</td><td>##8b4789</td><td>139</td> <td>71</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#eee8aa;width:4em;" /><td>palegoldenrod</td><td>palegoldenrod</td><td>##eee8aa</td><td>238</td> <td>232</td> <td>170</td>
</tr> <tr><td style="border:1px solid #666; background:#eee8aa;width:4em;" /><td>pale goldenrod</td><td>palegoldenrod</td><td>##eee8aa</td><td>238</td> <td>232</td> <td>170</td>
</tr> <tr><td style="border:1px solid #666; background:#98fb98;width:4em;" /><td>palegreen</td><td>palegreen</td><td>##98fb98</td><td>152</td> <td>251</td> <td>152</td>
</tr> <tr><td style="border:1px solid #666; background:#98fb98;width:4em;" /><td>pale green</td><td>palegreen</td><td>##98fb98</td><td>152</td> <td>251</td> <td>152</td>
</tr> <tr><td style="border:1px solid #666; background:#9aff9a;width:4em;" /><td>palegreen1</td><td>palegreen1</td><td>##9aff9a</td><td>154</td> <td>255</td> <td>154</td>
</tr> <tr><td style="border:1px solid #666; background:#90ee90;width:4em;" /><td>palegreen2</td><td>palegreen2</td><td>##90ee90</td><td>144</td> <td>238</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#7ccd7c;width:4em;" /><td>palegreen3</td><td>palegreen3</td><td>##7ccd7c</td><td>124</td> <td>205</td> <td>124</td>
</tr> <tr><td style="border:1px solid #666; background:#548b54;width:4em;" /><td>palegreen4</td><td>palegreen4</td><td>##548b54</td><td>84</td> <td>139</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#afeeee;width:4em;" /><td>pale turquoise</td><td>paleturquoise</td><td>##afeeee</td><td>175</td> <td>238</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#afeeee;width:4em;" /><td>paleturquoise</td><td>paleturquoise</td><td>##afeeee</td><td>175</td> <td>238</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#bbffff;width:4em;" /><td>paleturquoise1</td><td>paleturquoise1</td><td>##bbffff</td><td>187</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#aeeeee;width:4em;" /><td>paleturquoise2</td><td>paleturquoise2</td><td>##aeeeee</td><td>174</td> <td>238</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#96cdcd;width:4em;" /><td>paleturquoise3</td><td>paleturquoise3</td><td>##96cdcd</td><td>150</td> <td>205</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#668b8b;width:4em;" /><td>paleturquoise4</td><td>paleturquoise4</td><td>##668b8b</td><td>102</td> <td>139</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#db7093;width:4em;" /><td>pale violet red</td><td>palevioletred</td><td>##db7093</td><td>219</td> <td>112</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#db7093;width:4em;" /><td>palevioletred</td><td>palevioletred</td><td>##db7093</td><td>219</td> <td>112</td> <td>147</td>
</tr> <tr><td style="border:1px solid #666; background:#ff82ab;width:4em;" /><td>palevioletred1</td><td>palevioletred1</td><td>##ff82ab</td><td>255</td> <td>130</td> <td>171</td>
</tr> <tr><td style="border:1px solid #666; background:#ee799f;width:4em;" /><td>palevioletred2</td><td>palevioletred2</td><td>##ee799f</td><td>238</td> <td>121</td> <td>159</td>
</tr> <tr><td style="border:1px solid #666; background:#cd6889;width:4em;" /><td>palevioletred3</td><td>palevioletred3</td><td>##cd6889</td><td>205</td> <td>104</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#8b475d;width:4em;" /><td>palevioletred4</td><td>palevioletred4</td><td>##8b475d</td><td>139</td> <td>71</td> <td>93</td>
</tr> <tr><td style="border:1px solid #666; background:#ffefd5;width:4em;" /><td>papayawhip</td><td>papayawhip</td><td>##ffefd5</td><td>255</td> <td>239</td> <td>213</td>
</tr> <tr><td style="border:1px solid #666; background:#ffefd5;width:4em;" /><td>papaya whip</td><td>papayawhip</td><td>##ffefd5</td><td>255</td> <td>239</td> <td>213</td>
</tr> <tr><td style="border:1px solid #666; background:#ffdab9;width:4em;" /><td>peachpuff</td><td>peachpuff</td><td>##ffdab9</td><td>255</td> <td>218</td> <td>185</td>
</tr> <tr><td style="border:1px solid #666; background:#ffdab9;width:4em;" /><td>peach puff</td><td>peachpuff</td><td>##ffdab9</td><td>255</td> <td>218</td> <td>185</td>
</tr> <tr><td style="border:1px solid #666; background:#ffdab9;width:4em;" /><td>peachpuff1</td><td>peachpuff1</td><td>##ffdab9</td><td>255</td> <td>218</td> <td>185</td>
</tr> <tr><td style="border:1px solid #666; background:#eecbad;width:4em;" /><td>peachpuff2</td><td>peachpuff2</td><td>##eecbad</td><td>238</td> <td>203</td> <td>173</td>
</tr> <tr><td style="border:1px solid #666; background:#cdaf95;width:4em;" /><td>peachpuff3</td><td>peachpuff3</td><td>##cdaf95</td><td>205</td> <td>175</td> <td>149</td>
</tr> <tr><td style="border:1px solid #666; background:#8b7765;width:4em;" /><td>peachpuff4</td><td>peachpuff4</td><td>##8b7765</td><td>139</td> <td>119</td> <td>101</td>
</tr> <tr><td style="border:1px solid #666; background:#cd853f;width:4em;" /><td>peru</td><td>peru</td><td>##cd853f</td><td>205</td> <td>133</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc0cb;width:4em;" /><td>pink</td><td>pink</td><td>##ffc0cb</td><td>255</td> <td>192</td> <td>203</td>
</tr> <tr><td style="border:1px solid #666; background:#ffb5c5;width:4em;" /><td>pink1</td><td>pink1</td><td>##ffb5c5</td><td>255</td> <td>181</td> <td>197</td>
</tr> <tr><td style="border:1px solid #666; background:#eea9b8;width:4em;" /><td>pink2</td><td>pink2</td><td>##eea9b8</td><td>238</td> <td>169</td> <td>184</td>
</tr> <tr><td style="border:1px solid #666; background:#cd919e;width:4em;" /><td>pink3</td><td>pink3</td><td>##cd919e</td><td>205</td> <td>145</td> <td>158</td>
</tr> <tr><td style="border:1px solid #666; background:#8b636c;width:4em;" /><td>pink4</td><td>pink4</td><td>##8b636c</td><td>139</td> <td>99</td> <td>108</td>
</tr> <tr><td style="border:1px solid #666; background:#dda0dd;width:4em;" /><td>plum</td><td>plum</td><td>##dda0dd</td><td>221</td> <td>160</td> <td>221</td>
</tr> <tr><td style="border:1px solid #666; background:#ffbbff;width:4em;" /><td>plum1</td><td>plum1</td><td>##ffbbff</td><td>255</td> <td>187</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#eeaeee;width:4em;" /><td>plum2</td><td>plum2</td><td>##eeaeee</td><td>238</td> <td>174</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#cd96cd;width:4em;" /><td>plum3</td><td>plum3</td><td>##cd96cd</td><td>205</td> <td>150</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#8b668b;width:4em;" /><td>plum4</td><td>plum4</td><td>##8b668b</td><td>139</td> <td>102</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#b0e0e6;width:4em;" /><td>powder blue</td><td>powderblue</td><td>##b0e0e6</td><td>176</td> <td>224</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#b0e0e6;width:4em;" /><td>powderblue</td><td>powderblue</td><td>##b0e0e6</td><td>176</td> <td>224</td> <td>230</td>
</tr> <tr><td style="border:1px solid #666; background:#a020f0;width:4em;" /><td>purple</td><td>purple</td><td>##a020f0</td><td>160</td> <td>32</td> <td>240</td>
</tr> <tr><td style="border:1px solid #666; background:#9b30ff;width:4em;" /><td>purple1</td><td>purple1</td><td>##9b30ff</td><td>155</td> <td>48</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#912cee;width:4em;" /><td>purple2</td><td>purple2</td><td>##912cee</td><td>145</td> <td>44</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#7d26cd;width:4em;" /><td>purple3</td><td>purple3</td><td>##7d26cd</td><td>125</td> <td>38</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#551a8b;width:4em;" /><td>purple4</td><td>purple4</td><td>##551a8b</td><td>85</td> <td>26</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#ff0000;width:4em;" /><td>red</td><td>red</td><td>##ff0000</td><td>255</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ff0000;width:4em;" /><td>red1</td><td>red1</td><td>##ff0000</td><td>255</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ee0000;width:4em;" /><td>red2</td><td>red2</td><td>##ee0000</td><td>238</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#cd0000;width:4em;" /><td>red3</td><td>red3</td><td>##cd0000</td><td>205</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8b0000;width:4em;" /><td>red4</td><td>red4</td><td>##8b0000</td><td>139</td> <td>0</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#bc8f8f;width:4em;" /><td>rosybrown</td><td>rosybrown</td><td>##bc8f8f</td><td>188</td> <td>143</td> <td>143</td>
</tr> <tr><td style="border:1px solid #666; background:#bc8f8f;width:4em;" /><td>rosy brown</td><td>rosybrown</td><td>##bc8f8f</td><td>188</td> <td>143</td> <td>143</td>
</tr> <tr><td style="border:1px solid #666; background:#ffc1c1;width:4em;" /><td>rosybrown1</td><td>rosybrown1</td><td>##ffc1c1</td><td>255</td> <td>193</td> <td>193</td>
</tr> <tr><td style="border:1px solid #666; background:#eeb4b4;width:4em;" /><td>rosybrown2</td><td>rosybrown2</td><td>##eeb4b4</td><td>238</td> <td>180</td> <td>180</td>
</tr> <tr><td style="border:1px solid #666; background:#cd9b9b;width:4em;" /><td>rosybrown3</td><td>rosybrown3</td><td>##cd9b9b</td><td>205</td> <td>155</td> <td>155</td>
</tr> <tr><td style="border:1px solid #666; background:#8b6969;width:4em;" /><td>rosybrown4</td><td>rosybrown4</td><td>##8b6969</td><td>139</td> <td>105</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#4169e1;width:4em;" /><td>royalblue</td><td>royalblue</td><td>##4169e1</td><td>65</td> <td>105</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#4169e1;width:4em;" /><td>royal blue</td><td>royalblue</td><td>##4169e1</td><td>65</td> <td>105</td> <td>225</td>
</tr> <tr><td style="border:1px solid #666; background:#4876ff;width:4em;" /><td>royalblue1</td><td>royalblue1</td><td>##4876ff</td><td>72</td> <td>118</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#436eee;width:4em;" /><td>royalblue2</td><td>royalblue2</td><td>##436eee</td><td>67</td> <td>110</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#3a5fcd;width:4em;" /><td>royalblue3</td><td>royalblue3</td><td>##3a5fcd</td><td>58</td> <td>95</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#27408b;width:4em;" /><td>royalblue4</td><td>royalblue4</td><td>##27408b</td><td>39</td> <td>64</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#8b4513;width:4em;" /><td>saddlebrown</td><td>saddlebrown</td><td>##8b4513</td><td>139</td> <td>69</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#8b4513;width:4em;" /><td>saddle brown</td><td>saddlebrown</td><td>##8b4513</td><td>139</td> <td>69</td> <td>19</td>
</tr> <tr><td style="border:1px solid #666; background:#fa8072;width:4em;" /><td>salmon</td><td>salmon</td><td>##fa8072</td><td>250</td> <td>128</td> <td>114</td>
</tr> <tr><td style="border:1px solid #666; background:#ff8c69;width:4em;" /><td>salmon1</td><td>salmon1</td><td>##ff8c69</td><td>255</td> <td>140</td> <td>105</td>
</tr> <tr><td style="border:1px solid #666; background:#ee8262;width:4em;" /><td>salmon2</td><td>salmon2</td><td>##ee8262</td><td>238</td> <td>130</td> <td>98</td>
</tr> <tr><td style="border:1px solid #666; background:#cd7054;width:4em;" /><td>salmon3</td><td>salmon3</td><td>##cd7054</td><td>205</td> <td>112</td> <td>84</td>
</tr> <tr><td style="border:1px solid #666; background:#8b4c39;width:4em;" /><td>salmon4</td><td>salmon4</td><td>##8b4c39</td><td>139</td> <td>76</td> <td>57</td>
</tr> <tr><td style="border:1px solid #666; background:#f4a460;width:4em;" /><td>sandybrown</td><td>sandybrown</td><td>##f4a460</td><td>244</td> <td>164</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#f4a460;width:4em;" /><td>sandy brown</td><td>sandybrown</td><td>##f4a460</td><td>244</td> <td>164</td> <td>96</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8b57;width:4em;" /><td>sea green</td><td>seagreen</td><td>##2e8b57</td><td>46</td> <td>139</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8b57;width:4em;" /><td>seagreen</td><td>seagreen</td><td>##2e8b57</td><td>46</td> <td>139</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#54ff9f;width:4em;" /><td>seagreen1</td><td>seagreen1</td><td>##54ff9f</td><td>84</td> <td>255</td> <td>159</td>
</tr> <tr><td style="border:1px solid #666; background:#4eee94;width:4em;" /><td>seagreen2</td><td>seagreen2</td><td>##4eee94</td><td>78</td> <td>238</td> <td>148</td>
</tr> <tr><td style="border:1px solid #666; background:#43cd80;width:4em;" /><td>seagreen3</td><td>seagreen3</td><td>##43cd80</td><td>67</td> <td>205</td> <td>128</td>
</tr> <tr><td style="border:1px solid #666; background:#2e8b57;width:4em;" /><td>seagreen4</td><td>seagreen4</td><td>##2e8b57</td><td>46</td> <td>139</td> <td>87</td>
</tr> <tr><td style="border:1px solid #666; background:#fff5ee;width:4em;" /><td>seashell</td><td>seashell</td><td>##fff5ee</td><td>255</td> <td>245</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#fff5ee;width:4em;" /><td>seashell1</td><td>seashell1</td><td>##fff5ee</td><td>255</td> <td>245</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#eee5de;width:4em;" /><td>seashell2</td><td>seashell2</td><td>##eee5de</td><td>238</td> <td>229</td> <td>222</td>
</tr> <tr><td style="border:1px solid #666; background:#cdc5bf;width:4em;" /><td>seashell3</td><td>seashell3</td><td>##cdc5bf</td><td>205</td> <td>197</td> <td>191</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8682;width:4em;" /><td>seashell4</td><td>seashell4</td><td>##8b8682</td><td>139</td> <td>134</td> <td>130</td>
</tr> <tr><td style="border:1px solid #666; background:#a0522d;width:4em;" /><td>sienna</td><td>sienna</td><td>##a0522d</td><td>160</td> <td>82</td> <td>45</td>
</tr> <tr><td style="border:1px solid #666; background:#ff8247;width:4em;" /><td>sienna1</td><td>sienna1</td><td>##ff8247</td><td>255</td> <td>130</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ee7942;width:4em;" /><td>sienna2</td><td>sienna2</td><td>##ee7942</td><td>238</td> <td>121</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#cd6839;width:4em;" /><td>sienna3</td><td>sienna3</td><td>##cd6839</td><td>205</td> <td>104</td> <td>57</td>
</tr> <tr><td style="border:1px solid #666; background:#8b4726;width:4em;" /><td>sienna4</td><td>sienna4</td><td>##8b4726</td><td>139</td> <td>71</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#87ceeb;width:4em;" /><td>sky blue</td><td>skyblue</td><td>##87ceeb</td><td>135</td> <td>206</td> <td>235</td>
</tr> <tr><td style="border:1px solid #666; background:#87ceeb;width:4em;" /><td>skyblue</td><td>skyblue</td><td>##87ceeb</td><td>135</td> <td>206</td> <td>235</td>
</tr> <tr><td style="border:1px solid #666; background:#87ceff;width:4em;" /><td>skyblue1</td><td>skyblue1</td><td>##87ceff</td><td>135</td> <td>206</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#7ec0ee;width:4em;" /><td>skyblue2</td><td>skyblue2</td><td>##7ec0ee</td><td>126</td> <td>192</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#6ca6cd;width:4em;" /><td>skyblue3</td><td>skyblue3</td><td>##6ca6cd</td><td>108</td> <td>166</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#4a708b;width:4em;" /><td>skyblue4</td><td>skyblue4</td><td>##4a708b</td><td>74</td> <td>112</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#6a5acd;width:4em;" /><td>slateblue</td><td>slateblue</td><td>##6a5acd</td><td>106</td> <td>90</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#6a5acd;width:4em;" /><td>slate blue</td><td>slateblue</td><td>##6a5acd</td><td>106</td> <td>90</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#836fff;width:4em;" /><td>slateblue1</td><td>slateblue1</td><td>##836fff</td><td>131</td> <td>111</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#7a67ee;width:4em;" /><td>slateblue2</td><td>slateblue2</td><td>##7a67ee</td><td>122</td> <td>103</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#6959cd;width:4em;" /><td>slateblue3</td><td>slateblue3</td><td>##6959cd</td><td>105</td> <td>89</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#473c8b;width:4em;" /><td>slateblue4</td><td>slateblue4</td><td>##473c8b</td><td>71</td> <td>60</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#708090;width:4em;" /><td>slategray</td><td>slategray</td><td>##708090</td><td>112</td> <td>128</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#708090;width:4em;" /><td>slate gray</td><td>slategray</td><td>##708090</td><td>112</td> <td>128</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#c6e2ff;width:4em;" /><td>slategray1</td><td>slategray1</td><td>##c6e2ff</td><td>198</td> <td>226</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#b9d3ee;width:4em;" /><td>slategray2</td><td>slategray2</td><td>##b9d3ee</td><td>185</td> <td>211</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#9fb6cd;width:4em;" /><td>slategray3</td><td>slategray3</td><td>##9fb6cd</td><td>159</td> <td>182</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#6c7b8b;width:4em;" /><td>slategray4</td><td>slategray4</td><td>##6c7b8b</td><td>108</td> <td>123</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#708090;width:4em;" /><td>slategrey</td><td>slategrey</td><td>##708090</td><td>112</td> <td>128</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#708090;width:4em;" /><td>slate grey</td><td>slategrey</td><td>##708090</td><td>112</td> <td>128</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#c6e2ff;width:4em;" /><td>slategrey1</td><td>slategrey1</td><td>##c6e2ff</td><td>198</td> <td>226</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#b9d3ee;width:4em;" /><td>slategrey2</td><td>slategrey2</td><td>##b9d3ee</td><td>185</td> <td>211</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#9fb6cd;width:4em;" /><td>slategrey3</td><td>slategrey3</td><td>##9fb6cd</td><td>159</td> <td>182</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#6c7b8b;width:4em;" /><td>slategrey4</td><td>slategrey4</td><td>##6c7b8b</td><td>108</td> <td>123</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#fffafa;width:4em;" /><td>snow</td><td>snow</td><td>##fffafa</td><td>255</td> <td>250</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#fffafa;width:4em;" /><td>snow1</td><td>snow1</td><td>##fffafa</td><td>255</td> <td>250</td> <td>250</td>
</tr> <tr><td style="border:1px solid #666; background:#eee9e9;width:4em;" /><td>snow2</td><td>snow2</td><td>##eee9e9</td><td>238</td> <td>233</td> <td>233</td>
</tr> <tr><td style="border:1px solid #666; background:#cdc9c9;width:4em;" /><td>snow3</td><td>snow3</td><td>##cdc9c9</td><td>205</td> <td>201</td> <td>201</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8989;width:4em;" /><td>snow4</td><td>snow4</td><td>##8b8989</td><td>139</td> <td>137</td> <td>137</td>
</tr> <tr><td style="border:1px solid #666; background:#00ff7f;width:4em;" /><td>springgreen</td><td>springgreen</td><td>##00ff7f</td><td>0</td> <td>255</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#00ff7f;width:4em;" /><td>spring green</td><td>springgreen</td><td>##00ff7f</td><td>0</td> <td>255</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#00ff7f;width:4em;" /><td>springgreen1</td><td>springgreen1</td><td>##00ff7f</td><td>0</td> <td>255</td> <td>127</td>
</tr> <tr><td style="border:1px solid #666; background:#00ee76;width:4em;" /><td>springgreen2</td><td>springgreen2</td><td>##00ee76</td><td>0</td> <td>238</td> <td>118</td>
</tr> <tr><td style="border:1px solid #666; background:#00cd66;width:4em;" /><td>springgreen3</td><td>springgreen3</td><td>##00cd66</td><td>0</td> <td>205</td> <td>102</td>
</tr> <tr><td style="border:1px solid #666; background:#008b45;width:4em;" /><td>springgreen4</td><td>springgreen4</td><td>##008b45</td><td>0</td> <td>139</td> <td>69</td>
</tr> <tr><td style="border:1px solid #666; background:#4682b4;width:4em;" /><td>steel blue</td><td>steelblue</td><td>##4682b4</td><td>70</td> <td>130</td> <td>180</td>
</tr> <tr><td style="border:1px solid #666; background:#4682b4;width:4em;" /><td>steelblue</td><td>steelblue</td><td>##4682b4</td><td>70</td> <td>130</td> <td>180</td>
</tr> <tr><td style="border:1px solid #666; background:#63b8ff;width:4em;" /><td>steelblue1</td><td>steelblue1</td><td>##63b8ff</td><td>99</td> <td>184</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#5cacee;width:4em;" /><td>steelblue2</td><td>steelblue2</td><td>##5cacee</td><td>92</td> <td>172</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#4f94cd;width:4em;" /><td>steelblue3</td><td>steelblue3</td><td>##4f94cd</td><td>79</td> <td>148</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#36648b;width:4em;" /><td>steelblue4</td><td>steelblue4</td><td>##36648b</td><td>54</td> <td>100</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#d2b48c;width:4em;" /><td>tan</td><td>tan</td><td>##d2b48c</td><td>210</td> <td>180</td> <td>140</td>
</tr> <tr><td style="border:1px solid #666; background:#ffa54f;width:4em;" /><td>tan1</td><td>tan1</td><td>##ffa54f</td><td>255</td> <td>165</td> <td>79</td>
</tr> <tr><td style="border:1px solid #666; background:#ee9a49;width:4em;" /><td>tan2</td><td>tan2</td><td>##ee9a49</td><td>238</td> <td>154</td> <td>73</td>
</tr> <tr><td style="border:1px solid #666; background:#cd853f;width:4em;" /><td>tan3</td><td>tan3</td><td>##cd853f</td><td>205</td> <td>133</td> <td>63</td>
</tr> <tr><td style="border:1px solid #666; background:#8b5a2b;width:4em;" /><td>tan4</td><td>tan4</td><td>##8b5a2b</td><td>139</td> <td>90</td> <td>43</td>
</tr> <tr><td style="border:1px solid #666; background:#d8bfd8;width:4em;" /><td>thistle</td><td>thistle</td><td>##d8bfd8</td><td>216</td> <td>191</td> <td>216</td>
</tr> <tr><td style="border:1px solid #666; background:#ffe1ff;width:4em;" /><td>thistle1</td><td>thistle1</td><td>##ffe1ff</td><td>255</td> <td>225</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#eed2ee;width:4em;" /><td>thistle2</td><td>thistle2</td><td>##eed2ee</td><td>238</td> <td>210</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#cdb5cd;width:4em;" /><td>thistle3</td><td>thistle3</td><td>##cdb5cd</td><td>205</td> <td>181</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#8b7b8b;width:4em;" /><td>thistle4</td><td>thistle4</td><td>##8b7b8b</td><td>139</td> <td>123</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#ff6347;width:4em;" /><td>tomato</td><td>tomato</td><td>##ff6347</td><td>255</td> <td>99</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ff6347;width:4em;" /><td>tomato1</td><td>tomato1</td><td>##ff6347</td><td>255</td> <td>99</td> <td>71</td>
</tr> <tr><td style="border:1px solid #666; background:#ee5c42;width:4em;" /><td>tomato2</td><td>tomato2</td><td>##ee5c42</td><td>238</td> <td>92</td> <td>66</td>
</tr> <tr><td style="border:1px solid #666; background:#cd4f39;width:4em;" /><td>tomato3</td><td>tomato3</td><td>##cd4f39</td><td>205</td> <td>79</td> <td>57</td>
</tr> <tr><td style="border:1px solid #666; background:#8b3626;width:4em;" /><td>tomato4</td><td>tomato4</td><td>##8b3626</td><td>139</td> <td>54</td> <td>38</td>
</tr> <tr><td style="border:1px solid #666; background:#40e0d0;width:4em;" /><td>turquoise</td><td>turquoise</td><td>##40e0d0</td><td>64</td> <td>224</td> <td>208</td>
</tr> <tr><td style="border:1px solid #666; background:#00f5ff;width:4em;" /><td>turquoise1</td><td>turquoise1</td><td>##00f5ff</td><td>0</td> <td>245</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#00e5ee;width:4em;" /><td>turquoise2</td><td>turquoise2</td><td>##00e5ee</td><td>0</td> <td>229</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#00c5cd;width:4em;" /><td>turquoise3</td><td>turquoise3</td><td>##00c5cd</td><td>0</td> <td>197</td> <td>205</td>
</tr> <tr><td style="border:1px solid #666; background:#00868b;width:4em;" /><td>turquoise4</td><td>turquoise4</td><td>##00868b</td><td>0</td> <td>134</td> <td>139</td>
</tr> <tr><td style="border:1px solid #666; background:#ee82ee;width:4em;" /><td>violet</td><td>violet</td><td>##ee82ee</td><td>238</td> <td>130</td> <td>238</td>
</tr> <tr><td style="border:1px solid #666; background:#d02090;width:4em;" /><td>violet red</td><td>violetred</td><td>##d02090</td><td>208</td> <td>32</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#d02090;width:4em;" /><td>violetred</td><td>violetred</td><td>##d02090</td><td>208</td> <td>32</td> <td>144</td>
</tr> <tr><td style="border:1px solid #666; background:#ff3e96;width:4em;" /><td>violetred1</td><td>violetred1</td><td>##ff3e96</td><td>255</td> <td>62</td> <td>150</td>
</tr> <tr><td style="border:1px solid #666; background:#ee3a8c;width:4em;" /><td>violetred2</td><td>violetred2</td><td>##ee3a8c</td><td>238</td> <td>58</td> <td>140</td>
</tr> <tr><td style="border:1px solid #666; background:#cd3278;width:4em;" /><td>violetred3</td><td>violetred3</td><td>##cd3278</td><td>205</td> <td>50</td> <td>120</td>
</tr> <tr><td style="border:1px solid #666; background:#8b2252;width:4em;" /><td>violetred4</td><td>violetred4</td><td>##8b2252</td><td>139</td> <td>34</td> <td>82</td>
</tr> <tr><td style="border:1px solid #666; background:#f5deb3;width:4em;" /><td>wheat</td><td>wheat</td><td>##f5deb3</td><td>245</td> <td>222</td> <td>179</td>
</tr> <tr><td style="border:1px solid #666; background:#ffe7ba;width:4em;" /><td>wheat1</td><td>wheat1</td><td>##ffe7ba</td><td>255</td> <td>231</td> <td>186</td>
</tr> <tr><td style="border:1px solid #666; background:#eed8ae;width:4em;" /><td>wheat2</td><td>wheat2</td><td>##eed8ae</td><td>238</td> <td>216</td> <td>174</td>
</tr> <tr><td style="border:1px solid #666; background:#cdba96;width:4em;" /><td>wheat3</td><td>wheat3</td><td>##cdba96</td><td>205</td> <td>186</td> <td>150</td>
</tr> <tr><td style="border:1px solid #666; background:#8b7e66;width:4em;" /><td>wheat4</td><td>wheat4</td><td>##8b7e66</td><td>139</td> <td>126</td> <td>102</td>
</tr> <tr><td style="border:1px solid #666; background:#ffffff;width:4em;" /><td>white</td><td>white</td><td>##ffffff</td><td>255</td> <td>255</td> <td>255</td>
</tr> <tr><td style="border:1px solid #666; background:#f5f5f5;width:4em;" /><td>white smoke</td><td>whitesmoke</td><td>##f5f5f5</td><td>245</td> <td>245</td> <td>245</td>
</tr> <tr><td style="border:1px solid #666; background:#f5f5f5;width:4em;" /><td>whitesmoke</td><td>whitesmoke</td><td>##f5f5f5</td><td>245</td> <td>245</td> <td>245</td>
</tr> <tr><td style="border:1px solid #666; background:#ffff00;width:4em;" /><td>yellow</td><td>yellow</td><td>##ffff00</td><td>255</td> <td>255</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#ffff00;width:4em;" /><td>yellow1</td><td>yellow1</td><td>##ffff00</td><td>255</td> <td>255</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#eeee00;width:4em;" /><td>yellow2</td><td>yellow2</td><td>##eeee00</td><td>238</td> <td>238</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#cdcd00;width:4em;" /><td>yellow3</td><td>yellow3</td><td>##cdcd00</td><td>205</td> <td>205</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#8b8b00;width:4em;" /><td>yellow4</td><td>yellow4</td><td>##8b8b00</td><td>139</td> <td>139</td> <td>0</td>
</tr> <tr><td style="border:1px solid #666; background:#9acd32;width:4em;" /><td>yellow green</td><td>yellowgreen</td><td>##9acd32</td><td>154</td> <td>205</td> <td>50</td>
</tr> <tr><td style="border:1px solid #666; background:#9acd32;width:4em;" /><td>yellowgreen</td><td>yellowgreen</td><td>##9acd32</td><td>154</td> <td>205</td> <td>50</td>
</tr></table>

=end :html

=begin :man

=head1 COLORS

=over 4

=item aliceblue              aliceblue            #f0f8ff

=item alice blue             aliceblue            #f0f8ff

=item antiquewhite           antiquewhite         #faebd7

=item antique white          antiquewhite         #faebd7

=item antiquewhite1          antiquewhite1        #ffefdb

=item antiquewhite2          antiquewhite2        #eedfcc

=item antiquewhite3          antiquewhite3        #cdc0b0

=item antiquewhite4          antiquewhite4        #8b8378

=item aquamarine             aquamarine           #7fffd4

=item aquamarine1            aquamarine1          #7fffd4

=item aquamarine2            aquamarine2          #76eec6

=item aquamarine3            aquamarine3          #66cdaa

=item aquamarine4            aquamarine4          #458b74

=item azure                  azure                #f0ffff

=item azure1                 azure1               #f0ffff

=item azure2                 azure2               #e0eeee

=item azure3                 azure3               #c1cdcd

=item azure4                 azure4               #838b8b

=item beige                  beige                #f5f5dc

=item bisque                 bisque               #ffe4c4

=item bisque1                bisque1              #ffe4c4

=item bisque2                bisque2              #eed5b7

=item bisque3                bisque3              #cdb79e

=item bisque4                bisque4              #8b7d6b

=item black                  black                #000000

=item blanched almond        blanchedalmond       #ffebcd

=item blanchedalmond         blanchedalmond       #ffebcd

=item blue                   blue                 #0000ff

=item blue1                  blue1                #0000ff

=item blue2                  blue2                #0000ee

=item blue3                  blue3                #0000cd

=item blue4                  blue4                #00008b

=item blueviolet             blueviolet           #8a2be2

=item blue violet            blueviolet           #8a2be2

=item brown                  brown                #a52a2a

=item brown1                 brown1               #ff4040

=item brown2                 brown2               #ee3b3b

=item brown3                 brown3               #cd3333

=item brown4                 brown4               #8b2323

=item burlywood              burlywood            #deb887

=item burlywood1             burlywood1           #ffd39b

=item burlywood2             burlywood2           #eec591

=item burlywood3             burlywood3           #cdaa7d

=item burlywood4             burlywood4           #8b7355

=item cadetblue              cadetblue            #5f9ea0

=item cadet blue             cadetblue            #5f9ea0

=item cadetblue1             cadetblue1           #98f5ff

=item cadetblue2             cadetblue2           #8ee5ee

=item cadetblue3             cadetblue3           #7ac5cd

=item cadetblue4             cadetblue4           #53868b

=item chartreuse             chartreuse           #7fff00

=item chartreuse1            chartreuse1          #7fff00

=item chartreuse2            chartreuse2          #76ee00

=item chartreuse3            chartreuse3          #66cd00

=item chartreuse4            chartreuse4          #458b00

=item chocolate              chocolate            #d2691e

=item chocolate1             chocolate1           #ff7f24

=item chocolate2             chocolate2           #ee7621

=item chocolate3             chocolate3           #cd661d

=item chocolate4             chocolate4           #8b4513

=item coral                  coral                #ff7f50

=item coral1                 coral1               #ff7256

=item coral2                 coral2               #ee6a50

=item coral3                 coral3               #cd5b45

=item coral4                 coral4               #8b3e2f

=item cornflower blue        cornflowerblue       #6495ed

=item cornflowerblue         cornflowerblue       #6495ed

=item cornsilk               cornsilk             #fff8dc

=item cornsilk1              cornsilk1            #fff8dc

=item cornsilk2              cornsilk2            #eee8cd

=item cornsilk3              cornsilk3            #cdc8b1

=item cornsilk4              cornsilk4            #8b8878

=item cyan                   cyan                 #00ffff

=item cyan1                  cyan1                #00ffff

=item cyan2                  cyan2                #00eeee

=item cyan3                  cyan3                #00cdcd

=item cyan4                  cyan4                #008b8b

=item dark blue              darkblue             #00008b

=item darkblue               darkblue             #00008b

=item darkcyan               darkcyan             #008b8b

=item dark cyan              darkcyan             #008b8b

=item darkgoldenrod          darkgoldenrod        #b8860b

=item dark goldenrod         darkgoldenrod        #b8860b

=item darkgoldenrod1         darkgoldenrod1       #ffb90f

=item darkgoldenrod2         darkgoldenrod2       #eead0e

=item darkgoldenrod3         darkgoldenrod3       #cd950c

=item darkgoldenrod4         darkgoldenrod4       #8b6508

=item dark gray              darkgray             #a9a9a9

=item darkgray               darkgray             #a9a9a9

=item darkgreen              darkgreen            #006400

=item dark green             darkgreen            #006400

=item dark grey              darkgrey             #a9a9a9

=item darkgrey               darkgrey             #a9a9a9

=item dark khaki             darkkhaki            #bdb76b

=item darkkhaki              darkkhaki            #bdb76b

=item dark magenta           darkmagenta          #8b008b

=item darkmagenta            darkmagenta          #8b008b

=item dark olive green       darkolivegreen       #556b2f

=item darkolivegreen         darkolivegreen       #556b2f

=item darkolivegreen1        darkolivegreen1      #caff70

=item darkolivegreen2        darkolivegreen2      #bcee68

=item darkolivegreen3        darkolivegreen3      #a2cd5a

=item darkolivegreen4        darkolivegreen4      #6e8b3d

=item dark orange            darkorange           #ff8c00

=item darkorange             darkorange           #ff8c00

=item darkorange1            darkorange1          #ff7f00

=item darkorange2            darkorange2          #ee7600

=item darkorange3            darkorange3          #cd6600

=item darkorange4            darkorange4          #8b4500

=item darkorchid             darkorchid           #9932cc

=item dark orchid            darkorchid           #9932cc

=item darkorchid1            darkorchid1          #bf3eff

=item darkorchid2            darkorchid2          #b23aee

=item darkorchid3            darkorchid3          #9a32cd

=item darkorchid4            darkorchid4          #68228b

=item dark red               darkred              #8b0000

=item darkred                darkred              #8b0000

=item dark salmon            darksalmon           #e9967a

=item darksalmon             darksalmon           #e9967a

=item dark sea green         darkseagreen         #8fbc8f

=item darkseagreen           darkseagreen         #8fbc8f

=item darkseagreen1          darkseagreen1        #c1ffc1

=item darkseagreen2          darkseagreen2        #b4eeb4

=item darkseagreen3          darkseagreen3        #9bcd9b

=item darkseagreen4          darkseagreen4        #698b69

=item dark slate blue        darkslateblue        #483d8b

=item darkslateblue          darkslateblue        #483d8b

=item dark slate gray        darkslategray        #2f4f4f

=item darkslategray          darkslategray        #2f4f4f

=item darkslategray1         darkslategray1       #97ffff

=item darkslategray2         darkslategray2       #8deeee

=item darkslategray3         darkslategray3       #79cdcd

=item darkslategray4         darkslategray4       #528b8b

=item dark slate grey        darkslategrey        #2f4f4f

=item darkslategrey          darkslategrey        #2f4f4f

=item darkslategrey1         darkslategrey1       #97ffff

=item darkslategrey2         darkslategrey2       #8deeee

=item darkslategrey3         darkslategrey3       #79cdcd

=item darkslategrey4         darkslategrey4       #528b8b

=item dark turquoise         darkturquoise        #00ced1

=item darkturquoise          darkturquoise        #00ced1

=item darkviolet             darkviolet           #9400d3

=item dark violet            darkviolet           #9400d3

=item deep pink              deeppink             #ff1493

=item deeppink               deeppink             #ff1493

=item deeppink1              deeppink1            #ff1493

=item deeppink2              deeppink2            #ee1289

=item deeppink3              deeppink3            #cd1076

=item deeppink4              deeppink4            #8b0a50

=item deepskyblue            deepskyblue          #00bfff

=item deep sky blue          deepskyblue          #00bfff

=item deepskyblue1           deepskyblue1         #00bfff

=item deepskyblue2           deepskyblue2         #00b2ee

=item deepskyblue3           deepskyblue3         #009acd

=item deepskyblue4           deepskyblue4         #00688b

=item dimgray                dimgray              #696969

=item dim gray               dimgray              #696969

=item dim grey               dimgrey              #696969

=item dimgrey                dimgrey              #696969

=item dodger blue            dodgerblue           #1e90ff

=item dodgerblue             dodgerblue           #1e90ff

=item dodgerblue1            dodgerblue1          #1e90ff

=item dodgerblue2            dodgerblue2          #1c86ee

=item dodgerblue3            dodgerblue3          #1874cd

=item dodgerblue4            dodgerblue4          #104e8b

=item firebrick              firebrick            #b22222

=item firebrick1             firebrick1           #ff3030

=item firebrick2             firebrick2           #ee2c2c

=item firebrick3             firebrick3           #cd2626

=item firebrick4             firebrick4           #8b1a1a

=item floral white           floralwhite          #fffaf0

=item floralwhite            floralwhite          #fffaf0

=item forestgreen            forestgreen          #228b22

=item forest green           forestgreen          #228b22

=item gainsboro              gainsboro            #dcdcdc

=item ghostwhite             ghostwhite           #f8f8ff

=item ghost white            ghostwhite           #f8f8ff

=item gold                   gold                 #ffd700

=item gold1                  gold1                #ffd700

=item gold2                  gold2                #eec900

=item gold3                  gold3                #cdad00

=item gold4                  gold4                #8b7500

=item goldenrod              goldenrod            #daa520

=item goldenrod1             goldenrod1           #ffc125

=item goldenrod2             goldenrod2           #eeb422

=item goldenrod3             goldenrod3           #cd9b1d

=item goldenrod4             goldenrod4           #8b6914

=item gray                   gray                 #bebebe

=item gray0                  gray0                #000000

=item gray1                  gray1                #030303

=item gray10                 gray10               #1a1a1a

=item gray100                gray100              #ffffff

=item gray11                 gray11               #1c1c1c

=item gray12                 gray12               #1f1f1f

=item gray13                 gray13               #212121

=item gray14                 gray14               #242424

=item gray15                 gray15               #262626

=item gray16                 gray16               #292929

=item gray17                 gray17               #2b2b2b

=item gray18                 gray18               #2e2e2e

=item gray19                 gray19               #303030

=item gray2                  gray2                #050505

=item gray20                 gray20               #333333

=item gray21                 gray21               #363636

=item gray22                 gray22               #383838

=item gray23                 gray23               #3b3b3b

=item gray24                 gray24               #3d3d3d

=item gray25                 gray25               #404040

=item gray26                 gray26               #424242

=item gray27                 gray27               #454545

=item gray28                 gray28               #474747

=item gray29                 gray29               #4a4a4a

=item gray3                  gray3                #080808

=item gray30                 gray30               #4d4d4d

=item gray31                 gray31               #4f4f4f

=item gray32                 gray32               #525252

=item gray33                 gray33               #545454

=item gray34                 gray34               #575757

=item gray35                 gray35               #595959

=item gray36                 gray36               #5c5c5c

=item gray37                 gray37               #5e5e5e

=item gray38                 gray38               #616161

=item gray39                 gray39               #636363

=item gray4                  gray4                #0a0a0a

=item gray40                 gray40               #666666

=item gray41                 gray41               #696969

=item gray42                 gray42               #6b6b6b

=item gray43                 gray43               #6e6e6e

=item gray44                 gray44               #707070

=item gray45                 gray45               #737373

=item gray46                 gray46               #757575

=item gray47                 gray47               #787878

=item gray48                 gray48               #7a7a7a

=item gray49                 gray49               #7d7d7d

=item gray5                  gray5                #0d0d0d

=item gray50                 gray50               #7f7f7f

=item gray51                 gray51               #828282

=item gray52                 gray52               #858585

=item gray53                 gray53               #878787

=item gray54                 gray54               #8a8a8a

=item gray55                 gray55               #8c8c8c

=item gray56                 gray56               #8f8f8f

=item gray57                 gray57               #919191

=item gray58                 gray58               #949494

=item gray59                 gray59               #969696

=item gray6                  gray6                #0f0f0f

=item gray60                 gray60               #999999

=item gray61                 gray61               #9c9c9c

=item gray62                 gray62               #9e9e9e

=item gray63                 gray63               #a1a1a1

=item gray64                 gray64               #a3a3a3

=item gray65                 gray65               #a6a6a6

=item gray66                 gray66               #a8a8a8

=item gray67                 gray67               #ababab

=item gray68                 gray68               #adadad

=item gray69                 gray69               #b0b0b0

=item gray7                  gray7                #121212

=item gray70                 gray70               #b3b3b3

=item gray71                 gray71               #b5b5b5

=item gray72                 gray72               #b8b8b8

=item gray73                 gray73               #bababa

=item gray74                 gray74               #bdbdbd

=item gray75                 gray75               #bfbfbf

=item gray76                 gray76               #c2c2c2

=item gray77                 gray77               #c4c4c4

=item gray78                 gray78               #c7c7c7

=item gray79                 gray79               #c9c9c9

=item gray8                  gray8                #141414

=item gray80                 gray80               #cccccc

=item gray81                 gray81               #cfcfcf

=item gray82                 gray82               #d1d1d1

=item gray83                 gray83               #d4d4d4

=item gray84                 gray84               #d6d6d6

=item gray85                 gray85               #d9d9d9

=item gray86                 gray86               #dbdbdb

=item gray87                 gray87               #dedede

=item gray88                 gray88               #e0e0e0

=item gray89                 gray89               #e3e3e3

=item gray9                  gray9                #171717

=item gray90                 gray90               #e5e5e5

=item gray91                 gray91               #e8e8e8

=item gray92                 gray92               #ebebeb

=item gray93                 gray93               #ededed

=item gray94                 gray94               #f0f0f0

=item gray95                 gray95               #f2f2f2

=item gray96                 gray96               #f5f5f5

=item gray97                 gray97               #f7f7f7

=item gray98                 gray98               #fafafa

=item gray99                 gray99               #fcfcfc

=item green                  green                #00ff00

=item green1                 green1               #00ff00

=item green2                 green2               #00ee00

=item green3                 green3               #00cd00

=item green4                 green4               #008b00

=item green yellow           greenyellow          #adff2f

=item greenyellow            greenyellow          #adff2f

=item grey                   grey                 #bebebe

=item grey0                  grey0                #000000

=item grey1                  grey1                #030303

=item grey10                 grey10               #1a1a1a

=item grey100                grey100              #ffffff

=item grey11                 grey11               #1c1c1c

=item grey12                 grey12               #1f1f1f

=item grey13                 grey13               #212121

=item grey14                 grey14               #242424

=item grey15                 grey15               #262626

=item grey16                 grey16               #292929

=item grey17                 grey17               #2b2b2b

=item grey18                 grey18               #2e2e2e

=item grey19                 grey19               #303030

=item grey2                  grey2                #050505

=item grey20                 grey20               #333333

=item grey21                 grey21               #363636

=item grey22                 grey22               #383838

=item grey23                 grey23               #3b3b3b

=item grey24                 grey24               #3d3d3d

=item grey25                 grey25               #404040

=item grey26                 grey26               #424242

=item grey27                 grey27               #454545

=item grey28                 grey28               #474747

=item grey29                 grey29               #4a4a4a

=item grey3                  grey3                #080808

=item grey30                 grey30               #4d4d4d

=item grey31                 grey31               #4f4f4f

=item grey32                 grey32               #525252

=item grey33                 grey33               #545454

=item grey34                 grey34               #575757

=item grey35                 grey35               #595959

=item grey36                 grey36               #5c5c5c

=item grey37                 grey37               #5e5e5e

=item grey38                 grey38               #616161

=item grey39                 grey39               #636363

=item grey4                  grey4                #0a0a0a

=item grey40                 grey40               #666666

=item grey41                 grey41               #696969

=item grey42                 grey42               #6b6b6b

=item grey43                 grey43               #6e6e6e

=item grey44                 grey44               #707070

=item grey45                 grey45               #737373

=item grey46                 grey46               #757575

=item grey47                 grey47               #787878

=item grey48                 grey48               #7a7a7a

=item grey49                 grey49               #7d7d7d

=item grey5                  grey5                #0d0d0d

=item grey50                 grey50               #7f7f7f

=item grey51                 grey51               #828282

=item grey52                 grey52               #858585

=item grey53                 grey53               #878787

=item grey54                 grey54               #8a8a8a

=item grey55                 grey55               #8c8c8c

=item grey56                 grey56               #8f8f8f

=item grey57                 grey57               #919191

=item grey58                 grey58               #949494

=item grey59                 grey59               #969696

=item grey6                  grey6                #0f0f0f

=item grey60                 grey60               #999999

=item grey61                 grey61               #9c9c9c

=item grey62                 grey62               #9e9e9e

=item grey63                 grey63               #a1a1a1

=item grey64                 grey64               #a3a3a3

=item grey65                 grey65               #a6a6a6

=item grey66                 grey66               #a8a8a8

=item grey67                 grey67               #ababab

=item grey68                 grey68               #adadad

=item grey69                 grey69               #b0b0b0

=item grey7                  grey7                #121212

=item grey70                 grey70               #b3b3b3

=item grey71                 grey71               #b5b5b5

=item grey72                 grey72               #b8b8b8

=item grey73                 grey73               #bababa

=item grey74                 grey74               #bdbdbd

=item grey75                 grey75               #bfbfbf

=item grey76                 grey76               #c2c2c2

=item grey77                 grey77               #c4c4c4

=item grey78                 grey78               #c7c7c7

=item grey79                 grey79               #c9c9c9

=item grey8                  grey8                #141414

=item grey80                 grey80               #cccccc

=item grey81                 grey81               #cfcfcf

=item grey82                 grey82               #d1d1d1

=item grey83                 grey83               #d4d4d4

=item grey84                 grey84               #d6d6d6

=item grey85                 grey85               #d9d9d9

=item grey86                 grey86               #dbdbdb

=item grey87                 grey87               #dedede

=item grey88                 grey88               #e0e0e0

=item grey89                 grey89               #e3e3e3

=item grey9                  grey9                #171717

=item grey90                 grey90               #e5e5e5

=item grey91                 grey91               #e8e8e8

=item grey92                 grey92               #ebebeb

=item grey93                 grey93               #ededed

=item grey94                 grey94               #f0f0f0

=item grey95                 grey95               #f2f2f2

=item grey96                 grey96               #f5f5f5

=item grey97                 grey97               #f7f7f7

=item grey98                 grey98               #fafafa

=item grey99                 grey99               #fcfcfc

=item honeydew               honeydew             #f0fff0

=item honeydew1              honeydew1            #f0fff0

=item honeydew2              honeydew2            #e0eee0

=item honeydew3              honeydew3            #c1cdc1

=item honeydew4              honeydew4            #838b83

=item hot pink               hotpink              #ff69b4

=item hotpink                hotpink              #ff69b4

=item hotpink1               hotpink1             #ff6eb4

=item hotpink2               hotpink2             #ee6aa7

=item hotpink3               hotpink3             #cd6090

=item hotpink4               hotpink4             #8b3a62

=item indianred              indianred            #cd5c5c

=item indian red             indianred            #cd5c5c

=item indianred1             indianred1           #ff6a6a

=item indianred2             indianred2           #ee6363

=item indianred3             indianred3           #cd5555

=item indianred4             indianred4           #8b3a3a

=item ivory                  ivory                #fffff0

=item ivory1                 ivory1               #fffff0

=item ivory2                 ivory2               #eeeee0

=item ivory3                 ivory3               #cdcdc1

=item ivory4                 ivory4               #8b8b83

=item khaki                  khaki                #f0e68c

=item khaki1                 khaki1               #fff68f

=item khaki2                 khaki2               #eee685

=item khaki3                 khaki3               #cdc673

=item khaki4                 khaki4               #8b864e

=item lavender               lavender             #e6e6fa

=item lavenderblush          lavenderblush        #fff0f5

=item lavender blush         lavenderblush        #fff0f5

=item lavenderblush1         lavenderblush1       #fff0f5

=item lavenderblush2         lavenderblush2       #eee0e5

=item lavenderblush3         lavenderblush3       #cdc1c5

=item lavenderblush4         lavenderblush4       #8b8386

=item lawn green             lawngreen            #7cfc00

=item lawngreen              lawngreen            #7cfc00

=item lemonchiffon           lemonchiffon         #fffacd

=item lemon chiffon          lemonchiffon         #fffacd

=item lemonchiffon1          lemonchiffon1        #fffacd

=item lemonchiffon2          lemonchiffon2        #eee9bf

=item lemonchiffon3          lemonchiffon3        #cdc9a5

=item lemonchiffon4          lemonchiffon4        #8b8970

=item lightblue              lightblue            #add8e6

=item light blue             lightblue            #add8e6

=item lightblue1             lightblue1           #bfefff

=item lightblue2             lightblue2           #b2dfee

=item lightblue3             lightblue3           #9ac0cd

=item lightblue4             lightblue4           #68838b

=item lightcoral             lightcoral           #f08080

=item light coral            lightcoral           #f08080

=item lightcyan              lightcyan            #e0ffff

=item light cyan             lightcyan            #e0ffff

=item lightcyan1             lightcyan1           #e0ffff

=item lightcyan2             lightcyan2           #d1eeee

=item lightcyan3             lightcyan3           #b4cdcd

=item lightcyan4             lightcyan4           #7a8b8b

=item lightgoldenrod         lightgoldenrod       #eedd82

=item light goldenrod        lightgoldenrod       #eedd82

=item lightgoldenrod1        lightgoldenrod1      #ffec8b

=item lightgoldenrod2        lightgoldenrod2      #eedc82

=item lightgoldenrod3        lightgoldenrod3      #cdbe70

=item lightgoldenrod4        lightgoldenrod4      #8b814c

=item lightgoldenrodyellow   lightgoldenrodyellow #fafad2

=item light goldenrod yellow lightgoldenrodyellow #fafad2

=item lightgray              lightgray            #d3d3d3

=item light gray             lightgray            #d3d3d3

=item light green            lightgreen           #90ee90

=item lightgreen             lightgreen           #90ee90

=item lightgrey              lightgrey            #d3d3d3

=item light grey             lightgrey            #d3d3d3

=item lightpink              lightpink            #ffb6c1

=item light pink             lightpink            #ffb6c1

=item lightpink1             lightpink1           #ffaeb9

=item lightpink2             lightpink2           #eea2ad

=item lightpink3             lightpink3           #cd8c95

=item lightpink4             lightpink4           #8b5f65

=item light salmon           lightsalmon          #ffa07a

=item lightsalmon            lightsalmon          #ffa07a

=item lightsalmon1           lightsalmon1         #ffa07a

=item lightsalmon2           lightsalmon2         #ee9572

=item lightsalmon3           lightsalmon3         #cd8162

=item lightsalmon4           lightsalmon4         #8b5742

=item light sea green        lightseagreen        #20b2aa

=item lightseagreen          lightseagreen        #20b2aa

=item light sky blue         lightskyblue         #87cefa

=item lightskyblue           lightskyblue         #87cefa

=item lightskyblue1          lightskyblue1        #b0e2ff

=item lightskyblue2          lightskyblue2        #a4d3ee

=item lightskyblue3          lightskyblue3        #8db6cd

=item lightskyblue4          lightskyblue4        #607b8b

=item light slate blue       lightslateblue       #8470ff

=item lightslateblue         lightslateblue       #8470ff

=item light slate gray       lightslategray       #778899

=item lightslategray         lightslategray       #778899

=item light slate grey       lightslategrey       #778899

=item lightslategrey         lightslategrey       #778899

=item lightsteelblue         lightsteelblue       #b0c4de

=item light steel blue       lightsteelblue       #b0c4de

=item lightsteelblue1        lightsteelblue1      #cae1ff

=item lightsteelblue2        lightsteelblue2      #bcd2ee

=item lightsteelblue3        lightsteelblue3      #a2b5cd

=item lightsteelblue4        lightsteelblue4      #6e7b8b

=item lightyellow            lightyellow          #ffffe0

=item light yellow           lightyellow          #ffffe0

=item lightyellow1           lightyellow1         #ffffe0

=item lightyellow2           lightyellow2         #eeeed1

=item lightyellow3           lightyellow3         #cdcdb4

=item lightyellow4           lightyellow4         #8b8b7a

=item lime green             limegreen            #32cd32

=item limegreen              limegreen            #32cd32

=item linen                  linen                #faf0e6

=item magenta                magenta              #ff00ff

=item magenta1               magenta1             #ff00ff

=item magenta2               magenta2             #ee00ee

=item magenta3               magenta3             #cd00cd

=item magenta4               magenta4             #8b008b

=item maroon                 maroon               #b03060

=item maroon1                maroon1              #ff34b3

=item maroon2                maroon2              #ee30a7

=item maroon3                maroon3              #cd2990

=item maroon4                maroon4              #8b1c62

=item mediumaquamarine       mediumaquamarine     #66cdaa

=item medium aquamarine      mediumaquamarine     #66cdaa

=item mediumblue             mediumblue           #0000cd

=item medium blue            mediumblue           #0000cd

=item medium orchid          mediumorchid         #ba55d3

=item mediumorchid           mediumorchid         #ba55d3

=item mediumorchid1          mediumorchid1        #e066ff

=item mediumorchid2          mediumorchid2        #d15fee

=item mediumorchid3          mediumorchid3        #b452cd

=item mediumorchid4          mediumorchid4        #7a378b

=item medium purple          mediumpurple         #9370db

=item mediumpurple           mediumpurple         #9370db

=item mediumpurple1          mediumpurple1        #ab82ff

=item mediumpurple2          mediumpurple2        #9f79ee

=item mediumpurple3          mediumpurple3        #8968cd

=item mediumpurple4          mediumpurple4        #5d478b

=item medium sea green       mediumseagreen       #3cb371

=item mediumseagreen         mediumseagreen       #3cb371

=item mediumslateblue        mediumslateblue      #7b68ee

=item medium slate blue      mediumslateblue      #7b68ee

=item mediumspringgreen      mediumspringgreen    #00fa9a

=item medium spring green    mediumspringgreen    #00fa9a

=item medium turquoise       mediumturquoise      #48d1cc

=item mediumturquoise        mediumturquoise      #48d1cc

=item mediumvioletred        mediumvioletred      #c71585

=item medium violet red      mediumvioletred      #c71585

=item midnight blue          midnightblue         #191970

=item midnightblue           midnightblue         #191970

=item mint cream             mintcream            #f5fffa

=item mintcream              mintcream            #f5fffa

=item misty rose             mistyrose            #ffe4e1

=item mistyrose              mistyrose            #ffe4e1

=item mistyrose1             mistyrose1           #ffe4e1

=item mistyrose2             mistyrose2           #eed5d2

=item mistyrose3             mistyrose3           #cdb7b5

=item mistyrose4             mistyrose4           #8b7d7b

=item moccasin               moccasin             #ffe4b5

=item navajowhite            navajowhite          #ffdead

=item navajo white           navajowhite          #ffdead

=item navajowhite1           navajowhite1         #ffdead

=item navajowhite2           navajowhite2         #eecfa1

=item navajowhite3           navajowhite3         #cdb38b

=item navajowhite4           navajowhite4         #8b795e

=item navy                   navy                 #000080

=item navyblue               navyblue             #000080

=item navy blue              navyblue             #000080

=item oldlace                oldlace              #fdf5e6

=item old lace               oldlace              #fdf5e6

=item olivedrab              olivedrab            #6b8e23

=item olive drab             olivedrab            #6b8e23

=item olivedrab1             olivedrab1           #c0ff3e

=item olivedrab2             olivedrab2           #b3ee3a

=item olivedrab3             olivedrab3           #9acd32

=item olivedrab4             olivedrab4           #698b22

=item orange                 orange               #ffa500

=item orange1                orange1              #ffa500

=item orange2                orange2              #ee9a00

=item orange3                orange3              #cd8500

=item orange4                orange4              #8b5a00

=item orange red             orangered            #ff4500

=item orangered              orangered            #ff4500

=item orangered1             orangered1           #ff4500

=item orangered2             orangered2           #ee4000

=item orangered3             orangered3           #cd3700

=item orangered4             orangered4           #8b2500

=item orchid                 orchid               #da70d6

=item orchid1                orchid1              #ff83fa

=item orchid2                orchid2              #ee7ae9

=item orchid3                orchid3              #cd69c9

=item orchid4                orchid4              #8b4789

=item palegoldenrod          palegoldenrod        #eee8aa

=item pale goldenrod         palegoldenrod        #eee8aa

=item palegreen              palegreen            #98fb98

=item pale green             palegreen            #98fb98

=item palegreen1             palegreen1           #9aff9a

=item palegreen2             palegreen2           #90ee90

=item palegreen3             palegreen3           #7ccd7c

=item palegreen4             palegreen4           #548b54

=item pale turquoise         paleturquoise        #afeeee

=item paleturquoise          paleturquoise        #afeeee

=item paleturquoise1         paleturquoise1       #bbffff

=item paleturquoise2         paleturquoise2       #aeeeee

=item paleturquoise3         paleturquoise3       #96cdcd

=item paleturquoise4         paleturquoise4       #668b8b

=item pale violet red        palevioletred        #db7093

=item palevioletred          palevioletred        #db7093

=item palevioletred1         palevioletred1       #ff82ab

=item palevioletred2         palevioletred2       #ee799f

=item palevioletred3         palevioletred3       #cd6889

=item palevioletred4         palevioletred4       #8b475d

=item papayawhip             papayawhip           #ffefd5

=item papaya whip            papayawhip           #ffefd5

=item peachpuff              peachpuff            #ffdab9

=item peach puff             peachpuff            #ffdab9

=item peachpuff1             peachpuff1           #ffdab9

=item peachpuff2             peachpuff2           #eecbad

=item peachpuff3             peachpuff3           #cdaf95

=item peachpuff4             peachpuff4           #8b7765

=item peru                   peru                 #cd853f

=item pink                   pink                 #ffc0cb

=item pink1                  pink1                #ffb5c5

=item pink2                  pink2                #eea9b8

=item pink3                  pink3                #cd919e

=item pink4                  pink4                #8b636c

=item plum                   plum                 #dda0dd

=item plum1                  plum1                #ffbbff

=item plum2                  plum2                #eeaeee

=item plum3                  plum3                #cd96cd

=item plum4                  plum4                #8b668b

=item powder blue            powderblue           #b0e0e6

=item powderblue             powderblue           #b0e0e6

=item purple                 purple               #a020f0

=item purple1                purple1              #9b30ff

=item purple2                purple2              #912cee

=item purple3                purple3              #7d26cd

=item purple4                purple4              #551a8b

=item red                    red                  #ff0000

=item red1                   red1                 #ff0000

=item red2                   red2                 #ee0000

=item red3                   red3                 #cd0000

=item red4                   red4                 #8b0000

=item rosybrown              rosybrown            #bc8f8f

=item rosy brown             rosybrown            #bc8f8f

=item rosybrown1             rosybrown1           #ffc1c1

=item rosybrown2             rosybrown2           #eeb4b4

=item rosybrown3             rosybrown3           #cd9b9b

=item rosybrown4             rosybrown4           #8b6969

=item royalblue              royalblue            #4169e1

=item royal blue             royalblue            #4169e1

=item royalblue1             royalblue1           #4876ff

=item royalblue2             royalblue2           #436eee

=item royalblue3             royalblue3           #3a5fcd

=item royalblue4             royalblue4           #27408b

=item saddlebrown            saddlebrown          #8b4513

=item saddle brown           saddlebrown          #8b4513

=item salmon                 salmon               #fa8072

=item salmon1                salmon1              #ff8c69

=item salmon2                salmon2              #ee8262

=item salmon3                salmon3              #cd7054

=item salmon4                salmon4              #8b4c39

=item sandybrown             sandybrown           #f4a460

=item sandy brown            sandybrown           #f4a460

=item sea green              seagreen             #2e8b57

=item seagreen               seagreen             #2e8b57

=item seagreen1              seagreen1            #54ff9f

=item seagreen2              seagreen2            #4eee94

=item seagreen3              seagreen3            #43cd80

=item seagreen4              seagreen4            #2e8b57

=item seashell               seashell             #fff5ee

=item seashell1              seashell1            #fff5ee

=item seashell2              seashell2            #eee5de

=item seashell3              seashell3            #cdc5bf

=item seashell4              seashell4            #8b8682

=item sienna                 sienna               #a0522d

=item sienna1                sienna1              #ff8247

=item sienna2                sienna2              #ee7942

=item sienna3                sienna3              #cd6839

=item sienna4                sienna4              #8b4726

=item sky blue               skyblue              #87ceeb

=item skyblue                skyblue              #87ceeb

=item skyblue1               skyblue1             #87ceff

=item skyblue2               skyblue2             #7ec0ee

=item skyblue3               skyblue3             #6ca6cd

=item skyblue4               skyblue4             #4a708b

=item slateblue              slateblue            #6a5acd

=item slate blue             slateblue            #6a5acd

=item slateblue1             slateblue1           #836fff

=item slateblue2             slateblue2           #7a67ee

=item slateblue3             slateblue3           #6959cd

=item slateblue4             slateblue4           #473c8b

=item slategray              slategray            #708090

=item slate gray             slategray            #708090

=item slategray1             slategray1           #c6e2ff

=item slategray2             slategray2           #b9d3ee

=item slategray3             slategray3           #9fb6cd

=item slategray4             slategray4           #6c7b8b

=item slategrey              slategrey            #708090

=item slate grey             slategrey            #708090

=item slategrey1             slategrey1           #c6e2ff

=item slategrey2             slategrey2           #b9d3ee

=item slategrey3             slategrey3           #9fb6cd

=item slategrey4             slategrey4           #6c7b8b

=item snow                   snow                 #fffafa

=item snow1                  snow1                #fffafa

=item snow2                  snow2                #eee9e9

=item snow3                  snow3                #cdc9c9

=item snow4                  snow4                #8b8989

=item springgreen            springgreen          #00ff7f

=item spring green           springgreen          #00ff7f

=item springgreen1           springgreen1         #00ff7f

=item springgreen2           springgreen2         #00ee76

=item springgreen3           springgreen3         #00cd66

=item springgreen4           springgreen4         #008b45

=item steel blue             steelblue            #4682b4

=item steelblue              steelblue            #4682b4

=item steelblue1             steelblue1           #63b8ff

=item steelblue2             steelblue2           #5cacee

=item steelblue3             steelblue3           #4f94cd

=item steelblue4             steelblue4           #36648b

=item tan                    tan                  #d2b48c

=item tan1                   tan1                 #ffa54f

=item tan2                   tan2                 #ee9a49

=item tan3                   tan3                 #cd853f

=item tan4                   tan4                 #8b5a2b

=item thistle                thistle              #d8bfd8

=item thistle1               thistle1             #ffe1ff

=item thistle2               thistle2             #eed2ee

=item thistle3               thistle3             #cdb5cd

=item thistle4               thistle4             #8b7b8b

=item tomato                 tomato               #ff6347

=item tomato1                tomato1              #ff6347

=item tomato2                tomato2              #ee5c42

=item tomato3                tomato3              #cd4f39

=item tomato4                tomato4              #8b3626

=item turquoise              turquoise            #40e0d0

=item turquoise1             turquoise1           #00f5ff

=item turquoise2             turquoise2           #00e5ee

=item turquoise3             turquoise3           #00c5cd

=item turquoise4             turquoise4           #00868b

=item violet                 violet               #ee82ee

=item violet red             violetred            #d02090

=item violetred              violetred            #d02090

=item violetred1             violetred1           #ff3e96

=item violetred2             violetred2           #ee3a8c

=item violetred3             violetred3           #cd3278

=item violetred4             violetred4           #8b2252

=item wheat                  wheat                #f5deb3

=item wheat1                 wheat1               #ffe7ba

=item wheat2                 wheat2               #eed8ae

=item wheat3                 wheat3               #cdba96

=item wheat4                 wheat4               #8b7e66

=item white                  white                #ffffff

=item white smoke            whitesmoke           #f5f5f5

=item whitesmoke             whitesmoke           #f5f5f5

=item yellow                 yellow               #ffff00

=item yellow1                yellow1              #ffff00

=item yellow2                yellow2              #eeee00

=item yellow3                yellow3              #cdcd00

=item yellow4                yellow4              #8b8b00

=item yellow green           yellowgreen          #9acd32

=item yellowgreen            yellowgreen          #9acd32


=back

=end :man

=cut

sub _load_color_list() {
    return [
['x11:aliceblue','aliceblue','aliceblue',[240,248,255],'f0f8ff',15792383],
['x11:aliceblue','aliceblue','alice blue',[240,248,255],'f0f8ff',15792383],
['x11:antiquewhite','antiquewhite','antiquewhite',[250,235,215],'faebd7',16444375],
['x11:antiquewhite','antiquewhite','antique white',[250,235,215],'faebd7',16444375],
['x11:antiquewhite1','antiquewhite1','antiquewhite1',[255,239,219],'ffefdb',16773083],
['x11:antiquewhite2','antiquewhite2','antiquewhite2',[238,223,204],'eedfcc',15654860],
['x11:antiquewhite3','antiquewhite3','antiquewhite3',[205,192,176],'cdc0b0',13484208],
['x11:antiquewhite4','antiquewhite4','antiquewhite4',[139,131,120],'8b8378',9143160],
['x11:aquamarine','aquamarine','aquamarine',[127,255,212],'7fffd4',8388564],
['x11:aquamarine1','aquamarine1','aquamarine1',[127,255,212],'7fffd4',8388564],
['x11:aquamarine2','aquamarine2','aquamarine2',[118,238,198],'76eec6',7794374],
['x11:aquamarine3','aquamarine3','aquamarine3',[102,205,170],'66cdaa',6737322],
['x11:aquamarine4','aquamarine4','aquamarine4',[69,139,116],'458b74',4557684],
['x11:azure','azure','azure',[240,255,255],'f0ffff',15794175],
['x11:azure1','azure1','azure1',[240,255,255],'f0ffff',15794175],
['x11:azure2','azure2','azure2',[224,238,238],'e0eeee',14741230],
['x11:azure3','azure3','azure3',[193,205,205],'c1cdcd',12701133],
['x11:azure4','azure4','azure4',[131,139,139],'838b8b',8620939],
['x11:beige','beige','beige',[245,245,220],'f5f5dc',16119260],
['x11:bisque','bisque','bisque',[255,228,196],'ffe4c4',16770244],
['x11:bisque1','bisque1','bisque1',[255,228,196],'ffe4c4',16770244],
['x11:bisque2','bisque2','bisque2',[238,213,183],'eed5b7',15652279],
['x11:bisque3','bisque3','bisque3',[205,183,158],'cdb79e',13481886],
['x11:bisque4','bisque4','bisque4',[139,125,107],'8b7d6b',9141611],
['x11:black','black','black',[0,0,0],'000000',0],
['x11:blanchedalmond','blanchedalmond','blanched almond',[255,235,205],'ffebcd',16772045],
['x11:blanchedalmond','blanchedalmond','blanchedalmond',[255,235,205],'ffebcd',16772045],
['x11:blue','blue','blue',[0,0,255],'0000ff',255],
['x11:blue1','blue1','blue1',[0,0,255],'0000ff',255],
['x11:blue2','blue2','blue2',[0,0,238],'0000ee',238],
['x11:blue3','blue3','blue3',[0,0,205],'0000cd',205],
['x11:blue4','blue4','blue4',[0,0,139],'00008b',139],
['x11:blueviolet','blueviolet','blueviolet',[138,43,226],'8a2be2',9055202],
['x11:blueviolet','blueviolet','blue violet',[138,43,226],'8a2be2',9055202],
['x11:brown','brown','brown',[165,42,42],'a52a2a',10824234],
['x11:brown1','brown1','brown1',[255,64,64],'ff4040',16728128],
['x11:brown2','brown2','brown2',[238,59,59],'ee3b3b',15612731],
['x11:brown3','brown3','brown3',[205,51,51],'cd3333',13447987],
['x11:brown4','brown4','brown4',[139,35,35],'8b2323',9118499],
['x11:burlywood','burlywood','burlywood',[222,184,135],'deb887',14596231],
['x11:burlywood1','burlywood1','burlywood1',[255,211,155],'ffd39b',16765851],
['x11:burlywood2','burlywood2','burlywood2',[238,197,145],'eec591',15648145],
['x11:burlywood3','burlywood3','burlywood3',[205,170,125],'cdaa7d',13478525],
['x11:burlywood4','burlywood4','burlywood4',[139,115,85],'8b7355',9139029],
['x11:cadetblue','cadetblue','cadetblue',[95,158,160],'5f9ea0',6266528],
['x11:cadetblue','cadetblue','cadet blue',[95,158,160],'5f9ea0',6266528],
['x11:cadetblue1','cadetblue1','cadetblue1',[152,245,255],'98f5ff',10024447],
['x11:cadetblue2','cadetblue2','cadetblue2',[142,229,238],'8ee5ee',9364974],
['x11:cadetblue3','cadetblue3','cadetblue3',[122,197,205],'7ac5cd',8046029],
['x11:cadetblue4','cadetblue4','cadetblue4',[83,134,139],'53868b',5473931],
['x11:chartreuse','chartreuse','chartreuse',[127,255,0],'7fff00',8388352],
['x11:chartreuse1','chartreuse1','chartreuse1',[127,255,0],'7fff00',8388352],
['x11:chartreuse2','chartreuse2','chartreuse2',[118,238,0],'76ee00',7794176],
['x11:chartreuse3','chartreuse3','chartreuse3',[102,205,0],'66cd00',6737152],
['x11:chartreuse4','chartreuse4','chartreuse4',[69,139,0],'458b00',4557568],
['x11:chocolate','chocolate','chocolate',[210,105,30],'d2691e',13789470],
['x11:chocolate1','chocolate1','chocolate1',[255,127,36],'ff7f24',16744228],
['x11:chocolate2','chocolate2','chocolate2',[238,118,33],'ee7621',15627809],
['x11:chocolate3','chocolate3','chocolate3',[205,102,29],'cd661d',13461021],
['x11:chocolate4','chocolate4','chocolate4',[139,69,19],'8b4513',9127187],
['x11:coral','coral','coral',[255,127,80],'ff7f50',16744272],
['x11:coral1','coral1','coral1',[255,114,86],'ff7256',16740950],
['x11:coral2','coral2','coral2',[238,106,80],'ee6a50',15624784],
['x11:coral3','coral3','coral3',[205,91,69],'cd5b45',13458245],
['x11:coral4','coral4','coral4',[139,62,47],'8b3e2f',9125423],
['x11:cornflowerblue','cornflowerblue','cornflower blue',[100,149,237],'6495ed',6591981],
['x11:cornflowerblue','cornflowerblue','cornflowerblue',[100,149,237],'6495ed',6591981],
['x11:cornsilk','cornsilk','cornsilk',[255,248,220],'fff8dc',16775388],
['x11:cornsilk1','cornsilk1','cornsilk1',[255,248,220],'fff8dc',16775388],
['x11:cornsilk2','cornsilk2','cornsilk2',[238,232,205],'eee8cd',15657165],
['x11:cornsilk3','cornsilk3','cornsilk3',[205,200,177],'cdc8b1',13486257],
['x11:cornsilk4','cornsilk4','cornsilk4',[139,136,120],'8b8878',9144440],
['x11:cyan','cyan','cyan',[0,255,255],'00ffff',65535],
['x11:cyan1','cyan1','cyan1',[0,255,255],'00ffff',65535],
['x11:cyan2','cyan2','cyan2',[0,238,238],'00eeee',61166],
['x11:cyan3','cyan3','cyan3',[0,205,205],'00cdcd',52685],
['x11:cyan4','cyan4','cyan4',[0,139,139],'008b8b',35723],
['x11:darkblue','darkblue','dark blue',[0,0,139],'00008b',139],
['x11:darkblue','darkblue','darkblue',[0,0,139],'00008b',139],
['x11:darkcyan','darkcyan','darkcyan',[0,139,139],'008b8b',35723],
['x11:darkcyan','darkcyan','dark cyan',[0,139,139],'008b8b',35723],
['x11:darkgoldenrod','darkgoldenrod','darkgoldenrod',[184,134,11],'b8860b',12092939],
['x11:darkgoldenrod','darkgoldenrod','dark goldenrod',[184,134,11],'b8860b',12092939],
['x11:darkgoldenrod1','darkgoldenrod1','darkgoldenrod1',[255,185,15],'ffb90f',16759055],
['x11:darkgoldenrod2','darkgoldenrod2','darkgoldenrod2',[238,173,14],'eead0e',15641870],
['x11:darkgoldenrod3','darkgoldenrod3','darkgoldenrod3',[205,149,12],'cd950c',13473036],
['x11:darkgoldenrod4','darkgoldenrod4','darkgoldenrod4',[139,101,8],'8b6508',9135368],
['x11:darkgray','darkgray','dark gray',[169,169,169],'a9a9a9',11119017],
['x11:darkgray','darkgray','darkgray',[169,169,169],'a9a9a9',11119017],
['x11:darkgreen','darkgreen','darkgreen',[0,100,0],'006400',25600],
['x11:darkgreen','darkgreen','dark green',[0,100,0],'006400',25600],
['x11:darkgrey','darkgrey','dark grey',[169,169,169],'a9a9a9',11119017],
['x11:darkgrey','darkgrey','darkgrey',[169,169,169],'a9a9a9',11119017],
['x11:darkkhaki','darkkhaki','dark khaki',[189,183,107],'bdb76b',12433259],
['x11:darkkhaki','darkkhaki','darkkhaki',[189,183,107],'bdb76b',12433259],
['x11:darkmagenta','darkmagenta','dark magenta',[139,0,139],'8b008b',9109643],
['x11:darkmagenta','darkmagenta','darkmagenta',[139,0,139],'8b008b',9109643],
['x11:darkolivegreen','darkolivegreen','dark olive green',[85,107,47],'556b2f',5597999],
['x11:darkolivegreen','darkolivegreen','darkolivegreen',[85,107,47],'556b2f',5597999],
['x11:darkolivegreen1','darkolivegreen1','darkolivegreen1',[202,255,112],'caff70',13303664],
['x11:darkolivegreen2','darkolivegreen2','darkolivegreen2',[188,238,104],'bcee68',12381800],
['x11:darkolivegreen3','darkolivegreen3','darkolivegreen3',[162,205,90],'a2cd5a',10669402],
['x11:darkolivegreen4','darkolivegreen4','darkolivegreen4',[110,139,61],'6e8b3d',7244605],
['x11:darkorange','darkorange','dark orange',[255,140,0],'ff8c00',16747520],
['x11:darkorange','darkorange','darkorange',[255,140,0],'ff8c00',16747520],
['x11:darkorange1','darkorange1','darkorange1',[255,127,0],'ff7f00',16744192],
['x11:darkorange2','darkorange2','darkorange2',[238,118,0],'ee7600',15627776],
['x11:darkorange3','darkorange3','darkorange3',[205,102,0],'cd6600',13460992],
['x11:darkorange4','darkorange4','darkorange4',[139,69,0],'8b4500',9127168],
['x11:darkorchid','darkorchid','darkorchid',[153,50,204],'9932cc',10040012],
['x11:darkorchid','darkorchid','dark orchid',[153,50,204],'9932cc',10040012],
['x11:darkorchid1','darkorchid1','darkorchid1',[191,62,255],'bf3eff',12533503],
['x11:darkorchid2','darkorchid2','darkorchid2',[178,58,238],'b23aee',11680494],
['x11:darkorchid3','darkorchid3','darkorchid3',[154,50,205],'9a32cd',10105549],
['x11:darkorchid4','darkorchid4','darkorchid4',[104,34,139],'68228b',6824587],
['x11:darkred','darkred','dark red',[139,0,0],'8b0000',9109504],
['x11:darkred','darkred','darkred',[139,0,0],'8b0000',9109504],
['x11:darksalmon','darksalmon','dark salmon',[233,150,122],'e9967a',15308410],
['x11:darksalmon','darksalmon','darksalmon',[233,150,122],'e9967a',15308410],
['x11:darkseagreen','darkseagreen','dark sea green',[143,188,143],'8fbc8f',9419919],
['x11:darkseagreen','darkseagreen','darkseagreen',[143,188,143],'8fbc8f',9419919],
['x11:darkseagreen1','darkseagreen1','darkseagreen1',[193,255,193],'c1ffc1',12713921],
['x11:darkseagreen2','darkseagreen2','darkseagreen2',[180,238,180],'b4eeb4',11857588],
['x11:darkseagreen3','darkseagreen3','darkseagreen3',[155,205,155],'9bcd9b',10210715],
['x11:darkseagreen4','darkseagreen4','darkseagreen4',[105,139,105],'698b69',6916969],
['x11:darkslateblue','darkslateblue','dark slate blue',[72,61,139],'483d8b',4734347],
['x11:darkslateblue','darkslateblue','darkslateblue',[72,61,139],'483d8b',4734347],
['x11:darkslategray','darkslategray','dark slate gray',[47,79,79],'2f4f4f',3100495],
['x11:darkslategray','darkslategray','darkslategray',[47,79,79],'2f4f4f',3100495],
['x11:darkslategray1','darkslategray1','darkslategray1',[151,255,255],'97ffff',9961471],
['x11:darkslategray2','darkslategray2','darkslategray2',[141,238,238],'8deeee',9301742],
['x11:darkslategray3','darkslategray3','darkslategray3',[121,205,205],'79cdcd',7982541],
['x11:darkslategray4','darkslategray4','darkslategray4',[82,139,139],'528b8b',5409675],
['x11:darkslategrey','darkslategrey','dark slate grey',[47,79,79],'2f4f4f',3100495],
['x11:darkslategrey','darkslategrey','darkslategrey',[47,79,79],'2f4f4f',3100495],
['x11:darkslategrey1','darkslategrey1','darkslategrey1',[151,255,255],'97ffff',9961471],
['x11:darkslategrey2','darkslategrey2','darkslategrey2',[141,238,238],'8deeee',9301742],
['x11:darkslategrey3','darkslategrey3','darkslategrey3',[121,205,205],'79cdcd',7982541],
['x11:darkslategrey4','darkslategrey4','darkslategrey4',[82,139,139],'528b8b',5409675],
['x11:darkturquoise','darkturquoise','dark turquoise',[0,206,209],'00ced1',52945],
['x11:darkturquoise','darkturquoise','darkturquoise',[0,206,209],'00ced1',52945],
['x11:darkviolet','darkviolet','darkviolet',[148,0,211],'9400d3',9699539],
['x11:darkviolet','darkviolet','dark violet',[148,0,211],'9400d3',9699539],
['x11:deeppink','deeppink','deep pink',[255,20,147],'ff1493',16716947],
['x11:deeppink','deeppink','deeppink',[255,20,147],'ff1493',16716947],
['x11:deeppink1','deeppink1','deeppink1',[255,20,147],'ff1493',16716947],
['x11:deeppink2','deeppink2','deeppink2',[238,18,137],'ee1289',15602313],
['x11:deeppink3','deeppink3','deeppink3',[205,16,118],'cd1076',13439094],
['x11:deeppink4','deeppink4','deeppink4',[139,10,80],'8b0a50',9112144],
['x11:deepskyblue','deepskyblue','deepskyblue',[0,191,255],'00bfff',49151],
['x11:deepskyblue','deepskyblue','deep sky blue',[0,191,255],'00bfff',49151],
['x11:deepskyblue1','deepskyblue1','deepskyblue1',[0,191,255],'00bfff',49151],
['x11:deepskyblue2','deepskyblue2','deepskyblue2',[0,178,238],'00b2ee',45806],
['x11:deepskyblue3','deepskyblue3','deepskyblue3',[0,154,205],'009acd',39629],
['x11:deepskyblue4','deepskyblue4','deepskyblue4',[0,104,139],'00688b',26763],
['x11:dimgray','dimgray','dimgray',[105,105,105],'696969',6908265],
['x11:dimgray','dimgray','dim gray',[105,105,105],'696969',6908265],
['x11:dimgrey','dimgrey','dim grey',[105,105,105],'696969',6908265],
['x11:dimgrey','dimgrey','dimgrey',[105,105,105],'696969',6908265],
['x11:dodgerblue','dodgerblue','dodger blue',[30,144,255],'1e90ff',2003199],
['x11:dodgerblue','dodgerblue','dodgerblue',[30,144,255],'1e90ff',2003199],
['x11:dodgerblue1','dodgerblue1','dodgerblue1',[30,144,255],'1e90ff',2003199],
['x11:dodgerblue2','dodgerblue2','dodgerblue2',[28,134,238],'1c86ee',1869550],
['x11:dodgerblue3','dodgerblue3','dodgerblue3',[24,116,205],'1874cd',1602765],
['x11:dodgerblue4','dodgerblue4','dodgerblue4',[16,78,139],'104e8b',1068683],
['x11:firebrick','firebrick','firebrick',[178,34,34],'b22222',11674146],
['x11:firebrick1','firebrick1','firebrick1',[255,48,48],'ff3030',16724016],
['x11:firebrick2','firebrick2','firebrick2',[238,44,44],'ee2c2c',15608876],
['x11:firebrick3','firebrick3','firebrick3',[205,38,38],'cd2626',13444646],
['x11:firebrick4','firebrick4','firebrick4',[139,26,26],'8b1a1a',9116186],
['x11:floralwhite','floralwhite','floral white',[255,250,240],'fffaf0',16775920],
['x11:floralwhite','floralwhite','floralwhite',[255,250,240],'fffaf0',16775920],
['x11:forestgreen','forestgreen','forestgreen',[34,139,34],'228b22',2263842],
['x11:forestgreen','forestgreen','forest green',[34,139,34],'228b22',2263842],
['x11:gainsboro','gainsboro','gainsboro',[220,220,220],'dcdcdc',14474460],
['x11:ghostwhite','ghostwhite','ghostwhite',[248,248,255],'f8f8ff',16316671],
['x11:ghostwhite','ghostwhite','ghost white',[248,248,255],'f8f8ff',16316671],
['x11:gold','gold','gold',[255,215,0],'ffd700',16766720],
['x11:gold1','gold1','gold1',[255,215,0],'ffd700',16766720],
['x11:gold2','gold2','gold2',[238,201,0],'eec900',15649024],
['x11:gold3','gold3','gold3',[205,173,0],'cdad00',13479168],
['x11:gold4','gold4','gold4',[139,117,0],'8b7500',9139456],
['x11:goldenrod','goldenrod','goldenrod',[218,165,32],'daa520',14329120],
['x11:goldenrod1','goldenrod1','goldenrod1',[255,193,37],'ffc125',16761125],
['x11:goldenrod2','goldenrod2','goldenrod2',[238,180,34],'eeb422',15643682],
['x11:goldenrod3','goldenrod3','goldenrod3',[205,155,29],'cd9b1d',13474589],
['x11:goldenrod4','goldenrod4','goldenrod4',[139,105,20],'8b6914',9136404],
['x11:gray','gray','gray',[190,190,190],'bebebe',12500670],
['x11:gray0','gray0','gray0',[0,0,0],'000000',0],
['x11:gray1','gray1','gray1',[3,3,3],'030303',197379],
['x11:gray10','gray10','gray10',[26,26,26],'1a1a1a',1710618],
['x11:gray100','gray100','gray100',[255,255,255],'ffffff',16777215],
['x11:gray11','gray11','gray11',[28,28,28],'1c1c1c',1842204],
['x11:gray12','gray12','gray12',[31,31,31],'1f1f1f',2039583],
['x11:gray13','gray13','gray13',[33,33,33],'212121',2171169],
['x11:gray14','gray14','gray14',[36,36,36],'242424',2368548],
['x11:gray15','gray15','gray15',[38,38,38],'262626',2500134],
['x11:gray16','gray16','gray16',[41,41,41],'292929',2697513],
['x11:gray17','gray17','gray17',[43,43,43],'2b2b2b',2829099],
['x11:gray18','gray18','gray18',[46,46,46],'2e2e2e',3026478],
['x11:gray19','gray19','gray19',[48,48,48],'303030',3158064],
['x11:gray2','gray2','gray2',[5,5,5],'050505',328965],
['x11:gray20','gray20','gray20',[51,51,51],'333333',3355443],
['x11:gray21','gray21','gray21',[54,54,54],'363636',3552822],
['x11:gray22','gray22','gray22',[56,56,56],'383838',3684408],
['x11:gray23','gray23','gray23',[59,59,59],'3b3b3b',3881787],
['x11:gray24','gray24','gray24',[61,61,61],'3d3d3d',4013373],
['x11:gray25','gray25','gray25',[64,64,64],'404040',4210752],
['x11:gray26','gray26','gray26',[66,66,66],'424242',4342338],
['x11:gray27','gray27','gray27',[69,69,69],'454545',4539717],
['x11:gray28','gray28','gray28',[71,71,71],'474747',4671303],
['x11:gray29','gray29','gray29',[74,74,74],'4a4a4a',4868682],
['x11:gray3','gray3','gray3',[8,8,8],'080808',526344],
['x11:gray30','gray30','gray30',[77,77,77],'4d4d4d',5066061],
['x11:gray31','gray31','gray31',[79,79,79],'4f4f4f',5197647],
['x11:gray32','gray32','gray32',[82,82,82],'525252',5395026],
['x11:gray33','gray33','gray33',[84,84,84],'545454',5526612],
['x11:gray34','gray34','gray34',[87,87,87],'575757',5723991],
['x11:gray35','gray35','gray35',[89,89,89],'595959',5855577],
['x11:gray36','gray36','gray36',[92,92,92],'5c5c5c',6052956],
['x11:gray37','gray37','gray37',[94,94,94],'5e5e5e',6184542],
['x11:gray38','gray38','gray38',[97,97,97],'616161',6381921],
['x11:gray39','gray39','gray39',[99,99,99],'636363',6513507],
['x11:gray4','gray4','gray4',[10,10,10],'0a0a0a',657930],
['x11:gray40','gray40','gray40',[102,102,102],'666666',6710886],
['x11:gray41','gray41','gray41',[105,105,105],'696969',6908265],
['x11:gray42','gray42','gray42',[107,107,107],'6b6b6b',7039851],
['x11:gray43','gray43','gray43',[110,110,110],'6e6e6e',7237230],
['x11:gray44','gray44','gray44',[112,112,112],'707070',7368816],
['x11:gray45','gray45','gray45',[115,115,115],'737373',7566195],
['x11:gray46','gray46','gray46',[117,117,117],'757575',7697781],
['x11:gray47','gray47','gray47',[120,120,120],'787878',7895160],
['x11:gray48','gray48','gray48',[122,122,122],'7a7a7a',8026746],
['x11:gray49','gray49','gray49',[125,125,125],'7d7d7d',8224125],
['x11:gray5','gray5','gray5',[13,13,13],'0d0d0d',855309],
['x11:gray50','gray50','gray50',[127,127,127],'7f7f7f',8355711],
['x11:gray51','gray51','gray51',[130,130,130],'828282',8553090],
['x11:gray52','gray52','gray52',[133,133,133],'858585',8750469],
['x11:gray53','gray53','gray53',[135,135,135],'878787',8882055],
['x11:gray54','gray54','gray54',[138,138,138],'8a8a8a',9079434],
['x11:gray55','gray55','gray55',[140,140,140],'8c8c8c',9211020],
['x11:gray56','gray56','gray56',[143,143,143],'8f8f8f',9408399],
['x11:gray57','gray57','gray57',[145,145,145],'919191',9539985],
['x11:gray58','gray58','gray58',[148,148,148],'949494',9737364],
['x11:gray59','gray59','gray59',[150,150,150],'969696',9868950],
['x11:gray6','gray6','gray6',[15,15,15],'0f0f0f',986895],
['x11:gray60','gray60','gray60',[153,153,153],'999999',10066329],
['x11:gray61','gray61','gray61',[156,156,156],'9c9c9c',10263708],
['x11:gray62','gray62','gray62',[158,158,158],'9e9e9e',10395294],
['x11:gray63','gray63','gray63',[161,161,161],'a1a1a1',10592673],
['x11:gray64','gray64','gray64',[163,163,163],'a3a3a3',10724259],
['x11:gray65','gray65','gray65',[166,166,166],'a6a6a6',10921638],
['x11:gray66','gray66','gray66',[168,168,168],'a8a8a8',11053224],
['x11:gray67','gray67','gray67',[171,171,171],'ababab',11250603],
['x11:gray68','gray68','gray68',[173,173,173],'adadad',11382189],
['x11:gray69','gray69','gray69',[176,176,176],'b0b0b0',11579568],
['x11:gray7','gray7','gray7',[18,18,18],'121212',1184274],
['x11:gray70','gray70','gray70',[179,179,179],'b3b3b3',11776947],
['x11:gray71','gray71','gray71',[181,181,181],'b5b5b5',11908533],
['x11:gray72','gray72','gray72',[184,184,184],'b8b8b8',12105912],
['x11:gray73','gray73','gray73',[186,186,186],'bababa',12237498],
['x11:gray74','gray74','gray74',[189,189,189],'bdbdbd',12434877],
['x11:gray75','gray75','gray75',[191,191,191],'bfbfbf',12566463],
['x11:gray76','gray76','gray76',[194,194,194],'c2c2c2',12763842],
['x11:gray77','gray77','gray77',[196,196,196],'c4c4c4',12895428],
['x11:gray78','gray78','gray78',[199,199,199],'c7c7c7',13092807],
['x11:gray79','gray79','gray79',[201,201,201],'c9c9c9',13224393],
['x11:gray8','gray8','gray8',[20,20,20],'141414',1315860],
['x11:gray80','gray80','gray80',[204,204,204],'cccccc',13421772],
['x11:gray81','gray81','gray81',[207,207,207],'cfcfcf',13619151],
['x11:gray82','gray82','gray82',[209,209,209],'d1d1d1',13750737],
['x11:gray83','gray83','gray83',[212,212,212],'d4d4d4',13948116],
['x11:gray84','gray84','gray84',[214,214,214],'d6d6d6',14079702],
['x11:gray85','gray85','gray85',[217,217,217],'d9d9d9',14277081],
['x11:gray86','gray86','gray86',[219,219,219],'dbdbdb',14408667],
['x11:gray87','gray87','gray87',[222,222,222],'dedede',14606046],
['x11:gray88','gray88','gray88',[224,224,224],'e0e0e0',14737632],
['x11:gray89','gray89','gray89',[227,227,227],'e3e3e3',14935011],
['x11:gray9','gray9','gray9',[23,23,23],'171717',1513239],
['x11:gray90','gray90','gray90',[229,229,229],'e5e5e5',15066597],
['x11:gray91','gray91','gray91',[232,232,232],'e8e8e8',15263976],
['x11:gray92','gray92','gray92',[235,235,235],'ebebeb',15461355],
['x11:gray93','gray93','gray93',[237,237,237],'ededed',15592941],
['x11:gray94','gray94','gray94',[240,240,240],'f0f0f0',15790320],
['x11:gray95','gray95','gray95',[242,242,242],'f2f2f2',15921906],
['x11:gray96','gray96','gray96',[245,245,245],'f5f5f5',16119285],
['x11:gray97','gray97','gray97',[247,247,247],'f7f7f7',16250871],
['x11:gray98','gray98','gray98',[250,250,250],'fafafa',16448250],
['x11:gray99','gray99','gray99',[252,252,252],'fcfcfc',16579836],
['x11:green','green','green',[0,255,0],'00ff00',65280],
['x11:green1','green1','green1',[0,255,0],'00ff00',65280],
['x11:green2','green2','green2',[0,238,0],'00ee00',60928],
['x11:green3','green3','green3',[0,205,0],'00cd00',52480],
['x11:green4','green4','green4',[0,139,0],'008b00',35584],
['x11:greenyellow','greenyellow','green yellow',[173,255,47],'adff2f',11403055],
['x11:greenyellow','greenyellow','greenyellow',[173,255,47],'adff2f',11403055],
['x11:grey','grey','grey',[190,190,190],'bebebe',12500670],
['x11:grey0','grey0','grey0',[0,0,0],'000000',0],
['x11:grey1','grey1','grey1',[3,3,3],'030303',197379],
['x11:grey10','grey10','grey10',[26,26,26],'1a1a1a',1710618],
['x11:grey100','grey100','grey100',[255,255,255],'ffffff',16777215],
['x11:grey11','grey11','grey11',[28,28,28],'1c1c1c',1842204],
['x11:grey12','grey12','grey12',[31,31,31],'1f1f1f',2039583],
['x11:grey13','grey13','grey13',[33,33,33],'212121',2171169],
['x11:grey14','grey14','grey14',[36,36,36],'242424',2368548],
['x11:grey15','grey15','grey15',[38,38,38],'262626',2500134],
['x11:grey16','grey16','grey16',[41,41,41],'292929',2697513],
['x11:grey17','grey17','grey17',[43,43,43],'2b2b2b',2829099],
['x11:grey18','grey18','grey18',[46,46,46],'2e2e2e',3026478],
['x11:grey19','grey19','grey19',[48,48,48],'303030',3158064],
['x11:grey2','grey2','grey2',[5,5,5],'050505',328965],
['x11:grey20','grey20','grey20',[51,51,51],'333333',3355443],
['x11:grey21','grey21','grey21',[54,54,54],'363636',3552822],
['x11:grey22','grey22','grey22',[56,56,56],'383838',3684408],
['x11:grey23','grey23','grey23',[59,59,59],'3b3b3b',3881787],
['x11:grey24','grey24','grey24',[61,61,61],'3d3d3d',4013373],
['x11:grey25','grey25','grey25',[64,64,64],'404040',4210752],
['x11:grey26','grey26','grey26',[66,66,66],'424242',4342338],
['x11:grey27','grey27','grey27',[69,69,69],'454545',4539717],
['x11:grey28','grey28','grey28',[71,71,71],'474747',4671303],
['x11:grey29','grey29','grey29',[74,74,74],'4a4a4a',4868682],
['x11:grey3','grey3','grey3',[8,8,8],'080808',526344],
['x11:grey30','grey30','grey30',[77,77,77],'4d4d4d',5066061],
['x11:grey31','grey31','grey31',[79,79,79],'4f4f4f',5197647],
['x11:grey32','grey32','grey32',[82,82,82],'525252',5395026],
['x11:grey33','grey33','grey33',[84,84,84],'545454',5526612],
['x11:grey34','grey34','grey34',[87,87,87],'575757',5723991],
['x11:grey35','grey35','grey35',[89,89,89],'595959',5855577],
['x11:grey36','grey36','grey36',[92,92,92],'5c5c5c',6052956],
['x11:grey37','grey37','grey37',[94,94,94],'5e5e5e',6184542],
['x11:grey38','grey38','grey38',[97,97,97],'616161',6381921],
['x11:grey39','grey39','grey39',[99,99,99],'636363',6513507],
['x11:grey4','grey4','grey4',[10,10,10],'0a0a0a',657930],
['x11:grey40','grey40','grey40',[102,102,102],'666666',6710886],
['x11:grey41','grey41','grey41',[105,105,105],'696969',6908265],
['x11:grey42','grey42','grey42',[107,107,107],'6b6b6b',7039851],
['x11:grey43','grey43','grey43',[110,110,110],'6e6e6e',7237230],
['x11:grey44','grey44','grey44',[112,112,112],'707070',7368816],
['x11:grey45','grey45','grey45',[115,115,115],'737373',7566195],
['x11:grey46','grey46','grey46',[117,117,117],'757575',7697781],
['x11:grey47','grey47','grey47',[120,120,120],'787878',7895160],
['x11:grey48','grey48','grey48',[122,122,122],'7a7a7a',8026746],
['x11:grey49','grey49','grey49',[125,125,125],'7d7d7d',8224125],
['x11:grey5','grey5','grey5',[13,13,13],'0d0d0d',855309],
['x11:grey50','grey50','grey50',[127,127,127],'7f7f7f',8355711],
['x11:grey51','grey51','grey51',[130,130,130],'828282',8553090],
['x11:grey52','grey52','grey52',[133,133,133],'858585',8750469],
['x11:grey53','grey53','grey53',[135,135,135],'878787',8882055],
['x11:grey54','grey54','grey54',[138,138,138],'8a8a8a',9079434],
['x11:grey55','grey55','grey55',[140,140,140],'8c8c8c',9211020],
['x11:grey56','grey56','grey56',[143,143,143],'8f8f8f',9408399],
['x11:grey57','grey57','grey57',[145,145,145],'919191',9539985],
['x11:grey58','grey58','grey58',[148,148,148],'949494',9737364],
['x11:grey59','grey59','grey59',[150,150,150],'969696',9868950],
['x11:grey6','grey6','grey6',[15,15,15],'0f0f0f',986895],
['x11:grey60','grey60','grey60',[153,153,153],'999999',10066329],
['x11:grey61','grey61','grey61',[156,156,156],'9c9c9c',10263708],
['x11:grey62','grey62','grey62',[158,158,158],'9e9e9e',10395294],
['x11:grey63','grey63','grey63',[161,161,161],'a1a1a1',10592673],
['x11:grey64','grey64','grey64',[163,163,163],'a3a3a3',10724259],
['x11:grey65','grey65','grey65',[166,166,166],'a6a6a6',10921638],
['x11:grey66','grey66','grey66',[168,168,168],'a8a8a8',11053224],
['x11:grey67','grey67','grey67',[171,171,171],'ababab',11250603],
['x11:grey68','grey68','grey68',[173,173,173],'adadad',11382189],
['x11:grey69','grey69','grey69',[176,176,176],'b0b0b0',11579568],
['x11:grey7','grey7','grey7',[18,18,18],'121212',1184274],
['x11:grey70','grey70','grey70',[179,179,179],'b3b3b3',11776947],
['x11:grey71','grey71','grey71',[181,181,181],'b5b5b5',11908533],
['x11:grey72','grey72','grey72',[184,184,184],'b8b8b8',12105912],
['x11:grey73','grey73','grey73',[186,186,186],'bababa',12237498],
['x11:grey74','grey74','grey74',[189,189,189],'bdbdbd',12434877],
['x11:grey75','grey75','grey75',[191,191,191],'bfbfbf',12566463],
['x11:grey76','grey76','grey76',[194,194,194],'c2c2c2',12763842],
['x11:grey77','grey77','grey77',[196,196,196],'c4c4c4',12895428],
['x11:grey78','grey78','grey78',[199,199,199],'c7c7c7',13092807],
['x11:grey79','grey79','grey79',[201,201,201],'c9c9c9',13224393],
['x11:grey8','grey8','grey8',[20,20,20],'141414',1315860],
['x11:grey80','grey80','grey80',[204,204,204],'cccccc',13421772],
['x11:grey81','grey81','grey81',[207,207,207],'cfcfcf',13619151],
['x11:grey82','grey82','grey82',[209,209,209],'d1d1d1',13750737],
['x11:grey83','grey83','grey83',[212,212,212],'d4d4d4',13948116],
['x11:grey84','grey84','grey84',[214,214,214],'d6d6d6',14079702],
['x11:grey85','grey85','grey85',[217,217,217],'d9d9d9',14277081],
['x11:grey86','grey86','grey86',[219,219,219],'dbdbdb',14408667],
['x11:grey87','grey87','grey87',[222,222,222],'dedede',14606046],
['x11:grey88','grey88','grey88',[224,224,224],'e0e0e0',14737632],
['x11:grey89','grey89','grey89',[227,227,227],'e3e3e3',14935011],
['x11:grey9','grey9','grey9',[23,23,23],'171717',1513239],
['x11:grey90','grey90','grey90',[229,229,229],'e5e5e5',15066597],
['x11:grey91','grey91','grey91',[232,232,232],'e8e8e8',15263976],
['x11:grey92','grey92','grey92',[235,235,235],'ebebeb',15461355],
['x11:grey93','grey93','grey93',[237,237,237],'ededed',15592941],
['x11:grey94','grey94','grey94',[240,240,240],'f0f0f0',15790320],
['x11:grey95','grey95','grey95',[242,242,242],'f2f2f2',15921906],
['x11:grey96','grey96','grey96',[245,245,245],'f5f5f5',16119285],
['x11:grey97','grey97','grey97',[247,247,247],'f7f7f7',16250871],
['x11:grey98','grey98','grey98',[250,250,250],'fafafa',16448250],
['x11:grey99','grey99','grey99',[252,252,252],'fcfcfc',16579836],
['x11:honeydew','honeydew','honeydew',[240,255,240],'f0fff0',15794160],
['x11:honeydew1','honeydew1','honeydew1',[240,255,240],'f0fff0',15794160],
['x11:honeydew2','honeydew2','honeydew2',[224,238,224],'e0eee0',14741216],
['x11:honeydew3','honeydew3','honeydew3',[193,205,193],'c1cdc1',12701121],
['x11:honeydew4','honeydew4','honeydew4',[131,139,131],'838b83',8620931],
['x11:hotpink','hotpink','hot pink',[255,105,180],'ff69b4',16738740],
['x11:hotpink','hotpink','hotpink',[255,105,180],'ff69b4',16738740],
['x11:hotpink1','hotpink1','hotpink1',[255,110,180],'ff6eb4',16740020],
['x11:hotpink2','hotpink2','hotpink2',[238,106,167],'ee6aa7',15624871],
['x11:hotpink3','hotpink3','hotpink3',[205,96,144],'cd6090',13459600],
['x11:hotpink4','hotpink4','hotpink4',[139,58,98],'8b3a62',9124450],
['x11:indianred','indianred','indianred',[205,92,92],'cd5c5c',13458524],
['x11:indianred','indianred','indian red',[205,92,92],'cd5c5c',13458524],
['x11:indianred1','indianred1','indianred1',[255,106,106],'ff6a6a',16738922],
['x11:indianred2','indianred2','indianred2',[238,99,99],'ee6363',15623011],
['x11:indianred3','indianred3','indianred3',[205,85,85],'cd5555',13456725],
['x11:indianred4','indianred4','indianred4',[139,58,58],'8b3a3a',9124410],
['x11:ivory','ivory','ivory',[255,255,240],'fffff0',16777200],
['x11:ivory1','ivory1','ivory1',[255,255,240],'fffff0',16777200],
['x11:ivory2','ivory2','ivory2',[238,238,224],'eeeee0',15658720],
['x11:ivory3','ivory3','ivory3',[205,205,193],'cdcdc1',13487553],
['x11:ivory4','ivory4','ivory4',[139,139,131],'8b8b83',9145219],
['x11:khaki','khaki','khaki',[240,230,140],'f0e68c',15787660],
['x11:khaki1','khaki1','khaki1',[255,246,143],'fff68f',16774799],
['x11:khaki2','khaki2','khaki2',[238,230,133],'eee685',15656581],
['x11:khaki3','khaki3','khaki3',[205,198,115],'cdc673',13485683],
['x11:khaki4','khaki4','khaki4',[139,134,78],'8b864e',9143886],
['x11:lavender','lavender','lavender',[230,230,250],'e6e6fa',15132410],
['x11:lavenderblush','lavenderblush','lavenderblush',[255,240,245],'fff0f5',16773365],
['x11:lavenderblush','lavenderblush','lavender blush',[255,240,245],'fff0f5',16773365],
['x11:lavenderblush1','lavenderblush1','lavenderblush1',[255,240,245],'fff0f5',16773365],
['x11:lavenderblush2','lavenderblush2','lavenderblush2',[238,224,229],'eee0e5',15655141],
['x11:lavenderblush3','lavenderblush3','lavenderblush3',[205,193,197],'cdc1c5',13484485],
['x11:lavenderblush4','lavenderblush4','lavenderblush4',[139,131,134],'8b8386',9143174],
['x11:lawngreen','lawngreen','lawn green',[124,252,0],'7cfc00',8190976],
['x11:lawngreen','lawngreen','lawngreen',[124,252,0],'7cfc00',8190976],
['x11:lemonchiffon','lemonchiffon','lemonchiffon',[255,250,205],'fffacd',16775885],
['x11:lemonchiffon','lemonchiffon','lemon chiffon',[255,250,205],'fffacd',16775885],
['x11:lemonchiffon1','lemonchiffon1','lemonchiffon1',[255,250,205],'fffacd',16775885],
['x11:lemonchiffon2','lemonchiffon2','lemonchiffon2',[238,233,191],'eee9bf',15657407],
['x11:lemonchiffon3','lemonchiffon3','lemonchiffon3',[205,201,165],'cdc9a5',13486501],
['x11:lemonchiffon4','lemonchiffon4','lemonchiffon4',[139,137,112],'8b8970',9144688],
['x11:lightblue','lightblue','lightblue',[173,216,230],'add8e6',11393254],
['x11:lightblue','lightblue','light blue',[173,216,230],'add8e6',11393254],
['x11:lightblue1','lightblue1','lightblue1',[191,239,255],'bfefff',12578815],
['x11:lightblue2','lightblue2','lightblue2',[178,223,238],'b2dfee',11722734],
['x11:lightblue3','lightblue3','lightblue3',[154,192,205],'9ac0cd',10141901],
['x11:lightblue4','lightblue4','lightblue4',[104,131,139],'68838b',6849419],
['x11:lightcoral','lightcoral','lightcoral',[240,128,128],'f08080',15761536],
['x11:lightcoral','lightcoral','light coral',[240,128,128],'f08080',15761536],
['x11:lightcyan','lightcyan','lightcyan',[224,255,255],'e0ffff',14745599],
['x11:lightcyan','lightcyan','light cyan',[224,255,255],'e0ffff',14745599],
['x11:lightcyan1','lightcyan1','lightcyan1',[224,255,255],'e0ffff',14745599],
['x11:lightcyan2','lightcyan2','lightcyan2',[209,238,238],'d1eeee',13758190],
['x11:lightcyan3','lightcyan3','lightcyan3',[180,205,205],'b4cdcd',11849165],
['x11:lightcyan4','lightcyan4','lightcyan4',[122,139,139],'7a8b8b',8031115],
['x11:lightgoldenrod','lightgoldenrod','lightgoldenrod',[238,221,130],'eedd82',15654274],
['x11:lightgoldenrod','lightgoldenrod','light goldenrod',[238,221,130],'eedd82',15654274],
['x11:lightgoldenrod1','lightgoldenrod1','lightgoldenrod1',[255,236,139],'ffec8b',16772235],
['x11:lightgoldenrod2','lightgoldenrod2','lightgoldenrod2',[238,220,130],'eedc82',15654018],
['x11:lightgoldenrod3','lightgoldenrod3','lightgoldenrod3',[205,190,112],'cdbe70',13483632],
['x11:lightgoldenrod4','lightgoldenrod4','lightgoldenrod4',[139,129,76],'8b814c',9142604],
['x11:lightgoldenrodyellow','lightgoldenrodyellow','lightgoldenrodyellow',[250,250,210],'fafad2',16448210],
['x11:lightgoldenrodyellow','lightgoldenrodyellow','light goldenrod yellow',[250,250,210],'fafad2',16448210],
['x11:lightgray','lightgray','lightgray',[211,211,211],'d3d3d3',13882323],
['x11:lightgray','lightgray','light gray',[211,211,211],'d3d3d3',13882323],
['x11:lightgreen','lightgreen','light green',[144,238,144],'90ee90',9498256],
['x11:lightgreen','lightgreen','lightgreen',[144,238,144],'90ee90',9498256],
['x11:lightgrey','lightgrey','lightgrey',[211,211,211],'d3d3d3',13882323],
['x11:lightgrey','lightgrey','light grey',[211,211,211],'d3d3d3',13882323],
['x11:lightpink','lightpink','lightpink',[255,182,193],'ffb6c1',16758465],
['x11:lightpink','lightpink','light pink',[255,182,193],'ffb6c1',16758465],
['x11:lightpink1','lightpink1','lightpink1',[255,174,185],'ffaeb9',16756409],
['x11:lightpink2','lightpink2','lightpink2',[238,162,173],'eea2ad',15639213],
['x11:lightpink3','lightpink3','lightpink3',[205,140,149],'cd8c95',13470869],
['x11:lightpink4','lightpink4','lightpink4',[139,95,101],'8b5f65',9133925],
['x11:lightsalmon','lightsalmon','light salmon',[255,160,122],'ffa07a',16752762],
['x11:lightsalmon','lightsalmon','lightsalmon',[255,160,122],'ffa07a',16752762],
['x11:lightsalmon1','lightsalmon1','lightsalmon1',[255,160,122],'ffa07a',16752762],
['x11:lightsalmon2','lightsalmon2','lightsalmon2',[238,149,114],'ee9572',15635826],
['x11:lightsalmon3','lightsalmon3','lightsalmon3',[205,129,98],'cd8162',13468002],
['x11:lightsalmon4','lightsalmon4','lightsalmon4',[139,87,66],'8b5742',9131842],
['x11:lightseagreen','lightseagreen','light sea green',[32,178,170],'20b2aa',2142890],
['x11:lightseagreen','lightseagreen','lightseagreen',[32,178,170],'20b2aa',2142890],
['x11:lightskyblue','lightskyblue','light sky blue',[135,206,250],'87cefa',8900346],
['x11:lightskyblue','lightskyblue','lightskyblue',[135,206,250],'87cefa',8900346],
['x11:lightskyblue1','lightskyblue1','lightskyblue1',[176,226,255],'b0e2ff',11592447],
['x11:lightskyblue2','lightskyblue2','lightskyblue2',[164,211,238],'a4d3ee',10802158],
['x11:lightskyblue3','lightskyblue3','lightskyblue3',[141,182,205],'8db6cd',9287373],
['x11:lightskyblue4','lightskyblue4','lightskyblue4',[96,123,139],'607b8b',6323083],
['x11:lightslateblue','lightslateblue','light slate blue',[132,112,255],'8470ff',8679679],
['x11:lightslateblue','lightslateblue','lightslateblue',[132,112,255],'8470ff',8679679],
['x11:lightslategray','lightslategray','light slate gray',[119,136,153],'778899',7833753],
['x11:lightslategray','lightslategray','lightslategray',[119,136,153],'778899',7833753],
['x11:lightslategrey','lightslategrey','light slate grey',[119,136,153],'778899',7833753],
['x11:lightslategrey','lightslategrey','lightslategrey',[119,136,153],'778899',7833753],
['x11:lightsteelblue','lightsteelblue','lightsteelblue',[176,196,222],'b0c4de',11584734],
['x11:lightsteelblue','lightsteelblue','light steel blue',[176,196,222],'b0c4de',11584734],
['x11:lightsteelblue1','lightsteelblue1','lightsteelblue1',[202,225,255],'cae1ff',13296127],
['x11:lightsteelblue2','lightsteelblue2','lightsteelblue2',[188,210,238],'bcd2ee',12374766],
['x11:lightsteelblue3','lightsteelblue3','lightsteelblue3',[162,181,205],'a2b5cd',10663373],
['x11:lightsteelblue4','lightsteelblue4','lightsteelblue4',[110,123,139],'6e7b8b',7240587],
['x11:lightyellow','lightyellow','lightyellow',[255,255,224],'ffffe0',16777184],
['x11:lightyellow','lightyellow','light yellow',[255,255,224],'ffffe0',16777184],
['x11:lightyellow1','lightyellow1','lightyellow1',[255,255,224],'ffffe0',16777184],
['x11:lightyellow2','lightyellow2','lightyellow2',[238,238,209],'eeeed1',15658705],
['x11:lightyellow3','lightyellow3','lightyellow3',[205,205,180],'cdcdb4',13487540],
['x11:lightyellow4','lightyellow4','lightyellow4',[139,139,122],'8b8b7a',9145210],
['x11:limegreen','limegreen','lime green',[50,205,50],'32cd32',3329330],
['x11:limegreen','limegreen','limegreen',[50,205,50],'32cd32',3329330],
['x11:linen','linen','linen',[250,240,230],'faf0e6',16445670],
['x11:magenta','magenta','magenta',[255,0,255],'ff00ff',16711935],
['x11:magenta1','magenta1','magenta1',[255,0,255],'ff00ff',16711935],
['x11:magenta2','magenta2','magenta2',[238,0,238],'ee00ee',15597806],
['x11:magenta3','magenta3','magenta3',[205,0,205],'cd00cd',13435085],
['x11:magenta4','magenta4','magenta4',[139,0,139],'8b008b',9109643],
['x11:maroon','maroon','maroon',[176,48,96],'b03060',11546720],
['x11:maroon1','maroon1','maroon1',[255,52,179],'ff34b3',16725171],
['x11:maroon2','maroon2','maroon2',[238,48,167],'ee30a7',15610023],
['x11:maroon3','maroon3','maroon3',[205,41,144],'cd2990',13445520],
['x11:maroon4','maroon4','maroon4',[139,28,98],'8b1c62',9116770],
['x11:mediumaquamarine','mediumaquamarine','mediumaquamarine',[102,205,170],'66cdaa',6737322],
['x11:mediumaquamarine','mediumaquamarine','medium aquamarine',[102,205,170],'66cdaa',6737322],
['x11:mediumblue','mediumblue','mediumblue',[0,0,205],'0000cd',205],
['x11:mediumblue','mediumblue','medium blue',[0,0,205],'0000cd',205],
['x11:mediumorchid','mediumorchid','medium orchid',[186,85,211],'ba55d3',12211667],
['x11:mediumorchid','mediumorchid','mediumorchid',[186,85,211],'ba55d3',12211667],
['x11:mediumorchid1','mediumorchid1','mediumorchid1',[224,102,255],'e066ff',14706431],
['x11:mediumorchid2','mediumorchid2','mediumorchid2',[209,95,238],'d15fee',13721582],
['x11:mediumorchid3','mediumorchid3','mediumorchid3',[180,82,205],'b452cd',11817677],
['x11:mediumorchid4','mediumorchid4','mediumorchid4',[122,55,139],'7a378b',8009611],
['x11:mediumpurple','mediumpurple','medium purple',[147,112,219],'9370db',9662683],
['x11:mediumpurple','mediumpurple','mediumpurple',[147,112,219],'9370db',9662683],
['x11:mediumpurple1','mediumpurple1','mediumpurple1',[171,130,255],'ab82ff',11240191],
['x11:mediumpurple2','mediumpurple2','mediumpurple2',[159,121,238],'9f79ee',10451438],
['x11:mediumpurple3','mediumpurple3','mediumpurple3',[137,104,205],'8968cd',9005261],
['x11:mediumpurple4','mediumpurple4','mediumpurple4',[93,71,139],'5d478b',6113163],
['x11:mediumseagreen','mediumseagreen','medium sea green',[60,179,113],'3cb371',3978097],
['x11:mediumseagreen','mediumseagreen','mediumseagreen',[60,179,113],'3cb371',3978097],
['x11:mediumslateblue','mediumslateblue','mediumslateblue',[123,104,238],'7b68ee',8087790],
['x11:mediumslateblue','mediumslateblue','medium slate blue',[123,104,238],'7b68ee',8087790],
['x11:mediumspringgreen','mediumspringgreen','mediumspringgreen',[0,250,154],'00fa9a',64154],
['x11:mediumspringgreen','mediumspringgreen','medium spring green',[0,250,154],'00fa9a',64154],
['x11:mediumturquoise','mediumturquoise','medium turquoise',[72,209,204],'48d1cc',4772300],
['x11:mediumturquoise','mediumturquoise','mediumturquoise',[72,209,204],'48d1cc',4772300],
['x11:mediumvioletred','mediumvioletred','mediumvioletred',[199,21,133],'c71585',13047173],
['x11:mediumvioletred','mediumvioletred','medium violet red',[199,21,133],'c71585',13047173],
['x11:midnightblue','midnightblue','midnight blue',[25,25,112],'191970',1644912],
['x11:midnightblue','midnightblue','midnightblue',[25,25,112],'191970',1644912],
['x11:mintcream','mintcream','mint cream',[245,255,250],'f5fffa',16121850],
['x11:mintcream','mintcream','mintcream',[245,255,250],'f5fffa',16121850],
['x11:mistyrose','mistyrose','misty rose',[255,228,225],'ffe4e1',16770273],
['x11:mistyrose','mistyrose','mistyrose',[255,228,225],'ffe4e1',16770273],
['x11:mistyrose1','mistyrose1','mistyrose1',[255,228,225],'ffe4e1',16770273],
['x11:mistyrose2','mistyrose2','mistyrose2',[238,213,210],'eed5d2',15652306],
['x11:mistyrose3','mistyrose3','mistyrose3',[205,183,181],'cdb7b5',13481909],
['x11:mistyrose4','mistyrose4','mistyrose4',[139,125,123],'8b7d7b',9141627],
['x11:moccasin','moccasin','moccasin',[255,228,181],'ffe4b5',16770229],
['x11:navajowhite','navajowhite','navajowhite',[255,222,173],'ffdead',16768685],
['x11:navajowhite','navajowhite','navajo white',[255,222,173],'ffdead',16768685],
['x11:navajowhite1','navajowhite1','navajowhite1',[255,222,173],'ffdead',16768685],
['x11:navajowhite2','navajowhite2','navajowhite2',[238,207,161],'eecfa1',15650721],
['x11:navajowhite3','navajowhite3','navajowhite3',[205,179,139],'cdb38b',13480843],
['x11:navajowhite4','navajowhite4','navajowhite4',[139,121,94],'8b795e',9140574],
['x11:navy','navy','navy',[0,0,128],'000080',128],
['x11:navyblue','navyblue','navyblue',[0,0,128],'000080',128],
['x11:navyblue','navyblue','navy blue',[0,0,128],'000080',128],
['x11:oldlace','oldlace','oldlace',[253,245,230],'fdf5e6',16643558],
['x11:oldlace','oldlace','old lace',[253,245,230],'fdf5e6',16643558],
['x11:olivedrab','olivedrab','olivedrab',[107,142,35],'6b8e23',7048739],
['x11:olivedrab','olivedrab','olive drab',[107,142,35],'6b8e23',7048739],
['x11:olivedrab1','olivedrab1','olivedrab1',[192,255,62],'c0ff3e',12648254],
['x11:olivedrab2','olivedrab2','olivedrab2',[179,238,58],'b3ee3a',11791930],
['x11:olivedrab3','olivedrab3','olivedrab3',[154,205,50],'9acd32',10145074],
['x11:olivedrab4','olivedrab4','olivedrab4',[105,139,34],'698b22',6916898],
['x11:orange','orange','orange',[255,165,0],'ffa500',16753920],
['x11:orange1','orange1','orange1',[255,165,0],'ffa500',16753920],
['x11:orange2','orange2','orange2',[238,154,0],'ee9a00',15636992],
['x11:orange3','orange3','orange3',[205,133,0],'cd8500',13468928],
['x11:orange4','orange4','orange4',[139,90,0],'8b5a00',9132544],
['x11:orangered','orangered','orange red',[255,69,0],'ff4500',16729344],
['x11:orangered','orangered','orangered',[255,69,0],'ff4500',16729344],
['x11:orangered1','orangered1','orangered1',[255,69,0],'ff4500',16729344],
['x11:orangered2','orangered2','orangered2',[238,64,0],'ee4000',15613952],
['x11:orangered3','orangered3','orangered3',[205,55,0],'cd3700',13448960],
['x11:orangered4','orangered4','orangered4',[139,37,0],'8b2500',9118976],
['x11:orchid','orchid','orchid',[218,112,214],'da70d6',14315734],
['x11:orchid1','orchid1','orchid1',[255,131,250],'ff83fa',16745466],
['x11:orchid2','orchid2','orchid2',[238,122,233],'ee7ae9',15629033],
['x11:orchid3','orchid3','orchid3',[205,105,201],'cd69c9',13461961],
['x11:orchid4','orchid4','orchid4',[139,71,137],'8b4789',9127817],
['x11:palegoldenrod','palegoldenrod','palegoldenrod',[238,232,170],'eee8aa',15657130],
['x11:palegoldenrod','palegoldenrod','pale goldenrod',[238,232,170],'eee8aa',15657130],
['x11:palegreen','palegreen','palegreen',[152,251,152],'98fb98',10025880],
['x11:palegreen','palegreen','pale green',[152,251,152],'98fb98',10025880],
['x11:palegreen1','palegreen1','palegreen1',[154,255,154],'9aff9a',10157978],
['x11:palegreen2','palegreen2','palegreen2',[144,238,144],'90ee90',9498256],
['x11:palegreen3','palegreen3','palegreen3',[124,205,124],'7ccd7c',8179068],
['x11:palegreen4','palegreen4','palegreen4',[84,139,84],'548b54',5540692],
['x11:paleturquoise','paleturquoise','pale turquoise',[175,238,238],'afeeee',11529966],
['x11:paleturquoise','paleturquoise','paleturquoise',[175,238,238],'afeeee',11529966],
['x11:paleturquoise1','paleturquoise1','paleturquoise1',[187,255,255],'bbffff',12320767],
['x11:paleturquoise2','paleturquoise2','paleturquoise2',[174,238,238],'aeeeee',11464430],
['x11:paleturquoise3','paleturquoise3','paleturquoise3',[150,205,205],'96cdcd',9883085],
['x11:paleturquoise4','paleturquoise4','paleturquoise4',[102,139,139],'668b8b',6720395],
['x11:palevioletred','palevioletred','pale violet red',[219,112,147],'db7093',14381203],
['x11:palevioletred','palevioletred','palevioletred',[219,112,147],'db7093',14381203],
['x11:palevioletred1','palevioletred1','palevioletred1',[255,130,171],'ff82ab',16745131],
['x11:palevioletred2','palevioletred2','palevioletred2',[238,121,159],'ee799f',15628703],
['x11:palevioletred3','palevioletred3','palevioletred3',[205,104,137],'cd6889',13461641],
['x11:palevioletred4','palevioletred4','palevioletred4',[139,71,93],'8b475d',9127773],
['x11:papayawhip','papayawhip','papayawhip',[255,239,213],'ffefd5',16773077],
['x11:papayawhip','papayawhip','papaya whip',[255,239,213],'ffefd5',16773077],
['x11:peachpuff','peachpuff','peachpuff',[255,218,185],'ffdab9',16767673],
['x11:peachpuff','peachpuff','peach puff',[255,218,185],'ffdab9',16767673],
['x11:peachpuff1','peachpuff1','peachpuff1',[255,218,185],'ffdab9',16767673],
['x11:peachpuff2','peachpuff2','peachpuff2',[238,203,173],'eecbad',15649709],
['x11:peachpuff3','peachpuff3','peachpuff3',[205,175,149],'cdaf95',13479829],
['x11:peachpuff4','peachpuff4','peachpuff4',[139,119,101],'8b7765',9140069],
['x11:peru','peru','peru',[205,133,63],'cd853f',13468991],
['x11:pink','pink','pink',[255,192,203],'ffc0cb',16761035],
['x11:pink1','pink1','pink1',[255,181,197],'ffb5c5',16758213],
['x11:pink2','pink2','pink2',[238,169,184],'eea9b8',15641016],
['x11:pink3','pink3','pink3',[205,145,158],'cd919e',13472158],
['x11:pink4','pink4','pink4',[139,99,108],'8b636c',9134956],
['x11:plum','plum','plum',[221,160,221],'dda0dd',14524637],
['x11:plum1','plum1','plum1',[255,187,255],'ffbbff',16759807],
['x11:plum2','plum2','plum2',[238,174,238],'eeaeee',15642350],
['x11:plum3','plum3','plum3',[205,150,205],'cd96cd',13473485],
['x11:plum4','plum4','plum4',[139,102,139],'8b668b',9135755],
['x11:powderblue','powderblue','powder blue',[176,224,230],'b0e0e6',11591910],
['x11:powderblue','powderblue','powderblue',[176,224,230],'b0e0e6',11591910],
['x11:purple','purple','purple',[160,32,240],'a020f0',10494192],
['x11:purple1','purple1','purple1',[155,48,255],'9b30ff',10170623],
['x11:purple2','purple2','purple2',[145,44,238],'912cee',9514222],
['x11:purple3','purple3','purple3',[125,38,205],'7d26cd',8201933],
['x11:purple4','purple4','purple4',[85,26,139],'551a8b',5577355],
['x11:red','red','red',[255,0,0],'ff0000',16711680],
['x11:red1','red1','red1',[255,0,0],'ff0000',16711680],
['x11:red2','red2','red2',[238,0,0],'ee0000',15597568],
['x11:red3','red3','red3',[205,0,0],'cd0000',13434880],
['x11:red4','red4','red4',[139,0,0],'8b0000',9109504],
['x11:rosybrown','rosybrown','rosybrown',[188,143,143],'bc8f8f',12357519],
['x11:rosybrown','rosybrown','rosy brown',[188,143,143],'bc8f8f',12357519],
['x11:rosybrown1','rosybrown1','rosybrown1',[255,193,193],'ffc1c1',16761281],
['x11:rosybrown2','rosybrown2','rosybrown2',[238,180,180],'eeb4b4',15643828],
['x11:rosybrown3','rosybrown3','rosybrown3',[205,155,155],'cd9b9b',13474715],
['x11:rosybrown4','rosybrown4','rosybrown4',[139,105,105],'8b6969',9136489],
['x11:royalblue','royalblue','royalblue',[65,105,225],'4169e1',4286945],
['x11:royalblue','royalblue','royal blue',[65,105,225],'4169e1',4286945],
['x11:royalblue1','royalblue1','royalblue1',[72,118,255],'4876ff',4749055],
['x11:royalblue2','royalblue2','royalblue2',[67,110,238],'436eee',4419310],
['x11:royalblue3','royalblue3','royalblue3',[58,95,205],'3a5fcd',3825613],
['x11:royalblue4','royalblue4','royalblue4',[39,64,139],'27408b',2572427],
['x11:saddlebrown','saddlebrown','saddlebrown',[139,69,19],'8b4513',9127187],
['x11:saddlebrown','saddlebrown','saddle brown',[139,69,19],'8b4513',9127187],
['x11:salmon','salmon','salmon',[250,128,114],'fa8072',16416882],
['x11:salmon1','salmon1','salmon1',[255,140,105],'ff8c69',16747625],
['x11:salmon2','salmon2','salmon2',[238,130,98],'ee8262',15630946],
['x11:salmon3','salmon3','salmon3',[205,112,84],'cd7054',13463636],
['x11:salmon4','salmon4','salmon4',[139,76,57],'8b4c39',9129017],
['x11:sandybrown','sandybrown','sandybrown',[244,164,96],'f4a460',16032864],
['x11:sandybrown','sandybrown','sandy brown',[244,164,96],'f4a460',16032864],
['x11:seagreen','seagreen','sea green',[46,139,87],'2e8b57',3050327],
['x11:seagreen','seagreen','seagreen',[46,139,87],'2e8b57',3050327],
['x11:seagreen1','seagreen1','seagreen1',[84,255,159],'54ff9f',5570463],
['x11:seagreen2','seagreen2','seagreen2',[78,238,148],'4eee94',5172884],
['x11:seagreen3','seagreen3','seagreen3',[67,205,128],'43cd80',4443520],
['x11:seagreen4','seagreen4','seagreen4',[46,139,87],'2e8b57',3050327],
['x11:seashell','seashell','seashell',[255,245,238],'fff5ee',16774638],
['x11:seashell1','seashell1','seashell1',[255,245,238],'fff5ee',16774638],
['x11:seashell2','seashell2','seashell2',[238,229,222],'eee5de',15656414],
['x11:seashell3','seashell3','seashell3',[205,197,191],'cdc5bf',13485503],
['x11:seashell4','seashell4','seashell4',[139,134,130],'8b8682',9143938],
['x11:sienna','sienna','sienna',[160,82,45],'a0522d',10506797],
['x11:sienna1','sienna1','sienna1',[255,130,71],'ff8247',16745031],
['x11:sienna2','sienna2','sienna2',[238,121,66],'ee7942',15628610],
['x11:sienna3','sienna3','sienna3',[205,104,57],'cd6839',13461561],
['x11:sienna4','sienna4','sienna4',[139,71,38],'8b4726',9127718],
['x11:skyblue','skyblue','sky blue',[135,206,235],'87ceeb',8900331],
['x11:skyblue','skyblue','skyblue',[135,206,235],'87ceeb',8900331],
['x11:skyblue1','skyblue1','skyblue1',[135,206,255],'87ceff',8900351],
['x11:skyblue2','skyblue2','skyblue2',[126,192,238],'7ec0ee',8306926],
['x11:skyblue3','skyblue3','skyblue3',[108,166,205],'6ca6cd',7120589],
['x11:skyblue4','skyblue4','skyblue4',[74,112,139],'4a708b',4878475],
['x11:slateblue','slateblue','slateblue',[106,90,205],'6a5acd',6970061],
['x11:slateblue','slateblue','slate blue',[106,90,205],'6a5acd',6970061],
['x11:slateblue1','slateblue1','slateblue1',[131,111,255],'836fff',8613887],
['x11:slateblue2','slateblue2','slateblue2',[122,103,238],'7a67ee',8021998],
['x11:slateblue3','slateblue3','slateblue3',[105,89,205],'6959cd',6904269],
['x11:slateblue4','slateblue4','slateblue4',[71,60,139],'473c8b',4668555],
['x11:slategray','slategray','slategray',[112,128,144],'708090',7372944],
['x11:slategray','slategray','slate gray',[112,128,144],'708090',7372944],
['x11:slategray1','slategray1','slategray1',[198,226,255],'c6e2ff',13034239],
['x11:slategray2','slategray2','slategray2',[185,211,238],'b9d3ee',12178414],
['x11:slategray3','slategray3','slategray3',[159,182,205],'9fb6cd',10467021],
['x11:slategray4','slategray4','slategray4',[108,123,139],'6c7b8b',7109515],
['x11:slategrey','slategrey','slategrey',[112,128,144],'708090',7372944],
['x11:slategrey','slategrey','slate grey',[112,128,144],'708090',7372944],
['x11:slategrey1','slategrey1','slategrey1',[198,226,255],'c6e2ff',13034239],
['x11:slategrey2','slategrey2','slategrey2',[185,211,238],'b9d3ee',12178414],
['x11:slategrey3','slategrey3','slategrey3',[159,182,205],'9fb6cd',10467021],
['x11:slategrey4','slategrey4','slategrey4',[108,123,139],'6c7b8b',7109515],
['x11:snow','snow','snow',[255,250,250],'fffafa',16775930],
['x11:snow1','snow1','snow1',[255,250,250],'fffafa',16775930],
['x11:snow2','snow2','snow2',[238,233,233],'eee9e9',15657449],
['x11:snow3','snow3','snow3',[205,201,201],'cdc9c9',13486537],
['x11:snow4','snow4','snow4',[139,137,137],'8b8989',9144713],
['x11:springgreen','springgreen','springgreen',[0,255,127],'00ff7f',65407],
['x11:springgreen','springgreen','spring green',[0,255,127],'00ff7f',65407],
['x11:springgreen1','springgreen1','springgreen1',[0,255,127],'00ff7f',65407],
['x11:springgreen2','springgreen2','springgreen2',[0,238,118],'00ee76',61046],
['x11:springgreen3','springgreen3','springgreen3',[0,205,102],'00cd66',52582],
['x11:springgreen4','springgreen4','springgreen4',[0,139,69],'008b45',35653],
['x11:steelblue','steelblue','steel blue',[70,130,180],'4682b4',4620980],
['x11:steelblue','steelblue','steelblue',[70,130,180],'4682b4',4620980],
['x11:steelblue1','steelblue1','steelblue1',[99,184,255],'63b8ff',6535423],
['x11:steelblue2','steelblue2','steelblue2',[92,172,238],'5cacee',6073582],
['x11:steelblue3','steelblue3','steelblue3',[79,148,205],'4f94cd',5215437],
['x11:steelblue4','steelblue4','steelblue4',[54,100,139],'36648b',3564683],
['x11:tan','tan','tan',[210,180,140],'d2b48c',13808780],
['x11:tan1','tan1','tan1',[255,165,79],'ffa54f',16753999],
['x11:tan2','tan2','tan2',[238,154,73],'ee9a49',15637065],
['x11:tan3','tan3','tan3',[205,133,63],'cd853f',13468991],
['x11:tan4','tan4','tan4',[139,90,43],'8b5a2b',9132587],
['x11:thistle','thistle','thistle',[216,191,216],'d8bfd8',14204888],
['x11:thistle1','thistle1','thistle1',[255,225,255],'ffe1ff',16769535],
['x11:thistle2','thistle2','thistle2',[238,210,238],'eed2ee',15651566],
['x11:thistle3','thistle3','thistle3',[205,181,205],'cdb5cd',13481421],
['x11:thistle4','thistle4','thistle4',[139,123,139],'8b7b8b',9141131],
['x11:tomato','tomato','tomato',[255,99,71],'ff6347',16737095],
['x11:tomato1','tomato1','tomato1',[255,99,71],'ff6347',16737095],
['x11:tomato2','tomato2','tomato2',[238,92,66],'ee5c42',15621186],
['x11:tomato3','tomato3','tomato3',[205,79,57],'cd4f39',13455161],
['x11:tomato4','tomato4','tomato4',[139,54,38],'8b3626',9123366],
['x11:turquoise','turquoise','turquoise',[64,224,208],'40e0d0',4251856],
['x11:turquoise1','turquoise1','turquoise1',[0,245,255],'00f5ff',62975],
['x11:turquoise2','turquoise2','turquoise2',[0,229,238],'00e5ee',58862],
['x11:turquoise3','turquoise3','turquoise3',[0,197,205],'00c5cd',50637],
['x11:turquoise4','turquoise4','turquoise4',[0,134,139],'00868b',34443],
['x11:violet','violet','violet',[238,130,238],'ee82ee',15631086],
['x11:violetred','violetred','violet red',[208,32,144],'d02090',13639824],
['x11:violetred','violetred','violetred',[208,32,144],'d02090',13639824],
['x11:violetred1','violetred1','violetred1',[255,62,150],'ff3e96',16727702],
['x11:violetred2','violetred2','violetred2',[238,58,140],'ee3a8c',15612556],
['x11:violetred3','violetred3','violetred3',[205,50,120],'cd3278',13447800],
['x11:violetred4','violetred4','violetred4',[139,34,82],'8b2252',9118290],
['x11:wheat','wheat','wheat',[245,222,179],'f5deb3',16113331],
['x11:wheat1','wheat1','wheat1',[255,231,186],'ffe7ba',16771002],
['x11:wheat2','wheat2','wheat2',[238,216,174],'eed8ae',15653038],
['x11:wheat3','wheat3','wheat3',[205,186,150],'cdba96',13482646],
['x11:wheat4','wheat4','wheat4',[139,126,102],'8b7e66',9141862],
['x11:white','white','white',[255,255,255],'ffffff',16777215],
['x11:whitesmoke','whitesmoke','white smoke',[245,245,245],'f5f5f5',16119285],
['x11:whitesmoke','whitesmoke','whitesmoke',[245,245,245],'f5f5f5',16119285],
['x11:yellow','yellow','yellow',[255,255,0],'ffff00',16776960],
['x11:yellow1','yellow1','yellow1',[255,255,0],'ffff00',16776960],
['x11:yellow2','yellow2','yellow2',[238,238,0],'eeee00',15658496],
['x11:yellow3','yellow3','yellow3',[205,205,0],'cdcd00',13487360],
['x11:yellow4','yellow4','yellow4',[139,139,0],'8b8b00',9145088],
['x11:yellowgreen','yellowgreen','yellow green',[154,205,50],'9acd32',10145074],
['x11:yellowgreen','yellowgreen','yellowgreen',[154,205,50],'9acd32',10145074]
    ];
}

sub _description {
    return {
          'subtitle' => 'Colors for the X11 Window System (rgb.txt)',
          'title' => 'X11',
          'description' => 'X11/rgb.txt (often /usr/X11R6/lib/X11/rgb.txt) from the X11 Window System distribution.
'
        }

}

1;
